/* Automatically @generated by tree-sitter v0.25.8 */

#include "tree_sitter/parser.h"

#if defined(__GNUC__) || defined(__clang__)
#pragma GCC diagnostic ignored "-Wmissing-field-initializers"
#endif

#ifdef _MSC_VER
#pragma optimize("", off)
#elif defined(__clang__)
#pragma clang optimize off
#elif defined(__GNUC__)
#pragma GCC optimize ("O0")
#endif

#define LANGUAGE_VERSION 15
#define STATE_COUNT 327
#define LARGE_STATE_COUNT 2
#define SYMBOL_COUNT 178
#define ALIAS_COUNT 0
#define TOKEN_COUNT 119
#define EXTERNAL_TOKEN_COUNT 2
#define FIELD_COUNT 29
#define MAX_ALIAS_SEQUENCE_LENGTH 7
#define MAX_RESERVED_WORD_SET_SIZE 0
#define PRODUCTION_ID_COUNT 46
#define SUPERTYPE_COUNT 0

enum ts_symbol_identifiers {
  sym__empty_line = 1,
  anon_sym_SEMI = 2,
  anon_sym_PERCENT = 3,
  aux_sym_rest_of_line_comment_token1 = 4,
  sym_rest_of_line_comment_text = 5,
  sym_old_style_twic_section_comment = 6,
  anon_sym_LBRACK = 7,
  anon_sym_RBRACK = 8,
  anon_sym_DQUOTE = 9,
  aux_sym_double_quote_token1 = 10,
  anon_sym_uff02 = 11,
  aux_sym_double_quote_token2 = 12,
  anon_sym_u201c = 13,
  aux_sym_double_quote_token3 = 14,
  anon_sym_u201d = 15,
  aux_sym_double_quote_token4 = 16,
  anon_sym_u201f = 17,
  aux_sym_double_quote_token5 = 18,
  anon_sym_u2033 = 19,
  aux_sym_double_quote_token6 = 20,
  anon_sym_u2036 = 21,
  aux_sym_double_quote_token7 = 22,
  anon_sym_u3003 = 23,
  aux_sym_double_quote_token8 = 24,
  anon_sym_u05f4 = 25,
  aux_sym_double_quote_token9 = 26,
  anon_sym_u02dd = 27,
  aux_sym_double_quote_token10 = 28,
  anon_sym_u02ba = 29,
  aux_sym_double_quote_token11 = 30,
  anon_sym_u02f6 = 31,
  aux_sym_double_quote_token12 = 32,
  anon_sym_u02ee = 33,
  aux_sym_double_quote_token13 = 34,
  anon_sym_u05f2 = 35,
  aux_sym_double_quote_token14 = 36,
  anon_sym_u00ab = 37,
  aux_sym_double_quote_token15 = 38,
  anon_sym_u00bb = 39,
  aux_sym_double_quote_token16 = 40,
  sym_tagpair_key = 41,
  aux_sym_tagpair_value_contents_token1 = 42,
  sym_variation_delimiter_open = 43,
  anon_sym_RPAREN = 44,
  anon_sym_LBRACE = 45,
  anon_sym_RBRACE = 46,
  sym_command_delimiter_open = 47,
  aux_sym_inline_comment_text_token1 = 48,
  sym_command_name = 49,
  sym_command_parameters = 50,
  sym_move_number = 51,
  sym__san_file = 52,
  sym__san_file_immediate = 53,
  sym__san_rank_promoting = 54,
  sym__san_rank_nonpromoting = 55,
  sym__san_promotable_piece = 56,
  sym__san_major_or_minor_piece = 57,
  sym__san_capture_symbol = 58,
  sym__san_promotion_symbol = 59,
  anon_sym_P = 60,
  anon_sym_u2659 = 61,
  anon_sym_u265fufe0e = 62,
  anon_sym_AT = 63,
  anon_sym_AT2 = 64,
  aux_sym__lan_move_by_coordinates_token1 = 65,
  sym__san_move_castle = 66,
  sym__san_null_move = 67,
  sym_check_or_mate_condition = 68,
  aux_sym_annotation_token1 = 69,
  anon_sym_1 = 70,
  anon_sym_DASH = 71,
  aux_sym_result_code_token1 = 72,
  anon_sym_u2212 = 73,
  aux_sym_result_code_token2 = 74,
  anon_sym_u2010 = 75,
  aux_sym_result_code_token3 = 76,
  anon_sym_u2011 = 77,
  aux_sym_result_code_token4 = 78,
  anon_sym_u2012 = 79,
  aux_sym_result_code_token5 = 80,
  anon_sym_u2013 = 81,
  aux_sym_result_code_token6 = 82,
  anon_sym_u2014 = 83,
  aux_sym_result_code_token7 = 84,
  anon_sym_u2796 = 85,
  aux_sym_result_code_token8 = 86,
  anon_sym_O = 87,
  anon_sym_0 = 88,
  anon_sym_o = 89,
  anon_sym_SLASH = 90,
  aux_sym_result_code_token9 = 91,
  anon_sym_u2215 = 92,
  aux_sym_result_code_token10 = 93,
  anon_sym_u2044 = 94,
  aux_sym_result_code_token11 = 95,
  anon_sym_u27cb = 96,
  aux_sym_result_code_token12 = 97,
  anon_sym_u29f8 = 98,
  aux_sym_result_code_token13 = 99,
  anon_sym_2 = 100,
  anon_sym_u00bd = 101,
  aux_sym_result_code_token14 = 102,
  anon_sym_STAR = 103,
  aux_sym_result_code_token15 = 104,
  anon_sym_u2217 = 105,
  aux_sym_result_code_token16 = 106,
  anon_sym_u2731 = 107,
  aux_sym_result_code_token17 = 108,
  anon_sym_u204e = 109,
  aux_sym_result_code_token18 = 110,
  anon_sym_u066d = 111,
  aux_sym_result_code_token19 = 112,
  aux_sym_result_code_token20 = 113,
  aux_sym_result_code_token21 = 114,
  aux_sym_result_code_token22 = 115,
  aux_sym_result_code_token23 = 116,
  sym__full_line_comment_delimiter_bol_assertion = 117,
  sym__novelty_glyph_before_punctuation = 118,
  sym_series_of_games = 119,
  sym_game = 120,
  sym_freestanding_comment = 121,
  sym_rest_of_line_comment_delimiter_open = 122,
  sym_rest_of_line_comment = 123,
  sym_header = 124,
  sym_tagpair_delimiter_open = 125,
  sym_tagpair_delimiter_close = 126,
  sym_double_quote = 127,
  sym_tagpair = 128,
  sym__tagpair_value = 129,
  sym_tagpair_value_contents = 130,
  sym_movetext = 131,
  sym_variation_movetext = 132,
  sym_variation_delimiter_close = 133,
  sym_inline_comment_delimiter_open = 134,
  sym_inline_comment_delimiter_close = 135,
  sym__recursive_inline_comment_delimiter_open = 136,
  sym__recursive_inline_comment_delimiter_close = 137,
  sym_command_delimiter_close = 138,
  sym_trailing_garbage = 139,
  sym__movetext_element = 140,
  sym__variation_movetext_element = 141,
  sym_variation = 142,
  sym_recursive_variation = 143,
  sym_inline_comment = 144,
  sym_command = 145,
  sym__recursive_inline_comment = 146,
  sym_inline_comment_text = 147,
  aux_sym__recursive_inline_comment_text = 148,
  sym__command_text = 149,
  sym_san_move = 150,
  sym__san_move_piece = 151,
  sym_lan_move = 152,
  sym__san_rank_any = 153,
  sym__san_square_any = 154,
  sym__san_square_promoting = 155,
  sym__san_square_nonpromoting = 156,
  sym__san_square_any_immediate = 157,
  sym__san_square_promoting_immediate = 158,
  sym__san_square_nonpromoting_immediate = 159,
  sym__san_promotion = 160,
  sym__san_move_pawn = 161,
  sym__san_drop_pawn = 162,
  sym__san_move_major_or_minor_piece = 163,
  sym__san_drop_major_or_minor_piece = 164,
  sym__lan_move_by_coordinates = 165,
  sym_annotation = 166,
  sym_result_code = 167,
  aux_sym_series_of_games_repeat1 = 168,
  aux_sym_freestanding_comment_repeat1 = 169,
  aux_sym_header_repeat1 = 170,
  aux_sym_tagpair_delimiter_open_repeat1 = 171,
  aux_sym_tagpair_delimiter_close_repeat1 = 172,
  aux_sym_tagpair_value_contents_repeat1 = 173,
  aux_sym_movetext_repeat1 = 174,
  aux_sym_variation_movetext_repeat1 = 175,
  aux_sym_trailing_garbage_repeat1 = 176,
  aux_sym_inline_comment_text_repeat1 = 177,
};

static const char * const ts_symbol_names[] = {
  [ts_builtin_sym_end] = "end",
  [sym__empty_line] = "_empty_line",
  [anon_sym_SEMI] = ";",
  [anon_sym_PERCENT] = "%",
  [aux_sym_rest_of_line_comment_token1] = "rest_of_line_comment_token1",
  [sym_rest_of_line_comment_text] = "rest_of_line_comment_text",
  [sym_old_style_twic_section_comment] = "old_style_twic_section_comment",
  [anon_sym_LBRACK] = "[",
  [anon_sym_RBRACK] = "]",
  [anon_sym_DQUOTE] = "\"",
  [aux_sym_double_quote_token1] = "double_quote_token1",
  [anon_sym_uff02] = "\uff02",
  [aux_sym_double_quote_token2] = "double_quote_token2",
  [anon_sym_u201c] = "\u201c",
  [aux_sym_double_quote_token3] = "double_quote_token3",
  [anon_sym_u201d] = "\u201d",
  [aux_sym_double_quote_token4] = "double_quote_token4",
  [anon_sym_u201f] = "\u201f",
  [aux_sym_double_quote_token5] = "double_quote_token5",
  [anon_sym_u2033] = "\u2033",
  [aux_sym_double_quote_token6] = "double_quote_token6",
  [anon_sym_u2036] = "\u2036",
  [aux_sym_double_quote_token7] = "double_quote_token7",
  [anon_sym_u3003] = "\u3003",
  [aux_sym_double_quote_token8] = "double_quote_token8",
  [anon_sym_u05f4] = "\u05f4",
  [aux_sym_double_quote_token9] = "double_quote_token9",
  [anon_sym_u02dd] = "\u02dd",
  [aux_sym_double_quote_token10] = "double_quote_token10",
  [anon_sym_u02ba] = "\u02ba",
  [aux_sym_double_quote_token11] = "double_quote_token11",
  [anon_sym_u02f6] = "\u02f6",
  [aux_sym_double_quote_token12] = "double_quote_token12",
  [anon_sym_u02ee] = "\u02ee",
  [aux_sym_double_quote_token13] = "double_quote_token13",
  [anon_sym_u05f2] = "\u05f2",
  [aux_sym_double_quote_token14] = "double_quote_token14",
  [anon_sym_u00ab] = "\u00ab",
  [aux_sym_double_quote_token15] = "double_quote_token15",
  [anon_sym_u00bb] = "\u00bb",
  [aux_sym_double_quote_token16] = "double_quote_token16",
  [sym_tagpair_key] = "tagpair_key",
  [aux_sym_tagpair_value_contents_token1] = "tagpair_value_contents_token1",
  [sym_variation_delimiter_open] = "variation_delimiter_open",
  [anon_sym_RPAREN] = ")",
  [anon_sym_LBRACE] = "{",
  [anon_sym_RBRACE] = "}",
  [sym_command_delimiter_open] = "command_delimiter_open",
  [aux_sym_inline_comment_text_token1] = "inline_comment_text_token1",
  [sym_command_name] = "command_name",
  [sym_command_parameters] = "command_parameters",
  [sym_move_number] = "move_number",
  [sym__san_file] = "_san_file",
  [sym__san_file_immediate] = "_san_file_immediate",
  [sym__san_rank_promoting] = "_san_rank_promoting",
  [sym__san_rank_nonpromoting] = "_san_rank_nonpromoting",
  [sym__san_promotable_piece] = "_san_promotable_piece",
  [sym__san_major_or_minor_piece] = "_san_major_or_minor_piece",
  [sym__san_capture_symbol] = "_san_capture_symbol",
  [sym__san_promotion_symbol] = "_san_promotion_symbol",
  [anon_sym_P] = "P",
  [anon_sym_u2659] = "\u2659",
  [anon_sym_u265fufe0e] = "\u265f\ufe0e",
  [anon_sym_AT] = "@",
  [anon_sym_AT2] = "@",
  [aux_sym__lan_move_by_coordinates_token1] = "_lan_move_by_coordinates_token1",
  [sym__san_move_castle] = "_san_move_castle",
  [sym__san_null_move] = "_san_null_move",
  [sym_check_or_mate_condition] = "check_or_mate_condition",
  [aux_sym_annotation_token1] = "annotation_token1",
  [anon_sym_1] = "1",
  [anon_sym_DASH] = "-",
  [aux_sym_result_code_token1] = "result_code_token1",
  [anon_sym_u2212] = "\u2212",
  [aux_sym_result_code_token2] = "result_code_token2",
  [anon_sym_u2010] = "\u2010",
  [aux_sym_result_code_token3] = "result_code_token3",
  [anon_sym_u2011] = "\u2011",
  [aux_sym_result_code_token4] = "result_code_token4",
  [anon_sym_u2012] = "\u2012",
  [aux_sym_result_code_token5] = "result_code_token5",
  [anon_sym_u2013] = "\u2013",
  [aux_sym_result_code_token6] = "result_code_token6",
  [anon_sym_u2014] = "\u2014",
  [aux_sym_result_code_token7] = "result_code_token7",
  [anon_sym_u2796] = "\u2796",
  [aux_sym_result_code_token8] = "result_code_token8",
  [anon_sym_O] = "O",
  [anon_sym_0] = "0",
  [anon_sym_o] = "o",
  [anon_sym_SLASH] = "/",
  [aux_sym_result_code_token9] = "result_code_token9",
  [anon_sym_u2215] = "\u2215",
  [aux_sym_result_code_token10] = "result_code_token10",
  [anon_sym_u2044] = "\u2044",
  [aux_sym_result_code_token11] = "result_code_token11",
  [anon_sym_u27cb] = "\u27cb",
  [aux_sym_result_code_token12] = "result_code_token12",
  [anon_sym_u29f8] = "\u29f8",
  [aux_sym_result_code_token13] = "result_code_token13",
  [anon_sym_2] = "2",
  [anon_sym_u00bd] = "\u00bd",
  [aux_sym_result_code_token14] = "result_code_token14",
  [anon_sym_STAR] = "*",
  [aux_sym_result_code_token15] = "result_code_token15",
  [anon_sym_u2217] = "\u2217",
  [aux_sym_result_code_token16] = "result_code_token16",
  [anon_sym_u2731] = "\u2731",
  [aux_sym_result_code_token17] = "result_code_token17",
  [anon_sym_u204e] = "\u204e",
  [aux_sym_result_code_token18] = "result_code_token18",
  [anon_sym_u066d] = "\u066d",
  [aux_sym_result_code_token19] = "result_code_token19",
  [aux_sym_result_code_token20] = "result_code_token20",
  [aux_sym_result_code_token21] = "result_code_token21",
  [aux_sym_result_code_token22] = "result_code_token22",
  [aux_sym_result_code_token23] = "result_code_token23",
  [sym__full_line_comment_delimiter_bol_assertion] = "_full_line_comment_delimiter_bol_assertion",
  [sym__novelty_glyph_before_punctuation] = "_novelty_glyph_before_punctuation",
  [sym_series_of_games] = "series_of_games",
  [sym_game] = "game",
  [sym_freestanding_comment] = "freestanding_comment",
  [sym_rest_of_line_comment_delimiter_open] = "rest_of_line_comment_delimiter_open",
  [sym_rest_of_line_comment] = "rest_of_line_comment",
  [sym_header] = "header",
  [sym_tagpair_delimiter_open] = "tagpair_delimiter_open",
  [sym_tagpair_delimiter_close] = "tagpair_delimiter_close",
  [sym_double_quote] = "double_quote",
  [sym_tagpair] = "tagpair",
  [sym__tagpair_value] = "_tagpair_value",
  [sym_tagpair_value_contents] = "tagpair_value_contents",
  [sym_movetext] = "movetext",
  [sym_variation_movetext] = "variation_movetext",
  [sym_variation_delimiter_close] = "variation_delimiter_close",
  [sym_inline_comment_delimiter_open] = "inline_comment_delimiter_open",
  [sym_inline_comment_delimiter_close] = "inline_comment_delimiter_close",
  [sym__recursive_inline_comment_delimiter_open] = "_recursive_inline_comment_delimiter_open",
  [sym__recursive_inline_comment_delimiter_close] = "_recursive_inline_comment_delimiter_close",
  [sym_command_delimiter_close] = "command_delimiter_close",
  [sym_trailing_garbage] = "trailing_garbage",
  [sym__movetext_element] = "_movetext_element",
  [sym__variation_movetext_element] = "_variation_movetext_element",
  [sym_variation] = "variation",
  [sym_recursive_variation] = "recursive_variation",
  [sym_inline_comment] = "inline_comment",
  [sym_command] = "command",
  [sym__recursive_inline_comment] = "_recursive_inline_comment",
  [sym_inline_comment_text] = "inline_comment_text",
  [aux_sym__recursive_inline_comment_text] = "_recursive_inline_comment_text",
  [sym__command_text] = "_command_text",
  [sym_san_move] = "san_move",
  [sym__san_move_piece] = "_san_move_piece",
  [sym_lan_move] = "lan_move",
  [sym__san_rank_any] = "_san_rank_any",
  [sym__san_square_any] = "_san_square_any",
  [sym__san_square_promoting] = "_san_square_promoting",
  [sym__san_square_nonpromoting] = "_san_square_nonpromoting",
  [sym__san_square_any_immediate] = "_san_square_any_immediate",
  [sym__san_square_promoting_immediate] = "_san_square_promoting_immediate",
  [sym__san_square_nonpromoting_immediate] = "_san_square_nonpromoting_immediate",
  [sym__san_promotion] = "_san_promotion",
  [sym__san_move_pawn] = "_san_move_pawn",
  [sym__san_drop_pawn] = "_san_drop_pawn",
  [sym__san_move_major_or_minor_piece] = "_san_move_major_or_minor_piece",
  [sym__san_drop_major_or_minor_piece] = "_san_drop_major_or_minor_piece",
  [sym__lan_move_by_coordinates] = "_lan_move_by_coordinates",
  [sym_annotation] = "annotation",
  [sym_result_code] = "result_code",
  [aux_sym_series_of_games_repeat1] = "series_of_games_repeat1",
  [aux_sym_freestanding_comment_repeat1] = "freestanding_comment_repeat1",
  [aux_sym_header_repeat1] = "header_repeat1",
  [aux_sym_tagpair_delimiter_open_repeat1] = "tagpair_delimiter_open_repeat1",
  [aux_sym_tagpair_delimiter_close_repeat1] = "tagpair_delimiter_close_repeat1",
  [aux_sym_tagpair_value_contents_repeat1] = "tagpair_value_contents_repeat1",
  [aux_sym_movetext_repeat1] = "movetext_repeat1",
  [aux_sym_variation_movetext_repeat1] = "variation_movetext_repeat1",
  [aux_sym_trailing_garbage_repeat1] = "trailing_garbage_repeat1",
  [aux_sym_inline_comment_text_repeat1] = "inline_comment_text_repeat1",
};

static const TSSymbol ts_symbol_map[] = {
  [ts_builtin_sym_end] = ts_builtin_sym_end,
  [sym__empty_line] = sym__empty_line,
  [anon_sym_SEMI] = anon_sym_SEMI,
  [anon_sym_PERCENT] = anon_sym_PERCENT,
  [aux_sym_rest_of_line_comment_token1] = aux_sym_rest_of_line_comment_token1,
  [sym_rest_of_line_comment_text] = sym_rest_of_line_comment_text,
  [sym_old_style_twic_section_comment] = sym_old_style_twic_section_comment,
  [anon_sym_LBRACK] = anon_sym_LBRACK,
  [anon_sym_RBRACK] = anon_sym_RBRACK,
  [anon_sym_DQUOTE] = anon_sym_DQUOTE,
  [aux_sym_double_quote_token1] = aux_sym_double_quote_token1,
  [anon_sym_uff02] = anon_sym_uff02,
  [aux_sym_double_quote_token2] = aux_sym_double_quote_token2,
  [anon_sym_u201c] = anon_sym_u201c,
  [aux_sym_double_quote_token3] = aux_sym_double_quote_token3,
  [anon_sym_u201d] = anon_sym_u201d,
  [aux_sym_double_quote_token4] = aux_sym_double_quote_token4,
  [anon_sym_u201f] = anon_sym_u201f,
  [aux_sym_double_quote_token5] = aux_sym_double_quote_token5,
  [anon_sym_u2033] = anon_sym_u2033,
  [aux_sym_double_quote_token6] = aux_sym_double_quote_token6,
  [anon_sym_u2036] = anon_sym_u2036,
  [aux_sym_double_quote_token7] = aux_sym_double_quote_token7,
  [anon_sym_u3003] = anon_sym_u3003,
  [aux_sym_double_quote_token8] = aux_sym_double_quote_token8,
  [anon_sym_u05f4] = anon_sym_u05f4,
  [aux_sym_double_quote_token9] = aux_sym_double_quote_token9,
  [anon_sym_u02dd] = anon_sym_u02dd,
  [aux_sym_double_quote_token10] = aux_sym_double_quote_token10,
  [anon_sym_u02ba] = anon_sym_u02ba,
  [aux_sym_double_quote_token11] = aux_sym_double_quote_token11,
  [anon_sym_u02f6] = anon_sym_u02f6,
  [aux_sym_double_quote_token12] = aux_sym_double_quote_token12,
  [anon_sym_u02ee] = anon_sym_u02ee,
  [aux_sym_double_quote_token13] = aux_sym_double_quote_token13,
  [anon_sym_u05f2] = anon_sym_u05f2,
  [aux_sym_double_quote_token14] = aux_sym_double_quote_token14,
  [anon_sym_u00ab] = anon_sym_u00ab,
  [aux_sym_double_quote_token15] = aux_sym_double_quote_token15,
  [anon_sym_u00bb] = anon_sym_u00bb,
  [aux_sym_double_quote_token16] = aux_sym_double_quote_token16,
  [sym_tagpair_key] = sym_tagpair_key,
  [aux_sym_tagpair_value_contents_token1] = aux_sym_tagpair_value_contents_token1,
  [sym_variation_delimiter_open] = sym_variation_delimiter_open,
  [anon_sym_RPAREN] = anon_sym_RPAREN,
  [anon_sym_LBRACE] = anon_sym_LBRACE,
  [anon_sym_RBRACE] = anon_sym_RBRACE,
  [sym_command_delimiter_open] = sym_command_delimiter_open,
  [aux_sym_inline_comment_text_token1] = aux_sym_inline_comment_text_token1,
  [sym_command_name] = sym_command_name,
  [sym_command_parameters] = sym_command_parameters,
  [sym_move_number] = sym_move_number,
  [sym__san_file] = sym__san_file,
  [sym__san_file_immediate] = sym__san_file_immediate,
  [sym__san_rank_promoting] = sym__san_rank_promoting,
  [sym__san_rank_nonpromoting] = sym__san_rank_nonpromoting,
  [sym__san_promotable_piece] = sym__san_promotable_piece,
  [sym__san_major_or_minor_piece] = sym__san_major_or_minor_piece,
  [sym__san_capture_symbol] = sym__san_capture_symbol,
  [sym__san_promotion_symbol] = sym__san_promotion_symbol,
  [anon_sym_P] = anon_sym_P,
  [anon_sym_u2659] = anon_sym_u2659,
  [anon_sym_u265fufe0e] = anon_sym_u265fufe0e,
  [anon_sym_AT] = anon_sym_AT,
  [anon_sym_AT2] = anon_sym_AT,
  [aux_sym__lan_move_by_coordinates_token1] = aux_sym__lan_move_by_coordinates_token1,
  [sym__san_move_castle] = sym__san_move_castle,
  [sym__san_null_move] = sym__san_null_move,
  [sym_check_or_mate_condition] = sym_check_or_mate_condition,
  [aux_sym_annotation_token1] = aux_sym_annotation_token1,
  [anon_sym_1] = anon_sym_1,
  [anon_sym_DASH] = anon_sym_DASH,
  [aux_sym_result_code_token1] = aux_sym_result_code_token1,
  [anon_sym_u2212] = anon_sym_u2212,
  [aux_sym_result_code_token2] = aux_sym_result_code_token2,
  [anon_sym_u2010] = anon_sym_u2010,
  [aux_sym_result_code_token3] = aux_sym_result_code_token3,
  [anon_sym_u2011] = anon_sym_u2011,
  [aux_sym_result_code_token4] = aux_sym_result_code_token4,
  [anon_sym_u2012] = anon_sym_u2012,
  [aux_sym_result_code_token5] = aux_sym_result_code_token5,
  [anon_sym_u2013] = anon_sym_u2013,
  [aux_sym_result_code_token6] = aux_sym_result_code_token6,
  [anon_sym_u2014] = anon_sym_u2014,
  [aux_sym_result_code_token7] = aux_sym_result_code_token7,
  [anon_sym_u2796] = anon_sym_u2796,
  [aux_sym_result_code_token8] = aux_sym_result_code_token8,
  [anon_sym_O] = anon_sym_O,
  [anon_sym_0] = anon_sym_0,
  [anon_sym_o] = anon_sym_o,
  [anon_sym_SLASH] = anon_sym_SLASH,
  [aux_sym_result_code_token9] = aux_sym_result_code_token9,
  [anon_sym_u2215] = anon_sym_u2215,
  [aux_sym_result_code_token10] = aux_sym_result_code_token10,
  [anon_sym_u2044] = anon_sym_u2044,
  [aux_sym_result_code_token11] = aux_sym_result_code_token11,
  [anon_sym_u27cb] = anon_sym_u27cb,
  [aux_sym_result_code_token12] = aux_sym_result_code_token12,
  [anon_sym_u29f8] = anon_sym_u29f8,
  [aux_sym_result_code_token13] = aux_sym_result_code_token13,
  [anon_sym_2] = anon_sym_2,
  [anon_sym_u00bd] = anon_sym_u00bd,
  [aux_sym_result_code_token14] = aux_sym_result_code_token14,
  [anon_sym_STAR] = anon_sym_STAR,
  [aux_sym_result_code_token15] = aux_sym_result_code_token15,
  [anon_sym_u2217] = anon_sym_u2217,
  [aux_sym_result_code_token16] = aux_sym_result_code_token16,
  [anon_sym_u2731] = anon_sym_u2731,
  [aux_sym_result_code_token17] = aux_sym_result_code_token17,
  [anon_sym_u204e] = anon_sym_u204e,
  [aux_sym_result_code_token18] = aux_sym_result_code_token18,
  [anon_sym_u066d] = anon_sym_u066d,
  [aux_sym_result_code_token19] = aux_sym_result_code_token19,
  [aux_sym_result_code_token20] = aux_sym_result_code_token20,
  [aux_sym_result_code_token21] = aux_sym_result_code_token21,
  [aux_sym_result_code_token22] = aux_sym_result_code_token22,
  [aux_sym_result_code_token23] = aux_sym_result_code_token23,
  [sym__full_line_comment_delimiter_bol_assertion] = sym__full_line_comment_delimiter_bol_assertion,
  [sym__novelty_glyph_before_punctuation] = sym__novelty_glyph_before_punctuation,
  [sym_series_of_games] = sym_series_of_games,
  [sym_game] = sym_game,
  [sym_freestanding_comment] = sym_freestanding_comment,
  [sym_rest_of_line_comment_delimiter_open] = sym_rest_of_line_comment_delimiter_open,
  [sym_rest_of_line_comment] = sym_rest_of_line_comment,
  [sym_header] = sym_header,
  [sym_tagpair_delimiter_open] = sym_tagpair_delimiter_open,
  [sym_tagpair_delimiter_close] = sym_tagpair_delimiter_close,
  [sym_double_quote] = sym_double_quote,
  [sym_tagpair] = sym_tagpair,
  [sym__tagpair_value] = sym__tagpair_value,
  [sym_tagpair_value_contents] = sym_tagpair_value_contents,
  [sym_movetext] = sym_movetext,
  [sym_variation_movetext] = sym_variation_movetext,
  [sym_variation_delimiter_close] = sym_variation_delimiter_close,
  [sym_inline_comment_delimiter_open] = sym_inline_comment_delimiter_open,
  [sym_inline_comment_delimiter_close] = sym_inline_comment_delimiter_close,
  [sym__recursive_inline_comment_delimiter_open] = sym__recursive_inline_comment_delimiter_open,
  [sym__recursive_inline_comment_delimiter_close] = sym__recursive_inline_comment_delimiter_close,
  [sym_command_delimiter_close] = sym_command_delimiter_close,
  [sym_trailing_garbage] = sym_trailing_garbage,
  [sym__movetext_element] = sym__movetext_element,
  [sym__variation_movetext_element] = sym__variation_movetext_element,
  [sym_variation] = sym_variation,
  [sym_recursive_variation] = sym_recursive_variation,
  [sym_inline_comment] = sym_inline_comment,
  [sym_command] = sym_command,
  [sym__recursive_inline_comment] = sym__recursive_inline_comment,
  [sym_inline_comment_text] = sym_inline_comment_text,
  [aux_sym__recursive_inline_comment_text] = aux_sym__recursive_inline_comment_text,
  [sym__command_text] = sym__command_text,
  [sym_san_move] = sym_san_move,
  [sym__san_move_piece] = sym__san_move_piece,
  [sym_lan_move] = sym_lan_move,
  [sym__san_rank_any] = sym__san_rank_any,
  [sym__san_square_any] = sym__san_square_any,
  [sym__san_square_promoting] = sym__san_square_promoting,
  [sym__san_square_nonpromoting] = sym__san_square_nonpromoting,
  [sym__san_square_any_immediate] = sym__san_square_any_immediate,
  [sym__san_square_promoting_immediate] = sym__san_square_promoting_immediate,
  [sym__san_square_nonpromoting_immediate] = sym__san_square_nonpromoting_immediate,
  [sym__san_promotion] = sym__san_promotion,
  [sym__san_move_pawn] = sym__san_move_pawn,
  [sym__san_drop_pawn] = sym__san_drop_pawn,
  [sym__san_move_major_or_minor_piece] = sym__san_move_major_or_minor_piece,
  [sym__san_drop_major_or_minor_piece] = sym__san_drop_major_or_minor_piece,
  [sym__lan_move_by_coordinates] = sym__lan_move_by_coordinates,
  [sym_annotation] = sym_annotation,
  [sym_result_code] = sym_result_code,
  [aux_sym_series_of_games_repeat1] = aux_sym_series_of_games_repeat1,
  [aux_sym_freestanding_comment_repeat1] = aux_sym_freestanding_comment_repeat1,
  [aux_sym_header_repeat1] = aux_sym_header_repeat1,
  [aux_sym_tagpair_delimiter_open_repeat1] = aux_sym_tagpair_delimiter_open_repeat1,
  [aux_sym_tagpair_delimiter_close_repeat1] = aux_sym_tagpair_delimiter_close_repeat1,
  [aux_sym_tagpair_value_contents_repeat1] = aux_sym_tagpair_value_contents_repeat1,
  [aux_sym_movetext_repeat1] = aux_sym_movetext_repeat1,
  [aux_sym_variation_movetext_repeat1] = aux_sym_variation_movetext_repeat1,
  [aux_sym_trailing_garbage_repeat1] = aux_sym_trailing_garbage_repeat1,
  [aux_sym_inline_comment_text_repeat1] = aux_sym_inline_comment_text_repeat1,
};

static const TSSymbolMetadata ts_symbol_metadata[] = {
  [ts_builtin_sym_end] = {
    .visible = false,
    .named = true,
  },
  [sym__empty_line] = {
    .visible = false,
    .named = true,
  },
  [anon_sym_SEMI] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PERCENT] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_rest_of_line_comment_token1] = {
    .visible = false,
    .named = false,
  },
  [sym_rest_of_line_comment_text] = {
    .visible = true,
    .named = true,
  },
  [sym_old_style_twic_section_comment] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_LBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DQUOTE] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_double_quote_token1] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_uff02] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_double_quote_token2] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_u201c] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_double_quote_token3] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_u201d] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_double_quote_token4] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_u201f] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_double_quote_token5] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_u2033] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_double_quote_token6] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_u2036] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_double_quote_token7] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_u3003] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_double_quote_token8] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_u05f4] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_double_quote_token9] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_u02dd] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_double_quote_token10] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_u02ba] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_double_quote_token11] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_u02f6] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_double_quote_token12] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_u02ee] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_double_quote_token13] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_u05f2] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_double_quote_token14] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_u00ab] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_double_quote_token15] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_u00bb] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_double_quote_token16] = {
    .visible = false,
    .named = false,
  },
  [sym_tagpair_key] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_tagpair_value_contents_token1] = {
    .visible = false,
    .named = false,
  },
  [sym_variation_delimiter_open] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_RPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACE] = {
    .visible = true,
    .named = false,
  },
  [sym_command_delimiter_open] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_inline_comment_text_token1] = {
    .visible = false,
    .named = false,
  },
  [sym_command_name] = {
    .visible = true,
    .named = true,
  },
  [sym_command_parameters] = {
    .visible = true,
    .named = true,
  },
  [sym_move_number] = {
    .visible = true,
    .named = true,
  },
  [sym__san_file] = {
    .visible = false,
    .named = true,
  },
  [sym__san_file_immediate] = {
    .visible = false,
    .named = true,
  },
  [sym__san_rank_promoting] = {
    .visible = false,
    .named = true,
  },
  [sym__san_rank_nonpromoting] = {
    .visible = false,
    .named = true,
  },
  [sym__san_promotable_piece] = {
    .visible = false,
    .named = true,
  },
  [sym__san_major_or_minor_piece] = {
    .visible = false,
    .named = true,
  },
  [sym__san_capture_symbol] = {
    .visible = false,
    .named = true,
  },
  [sym__san_promotion_symbol] = {
    .visible = false,
    .named = true,
  },
  [anon_sym_P] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_u2659] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_u265fufe0e] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AT2] = {
    .visible = true,
    .named = false,
  },
  [aux_sym__lan_move_by_coordinates_token1] = {
    .visible = false,
    .named = false,
  },
  [sym__san_move_castle] = {
    .visible = false,
    .named = true,
  },
  [sym__san_null_move] = {
    .visible = false,
    .named = true,
  },
  [sym_check_or_mate_condition] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_annotation_token1] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_1] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_result_code_token1] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_u2212] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_result_code_token2] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_u2010] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_result_code_token3] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_u2011] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_result_code_token4] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_u2012] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_result_code_token5] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_u2013] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_result_code_token6] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_u2014] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_result_code_token7] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_u2796] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_result_code_token8] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_O] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_0] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_o] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SLASH] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_result_code_token9] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_u2215] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_result_code_token10] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_u2044] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_result_code_token11] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_u27cb] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_result_code_token12] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_u29f8] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_result_code_token13] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_2] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_u00bd] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_result_code_token14] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_STAR] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_result_code_token15] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_u2217] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_result_code_token16] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_u2731] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_result_code_token17] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_u204e] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_result_code_token18] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_u066d] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_result_code_token19] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_result_code_token20] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_result_code_token21] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_result_code_token22] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_result_code_token23] = {
    .visible = false,
    .named = false,
  },
  [sym__full_line_comment_delimiter_bol_assertion] = {
    .visible = false,
    .named = true,
  },
  [sym__novelty_glyph_before_punctuation] = {
    .visible = false,
    .named = true,
  },
  [sym_series_of_games] = {
    .visible = true,
    .named = true,
  },
  [sym_game] = {
    .visible = true,
    .named = true,
  },
  [sym_freestanding_comment] = {
    .visible = true,
    .named = true,
  },
  [sym_rest_of_line_comment_delimiter_open] = {
    .visible = true,
    .named = true,
  },
  [sym_rest_of_line_comment] = {
    .visible = true,
    .named = true,
  },
  [sym_header] = {
    .visible = true,
    .named = true,
  },
  [sym_tagpair_delimiter_open] = {
    .visible = true,
    .named = true,
  },
  [sym_tagpair_delimiter_close] = {
    .visible = true,
    .named = true,
  },
  [sym_double_quote] = {
    .visible = true,
    .named = true,
  },
  [sym_tagpair] = {
    .visible = true,
    .named = true,
  },
  [sym__tagpair_value] = {
    .visible = false,
    .named = true,
  },
  [sym_tagpair_value_contents] = {
    .visible = true,
    .named = true,
  },
  [sym_movetext] = {
    .visible = true,
    .named = true,
  },
  [sym_variation_movetext] = {
    .visible = true,
    .named = true,
  },
  [sym_variation_delimiter_close] = {
    .visible = true,
    .named = true,
  },
  [sym_inline_comment_delimiter_open] = {
    .visible = true,
    .named = true,
  },
  [sym_inline_comment_delimiter_close] = {
    .visible = true,
    .named = true,
  },
  [sym__recursive_inline_comment_delimiter_open] = {
    .visible = false,
    .named = true,
  },
  [sym__recursive_inline_comment_delimiter_close] = {
    .visible = false,
    .named = true,
  },
  [sym_command_delimiter_close] = {
    .visible = true,
    .named = true,
  },
  [sym_trailing_garbage] = {
    .visible = true,
    .named = true,
  },
  [sym__movetext_element] = {
    .visible = false,
    .named = true,
  },
  [sym__variation_movetext_element] = {
    .visible = false,
    .named = true,
  },
  [sym_variation] = {
    .visible = true,
    .named = true,
  },
  [sym_recursive_variation] = {
    .visible = true,
    .named = true,
  },
  [sym_inline_comment] = {
    .visible = true,
    .named = true,
  },
  [sym_command] = {
    .visible = true,
    .named = true,
  },
  [sym__recursive_inline_comment] = {
    .visible = false,
    .named = true,
  },
  [sym_inline_comment_text] = {
    .visible = true,
    .named = true,
  },
  [aux_sym__recursive_inline_comment_text] = {
    .visible = false,
    .named = false,
  },
  [sym__command_text] = {
    .visible = false,
    .named = true,
  },
  [sym_san_move] = {
    .visible = true,
    .named = true,
  },
  [sym__san_move_piece] = {
    .visible = false,
    .named = true,
  },
  [sym_lan_move] = {
    .visible = true,
    .named = true,
  },
  [sym__san_rank_any] = {
    .visible = false,
    .named = true,
  },
  [sym__san_square_any] = {
    .visible = false,
    .named = true,
  },
  [sym__san_square_promoting] = {
    .visible = false,
    .named = true,
  },
  [sym__san_square_nonpromoting] = {
    .visible = false,
    .named = true,
  },
  [sym__san_square_any_immediate] = {
    .visible = false,
    .named = true,
  },
  [sym__san_square_promoting_immediate] = {
    .visible = false,
    .named = true,
  },
  [sym__san_square_nonpromoting_immediate] = {
    .visible = false,
    .named = true,
  },
  [sym__san_promotion] = {
    .visible = false,
    .named = true,
  },
  [sym__san_move_pawn] = {
    .visible = false,
    .named = true,
  },
  [sym__san_drop_pawn] = {
    .visible = false,
    .named = true,
  },
  [sym__san_move_major_or_minor_piece] = {
    .visible = false,
    .named = true,
  },
  [sym__san_drop_major_or_minor_piece] = {
    .visible = false,
    .named = true,
  },
  [sym__lan_move_by_coordinates] = {
    .visible = false,
    .named = true,
  },
  [sym_annotation] = {
    .visible = true,
    .named = true,
  },
  [sym_result_code] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_series_of_games_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_freestanding_comment_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_header_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_tagpair_delimiter_open_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_tagpair_delimiter_close_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_tagpair_value_contents_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_movetext_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_variation_movetext_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_trailing_garbage_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_inline_comment_text_repeat1] = {
    .visible = false,
    .named = false,
  },
};

enum ts_field_identifiers {
  field_annotation = 1,
  field_command_delimiter = 2,
  field_command_name = 3,
  field_command_parameters = 4,
  field_comment = 5,
  field_comment_content = 6,
  field_comment_delimiter = 7,
  field_freestanding_comment = 8,
  field_game = 9,
  field_header = 10,
  field_lan_move = 11,
  field_move_number = 12,
  field_movetext = 13,
  field_recursive_variation_content = 14,
  field_recursive_variation_delimiter = 15,
  field_result_code = 16,
  field_san_move = 17,
  field_tagpair = 18,
  field_tagpair_delimiter = 19,
  field_tagpair_key = 20,
  field_tagpair_value_contents = 21,
  field_tagpair_value_delimiter = 22,
  field_variation_annotation = 23,
  field_variation_comment = 24,
  field_variation_content = 25,
  field_variation_delimiter = 26,
  field_variation_lan_move = 27,
  field_variation_move_number = 28,
  field_variation_san_move = 29,
};

static const char * const ts_field_names[] = {
  [0] = NULL,
  [field_annotation] = "annotation",
  [field_command_delimiter] = "command_delimiter",
  [field_command_name] = "command_name",
  [field_command_parameters] = "command_parameters",
  [field_comment] = "comment",
  [field_comment_content] = "comment_content",
  [field_comment_delimiter] = "comment_delimiter",
  [field_freestanding_comment] = "freestanding_comment",
  [field_game] = "game",
  [field_header] = "header",
  [field_lan_move] = "lan_move",
  [field_move_number] = "move_number",
  [field_movetext] = "movetext",
  [field_recursive_variation_content] = "recursive_variation_content",
  [field_recursive_variation_delimiter] = "recursive_variation_delimiter",
  [field_result_code] = "result_code",
  [field_san_move] = "san_move",
  [field_tagpair] = "tagpair",
  [field_tagpair_delimiter] = "tagpair_delimiter",
  [field_tagpair_key] = "tagpair_key",
  [field_tagpair_value_contents] = "tagpair_value_contents",
  [field_tagpair_value_delimiter] = "tagpair_value_delimiter",
  [field_variation_annotation] = "variation_annotation",
  [field_variation_comment] = "variation_comment",
  [field_variation_content] = "variation_content",
  [field_variation_delimiter] = "variation_delimiter",
  [field_variation_lan_move] = "variation_lan_move",
  [field_variation_move_number] = "variation_move_number",
  [field_variation_san_move] = "variation_san_move",
};

static const TSMapSlice ts_field_map_slices[PRODUCTION_ID_COUNT] = {
  [1] = {.index = 0, .length = 1},
  [2] = {.index = 1, .length = 1},
  [3] = {.index = 2, .length = 1},
  [4] = {.index = 3, .length = 1},
  [5] = {.index = 4, .length = 1},
  [6] = {.index = 5, .length = 5},
  [7] = {.index = 10, .length = 1},
  [8] = {.index = 11, .length = 1},
  [9] = {.index = 12, .length = 1},
  [10] = {.index = 13, .length = 2},
  [11] = {.index = 15, .length = 1},
  [12] = {.index = 16, .length = 1},
  [13] = {.index = 17, .length = 2},
  [14] = {.index = 19, .length = 5},
  [15] = {.index = 24, .length = 1},
  [16] = {.index = 25, .length = 1},
  [17] = {.index = 26, .length = 1},
  [18] = {.index = 27, .length = 2},
  [19] = {.index = 29, .length = 2},
  [20] = {.index = 31, .length = 2},
  [21] = {.index = 33, .length = 2},
  [22] = {.index = 35, .length = 3},
  [23] = {.index = 38, .length = 2},
  [24] = {.index = 40, .length = 2},
  [25] = {.index = 42, .length = 3},
  [26] = {.index = 45, .length = 4},
  [27] = {.index = 49, .length = 10},
  [28] = {.index = 59, .length = 2},
  [29] = {.index = 61, .length = 3},
  [30] = {.index = 64, .length = 10},
  [31] = {.index = 74, .length = 2},
  [32] = {.index = 76, .length = 2},
  [33] = {.index = 78, .length = 3},
  [34] = {.index = 81, .length = 4},
  [35] = {.index = 85, .length = 2},
  [36] = {.index = 87, .length = 3},
  [37] = {.index = 90, .length = 3},
  [38] = {.index = 93, .length = 3},
  [39] = {.index = 96, .length = 3},
  [40] = {.index = 99, .length = 2},
  [41] = {.index = 101, .length = 5},
  [42] = {.index = 106, .length = 2},
  [43] = {.index = 108, .length = 4},
  [44] = {.index = 112, .length = 3},
  [45] = {.index = 115, .length = 3},
};

static const TSFieldMapEntry ts_field_map_entries[] = {
  [0] =
    {field_move_number, 0},
  [1] =
    {field_game, 0},
  [2] =
    {field_freestanding_comment, 0},
  [3] =
    {field_comment, 0},
  [4] =
    {field_tagpair, 0},
  [5] =
    {field_annotation, 0, .inherited = true},
    {field_comment, 0, .inherited = true},
    {field_lan_move, 0, .inherited = true},
    {field_move_number, 0, .inherited = true},
    {field_san_move, 0, .inherited = true},
  [10] =
    {field_san_move, 0},
  [11] =
    {field_lan_move, 0},
  [12] =
    {field_annotation, 0},
  [13] =
    {field_freestanding_comment, 0, .inherited = true},
    {field_game, 0, .inherited = true},
  [15] =
    {field_variation_move_number, 0},
  [16] =
    {field_variation_comment, 0},
  [17] =
    {field_variation_delimiter, 0},
    {field_variation_delimiter, 1},
  [19] =
    {field_variation_annotation, 0, .inherited = true},
    {field_variation_comment, 0, .inherited = true},
    {field_variation_lan_move, 0, .inherited = true},
    {field_variation_move_number, 0, .inherited = true},
    {field_variation_san_move, 0, .inherited = true},
  [24] =
    {field_variation_san_move, 0},
  [25] =
    {field_variation_lan_move, 0},
  [26] =
    {field_variation_annotation, 0},
  [27] =
    {field_freestanding_comment, 0},
    {field_game, 1},
  [29] =
    {field_comment_content, 1},
    {field_comment_delimiter, 0},
  [31] =
    {field_header, 0},
    {field_movetext, 1},
  [33] =
    {field_header, 0},
    {field_result_code, 1},
  [35] =
    {field_comment, 1, .inherited = true},
    {field_tagpair, 0},
    {field_tagpair, 1, .inherited = true},
  [38] =
    {field_movetext, 0},
    {field_result_code, 1},
  [40] =
    {field_comment_delimiter, 0},
    {field_comment_delimiter, 1},
  [42] =
    {field_freestanding_comment, 0, .inherited = true},
    {field_freestanding_comment, 1},
    {field_game, 0, .inherited = true},
  [45] =
    {field_freestanding_comment, 0, .inherited = true},
    {field_freestanding_comment, 1, .inherited = true},
    {field_game, 0, .inherited = true},
    {field_game, 1, .inherited = true},
  [49] =
    {field_annotation, 0, .inherited = true},
    {field_annotation, 1, .inherited = true},
    {field_comment, 0, .inherited = true},
    {field_comment, 1, .inherited = true},
    {field_lan_move, 0, .inherited = true},
    {field_lan_move, 1, .inherited = true},
    {field_move_number, 0, .inherited = true},
    {field_move_number, 1, .inherited = true},
    {field_san_move, 0, .inherited = true},
    {field_san_move, 1, .inherited = true},
  [59] =
    {field_recursive_variation_delimiter, 0},
    {field_recursive_variation_delimiter, 1},
  [61] =
    {field_variation_content, 1},
    {field_variation_delimiter, 0},
    {field_variation_delimiter, 2},
  [64] =
    {field_variation_annotation, 0, .inherited = true},
    {field_variation_annotation, 1, .inherited = true},
    {field_variation_comment, 0, .inherited = true},
    {field_variation_comment, 1, .inherited = true},
    {field_variation_lan_move, 0, .inherited = true},
    {field_variation_lan_move, 1, .inherited = true},
    {field_variation_move_number, 0, .inherited = true},
    {field_variation_move_number, 1, .inherited = true},
    {field_variation_san_move, 0, .inherited = true},
    {field_variation_san_move, 1, .inherited = true},
  [74] =
    {field_header, 0},
    {field_movetext, 2},
  [76] =
    {field_header, 0},
    {field_result_code, 2},
  [78] =
    {field_header, 0},
    {field_movetext, 1},
    {field_result_code, 2},
  [81] =
    {field_comment, 0, .inherited = true},
    {field_comment, 1, .inherited = true},
    {field_tagpair, 0, .inherited = true},
    {field_tagpair, 1, .inherited = true},
  [85] =
    {field_movetext, 0},
    {field_result_code, 2},
  [87] =
    {field_comment_content, 1},
    {field_comment_delimiter, 0},
    {field_comment_delimiter, 2},
  [90] =
    {field_recursive_variation_content, 1},
    {field_recursive_variation_delimiter, 0},
    {field_recursive_variation_delimiter, 2},
  [93] =
    {field_header, 0},
    {field_movetext, 2},
    {field_result_code, 3},
  [96] =
    {field_header, 0},
    {field_movetext, 1},
    {field_result_code, 3},
  [99] =
    {field_tagpair_value_delimiter, 0},
    {field_tagpair_value_delimiter, 1},
  [101] =
    {field_tagpair_delimiter, 0},
    {field_tagpair_delimiter, 3},
    {field_tagpair_key, 1},
    {field_tagpair_value_contents, 2, .inherited = true},
    {field_tagpair_value_delimiter, 2, .inherited = true},
  [106] =
    {field_command_name, 0},
    {field_command_parameters, 1},
  [108] =
    {field_command_delimiter, 0},
    {field_command_delimiter, 2},
    {field_command_name, 1, .inherited = true},
    {field_command_parameters, 1, .inherited = true},
  [112] =
    {field_header, 0},
    {field_movetext, 2},
    {field_result_code, 4},
  [115] =
    {field_tagpair_value_contents, 1},
    {field_tagpair_value_delimiter, 0},
    {field_tagpair_value_delimiter, 2},
};

static const TSSymbol ts_alias_sequences[PRODUCTION_ID_COUNT][MAX_ALIAS_SEQUENCE_LENGTH] = {
  [0] = {0},
};

static const uint16_t ts_non_terminal_alias_map[] = {
  0,
};

static const TSStateId ts_primary_state_ids[STATE_COUNT] = {
  [0] = 0,
  [1] = 1,
  [2] = 2,
  [3] = 3,
  [4] = 4,
  [5] = 5,
  [6] = 2,
  [7] = 3,
  [8] = 8,
  [9] = 9,
  [10] = 10,
  [11] = 11,
  [12] = 12,
  [13] = 13,
  [14] = 14,
  [15] = 15,
  [16] = 16,
  [17] = 17,
  [18] = 18,
  [19] = 19,
  [20] = 20,
  [21] = 21,
  [22] = 22,
  [23] = 23,
  [24] = 12,
  [25] = 25,
  [26] = 26,
  [27] = 13,
  [28] = 28,
  [29] = 10,
  [30] = 30,
  [31] = 31,
  [32] = 32,
  [33] = 33,
  [34] = 34,
  [35] = 35,
  [36] = 36,
  [37] = 37,
  [38] = 38,
  [39] = 39,
  [40] = 40,
  [41] = 41,
  [42] = 42,
  [43] = 43,
  [44] = 44,
  [45] = 11,
  [46] = 46,
  [47] = 47,
  [48] = 48,
  [49] = 49,
  [50] = 50,
  [51] = 19,
  [52] = 52,
  [53] = 53,
  [54] = 54,
  [55] = 55,
  [56] = 56,
  [57] = 25,
  [58] = 58,
  [59] = 59,
  [60] = 60,
  [61] = 61,
  [62] = 62,
  [63] = 63,
  [64] = 64,
  [65] = 65,
  [66] = 56,
  [67] = 49,
  [68] = 68,
  [69] = 69,
  [70] = 54,
  [71] = 61,
  [72] = 64,
  [73] = 28,
  [74] = 39,
  [75] = 46,
  [76] = 37,
  [77] = 41,
  [78] = 38,
  [79] = 42,
  [80] = 43,
  [81] = 40,
  [82] = 44,
  [83] = 26,
  [84] = 22,
  [85] = 25,
  [86] = 31,
  [87] = 32,
  [88] = 33,
  [89] = 34,
  [90] = 35,
  [91] = 36,
  [92] = 25,
  [93] = 30,
  [94] = 94,
  [95] = 95,
  [96] = 96,
  [97] = 53,
  [98] = 59,
  [99] = 63,
  [100] = 65,
  [101] = 54,
  [102] = 56,
  [103] = 60,
  [104] = 48,
  [105] = 50,
  [106] = 49,
  [107] = 64,
  [108] = 108,
  [109] = 95,
  [110] = 47,
  [111] = 111,
  [112] = 58,
  [113] = 52,
  [114] = 49,
  [115] = 62,
  [116] = 55,
  [117] = 117,
  [118] = 118,
  [119] = 119,
  [120] = 120,
  [121] = 121,
  [122] = 122,
  [123] = 123,
  [124] = 124,
  [125] = 125,
  [126] = 126,
  [127] = 127,
  [128] = 128,
  [129] = 129,
  [130] = 130,
  [131] = 131,
  [132] = 128,
  [133] = 131,
  [134] = 134,
  [135] = 135,
  [136] = 136,
  [137] = 11,
  [138] = 10,
  [139] = 12,
  [140] = 13,
  [141] = 19,
  [142] = 25,
  [143] = 143,
  [144] = 144,
  [145] = 145,
  [146] = 146,
  [147] = 147,
  [148] = 148,
  [149] = 54,
  [150] = 56,
  [151] = 151,
  [152] = 64,
  [153] = 153,
  [154] = 154,
  [155] = 155,
  [156] = 49,
  [157] = 157,
  [158] = 158,
  [159] = 25,
  [160] = 160,
  [161] = 31,
  [162] = 49,
  [163] = 26,
  [164] = 22,
  [165] = 28,
  [166] = 46,
  [167] = 30,
  [168] = 25,
  [169] = 32,
  [170] = 33,
  [171] = 34,
  [172] = 35,
  [173] = 36,
  [174] = 37,
  [175] = 38,
  [176] = 39,
  [177] = 40,
  [178] = 41,
  [179] = 42,
  [180] = 43,
  [181] = 44,
  [182] = 54,
  [183] = 56,
  [184] = 64,
  [185] = 185,
  [186] = 186,
  [187] = 49,
  [188] = 64,
  [189] = 58,
  [190] = 190,
  [191] = 191,
  [192] = 192,
  [193] = 193,
  [194] = 194,
  [195] = 195,
  [196] = 196,
  [197] = 53,
  [198] = 198,
  [199] = 199,
  [200] = 54,
  [201] = 56,
  [202] = 63,
  [203] = 65,
  [204] = 204,
  [205] = 205,
  [206] = 205,
  [207] = 205,
  [208] = 205,
  [209] = 205,
  [210] = 205,
  [211] = 211,
  [212] = 212,
  [213] = 213,
  [214] = 214,
  [215] = 215,
  [216] = 216,
  [217] = 216,
  [218] = 218,
  [219] = 218,
  [220] = 216,
  [221] = 218,
  [222] = 222,
  [223] = 222,
  [224] = 222,
  [225] = 225,
  [226] = 225,
  [227] = 225,
  [228] = 228,
  [229] = 229,
  [230] = 230,
  [231] = 231,
  [232] = 232,
  [233] = 233,
  [234] = 234,
  [235] = 235,
  [236] = 236,
  [237] = 237,
  [238] = 238,
  [239] = 239,
  [240] = 240,
  [241] = 241,
  [242] = 239,
  [243] = 243,
  [244] = 243,
  [245] = 245,
  [246] = 237,
  [247] = 238,
  [248] = 248,
  [249] = 240,
  [250] = 234,
  [251] = 241,
  [252] = 240,
  [253] = 241,
  [254] = 239,
  [255] = 234,
  [256] = 243,
  [257] = 245,
  [258] = 237,
  [259] = 238,
  [260] = 260,
  [261] = 245,
  [262] = 262,
  [263] = 263,
  [264] = 264,
  [265] = 19,
  [266] = 266,
  [267] = 266,
  [268] = 268,
  [269] = 269,
  [270] = 270,
  [271] = 269,
  [272] = 272,
  [273] = 273,
  [274] = 274,
  [275] = 275,
  [276] = 276,
  [277] = 270,
  [278] = 264,
  [279] = 279,
  [280] = 273,
  [281] = 266,
  [282] = 268,
  [283] = 263,
  [284] = 269,
  [285] = 274,
  [286] = 266,
  [287] = 287,
  [288] = 270,
  [289] = 264,
  [290] = 266,
  [291] = 273,
  [292] = 274,
  [293] = 275,
  [294] = 263,
  [295] = 266,
  [296] = 274,
  [297] = 274,
  [298] = 274,
  [299] = 275,
  [300] = 300,
  [301] = 301,
  [302] = 302,
  [303] = 303,
  [304] = 304,
  [305] = 305,
  [306] = 302,
  [307] = 300,
  [308] = 125,
  [309] = 309,
  [310] = 310,
  [311] = 311,
  [312] = 300,
  [313] = 313,
  [314] = 314,
  [315] = 302,
  [316] = 316,
  [317] = 302,
  [318] = 302,
  [319] = 319,
  [320] = 320,
  [321] = 302,
  [322] = 322,
  [323] = 323,
  [324] = 302,
  [325] = 319,
  [326] = 319,
};

static const TSCharacterRange extras_character_set_1[] = {
  {'\t', '\t'}, {0x0b, '\f'}, {' ', ' '}, {0x85, 0x85}, {0xa0, 0xa0}, {0x1680, 0x1680}, {0x2000, 0x200a}, {0x2028, 0x2029},
  {0x202f, 0x202f}, {0x205f, 0x205f}, {0x3000, 0x3000},
};

static const TSCharacterRange extras_character_set_2[] = {
  {'\t', '\r'}, {' ', ' '}, {0x85, 0x85}, {0xa0, 0xa0}, {0x1680, 0x1680}, {0x2000, 0x200a}, {0x2028, 0x2029}, {0x202f, 0x202f},
  {0x205f, 0x205f}, {0x3000, 0x3000},
};

static const TSCharacterRange sym_tagpair_key_character_set_1[] = {
  {0, 0x08}, {0x0e, 0x1f}, {'!', 0x84}, {0x86, 0x9f}, {0xa1, 0x167f}, {0x1681, 0x1fff}, {0x200b, 0x2027}, {0x202a, 0x202e},
  {0x2030, 0x205e}, {0x2060, 0x2fff}, {0x3001, 0x10ffff},
};

static const TSCharacterRange aux_sym_tagpair_value_contents_token1_character_set_1[] = {
  {0, '\t'}, {0x0b, '\f'}, {0x0e, '!'}, {'#', 0xaa}, {0xac, 0xba}, {0xbc, 0x2b9}, {0x2bb, 0x2dc}, {0x2de, 0x2ed},
  {0x2ef, 0x2f5}, {0x2f7, 0x5f1}, {0x5f3, 0x5f3}, {0x5f5, 0x201b}, {0x201e, 0x201e}, {0x2020, 0x2032}, {0x2034, 0x2035}, {0x2037, 0x3002},
  {0x3004, 0xff01}, {0xff03, 0x10ffff},
};

static const TSCharacterRange sym_move_number_character_set_2[] = {
  {'\t', '\r'}, {' ', ' '}, {'.', '.'}, {0x85, 0x85}, {0xa0, 0xa0}, {0x660, 0x660}, {0x6f0, 0x6f0}, {0x701, 0x702},
  {0x1680, 0x1680}, {0x2000, 0x200a}, {0x200e, 0x200e}, {0x2024, 0x2024}, {0x2028, 0x2029}, {0x202f, 0x202f}, {0x205f, 0x205f}, {0x3000, 0x3000},
  {0xa4f8, 0xa4f8}, {0xa60e, 0xa60e}, {0x1d16d, 0x1d16d},
};

static const TSCharacterRange aux_sym_annotation_token1_character_set_1[] = {
  {'!', '!'}, {'$', '$'}, {'&', '&'}, {'+', '+'}, {'-', '-'}, {'/', '/'}, {'<', '='}, {'?', '?'},
  {'N', 'N'}, {'R', 'R'}, {'T', 'T'}, {'e', 'e'}, {0xb1, 0xb1}, {0xd8, 0xd8}, {0xf8, 0xf8}, {0x16ed, 0x16ed},
  {0x2010, 0x2014}, {0x203c, 0x203d}, {0x2044, 0x2044}, {0x2047, 0x2049}, {0x2191, 0x2192}, {0x21c6, 0x21c6}, {0x21c8, 0x21c8}, {0x21d4, 0x21d4},
  {0x21d7, 0x21d7}, {0x2206, 0x2207}, {0x2212, 0x2213}, {0x2215, 0x2215}, {0x221e, 0x221e}, {0x2264, 0x2264}, {0x2295, 0x2295}, {0x2299, 0x2299},
  {0x229e, 0x229e}, {0x22a5, 0x22a5}, {0x2313, 0x2313}, {0x2514, 0x2514}, {0x2518, 0x2518}, {0x25a1, 0x25a1}, {0x25cb, 0x25cb}, {0x25fa, 0x25fa},
  {0x25ff, 0x25ff}, {0x2612, 0x2612}, {0x2642, 0x2642}, {0x2715, 0x2715}, {0x2795, 0x2796}, {0x27cb, 0x27cb}, {0x27ea, 0x27eb}, {0x27f3, 0x27f3},
  {0x29f8, 0x29f8}, {0x2a00, 0x2a01}, {0x2a71, 0x2a72}, {0x2b12, 0x2b13}, {0x2e40, 0x2e40}, {0xff1d, 0xff1d},
};

static const TSCharacterRange aux_sym_annotation_token1_character_set_4[] = {
  {'\t', '\r'}, {' ', ' '}, {'&', '&'}, {'/', '/'}, {0x85, 0x85}, {0xa0, 0xa0}, {0x1680, 0x1680}, {0x2000, 0x200a},
  {0x2028, 0x2029}, {0x202f, 0x202f}, {0x2044, 0x2044}, {0x205f, 0x205f}, {0x2215, 0x2215}, {0x27cb, 0x27cb}, {0x29f8, 0x29f8}, {0x3000, 0x3000},
};

static const TSCharacterRange aux_sym_annotation_token1_character_set_7[] = {
  {'\t', '\r'}, {' ', ' '}, {'&', '&'}, {'=', '='}, {0x85, 0x85}, {0xa0, 0xa0}, {0x1680, 0x1680}, {0x2000, 0x200a},
  {0x2028, 0x2029}, {0x202f, 0x202f}, {0x205f, 0x205f}, {0x2e40, 0x2e40}, {0x3000, 0x3000}, {0xff1d, 0xff1d},
};

static const TSCharacterRange aux_sym_result_code_token20_character_set_1[] = {
  {'\t', '\r'}, {' ', ' '}, {'&', '&'}, {'-', '-'}, {0x85, 0x85}, {0xa0, 0xa0}, {0x1680, 0x1680}, {0x2000, 0x200a},
  {0x2010, 0x2014}, {0x2028, 0x2029}, {0x202f, 0x202f}, {0x205f, 0x205f}, {0x2212, 0x2212}, {0x2796, 0x2796}, {0x3000, 0x3000},
};

static const TSCharacterRange aux_sym_result_code_token20_character_set_2[] = {
  {'\t', '\r'}, {' ', ' '}, {'0', '0'}, {'O', 'O'}, {'o', 'o'}, {0x85, 0x85}, {0xa0, 0xa0}, {0x1680, 0x1680},
  {0x2000, 0x200a}, {0x2028, 0x2029}, {0x202f, 0x202f}, {0x205f, 0x205f}, {0x3000, 0x3000},
};

static const TSCharacterRange aux_sym_result_code_token21_character_set_1[] = {
  {'\t', '\r'}, {' ', ' '}, {'1', '1'}, {0x85, 0x85}, {0xa0, 0xa0}, {0x1680, 0x1680}, {0x2000, 0x200a}, {0x2028, 0x2029},
  {0x202f, 0x202f}, {0x205f, 0x205f}, {0x3000, 0x3000},
};

static const TSCharacterRange aux_sym_result_code_token22_character_set_1[] = {
  {'\t', '\r'}, {' ', ' '}, {'2', '2'}, {0x85, 0x85}, {0xa0, 0xa0}, {0x1680, 0x1680}, {0x2000, 0x200a}, {0x2028, 0x2029},
  {0x202f, 0x202f}, {0x205f, 0x205f}, {0x3000, 0x3000},
};

static const TSCharacterRange aux_sym_result_code_token23_character_set_1[] = {
  {'\t', '\r'}, {' ', ' '}, {'&', '&'}, {0x85, 0x85}, {0xa0, 0xa0}, {0xbd, 0xbd}, {0x1680, 0x1680}, {0x2000, 0x200a},
  {0x2028, 0x2029}, {0x202f, 0x202f}, {0x205f, 0x205f}, {0x3000, 0x3000},
};

static bool ts_lex(TSLexer *lexer, TSStateId state) {
  START_LEXER();
  eof = lexer->eof(lexer);
  switch (state) {
    case 0:
      if (eof) ADVANCE(2460);
      ADVANCE_MAP(
        '"', 2480,
        '#', 2644,
        '%', 2465,
        '&', 1201,
        '(', 2562,
        ')', 2564,
        '*', 2720,
        '-', 2674,
        '/', 2703,
        '0', 2697,
        '1', 2670,
        '2', 2713,
        '8', 2601,
        ';', 2463,
        '@', 2631,
        'O', 2692,
        'P', 2624,
        '[', 2476,
        ']', 2478,
        'o', 2701,
        '{', 2566,
        '}', 2568,
        0xab, 2508,
        0xbb, 2510,
        0xbd, 2716,
        0x2ba, 2500,
        0x2dd, 2498,
        0x2ee, 2504,
        0x2f6, 2502,
        0x5f2, 2506,
        0x5f4, 2496,
        0x66d, 2736,
        0x2010, 2678,
        0x2011, 2680,
        0x2012, 2682,
        0x2013, 2684,
        0x2014, 2686,
        0x201c, 2484,
        0x201d, 2486,
        0x201f, 2488,
        0x2033, 2490,
        0x2036, 2492,
        0x2044, 2707,
        0x204e, 2732,
        0x2212, 2676,
        0x2215, 2705,
        0x2217, 2724,
        0x2659, 2627,
        0x265f, 2378,
        0x2731, 2728,
        0x2796, 2688,
        0x27cb, 2709,
        0x29f8, 2711,
        0x3003, 2494,
        0xff02, 2482,
        '+', 2647,
        0x16ed, 2647,
        0x2795, 2647,
        ':', 2615,
        'X', 2615,
        'x', 2615,
        '=', 2617,
        0x2e40, 2617,
        0xff1d, 2617,
      );
      if (('3' <= lookahead && lookahead <= '7')) ADVANCE(2602);
      if (('a' <= lookahead && lookahead <= 'h')) ADVANCE(2597);
      if (lookahead == 'B' ||
          lookahead == 'K' ||
          ('N' <= lookahead && lookahead <= 'R') ||
          (0x2654 <= lookahead && lookahead <= 0x265e)) ADVANCE(2603);
      if (set_contains(aux_sym_result_code_token23_character_set_1, 12, lookahead)) SKIP(2459);
      END_STATE();
    case 1:
      if (lookahead == '\n') ADVANCE(1273);
      END_STATE();
    case 2:
      ADVANCE_MAP(
        '\n', 1273,
        '\r', 1,
        '#', 148,
        'D', 617,
        'L', 554,
        'M', 678,
        'O', 784,
        'P', 684,
        'R', 555,
        'S', 649,
        'U', 744,
        'b', 676,
        'c', 675,
        'd', 553,
        'e', 750,
        'h', 558,
        'i', 706,
        'l', 616,
        'm', 565,
        'n', 551,
        'o', 593,
        'p', 619,
        'q', 825,
        'r', 556,
        's', 683,
        'u', 557,
        'x', 732,
      );
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 3:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '#') ADVANCE(150);
      if (lookahead == 'd') ADVANCE(578);
      if (lookahead == 'h') ADVANCE(852);
      if (lookahead == 'm') ADVANCE(599);
      if (lookahead == 'n') ADVANCE(600);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 4:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '#') ADVANCE(168);
      if (lookahead == 'p') ADVANCE(701);
      if (lookahead == 's') ADVANCE(738);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 5:
      ADVANCE_MAP(
        '\n', 1273,
        '\r', 1,
        '#', 151,
        'd', 572,
        'e', 763,
        'h', 851,
        'm', 595,
        'n', 596,
        's', 740,
      );
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 6:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '#') ADVANCE(166);
      if (lookahead == 'e') ADVANCE(763);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 7:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '#') ADVANCE(452);
      if (lookahead == 'i') ADVANCE(731);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 8:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '#') ADVANCE(203);
      if (lookahead == 'p') ADVANCE(701);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 9:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '#') ADVANCE(412);
      if (lookahead == 'e') ADVANCE(763);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 10:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '#') ADVANCE(342);
      if (lookahead == 'e') ADVANCE(850);
      if (lookahead == 'q') ADVANCE(836);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 11:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '#') ADVANCE(167);
      if (lookahead == 'e') ADVANCE(763);
      if (lookahead == 'p') ADVANCE(701);
      if (lookahead == 's') ADVANCE(738);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 12:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '#') ADVANCE(184);
      if (lookahead == 'f') ADVANCE(777);
      if (lookahead == 'h') ADVANCE(570);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 13:
      ADVANCE_MAP(
        '\n', 1273,
        '\r', 1,
        '#', 159,
        'D', 617,
        'L', 554,
        'M', 678,
        'O', 784,
        'P', 684,
        'R', 555,
        'S', 649,
        'U', 744,
        'a', 792,
        'b', 676,
        'c', 675,
        'd', 553,
        'e', 750,
        'f', 772,
        'h', 562,
        'i', 706,
        'l', 615,
        'm', 564,
        'n', 551,
        'o', 593,
        'p', 620,
        'q', 825,
        'r', 556,
        's', 683,
        'u', 557,
        'x', 732,
      );
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 14:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '#') ADVANCE(177);
      if (lookahead == 's') ADVANCE(739);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 15:
      ADVANCE_MAP(
        '\n', 1273,
        '\r', 1,
        '#', 182,
        'd', 580,
        'h', 853,
        'm', 601,
        'n', 602,
        'p', 701,
        's', 741,
      );
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 16:
      ADVANCE_MAP(
        '\n', 1273,
        '\r', 1,
        '#', 197,
        'd', 572,
        'e', 763,
        'h', 851,
        'm', 595,
        'n', 596,
        'p', 703,
        's', 740,
      );
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 17:
      ADVANCE_MAP(
        '\n', 1273,
        '\r', 1,
        '#', 201,
        'd', 583,
        'h', 856,
        'm', 607,
        'n', 608,
        's', 742,
      );
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 18:
      ADVANCE_MAP(
        '\n', 1273,
        '\r', 1,
        '#', 242,
        'D', 617,
        'L', 554,
        'M', 678,
        'O', 784,
        'P', 684,
        'R', 555,
        'S', 649,
        'U', 744,
        'a', 792,
        'b', 676,
        'c', 675,
        'd', 553,
        'e', 750,
        'f', 772,
        'h', 562,
        'i', 706,
        'l', 615,
        'm', 564,
        'n', 551,
        'o', 593,
        'p', 619,
        'q', 825,
        'r', 556,
        's', 683,
        'u', 557,
        'x', 732,
      );
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 19:
      ADVANCE_MAP(
        '\n', 1273,
        '\r', 1,
        '#', 245,
        'D', 617,
        'L', 554,
        'M', 678,
        'O', 784,
        'P', 684,
        'R', 555,
        'S', 649,
        'U', 744,
        'a', 792,
        'b', 676,
        'c', 675,
        'd', 553,
        'e', 751,
        'f', 772,
        'h', 562,
        'i', 706,
        'l', 615,
        'm', 564,
        'n', 551,
        'o', 593,
        'p', 620,
        'q', 825,
        'r', 556,
        's', 683,
        'u', 557,
        'x', 732,
      );
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 20:
      ADVANCE_MAP(
        '\n', 1273,
        '\r', 1,
        '#', 249,
        'D', 617,
        'L', 554,
        'M', 678,
        'O', 784,
        'P', 684,
        'R', 555,
        'S', 649,
        'U', 744,
        'a', 792,
        'b', 676,
        'c', 675,
        'd', 587,
        'e', 750,
        'f', 772,
        'h', 563,
        'i', 706,
        'l', 615,
        'm', 566,
        'n', 552,
        'o', 593,
        'p', 620,
        'q', 825,
        'r', 556,
        's', 683,
        'u', 557,
        'x', 732,
      );
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 21:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '#') ADVANCE(192);
      if (lookahead == 'd') ADVANCE(572);
      if (lookahead == 'h') ADVANCE(851);
      if (lookahead == 'm') ADVANCE(595);
      if (lookahead == 'n') ADVANCE(596);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 22:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '#') ADVANCE(243);
      if (lookahead == 's') ADVANCE(743);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 23:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '#') ADVANCE(241);
      if (lookahead == 'd') ADVANCE(581);
      if (lookahead == 'h') ADVANCE(854);
      if (lookahead == 'm') ADVANCE(603);
      if (lookahead == 'n') ADVANCE(604);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 24:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '#') ADVANCE(244);
      if (lookahead == 'd') ADVANCE(582);
      if (lookahead == 'h') ADVANCE(855);
      if (lookahead == 'm') ADVANCE(605);
      if (lookahead == 'n') ADVANCE(606);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 25:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '#') ADVANCE(246);
      if (lookahead == 'd') ADVANCE(584);
      if (lookahead == 'h') ADVANCE(857);
      if (lookahead == 'm') ADVANCE(609);
      if (lookahead == 'n') ADVANCE(610);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 26:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '#') ADVANCE(247);
      if (lookahead == 'd') ADVANCE(585);
      if (lookahead == 'h') ADVANCE(858);
      if (lookahead == 'm') ADVANCE(611);
      if (lookahead == 'n') ADVANCE(612);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 27:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '#') ADVANCE(248);
      if (lookahead == 'd') ADVANCE(586);
      if (lookahead == 'h') ADVANCE(859);
      if (lookahead == 'm') ADVANCE(613);
      if (lookahead == 'n') ADVANCE(614);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 28:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '&') ADVANCE(3);
      if (lookahead == '-' ||
          (0x2010 <= lookahead && lookahead <= 0x2014) ||
          lookahead == 0x2212 ||
          lookahead == 0x2796) ADVANCE(904);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 29:
      ADVANCE_MAP(
        '\n', 1273,
        '\r', 1,
        '&', 5,
        '/', 35,
        0x2044, 35,
        0x2215, 35,
        0x27cb, 35,
        0x29f8, 35,
      );
      if (lookahead == '-' ||
          lookahead == '=' ||
          (0x2010 <= lookahead && lookahead <= 0x2014) ||
          lookahead == 0x2212 ||
          lookahead == 0x2796 ||
          lookahead == 0x2e40 ||
          lookahead == 0xff1d) ADVANCE(2659);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 30:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '&') ADVANCE(6);
      if (lookahead == '=' ||
          lookahead == 0x2e40 ||
          lookahead == 0xff1d) ADVANCE(2659);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 31:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '&') ADVANCE(7);
      if (lookahead == 0x221e) ADVANCE(2659);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 32:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '&') ADVANCE(8);
      if (lookahead == '+' ||
          lookahead == 0x16ed ||
          lookahead == 0x2795) ADVANCE(2659);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 33:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '&') ADVANCE(12);
      if (lookahead == 0xbd) ADVANCE(2747);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 34:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '&') ADVANCE(9);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 35:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '&') ADVANCE(21);
      if (lookahead == '-' ||
          (0x2010 <= lookahead && lookahead <= 0x2014) ||
          lookahead == 0x2212 ||
          lookahead == 0x2796) ADVANCE(2659);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 36:
      ADVANCE_MAP(
        '\n', 1273,
        '\r', 1,
        '&', 22,
        '/', 1177,
        0x2044, 1177,
        0x2215, 1177,
        0x27cb, 1177,
        0x29f8, 1177,
      );
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 37:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '&') ADVANCE(25);
      if (lookahead == '-' ||
          (0x2010 <= lookahead && lookahead <= 0x2014) ||
          lookahead == 0x2212 ||
          lookahead == 0x2796) ADVANCE(1170);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 38:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '&') ADVANCE(26);
      if (lookahead == '-' ||
          (0x2010 <= lookahead && lookahead <= 0x2014) ||
          lookahead == 0x2212 ||
          lookahead == 0x2796) ADVANCE(1167);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 39:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '&') ADVANCE(27);
      if (lookahead == '-' ||
          (0x2010 <= lookahead && lookahead <= 0x2014) ||
          lookahead == 0x2212 ||
          lookahead == 0x2796) ADVANCE(1176);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 40:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '-') ADVANCE(1162);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 41:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '.') ADVANCE(2659);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 42:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '0') ADVANCE(516);
      if (lookahead == '1') ADVANCE(537);
      if (lookahead == '3') ADVANCE(517);
      if (lookahead == '5') ADVANCE(335);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 43:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '0') ADVANCE(516);
      if (lookahead == '1') ADVANCE(540);
      if (lookahead == '3') ADVANCE(517);
      if (lookahead == '5') ADVANCE(358);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 44:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '0') ADVANCE(79);
      if (lookahead == '1') ADVANCE(70);
      if (lookahead == '7') ADVANCE(436);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 45:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '0') ADVANCE(453);
      if (lookahead == '1') ADVANCE(77);
      if (lookahead == '5') ADVANCE(262);
      if (lookahead == '6') ADVANCE(80);
      if (lookahead == '7') ADVANCE(102);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 46:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '0') ADVANCE(453);
      if (lookahead == '1') ADVANCE(77);
      if (lookahead == '5') ADVANCE(262);
      if (lookahead == '6') ADVANCE(80);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 47:
      ADVANCE_MAP(
        '\n', 1273,
        '\r', 1,
        '0', 155,
        '1', 483,
        '2', 49,
        '3', 191,
        '5', 157,
        '6', 186,
        '7', 196,
        '9', 893,
        'A', 60,
        'a', 60,
        'B', 152,
        'b', 152,
        'D', 506,
        'd', 506,
        'E', 367,
        'e', 367,
        'F', 505,
        'f', 505,
      );
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 48:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '0') ADVANCE(172);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 49:
      ADVANCE_MAP(
        '\n', 1273,
        '\r', 1,
        '0', 415,
        '1', 273,
        '6', 362,
        '9', 395,
        'A', 396,
        'a', 396,
      );
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 50:
      ADVANCE_MAP(
        '\n', 1273,
        '\r', 1,
        '0', 415,
        '1', 271,
        '6', 362,
        '9', 395,
        'A', 396,
        'a', 396,
      );
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 51:
      ADVANCE_MAP(
        '\n', 1273,
        '\r', 1,
        '0', 415,
        '1', 294,
        '6', 362,
        '9', 395,
        'A', 396,
        'a', 396,
      );
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 52:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '0') ADVANCE(511);
      if (lookahead == '1') ADVANCE(511);
      if (lookahead == '2') ADVANCE(511);
      if (lookahead == '3') ADVANCE(511);
      if (lookahead == '4') ADVANCE(511);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 53:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '0') ADVANCE(511);
      if (lookahead == '1') ADVANCE(511);
      if (lookahead == '2') ADVANCE(511);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 54:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '0') ADVANCE(511);
      if (lookahead == '1') ADVANCE(511);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 55:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '0') ADVANCE(511);
      if (lookahead == '3') ADVANCE(511);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 56:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '0') ADVANCE(511);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 57:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '0') ADVANCE(62);
      if (lookahead == '1') ADVANCE(70);
      if (lookahead == '6') ADVANCE(388);
      if (lookahead == '7') ADVANCE(436);
      if (lookahead == '8') ADVANCE(486);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 58:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '0') ADVANCE(62);
      if (lookahead == '1') ADVANCE(71);
      if (lookahead == '6') ADVANCE(388);
      if (lookahead == '7') ADVANCE(436);
      if (lookahead == '8') ADVANCE(486);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 59:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '0') ADVANCE(54);
      if (lookahead == '7') ADVANCE(162);
      if (lookahead == ';') ADVANCE(2723);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 60:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '0') ADVANCE(54);
      if (lookahead == '7') ADVANCE(162);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 61:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '0') ADVANCE(111);
      if (lookahead == '1') ADVANCE(346);
      if (lookahead == '2') ADVANCE(198);
      if (lookahead == '7') ADVANCE(383);
      if (lookahead == '8') ADVANCE(414);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 62:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '0') ADVANCE(111);
      if (lookahead == '1') ADVANCE(349);
      if (lookahead == '2') ADVANCE(198);
      if (lookahead == '7') ADVANCE(383);
      if (lookahead == '8') ADVANCE(414);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 63:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '0') ADVANCE(111);
      if (lookahead == '1') ADVANCE(351);
      if (lookahead == '2') ADVANCE(198);
      if (lookahead == '7') ADVANCE(383);
      if (lookahead == '8') ADVANCE(414);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 64:
      ADVANCE_MAP(
        '\n', 1273,
        '\r', 1,
        '0', 156,
        '1', 483,
        '2', 50,
        '3', 191,
        '5', 157,
        '6', 186,
        '7', 194,
        '9', 893,
        'A', 59,
        'a', 59,
        'B', 153,
        'b', 153,
        'D', 506,
        'd', 506,
        'E', 367,
        'e', 367,
        'F', 505,
        'f', 505,
      );
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 65:
      ADVANCE_MAP(
        '\n', 1273,
        '\r', 1,
        '0', 156,
        '1', 483,
        '2', 50,
        '3', 191,
        '5', 157,
        '6', 186,
        '7', 194,
        '9', 893,
        'A', 59,
        'a', 59,
        'B', 153,
        'b', 153,
        'D', 506,
        'd', 506,
        'E', 389,
        'e', 389,
        'F', 505,
        'f', 505,
      );
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 66:
      ADVANCE_MAP(
        '\n', 1273,
        '\r', 1,
        '0', 156,
        '1', 483,
        '2', 50,
        '3', 191,
        '5', 157,
        '6', 186,
        '7', 193,
        '9', 893,
        'A', 59,
        'a', 59,
        'B', 152,
        'b', 152,
        'D', 506,
        'd', 506,
        'E', 367,
        'e', 367,
        'F', 505,
        'f', 505,
      );
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 67:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '0') ADVANCE(181);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 68:
      ADVANCE_MAP(
        '\n', 1273,
        '\r', 1,
        '0', 205,
        '2', 158,
        '7', 477,
        '9', 897,
        'D', 511,
        'd', 511,
        'E', 370,
        'e', 370,
        'F', 535,
        'f', 535,
      );
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 69:
      ADVANCE_MAP(
        '\n', 1273,
        '\r', 1,
        '0', 205,
        '2', 158,
        '7', 497,
        '9', 897,
        'B', 518,
        'b', 518,
        'D', 511,
        'd', 511,
        'E', 370,
        'e', 370,
        'F', 535,
        'f', 535,
      );
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 70:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '0') ADVANCE(256);
      if (lookahead == '8') ADVANCE(367);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 71:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '0') ADVANCE(256);
      if (lookahead == '8') ADVANCE(389);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 72:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '0') ADVANCE(362);
      if (lookahead == '5') ADVANCE(327);
      if (lookahead == '6') ADVANCE(266);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 73:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '0') ADVANCE(225);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 74:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '0') ADVANCE(481);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 75:
      ADVANCE_MAP(
        '\n', 1273,
        '\r', 1,
        '0', 384,
        '2', 209,
        '7', 491,
        '9', 895,
        'B', 511,
        'b', 511,
        'F', 512,
        'f', 512,
      );
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 76:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '0') ADVANCE(506);
      if (lookahead == '1') ADVANCE(506);
      if (lookahead == '2') ADVANCE(506);
      if (lookahead == '3') ADVANCE(506);
      if (lookahead == '4') ADVANCE(506);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 77:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '0') ADVANCE(506);
      if (lookahead == '1') ADVANCE(506);
      if (lookahead == '2') ADVANCE(506);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 78:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '0') ADVANCE(173);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 79:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '0') ADVANCE(112);
      if (lookahead == '1') ADVANCE(346);
      if (lookahead == '2') ADVANCE(198);
      if (lookahead == '7') ADVANCE(383);
      if (lookahead == '8') ADVANCE(414);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 80:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '0') ADVANCE(505);
      if (lookahead == '3') ADVANCE(511);
      if (lookahead == '4') ADVANCE(511);
      if (lookahead == '5') ADVANCE(511);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 81:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '0') ADVANCE(199);
      if (lookahead == '2') ADVANCE(188);
      if (lookahead == '7') ADVANCE(490);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(536);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 82:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '0') ADVANCE(536);
      if (lookahead == '1') ADVANCE(536);
      if (lookahead == '2') ADVANCE(536);
      if (lookahead == '3') ADVANCE(536);
      if (lookahead == '4') ADVANCE(536);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 83:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '0') ADVANCE(536);
      if (lookahead == '1') ADVANCE(536);
      if (lookahead == '2') ADVANCE(536);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 84:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '0') ADVANCE(512);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 85:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '0') ADVANCE(513);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 86:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '0') ADVANCE(180);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 87:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '0') ADVANCE(535);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 88:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '0') ADVANCE(185);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 89:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '0') ADVANCE(514);
      if (lookahead == '1') ADVANCE(514);
      if (lookahead == '2') ADVANCE(514);
      if (lookahead == '3') ADVANCE(514);
      if (lookahead == '4') ADVANCE(514);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 90:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '0') ADVANCE(514);
      if (lookahead == '1') ADVANCE(514);
      if (lookahead == '2') ADVANCE(514);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 91:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '0') ADVANCE(515);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 92:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '0') ADVANCE(502);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 93:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '0') ADVANCE(541);
      if (lookahead == '1') ADVANCE(541);
      if (lookahead == '2') ADVANCE(541);
      if (lookahead == '3') ADVANCE(541);
      if (lookahead == '4') ADVANCE(541);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 94:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '0') ADVANCE(541);
      if (lookahead == '1') ADVANCE(541);
      if (lookahead == '2') ADVANCE(541);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 95:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '0') ADVANCE(521);
      if (lookahead == '1') ADVANCE(521);
      if (lookahead == '2') ADVANCE(521);
      if (lookahead == '3') ADVANCE(521);
      if (lookahead == '4') ADVANCE(521);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 96:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '0') ADVANCE(521);
      if (lookahead == '1') ADVANCE(521);
      if (lookahead == '2') ADVANCE(521);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 97:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '0') ADVANCE(523);
      if (lookahead == '1') ADVANCE(523);
      if (lookahead == '2') ADVANCE(523);
      if (lookahead == '3') ADVANCE(523);
      if (lookahead == '4') ADVANCE(523);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 98:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '0') ADVANCE(523);
      if (lookahead == '1') ADVANCE(523);
      if (lookahead == '2') ADVANCE(523);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 99:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '0') ADVANCE(522);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 100:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '0') ADVANCE(524);
      if (lookahead == '1') ADVANCE(524);
      if (lookahead == '2') ADVANCE(524);
      if (lookahead == '3') ADVANCE(524);
      if (lookahead == '4') ADVANCE(524);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 101:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '0') ADVANCE(524);
      if (lookahead == '1') ADVANCE(524);
      if (lookahead == '2') ADVANCE(524);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 102:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '0') ADVANCE(530);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 103:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '0') ADVANCE(525);
      if (lookahead == '1') ADVANCE(525);
      if (lookahead == '2') ADVANCE(525);
      if (lookahead == '3') ADVANCE(525);
      if (lookahead == '4') ADVANCE(525);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 104:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '0') ADVANCE(525);
      if (lookahead == '1') ADVANCE(525);
      if (lookahead == '2') ADVANCE(525);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 105:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '0') ADVANCE(539);
      if (lookahead == '1') ADVANCE(539);
      if (lookahead == '2') ADVANCE(539);
      if (lookahead == '3') ADVANCE(539);
      if (lookahead == '4') ADVANCE(539);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 106:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '0') ADVANCE(539);
      if (lookahead == '1') ADVANCE(539);
      if (lookahead == '2') ADVANCE(539);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 107:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '0') ADVANCE(538);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 108:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '0') ADVANCE(533);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 109:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '0') ADVANCE(534);
      if (lookahead == '1') ADVANCE(534);
      if (lookahead == '2') ADVANCE(534);
      if (lookahead == '3') ADVANCE(534);
      if (lookahead == '4') ADVANCE(534);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 110:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '0') ADVANCE(534);
      if (lookahead == '1') ADVANCE(534);
      if (lookahead == '2') ADVANCE(534);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 111:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '0') ADVANCE(396);
      if (lookahead == '3') ADVANCE(341);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 112:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '0') ADVANCE(396);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 113:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '0') ADVANCE(447);
      if (lookahead == '1') ADVANCE(53);
      if (lookahead == '6') ADVANCE(87);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 114:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '0') ADVANCE(447);
      if (lookahead == '1') ADVANCE(53);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 115:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '0') ADVANCE(178);
      if (lookahead == '1') ADVANCE(471);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 116:
      ADVANCE_MAP(
        '\n', 1273,
        '\r', 1,
        '0', 224,
        '1', 483,
        '2', 51,
        '3', 191,
        '5', 157,
        '6', 186,
        '7', 195,
        '9', 893,
        'A', 59,
        'a', 59,
        'B', 153,
        'b', 153,
        'D', 534,
        'd', 534,
        'E', 367,
        'e', 367,
        'F', 505,
        'f', 505,
      );
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 117:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '0') ADVANCE(484);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 118:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '0') ADVANCE(455);
      if (lookahead == '1') ADVANCE(83);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 119:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '0') ADVANCE(183);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 120:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '0') ADVANCE(459);
      if (lookahead == '1') ADVANCE(90);
      if (lookahead == '6') ADVANCE(91);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 121:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '0') ADVANCE(461);
      if (lookahead == '1') ADVANCE(94);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 122:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '0') ADVANCE(462);
      if (lookahead == '1') ADVANCE(96);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 123:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '0') ADVANCE(463);
      if (lookahead == '1') ADVANCE(98);
      if (lookahead == '6') ADVANCE(99);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 124:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '0') ADVANCE(489);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 125:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '0') ADVANCE(465);
      if (lookahead == '1') ADVANCE(101);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 126:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '0') ADVANCE(466);
      if (lookahead == '1') ADVANCE(104);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 127:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '0') ADVANCE(467);
      if (lookahead == '1') ADVANCE(106);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 128:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '0') ADVANCE(469);
      if (lookahead == '1') ADVANCE(110);
      if (lookahead == '5') ADVANCE(262);
      if (lookahead == '6') ADVANCE(80);
      if (lookahead == '7') ADVANCE(102);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 129:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '0') ADVANCE(61);
      if (lookahead == '1') ADVANCE(70);
      if (lookahead == '6') ADVANCE(388);
      if (lookahead == '7') ADVANCE(436);
      if (lookahead == '8') ADVANCE(486);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 130:
      ADVANCE_MAP(
        '\n', 1273,
        '\r', 1,
        '0', 210,
        '2', 200,
        '7', 494,
        '9', 898,
        'B', 511,
        'b', 511,
        'D', 514,
        'd', 514,
        'F', 515,
        'f', 515,
      );
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 131:
      ADVANCE_MAP(
        '\n', 1273,
        '\r', 1,
        '0', 385,
        '2', 212,
        '7', 876,
        '9', 896,
        'F', 513,
        'f', 513,
      );
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 132:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '0') ADVANCE(226);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 133:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '0') ADVANCE(206);
      if (lookahead == '2') ADVANCE(187);
      if (lookahead == '7') ADVANCE(478);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(511);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 134:
      ADVANCE_MAP(
        '\n', 1273,
        '\r', 1,
        '0', 217,
        '2', 207,
        '7', 496,
        '9', 899,
        'D', 523,
        'd', 523,
        'F', 522,
        'f', 522,
      );
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 135:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '0') ADVANCE(232);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 136:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '0') ADVANCE(213);
      if (lookahead == '2') ADVANCE(189);
      if (lookahead == '7') ADVANCE(493);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(541);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 137:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '0') ADVANCE(237);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 138:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '0') ADVANCE(215);
      if (lookahead == '2') ADVANCE(208);
      if (lookahead == '7') ADVANCE(495);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(521);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 139:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '0') ADVANCE(239);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 140:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '0') ADVANCE(220);
      if (lookahead == '2') ADVANCE(211);
      if (lookahead == '7') ADVANCE(498);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(524);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 141:
      ADVANCE_MAP(
        '\n', 1273,
        '\r', 1,
        '0', 391,
        '2', 223,
        '7', 877,
        '9', 900,
        'F', 538,
        'f', 538,
      );
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 142:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '0') ADVANCE(240);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 143:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '0') ADVANCE(221);
      if (lookahead == '2') ADVANCE(214);
      if (lookahead == '7') ADVANCE(499);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(525);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 144:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '0') ADVANCE(222);
      if (lookahead == '2') ADVANCE(216);
      if (lookahead == '7') ADVANCE(500);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(539);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 145:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '0') ADVANCE(63);
      if (lookahead == '1') ADVANCE(70);
      if (lookahead == '6') ADVANCE(388);
      if (lookahead == '7') ADVANCE(436);
      if (lookahead == '8') ADVANCE(486);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 146:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '0') ADVANCE(231);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 147:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '0') ADVANCE(236);
      if (lookahead == '1') ADVANCE(471);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 148:
      ADVANCE_MAP(
        '\n', 1273,
        '\r', 1,
        '1', 44,
        '2', 149,
        '3', 330,
        '4', 334,
        '5', 451,
        '6', 42,
        '8', 250,
        '9', 363,
        'X', 175,
        'x', 175,
      );
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 149:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '1') ADVANCE(417);
      if (lookahead == '4') ADVANCE(450);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 150:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '1') ADVANCE(78);
      if (lookahead == '4') ADVANCE(398);
      if (lookahead == '8') ADVANCE(269);
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(252);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 151:
      ADVANCE_MAP(
        '\n', 1273,
        '\r', 1,
        '1', 115,
        '4', 394,
        '6', 163,
        '8', 254,
        'X', 255,
        'x', 255,
      );
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 152:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '1') ADVANCE(262);
      if (lookahead == ';') ADVANCE(29);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 153:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '1') ADVANCE(262);
      if (lookahead == ';') ADVANCE(2645);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 154:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '1') ADVANCE(878);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 155:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '1') ADVANCE(76);
      if (lookahead == '3') ADVANCE(875);
      if (lookahead == '4') ADVANCE(365);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 156:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '1') ADVANCE(76);
      if (lookahead == '3') ADVANCE(875);
      if (lookahead == '4') ADVANCE(364);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 157:
      ADVANCE_MAP(
        '\n', 1273,
        '\r', 1,
        '1', 361,
        'A', 165,
        'a', 165,
        'C', 864,
        'c', 864,
        'F', 863,
        'f', 863,
      );
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 158:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '1') ADVANCE(263);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 159:
      ADVANCE_MAP(
        '\n', 1273,
        '\r', 1,
        '1', 57,
        '2', 149,
        '3', 330,
        '4', 285,
        '5', 475,
        '6', 42,
        '8', 259,
        '9', 363,
        'X', 233,
        'x', 233,
      );
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 160:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '1') ADVANCE(2743);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 161:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '1') ADVANCE(1171);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 162:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '1') ADVANCE(511);
      if (lookahead == '2') ADVANCE(511);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 163:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '1') ADVANCE(511);
      if (lookahead == '5') ADVANCE(336);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 164:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '1') ADVANCE(511);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(528);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 165:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '1') ADVANCE(511);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 166:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '1') ADVANCE(174);
      if (lookahead == '6') ADVANCE(163);
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(268);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 167:
      ADVANCE_MAP(
        '\n', 1273,
        '\r', 1,
        '1', 48,
        '4', 328,
        '5', 472,
        '6', 165,
        '8', 275,
        'X', 227,
        'x', 227,
      );
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 168:
      ADVANCE_MAP(
        '\n', 1273,
        '\r', 1,
        '1', 48,
        '4', 328,
        '5', 472,
        '8', 275,
        'X', 228,
        'x', 228,
      );
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 169:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '1') ADVANCE(54);
      if (lookahead == '2') ADVANCE(274);
      if (lookahead == '3') ADVANCE(374);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 170:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '1') ADVANCE(54);
      if (lookahead == '2') ADVANCE(272);
      if (lookahead == '3') ADVANCE(374);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 171:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '1') ADVANCE(54);
      if (lookahead == '2') ADVANCE(295);
      if (lookahead == '3') ADVANCE(374);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 172:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '1') ADVANCE(344);
      if (lookahead == '7') ADVANCE(384);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 173:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '1') ADVANCE(348);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 174:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '1') ADVANCE(471);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 175:
      ADVANCE_MAP(
        '\n', 1273,
        '\r', 1,
        '1', 413,
        '2', 47,
        '3', 873,
        'B', 165,
        'b', 165,
        'D', 450,
        'd', 450,
        'F', 448,
        'f', 448,
      );
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 176:
      ADVANCE_MAP(
        '\n', 1273,
        '\r', 1,
        '1', 413,
        '2', 66,
        '3', 873,
        '6', 429,
        'B', 164,
        'b', 164,
        'D', 450,
        'd', 450,
        'F', 448,
        'f', 448,
      );
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 177:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '1') ADVANCE(67);
      if (lookahead == '4') ADVANCE(442);
      if (lookahead == '8') ADVANCE(315);
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(253);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 178:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '1') ADVANCE(331);
      if (lookahead == '7') ADVANCE(386);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 179:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '1') ADVANCE(887);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 180:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '1') ADVANCE(332);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 181:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '1') ADVANCE(470);
      if (lookahead == '7') ADVANCE(385);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 182:
      ADVANCE_MAP(
        '\n', 1273,
        '\r', 1,
        '1', 73,
        '4', 326,
        '5', 472,
        '8', 313,
        'X', 229,
        'x', 229,
      );
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 183:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '1') ADVANCE(354);
      if (lookahead == '7') ADVANCE(390);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 184:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '1') ADVANCE(473);
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(872);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 185:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '1') ADVANCE(345);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 186:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '1') ADVANCE(267);
      if (lookahead == '4') ADVANCE(267);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 187:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '1') ADVANCE(267);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 188:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '1') ADVANCE(277);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 189:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '1') ADVANCE(283);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 190:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '1') ADVANCE(532);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 191:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '1') ADVANCE(329);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 192:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '1') ADVANCE(86);
      if (lookahead == '4') ADVANCE(396);
      if (lookahead == '8') ADVANCE(314);
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(296);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 193:
      ADVANCE_MAP(
        '\n', 1273,
        '\r', 1,
        '1', 396,
        '3', 190,
        '9', 397,
        'C', 865,
        'c', 865,
        'E', 862,
        'e', 862,
        'F', 329,
        'f', 329,
      );
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 194:
      ADVANCE_MAP(
        '\n', 1273,
        '\r', 1,
        '1', 396,
        '3', 190,
        '9', 402,
        'C', 865,
        'c', 865,
        'E', 862,
        'e', 862,
        'F', 329,
        'f', 329,
      );
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 195:
      ADVANCE_MAP(
        '\n', 1273,
        '\r', 1,
        '1', 396,
        '3', 190,
        '9', 403,
        'C', 865,
        'c', 865,
        'E', 862,
        'e', 862,
        'F', 329,
        'f', 329,
      );
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 196:
      ADVANCE_MAP(
        '\n', 1273,
        '\r', 1,
        '1', 396,
        '9', 397,
        'C', 865,
        'c', 865,
        'E', 862,
        'e', 862,
        'F', 329,
        'f', 329,
      );
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 197:
      ADVANCE_MAP(
        '\n', 1273,
        '\r', 1,
        '1', 147,
        '4', 340,
        '5', 476,
        '6', 163,
        '8', 254,
        'X', 238,
        'x', 238,
      );
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 198:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '1') ADVANCE(447);
      if (lookahead == '2') ADVANCE(436);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 199:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '1') ADVANCE(82);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 200:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '1') ADVANCE(281);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 201:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '1') ADVANCE(119);
      if (lookahead == '4') ADVANCE(405);
      if (lookahead == '8') ADVANCE(316);
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(260);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 202:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '1') ADVANCE(287);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 203:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '1') ADVANCE(88);
      if (lookahead == '4') ADVANCE(329);
      if (lookahead == '5') ADVANCE(472);
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(230);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 204:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '1') ADVANCE(880);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 205:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '1') ADVANCE(52);
      if (lookahead == '4') ADVANCE(372);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 206:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '1') ADVANCE(52);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 207:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '1') ADVANCE(289);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 208:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '1') ADVANCE(288);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 209:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '1') ADVANCE(399);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 210:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '1') ADVANCE(89);
      if (lookahead == '4') ADVANCE(373);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 211:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '1') ADVANCE(290);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 212:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '1') ADVANCE(400);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 213:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '1') ADVANCE(93);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 214:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '1') ADVANCE(291);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 215:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '1') ADVANCE(95);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 216:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '1') ADVANCE(292);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 217:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '1') ADVANCE(97);
      if (lookahead == '4') ADVANCE(378);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 218:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '1') ADVANCE(293);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 219:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '1') ADVANCE(885);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 220:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '1') ADVANCE(100);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 221:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '1') ADVANCE(103);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 222:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '1') ADVANCE(105);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 223:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '1') ADVANCE(411);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 224:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '1') ADVANCE(109);
      if (lookahead == '3') ADVANCE(875);
      if (lookahead == '4') ADVANCE(364);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 225:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '1') ADVANCE(347);
      if (lookahead == '7') ADVANCE(387);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 226:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '1') ADVANCE(352);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 227:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '1') ADVANCE(433);
      if (lookahead == '2') ADVANCE(75);
      if (lookahead == '3') ADVANCE(878);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 228:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '1') ADVANCE(433);
      if (lookahead == '2') ADVANCE(75);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 229:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '1') ADVANCE(433);
      if (lookahead == '2') ADVANCE(130);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 230:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '1') ADVANCE(433);
      if (lookahead == '2') ADVANCE(440);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 231:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '1') ADVANCE(474);
      if (lookahead == '7') ADVANCE(391);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 232:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '1') ADVANCE(353);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 233:
      ADVANCE_MAP(
        '\n', 1273,
        '\r', 1,
        '1', 434,
        '2', 64,
        '3', 873,
        '6', 429,
        'B', 164,
        'b', 164,
        'D', 450,
        'd', 450,
        'F', 448,
        'f', 448,
      );
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 234:
      ADVANCE_MAP(
        '\n', 1273,
        '\r', 1,
        '1', 434,
        '2', 116,
        '3', 873,
        '6', 429,
        'B', 164,
        'b', 164,
        'D', 450,
        'd', 450,
        'F', 448,
        'f', 448,
      );
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 235:
      ADVANCE_MAP(
        '\n', 1273,
        '\r', 1,
        '1', 434,
        '2', 65,
        '3', 874,
        '6', 429,
        'B', 164,
        'b', 164,
        'D', 450,
        'd', 450,
        'F', 449,
        'f', 449,
      );
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 236:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '1') ADVANCE(350);
      if (lookahead == '7') ADVANCE(386);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 237:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '1') ADVANCE(355);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 238:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '1') ADVANCE(435);
      if (lookahead == '2') ADVANCE(69);
      if (lookahead == '3') ADVANCE(878);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(894);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 239:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '1') ADVANCE(356);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 240:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '1') ADVANCE(357);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 241:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '1') ADVANCE(132);
      if (lookahead == '4') ADVANCE(401);
      if (lookahead == '8') ADVANCE(317);
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(300);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 242:
      ADVANCE_MAP(
        '\n', 1273,
        '\r', 1,
        '1', 129,
        '2', 149,
        '3', 330,
        '4', 284,
        '5', 451,
        '6', 42,
        '8', 259,
        '9', 363,
        'X', 176,
        'x', 176,
      );
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 243:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '1') ADVANCE(146);
      if (lookahead == '4') ADVANCE(446);
      if (lookahead == '8') ADVANCE(318);
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(297);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 244:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '1') ADVANCE(135);
      if (lookahead == '4') ADVANCE(404);
      if (lookahead == '8') ADVANCE(319);
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(304);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 245:
      ADVANCE_MAP(
        '\n', 1273,
        '\r', 1,
        '1', 58,
        '2', 149,
        '3', 330,
        '4', 285,
        '5', 475,
        '6', 43,
        '8', 259,
        '9', 363,
        'X', 235,
        'x', 235,
      );
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 246:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '1') ADVANCE(137);
      if (lookahead == '4') ADVANCE(406);
      if (lookahead == '8') ADVANCE(320);
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(307);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 247:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '1') ADVANCE(139);
      if (lookahead == '4') ADVANCE(409);
      if (lookahead == '8') ADVANCE(321);
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(309);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 248:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '1') ADVANCE(142);
      if (lookahead == '4') ADVANCE(410);
      if (lookahead == '8') ADVANCE(322);
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(311);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 249:
      ADVANCE_MAP(
        '\n', 1273,
        '\r', 1,
        '1', 145,
        '2', 149,
        '3', 330,
        '4', 286,
        '5', 475,
        '6', 42,
        '8', 299,
        '9', 363,
        'X', 234,
        'x', 234,
      );
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 250:
      ADVANCE_MAP(
        '\n', 1273,
        '\r', 1,
        '2', 46,
        '5', 479,
        '6', 359,
        '7', 169,
        '8', 72,
        '9', 438,
      );
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 251:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '2') ADVANCE(165);
      if (lookahead == '3') ADVANCE(892);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 252:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '2') ADVANCE(81);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 253:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '2') ADVANCE(131);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 254:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '2') ADVANCE(113);
      if (lookahead == '7') ADVANCE(257);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 255:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '2') ADVANCE(68);
      if (lookahead == '3') ADVANCE(878);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(894);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 256:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '2') ADVANCE(415);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 257:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '2') ADVANCE(263);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 258:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '2') ADVANCE(1182);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 259:
      ADVANCE_MAP(
        '\n', 1273,
        '\r', 1,
        '2', 45,
        '5', 479,
        '6', 359,
        '7', 170,
        '8', 72,
        '9', 438,
      );
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 260:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '2') ADVANCE(134);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 261:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '2') ADVANCE(2745);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 262:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '2') ADVANCE(511);
      if (lookahead == '3') ADVANCE(511);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 263:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '2') ADVANCE(511);
      if (lookahead == '5') ADVANCE(535);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 264:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '2') ADVANCE(511);
      if (lookahead == '6') ADVANCE(511);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 265:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '2') ADVANCE(511);
      if (lookahead == '7') ADVANCE(511);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 266:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '2') ADVANCE(511);
      if (lookahead == '9') ADVANCE(511);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 267:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '2') ADVANCE(511);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 268:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '2') ADVANCE(888);
      if (lookahead == '3') ADVANCE(878);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(894);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 269:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '2') ADVANCE(118);
      if (lookahead == '7') ADVANCE(278);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 270:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '2') ADVANCE(265);
      if (lookahead == '4') ADVANCE(417);
      if (lookahead == '9') ADVANCE(362);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 271:
      ADVANCE_MAP(
        '\n', 1273,
        '\r', 1,
        '2', 506,
        '3', 511,
        '5', 505,
        '7', 531,
        'E', 501,
        'e', 501,
      );
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 272:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '2') ADVANCE(506);
      if (lookahead == '3') ADVANCE(511);
      if (lookahead == '5') ADVANCE(505);
      if (lookahead == '7') ADVANCE(531);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 273:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '2') ADVANCE(506);
      if (lookahead == '3') ADVANCE(511);
      if (lookahead == '5') ADVANCE(505);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(501);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 274:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '2') ADVANCE(506);
      if (lookahead == '3') ADVANCE(511);
      if (lookahead == '5') ADVANCE(505);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 275:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '2') ADVANCE(427);
      if (lookahead == '7') ADVANCE(303);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 276:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '2') ADVANCE(267);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 277:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '2') ADVANCE(536);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 278:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '2') ADVANCE(277);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 279:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '2') ADVANCE(282);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 280:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '2') ADVANCE(283);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 281:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '2') ADVANCE(514);
      if (lookahead == '5') ADVANCE(515);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 282:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '2') ADVANCE(179);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 283:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '2') ADVANCE(541);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 284:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '2') ADVANCE(527);
      if (lookahead == '3') ADVANCE(504);
      if (lookahead == '5') ADVANCE(506);
      if (lookahead == '7') ADVANCE(505);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 285:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '2') ADVANCE(527);
      if (lookahead == '3') ADVANCE(520);
      if (lookahead == '5') ADVANCE(506);
      if (lookahead == '7') ADVANCE(505);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 286:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '2') ADVANCE(527);
      if (lookahead == '3') ADVANCE(520);
      if (lookahead == '5') ADVANCE(534);
      if (lookahead == '7') ADVANCE(505);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 287:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '2') ADVANCE(528);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 288:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '2') ADVANCE(521);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 289:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '2') ADVANCE(523);
      if (lookahead == '5') ADVANCE(522);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 290:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '2') ADVANCE(524);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 291:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '2') ADVANCE(525);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 292:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '2') ADVANCE(539);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 293:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '2') ADVANCE(526);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 294:
      ADVANCE_MAP(
        '\n', 1273,
        '\r', 1,
        '2', 534,
        '3', 511,
        '5', 505,
        '7', 531,
        'E', 501,
        'e', 501,
      );
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 295:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '2') ADVANCE(534);
      if (lookahead == '3') ADVANCE(511);
      if (lookahead == '5') ADVANCE(505);
      if (lookahead == '7') ADVANCE(531);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 296:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '2') ADVANCE(133);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 297:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '2') ADVANCE(141);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 298:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '2') ADVANCE(281);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 299:
      ADVANCE_MAP(
        '\n', 1273,
        '\r', 1,
        '2', 128,
        '5', 479,
        '6', 359,
        '7', 171,
        '8', 72,
        '9', 438,
      );
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 300:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '2') ADVANCE(136);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 301:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '2') ADVANCE(289);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 302:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '2') ADVANCE(288);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 303:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '2') ADVANCE(399);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 304:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '2') ADVANCE(138);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 305:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '2') ADVANCE(290);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 306:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '2') ADVANCE(400);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 307:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '2') ADVANCE(140);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 308:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '2') ADVANCE(291);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 309:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '2') ADVANCE(143);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 310:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '2') ADVANCE(292);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 311:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '2') ADVANCE(144);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 312:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '2') ADVANCE(411);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 313:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '2') ADVANCE(120);
      if (lookahead == '7') ADVANCE(298);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 314:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '2') ADVANCE(114);
      if (lookahead == '7') ADVANCE(276);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 315:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '2') ADVANCE(428);
      if (lookahead == '7') ADVANCE(306);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 316:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '2') ADVANCE(123);
      if (lookahead == '7') ADVANCE(301);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 317:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '2') ADVANCE(121);
      if (lookahead == '7') ADVANCE(280);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 318:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '2') ADVANCE(432);
      if (lookahead == '7') ADVANCE(312);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 319:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '2') ADVANCE(122);
      if (lookahead == '7') ADVANCE(302);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 320:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '2') ADVANCE(125);
      if (lookahead == '7') ADVANCE(305);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 321:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '2') ADVANCE(126);
      if (lookahead == '7') ADVANCE(308);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 322:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '2') ADVANCE(127);
      if (lookahead == '7') ADVANCE(310);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 323:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '3') ADVANCE(878);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 324:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '3') ADVANCE(511);
      if (lookahead == '4') ADVANCE(511);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 325:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '3') ADVANCE(511);
      if (lookahead == '4') ADVANCE(514);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 326:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '3') ADVANCE(511);
      if (lookahead == '5') ADVANCE(514);
      if (lookahead == '7') ADVANCE(515);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 327:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '3') ADVANCE(511);
      if (lookahead == '7') ADVANCE(511);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 328:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '3') ADVANCE(511);
      if (lookahead == '7') ADVANCE(512);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 329:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '3') ADVANCE(511);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 330:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '3') ADVANCE(517);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 331:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '3') ADVANCE(362);
      if (lookahead == '8') ADVANCE(443);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 332:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '3') ADVANCE(362);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 333:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '3') ADVANCE(504);
      if (lookahead == '4') ADVANCE(506);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 334:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '3') ADVANCE(504);
      if (lookahead == '5') ADVANCE(506);
      if (lookahead == '7') ADVANCE(505);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 335:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '3') ADVANCE(117);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 336:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '3') ADVANCE(74);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 337:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '3') ADVANCE(520);
      if (lookahead == '4') ADVANCE(506);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 338:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '3') ADVANCE(520);
      if (lookahead == '4') ADVANCE(534);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 339:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '3') ADVANCE(518);
      if (lookahead == '4') ADVANCE(511);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 340:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '3') ADVANCE(518);
      if (lookahead == '5') ADVANCE(511);
      if (lookahead == '7') ADVANCE(535);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 341:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '3') ADVANCE(532);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 342:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '3') ADVANCE(329);
      if (lookahead == '6') ADVANCE(329);
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(251);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 343:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '3') ADVANCE(329);
      if (lookahead == '7') ADVANCE(396);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 344:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '3') ADVANCE(329);
      if (lookahead == '8') ADVANCE(441);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 345:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '3') ADVANCE(329);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 346:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '3') ADVANCE(333);
      if (lookahead == '8') ADVANCE(439);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 347:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '3') ADVANCE(325);
      if (lookahead == '8') ADVANCE(444);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 348:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '3') ADVANCE(368);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 349:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '3') ADVANCE(337);
      if (lookahead == '8') ADVANCE(439);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 350:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '3') ADVANCE(339);
      if (lookahead == '8') ADVANCE(443);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 351:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '3') ADVANCE(338);
      if (lookahead == '8') ADVANCE(439);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 352:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '3') ADVANCE(375);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 353:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '3') ADVANCE(376);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 354:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '3') ADVANCE(377);
      if (lookahead == '8') ADVANCE(445);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 355:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '3') ADVANCE(379);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 356:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '3') ADVANCE(380);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 357:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '3') ADVANCE(381);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 358:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '3') ADVANCE(124);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 359:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '4') ADVANCE(416);
      if (lookahead == '6') ADVANCE(55);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 360:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '4') ADVANCE(511);
      if (lookahead == '7') ADVANCE(511);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 361:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '4') ADVANCE(511);
      if (lookahead == '8') ADVANCE(511);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 362:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '4') ADVANCE(511);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 363:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '4') ADVANCE(480);
      if (lookahead == '6') ADVANCE(343);
      if (lookahead == '7') ADVANCE(270);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 364:
      ADVANCE_MAP(
        '\n', 1273,
        '\r', 1,
        '4', 505,
        '7', 511,
        '8', 511,
        '9', 511,
        'E', 530,
        'e', 530,
      );
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 365:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '4') ADVANCE(505);
      if (lookahead == '7') ADVANCE(511);
      if (lookahead == '8') ADVANCE(511);
      if (lookahead == '9') ADVANCE(511);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 366:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '4') ADVANCE(505);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 367:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '4') ADVANCE(92);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 368:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '4') ADVANCE(536);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 369:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '4') ADVANCE(512);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 370:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '4') ADVANCE(56);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 371:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '4') ADVANCE(513);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 372:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '4') ADVANCE(535);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 373:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '4') ADVANCE(515);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 374:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '4') ADVANCE(501);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 375:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '4') ADVANCE(541);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 376:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '4') ADVANCE(521);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 377:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '4') ADVANCE(523);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 378:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '4') ADVANCE(522);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 379:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '4') ADVANCE(524);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 380:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '4') ADVANCE(525);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 381:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '4') ADVANCE(539);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 382:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '4') ADVANCE(538);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 383:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '4') ADVANCE(366);
      if (lookahead == '5') ADVANCE(262);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 384:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '4') ADVANCE(369);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 385:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '4') ADVANCE(371);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 386:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '4') ADVANCE(372);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 387:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '4') ADVANCE(373);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 388:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '4') ADVANCE(408);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 389:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '4') ADVANCE(108);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 390:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '4') ADVANCE(378);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 391:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '4') ADVANCE(382);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 392:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '5') ADVANCE(511);
      if (lookahead == '6') ADVANCE(511);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 393:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '5') ADVANCE(511);
      if (lookahead == '6') ADVANCE(514);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 394:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '5') ADVANCE(511);
      if (lookahead == '7') ADVANCE(535);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 395:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '5') ADVANCE(511);
      if (lookahead == '9') ADVANCE(511);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(511);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 396:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '5') ADVANCE(511);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 397:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '5') ADVANCE(504);
      if (lookahead == '6') ADVANCE(506);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 398:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '5') ADVANCE(536);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 399:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '5') ADVANCE(512);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 400:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '5') ADVANCE(513);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 401:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '5') ADVANCE(541);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 402:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '5') ADVANCE(520);
      if (lookahead == '6') ADVANCE(506);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 403:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '5') ADVANCE(520);
      if (lookahead == '6') ADVANCE(534);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 404:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '5') ADVANCE(521);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 405:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '5') ADVANCE(523);
      if (lookahead == '7') ADVANCE(522);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 406:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '5') ADVANCE(524);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 407:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '5') ADVANCE(518);
      if (lookahead == '6') ADVANCE(511);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 408:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '5') ADVANCE(529);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 409:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '5') ADVANCE(525);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 410:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '5') ADVANCE(539);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 411:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '5') ADVANCE(538);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 412:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '6') ADVANCE(165);
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(323);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 413:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '6') ADVANCE(889);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 414:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '6') ADVANCE(392);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 415:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '6') ADVANCE(511);
      if (lookahead == '7') ADVANCE(511);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 416:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '6') ADVANCE(511);
      if (lookahead == '8') ADVANCE(511);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 417:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '6') ADVANCE(511);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 418:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '6') ADVANCE(482);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 419:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '6') ADVANCE(481);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 420:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '6') ADVANCE(536);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 421:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '6') ADVANCE(541);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 422:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '6') ADVANCE(521);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 423:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '6') ADVANCE(523);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 424:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '6') ADVANCE(524);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 425:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '6') ADVANCE(525);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 426:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '6') ADVANCE(539);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 427:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '6') ADVANCE(84);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 428:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '6') ADVANCE(85);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 429:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '6') ADVANCE(883);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 430:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '6') ADVANCE(485);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 431:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '6') ADVANCE(487);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 432:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '6') ADVANCE(107);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 433:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '6') ADVANCE(886);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 434:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '6') ADVANCE(890);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 435:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '6') ADVANCE(891);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 436:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '7') ADVANCE(511);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 437:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '7') ADVANCE(332);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 438:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '7') ADVANCE(481);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 439:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '7') ADVANCE(505);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 440:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '7') ADVANCE(492);
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(511);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 441:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '7') ADVANCE(512);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 442:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '7') ADVANCE(513);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 443:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '7') ADVANCE(535);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 444:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '7') ADVANCE(515);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 445:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '7') ADVANCE(522);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 446:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '7') ADVANCE(538);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 447:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '8') ADVANCE(511);
      if (lookahead == '9') ADVANCE(511);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 448:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '8') ADVANCE(511);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(204);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 449:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '8') ADVANCE(511);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(219);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 450:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '8') ADVANCE(511);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 451:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '8') ADVANCE(418);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 452:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '8') ADVANCE(437);
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(279);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 453:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '8') ADVANCE(506);
      if (lookahead == '9') ADVANCE(506);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 454:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '8') ADVANCE(505);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 455:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '8') ADVANCE(536);
      if (lookahead == '9') ADVANCE(536);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 456:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '8') ADVANCE(512);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 457:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '8') ADVANCE(513);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 458:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '8') ADVANCE(535);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 459:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '8') ADVANCE(514);
      if (lookahead == '9') ADVANCE(514);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 460:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '8') ADVANCE(515);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 461:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '8') ADVANCE(541);
      if (lookahead == '9') ADVANCE(541);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 462:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '8') ADVANCE(521);
      if (lookahead == '9') ADVANCE(521);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 463:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '8') ADVANCE(523);
      if (lookahead == '9') ADVANCE(523);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 464:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '8') ADVANCE(522);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 465:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '8') ADVANCE(524);
      if (lookahead == '9') ADVANCE(524);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 466:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '8') ADVANCE(525);
      if (lookahead == '9') ADVANCE(525);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 467:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '8') ADVANCE(539);
      if (lookahead == '9') ADVANCE(539);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 468:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '8') ADVANCE(538);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 469:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '8') ADVANCE(534);
      if (lookahead == '9') ADVANCE(534);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 470:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '8') ADVANCE(442);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 471:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '8') ADVANCE(370);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 472:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '8') ADVANCE(419);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 473:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '8') ADVANCE(488);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 474:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '8') ADVANCE(446);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 475:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '8') ADVANCE(430);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 476:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '8') ADVANCE(431);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 477:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '9') ADVANCE(417);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(868);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 478:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '9') ADVANCE(417);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 479:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '9') ADVANCE(324);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 480:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '9') ADVANCE(264);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 481:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '9') ADVANCE(511);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 482:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '9') ADVANCE(504);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 483:
      ADVANCE_MAP(
        '\n', 1273,
        '\r', 1,
        '9', 162,
        ';', 2655,
        'C', 416,
        'c', 416,
        'D', 360,
        'd', 360,
      );
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 484:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '9') ADVANCE(502);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 485:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '9') ADVANCE(520);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 486:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '9') ADVANCE(528);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 487:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '9') ADVANCE(518);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 488:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '9') ADVANCE(526);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 489:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '9') ADVANCE(533);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 490:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '9') ADVANCE(420);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 491:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '9') ADVANCE(396);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(866);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 492:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '9') ADVANCE(396);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 493:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '9') ADVANCE(421);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 494:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '9') ADVANCE(393);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(869);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 495:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '9') ADVANCE(422);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 496:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '9') ADVANCE(423);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(870);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 497:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '9') ADVANCE(407);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(868);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 498:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '9') ADVANCE(424);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 499:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '9') ADVANCE(425);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 500:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '9') ADVANCE(426);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 501:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == ';') ADVANCE(2660);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 502:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == ';') ADVANCE(2651);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 503:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == ';') ADVANCE(29);
      if (lookahead == 'b') ADVANCE(511);
      if (lookahead == 'e') ADVANCE(511);
      if (lookahead == 'm') ADVANCE(707);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 504:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == ';') ADVANCE(29);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 505:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == ';') ADVANCE(30);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 506:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == ';') ADVANCE(2654);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 507:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == ';') ADVANCE(2659);
      if (lookahead == 'a') ADVANCE(770);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 508:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == ';') ADVANCE(2659);
      if (lookahead == 'f') ADVANCE(815);
      if (lookahead == 'q') ADVANCE(511);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 509:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == ';') ADVANCE(2659);
      if (lookahead == 'o') ADVANCE(848);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 510:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == ';') ADVANCE(2659);
      if (lookahead == 't') ADVANCE(733);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 511:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == ';') ADVANCE(2659);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 512:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == ';') ADVANCE(31);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 513:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == ';') ADVANCE(926);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 514:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == ';') ADVANCE(2643);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 515:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == ';') ADVANCE(32);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 516:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == ';') ADVANCE(34);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 517:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == ';') ADVANCE(2655);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 518:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == ';') ADVANCE(2646);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 519:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == ';') ADVANCE(2645);
      if (lookahead == 'b') ADVANCE(511);
      if (lookahead == 'e') ADVANCE(511);
      if (lookahead == 'm') ADVANCE(707);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 520:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == ';') ADVANCE(2645);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 521:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == ';') ADVANCE(1166);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 522:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == ';') ADVANCE(1168);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 523:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == ';') ADVANCE(1169);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 524:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == ';') ADVANCE(1170);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 525:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == ';') ADVANCE(1167);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 526:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == ';') ADVANCE(2747);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 527:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == ';') ADVANCE(2723);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 528:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == ';') ADVANCE(2718);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 529:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == ';') ADVANCE(2739);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 530:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == ';') ADVANCE(2735);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 531:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == ';') ADVANCE(2727);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 532:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == ';') ADVANCE(2731);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 533:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == ';') ADVANCE(2618);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 534:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == ';') ADVANCE(2635);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 535:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == ';') ADVANCE(35);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 536:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == ';') ADVANCE(904);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 537:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == ';') ADVANCE(2656);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 538:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == ';') ADVANCE(1177);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 539:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == ';') ADVANCE(1176);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 540:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == ';') ADVANCE(2620);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 541:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == ';') ADVANCE(905);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 542:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '=') ADVANCE(2659);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 543:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'A') ADVANCE(775);
      if (lookahead == 'R') ADVANCE(674);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 544:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'A') ADVANCE(775);
      if (lookahead == 'T') ADVANCE(621);
      if (lookahead == 'p') ADVANCE(624);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 545:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'A') ADVANCE(775);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 546:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'L') ADVANCE(626);
      if (lookahead == 'R') ADVANCE(674);
      if (lookahead == 'U') ADVANCE(749);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 547:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'M') ADVANCE(682);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 548:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'N') ADVANCE(2659);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 549:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'P') ADVANCE(701);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 550:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'R') ADVANCE(674);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 551:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'a') ADVANCE(588);
      if (lookahead == 'd') ADVANCE(553);
      if (lookahead == 'e') ADVANCE(574);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 552:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'a') ADVANCE(588);
      if (lookahead == 'd') ADVANCE(587);
      if (lookahead == 'e') ADVANCE(574);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 553:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'a') ADVANCE(782);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 554:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'a') ADVANCE(708);
      if (lookahead == 'e') ADVANCE(637);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 555:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'a') ADVANCE(708);
      if (lookahead == 'i') ADVANCE(646);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 556:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'a') ADVANCE(764);
      if (lookahead == 'i') ADVANCE(648);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 557:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'a') ADVANCE(764);
      if (lookahead == 'p') ADVANCE(568);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 558:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'a') ADVANCE(764);
      if (lookahead == 'y') ADVANCE(747);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 559:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'a') ADVANCE(764);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 560:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'a') ADVANCE(591);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 561:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'a') ADVANCE(511);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 562:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'a') ADVANCE(690);
      if (lookahead == 'y') ADVANCE(747);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 563:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'a') ADVANCE(690);
      if (lookahead == 'y') ADVANCE(762);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 564:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'a') ADVANCE(689);
      if (lookahead == 'd') ADVANCE(553);
      if (lookahead == 'i') ADVANCE(597);
      if (lookahead == 'n') ADVANCE(753);
      if (lookahead == 'p') ADVANCE(511);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 565:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'a') ADVANCE(689);
      if (lookahead == 'd') ADVANCE(553);
      if (lookahead == 'i') ADVANCE(722);
      if (lookahead == 'n') ADVANCE(753);
      if (lookahead == 'p') ADVANCE(511);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 566:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'a') ADVANCE(689);
      if (lookahead == 'd') ADVANCE(587);
      if (lookahead == 'i') ADVANCE(598);
      if (lookahead == 'n') ADVANCE(753);
      if (lookahead == 'p') ADVANCE(511);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 567:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'a') ADVANCE(775);
      if (lookahead == 'r') ADVANCE(681);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 568:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'a') ADVANCE(775);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 569:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'a') ADVANCE(694);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 570:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'a') ADVANCE(700);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 571:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'a') ADVANCE(770);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 572:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'a') ADVANCE(786);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 573:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'a') ADVANCE(792);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 574:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'a') ADVANCE(776);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 575:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'a') ADVANCE(692);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 576:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'a') ADVANCE(804);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 577:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'a') ADVANCE(702);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 578:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'a') ADVANCE(803);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 579:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'a') ADVANCE(592);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 580:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'a') ADVANCE(805);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 581:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'a') ADVANCE(806);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 582:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'a') ADVANCE(807);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 583:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'a') ADVANCE(808);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 584:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'a') ADVANCE(809);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 585:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'a') ADVANCE(810);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 586:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'a') ADVANCE(811);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 587:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'a') ADVANCE(812);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 588:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'b') ADVANCE(688);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 589:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'c') ADVANCE(686);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 590:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'c') ADVANCE(687);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 591:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'c') ADVANCE(202);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 592:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'c') ADVANCE(218);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 593:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'd') ADVANCE(737);
      if (lookahead == 'p') ADVANCE(701);
      if (lookahead == 's') ADVANCE(704);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 594:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'd') ADVANCE(737);
      if (lookahead == 'p') ADVANCE(701);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 595:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'd') ADVANCE(572);
      if (lookahead == 'i') ADVANCE(721);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 596:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'd') ADVANCE(572);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 597:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'd') ADVANCE(573);
      if (lookahead == 'n') ADVANCE(831);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 598:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'd') ADVANCE(573);
      if (lookahead == 'n') ADVANCE(845);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 599:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'd') ADVANCE(578);
      if (lookahead == 'i') ADVANCE(723);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 600:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'd') ADVANCE(578);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 601:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'd') ADVANCE(580);
      if (lookahead == 'i') ADVANCE(724);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 602:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'd') ADVANCE(580);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 603:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'd') ADVANCE(581);
      if (lookahead == 'i') ADVANCE(725);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 604:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'd') ADVANCE(581);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 605:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'd') ADVANCE(582);
      if (lookahead == 'i') ADVANCE(726);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 606:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'd') ADVANCE(582);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 607:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'd') ADVANCE(583);
      if (lookahead == 'i') ADVANCE(727);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 608:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'd') ADVANCE(583);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 609:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'd') ADVANCE(584);
      if (lookahead == 'i') ADVANCE(728);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 610:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'd') ADVANCE(584);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 611:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'd') ADVANCE(585);
      if (lookahead == 'i') ADVANCE(729);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 612:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'd') ADVANCE(585);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 613:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'd') ADVANCE(586);
      if (lookahead == 'i') ADVANCE(730);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 614:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'd') ADVANCE(586);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 615:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'e') ADVANCE(508);
      if (lookahead == 'l') ADVANCE(820);
      if (lookahead == 'o') ADVANCE(849);
      if (lookahead == 'r') ADVANCE(559);
      if (lookahead == 't') ADVANCE(516);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 616:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'e') ADVANCE(508);
      if (lookahead == 'l') ADVANCE(820);
      if (lookahead == 'r') ADVANCE(559);
      if (lookahead == 't') ADVANCE(516);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 617:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'e') ADVANCE(686);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 618:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'e') ADVANCE(511);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 619:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'e') ADVANCE(771);
      if (lookahead == 'l') ADVANCE(828);
      if (lookahead == 'm') ADVANCE(511);
      if (lookahead == 'r') ADVANCE(735);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 620:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'e') ADVANCE(771);
      if (lookahead == 'l') ADVANCE(835);
      if (lookahead == 'm') ADVANCE(511);
      if (lookahead == 'r') ADVANCE(735);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 621:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'e') ADVANCE(618);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 622:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'e') ADVANCE(789);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 623:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'e') ADVANCE(707);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 624:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'e') ADVANCE(765);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 625:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'e') ADVANCE(785);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 626:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'e') ADVANCE(639);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 627:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'e') ADVANCE(709);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 628:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'e') ADVANCE(710);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 629:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'e') ADVANCE(711);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 630:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'e') ADVANCE(713);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 631:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'e') ADVANCE(714);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 632:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'e') ADVANCE(715);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 633:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'e') ADVANCE(716);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 634:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'e') ADVANCE(717);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 635:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'e') ADVANCE(718);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 636:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'e') ADVANCE(719);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 637:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'f') ADVANCE(814);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 638:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'f') ADVANCE(511);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 639:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'f') ADVANCE(816);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 640:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'f') ADVANCE(788);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 641:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'f') ADVANCE(528);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 642:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'f') ADVANCE(526);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 643:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'f') ADVANCE(679);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 644:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'f') ADVANCE(680);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 645:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'g') ADVANCE(732);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 646:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'g') ADVANCE(651);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 647:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'g') ADVANCE(511);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 648:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'g') ADVANCE(655);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 649:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'h') ADVANCE(736);
      if (lookahead == 'q') ADVANCE(839);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 650:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'h') ADVANCE(511);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 651:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'h') ADVANCE(816);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 652:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'h') ADVANCE(506);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 653:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'h') ADVANCE(627);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 654:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'h') ADVANCE(623);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 655:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'h') ADVANCE(823);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 656:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'h') ADVANCE(536);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 657:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'h') ADVANCE(514);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 658:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'h') ADVANCE(541);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 659:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'h') ADVANCE(521);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 660:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'h') ADVANCE(523);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 661:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'h') ADVANCE(524);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 662:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'h') ADVANCE(525);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 663:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'h') ADVANCE(539);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 664:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'h') ADVANCE(534);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 665:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'h') ADVANCE(628);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 666:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'h') ADVANCE(629);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 667:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'h') ADVANCE(630);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 668:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'h') ADVANCE(631);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 669:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'h') ADVANCE(632);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 670:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'h') ADVANCE(633);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 671:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'h') ADVANCE(634);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 672:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'h') ADVANCE(635);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 673:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'h') ADVANCE(636);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 674:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'i') ADVANCE(646);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 675:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'i') ADVANCE(767);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 676:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'i') ADVANCE(645);
      if (lookahead == 'o') ADVANCE(813);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 677:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'i') ADVANCE(511);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 678:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'i') ADVANCE(720);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 679:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'i') ADVANCE(712);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 680:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'i') ADVANCE(707);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 681:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'i') ADVANCE(648);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 682:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'i') ADVANCE(721);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 683:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'l') ADVANCE(559);
      if (lookahead == 'o') ADVANCE(691);
      if (lookahead == 'q') ADVANCE(824);
      if (lookahead == 'r') ADVANCE(559);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 684:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'l') ADVANCE(826);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 685:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'l') ADVANCE(511);
      if (lookahead == 'r') ADVANCE(511);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 686:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'l') ADVANCE(511);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 687:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'l') ADVANCE(517);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 688:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'l') ADVANCE(561);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 689:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'l') ADVANCE(618);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 690:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'l') ADVANCE(641);
      if (lookahead == 'r') ADVANCE(767);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 691:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'l') ADVANCE(505);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 692:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'l') ADVANCE(781);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 693:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'l') ADVANCE(512);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 694:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'l') ADVANCE(790);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 695:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'l') ADVANCE(513);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 696:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'l') ADVANCE(535);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 697:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'l') ADVANCE(515);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 698:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'l') ADVANCE(522);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 699:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'l') ADVANCE(538);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 700:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'l') ADVANCE(642);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 701:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'l') ADVANCE(830);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 702:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'l') ADVANCE(801);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 703:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'l') ADVANCE(838);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 704:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'l') ADVANCE(572);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 705:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'm') ADVANCE(511);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 706:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'n') ADVANCE(643);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 707:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'n') ADVANCE(511);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 708:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'n') ADVANCE(647);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 709:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'n') ADVANCE(506);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 710:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'n') ADVANCE(536);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 711:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'n') ADVANCE(514);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 712:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'n') ADVANCE(501);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 713:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'n') ADVANCE(541);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 714:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'n') ADVANCE(521);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 715:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'n') ADVANCE(523);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 716:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'n') ADVANCE(524);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 717:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'n') ADVANCE(525);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 718:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'n') ADVANCE(539);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 719:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'n') ADVANCE(534);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 720:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'n') ADVANCE(829);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 721:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'n') ADVANCE(830);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 722:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'n') ADVANCE(831);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 723:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'n') ADVANCE(832);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 724:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'n') ADVANCE(834);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 725:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'n') ADVANCE(837);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 726:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'n') ADVANCE(840);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 727:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'n') ADVANCE(841);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 728:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'n') ADVANCE(842);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 729:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'n') ADVANCE(843);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 730:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'n') ADVANCE(844);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 731:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'n') ADVANCE(644);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 732:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'o') ADVANCE(594);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 733:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'o') ADVANCE(705);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 734:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'o') ADVANCE(848);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 735:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'o') ADVANCE(640);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 736:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'o') ADVANCE(773);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 737:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'o') ADVANCE(818);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 738:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'o') ADVANCE(693);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 739:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'o') ADVANCE(695);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 740:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'o') ADVANCE(696);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 741:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'o') ADVANCE(697);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 742:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'o') ADVANCE(698);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 743:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'o') ADVANCE(699);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 744:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'p') ADVANCE(544);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 745:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'p') ADVANCE(41);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 746:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'p') ADVANCE(511);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 747:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'p') ADVANCE(653);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 748:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'p') ADVANCE(654);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 749:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'p') ADVANCE(568);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 750:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'p') ADVANCE(701);
      if (lookahead == 'q') ADVANCE(827);
      if (lookahead == 'x') ADVANCE(590);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 751:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'p') ADVANCE(701);
      if (lookahead == 'q') ADVANCE(847);
      if (lookahead == 'x') ADVANCE(590);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 752:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'p') ADVANCE(701);
      if (lookahead == 'u') ADVANCE(685);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 753:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'p') ADVANCE(701);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 754:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'p') ADVANCE(665);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 755:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'p') ADVANCE(666);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 756:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'p') ADVANCE(667);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 757:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'p') ADVANCE(668);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 758:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'p') ADVANCE(669);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 759:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'p') ADVANCE(670);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 760:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'p') ADVANCE(671);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 761:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'p') ADVANCE(672);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 762:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'p') ADVANCE(673);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 763:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'q') ADVANCE(846);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 764:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'r') ADVANCE(767);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 765:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'r') ADVANCE(550);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 766:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'r') ADVANCE(509);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 767:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'r') ADVANCE(511);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 768:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'r') ADVANCE(677);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 769:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'r') ADVANCE(638);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 770:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'r') ADVANCE(618);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 771:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'r') ADVANCE(746);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 772:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'r') ADVANCE(560);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 773:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'r') ADVANCE(817);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 774:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'r') ADVANCE(734);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 775:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'r') ADVANCE(774);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 776:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'r') ADVANCE(766);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 777:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'r') ADVANCE(579);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 778:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 's') ADVANCE(547);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 779:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 's') ADVANCE(503);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 780:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 's') ADVANCE(549);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 781:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 's') ADVANCE(511);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 782:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 's') ADVANCE(652);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 783:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 's') ADVANCE(519);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 784:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 's') ADVANCE(704);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 785:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 's') ADVANCE(818);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 786:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 's') ADVANCE(650);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 787:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 's') ADVANCE(506);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 788:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 's') ADVANCE(833);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 789:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 's') ADVANCE(819);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 790:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 's') ADVANCE(537);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 791:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 's') ADVANCE(536);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 792:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 's') ADVANCE(821);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 793:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 's') ADVANCE(514);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 794:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 's') ADVANCE(541);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 795:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 's') ADVANCE(521);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 796:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 's') ADVANCE(523);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 797:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 's') ADVANCE(524);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 798:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 's') ADVANCE(518);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 799:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 's') ADVANCE(525);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 800:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 's') ADVANCE(539);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 801:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 's') ADVANCE(540);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 802:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 's') ADVANCE(534);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 803:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 's') ADVANCE(656);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 804:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 's') ADVANCE(822);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 805:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 's') ADVANCE(657);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 806:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 's') ADVANCE(658);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 807:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 's') ADVANCE(659);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 808:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 's') ADVANCE(660);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 809:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 's') ADVANCE(661);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 810:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 's') ADVANCE(662);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 811:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 's') ADVANCE(663);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 812:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 's') ADVANCE(664);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 813:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 't') ADVANCE(510);
      if (lookahead == 'x') ADVANCE(752);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 814:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 't') ADVANCE(543);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 815:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 't') ADVANCE(567);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 816:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 't') ADVANCE(545);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 817:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 't') ADVANCE(546);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 818:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 't') ADVANCE(511);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 819:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 't') ADVANCE(517);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 820:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 't') ADVANCE(768);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 821:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 't') ADVANCE(527);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 822:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 't') ADVANCE(531);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 823:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 't') ADVANCE(568);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 824:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'u') ADVANCE(507);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 825:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'u') ADVANCE(622);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 826:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'u') ADVANCE(778);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 827:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'u') ADVANCE(569);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 828:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'u') ADVANCE(779);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 829:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'u') ADVANCE(780);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 830:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'u') ADVANCE(781);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 831:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'u') ADVANCE(787);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 832:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'u') ADVANCE(791);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 833:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'u') ADVANCE(769);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 834:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'u') ADVANCE(793);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 835:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'u') ADVANCE(783);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 836:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'u') ADVANCE(625);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 837:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'u') ADVANCE(794);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 838:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'u') ADVANCE(798);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 839:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'u') ADVANCE(571);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 840:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'u') ADVANCE(795);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 841:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'u') ADVANCE(796);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 842:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'u') ADVANCE(797);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 843:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'u') ADVANCE(799);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 844:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'u') ADVANCE(800);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 845:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'u') ADVANCE(802);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 846:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'u') ADVANCE(575);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 847:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'u') ADVANCE(577);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 848:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'w') ADVANCE(511);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 849:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'w') ADVANCE(576);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 850:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'x') ADVANCE(589);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 851:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'y') ADVANCE(748);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 852:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'y') ADVANCE(754);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 853:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'y') ADVANCE(755);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 854:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'y') ADVANCE(756);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 855:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'y') ADVANCE(757);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 856:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'y') ADVANCE(758);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 857:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'y') ADVANCE(759);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 858:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'y') ADVANCE(760);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 859:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'y') ADVANCE(761);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 860:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 0xfe0e) ADVANCE(2630);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 861:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(902);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 862:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(511);
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(511);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 863:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(511);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(511);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 864:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(511);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 865:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(505);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 866:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(512);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 867:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(513);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 868:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(535);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 869:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(515);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 870:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(522);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 871:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(538);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 872:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(884);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 873:
      ADVANCE_MAP(
        '\n', 1273,
        '\r', 1,
        'C', 516,
        'c', 516,
        'D', 537,
        'd', 537,
        'F', 517,
        'f', 517,
      );
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 874:
      ADVANCE_MAP(
        '\n', 1273,
        '\r', 1,
        'C', 516,
        'c', 516,
        'D', 540,
        'd', 540,
        'F', 517,
        'f', 517,
      );
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 875:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(511);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(511);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 876:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(867);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 877:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(871);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 878:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(511);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 879:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(504);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 880:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(502);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 881:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(520);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 882:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(518);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 883:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(529);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 884:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(526);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 885:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(533);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 886:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(878);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 887:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(511);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 888:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(370);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 889:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(879);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 890:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(881);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 891:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(882);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 892:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(511);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 893:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(454);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 894:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(154);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 895:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(456);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 896:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(457);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 897:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(458);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 898:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(460);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 899:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(464);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 900:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(468);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 901:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(2643);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 902:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(901);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 903:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '0' ||
          lookahead == 'O' ||
          lookahead == 'o') ADVANCE(2643);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 904:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '0' ||
          lookahead == 'O' ||
          lookahead == 'o') ADVANCE(2638);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 905:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '0' ||
          lookahead == 'O' ||
          lookahead == 'o') ADVANCE(2639);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 906:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '0' ||
          lookahead == 'O' ||
          lookahead == 'o') ADVANCE(2741);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 907:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(2658);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 908:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 909:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '&') ADVANCE(1205);
      if (lookahead == 0xbd) ADVANCE(2746);
      END_STATE();
    case 910:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '&') ADVANCE(1227);
      if (lookahead == '-' ||
          (0x2010 <= lookahead && lookahead <= 0x2014) ||
          lookahead == 0x2212 ||
          lookahead == 0x2796) ADVANCE(1241);
      END_STATE();
    case 911:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '&') ADVANCE(1230);
      if (lookahead == '/' ||
          lookahead == 0x2044 ||
          lookahead == 0x2215 ||
          lookahead == 0x27cb ||
          lookahead == 0x29f8) ADVANCE(1585);
      END_STATE();
    case 912:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '&') ADVANCE(1231);
      if (lookahead == '-' ||
          (0x2010 <= lookahead && lookahead <= 0x2014) ||
          lookahead == 0x2212 ||
          lookahead == 0x2796) ADVANCE(1434);
      END_STATE();
    case 913:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '&') ADVANCE(1235);
      if (lookahead == '-' ||
          (0x2010 <= lookahead && lookahead <= 0x2014) ||
          lookahead == 0x2212 ||
          lookahead == 0x2796) ADVANCE(1450);
      END_STATE();
    case 914:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '1') ADVANCE(2742);
      END_STATE();
    case 915:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '1') ADVANCE(1258);
      END_STATE();
    case 916:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '2') ADVANCE(1263);
      END_STATE();
    case 917:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '2') ADVANCE(2744);
      END_STATE();
    case 918:
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '0' ||
          lookahead == 'O' ||
          lookahead == 'o') ADVANCE(2740);
      END_STATE();
    case 919:
      if (lookahead == '\n') ADVANCE(2589);
      if (lookahead == '\r') ADVANCE(2582);
      if (lookahead == '&') ADVANCE(3);
      if (lookahead == 'A' ||
          lookahead == 'B' ||
          lookahead == 'a' ||
          lookahead == 'b') ADVANCE(921);
      if (lookahead == '-' ||
          (0x2010 <= lookahead && lookahead <= 0x2014) ||
          lookahead == 0x2212 ||
          lookahead == 0x2796) ADVANCE(904);
      if (lookahead == '.' ||
          lookahead == 0x660 ||
          lookahead == 0x6f0 ||
          lookahead == 0x701 ||
          lookahead == 0x702 ||
          lookahead == 0x200e ||
          lookahead == 0x2024 ||
          lookahead == 0xa4f8 ||
          lookahead == 0xa60e ||
          lookahead == 0x1d16d) ADVANCE(2583);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(920);
      if (set_contains(aux_sym_result_code_token22_character_set_1, 11, lookahead)) ADVANCE(2579);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 920:
      if (lookahead == '\n') ADVANCE(2589);
      if (lookahead == '\r') ADVANCE(2582);
      if (lookahead == 'A' ||
          lookahead == 'B' ||
          lookahead == 'a' ||
          lookahead == 'b') ADVANCE(921);
      if (lookahead == '.' ||
          lookahead == 0x660 ||
          lookahead == 0x6f0 ||
          lookahead == 0x701 ||
          lookahead == 0x702 ||
          lookahead == 0x200e ||
          lookahead == 0x2024 ||
          lookahead == 0xa4f8 ||
          lookahead == 0xa60e ||
          lookahead == 0x1d16d) ADVANCE(2583);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(920);
      if (set_contains(aux_sym_result_code_token22_character_set_1, 11, lookahead)) ADVANCE(2579);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 921:
      if (lookahead == '\n') ADVANCE(2589);
      if (lookahead == '\r') ADVANCE(2582);
      if (lookahead == '.' ||
          lookahead == 0x660 ||
          lookahead == 0x6f0 ||
          lookahead == 0x701 ||
          lookahead == 0x702 ||
          lookahead == 0x200e ||
          lookahead == 0x2024 ||
          lookahead == 0xa4f8 ||
          lookahead == 0xa60e ||
          lookahead == 0x1d16d) ADVANCE(2583);
      if (set_contains(sym_move_number_character_set_2, 19, lookahead)) ADVANCE(2579);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 922:
      ADVANCE_MAP(
        '\n', 1242,
        '\r', 923,
        '&', 14,
        '/', 926,
        0x2044, 926,
        0x2215, 926,
        0x27cb, 926,
        0x29f8, 926,
      );
      if (set_contains(aux_sym_annotation_token1_character_set_4, 16, lookahead)) ADVANCE(922);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 923:
      if (lookahead == '\n') ADVANCE(1242);
      if (lookahead == '&') ADVANCE(1215);
      if (lookahead == '/' ||
          lookahead == 0x2044 ||
          lookahead == 0x2215 ||
          lookahead == 0x27cb ||
          lookahead == 0x29f8) ADVANCE(1246);
      if (set_contains(aux_sym_annotation_token1_character_set_4, 16, lookahead)) ADVANCE(1243);
      END_STATE();
    case 924:
      ADVANCE_MAP(
        '\n', 1184,
        '\r', 925,
        '!', 2657,
        '$', 907,
        '&', 2,
        '(', 2563,
        '0', 919,
        ';', 2464,
        '<', 542,
        '=', 2652,
        '?', 2657,
        '@', 2633,
        'N', 2612,
        'P', 2625,
        'R', 2610,
        'T', 548,
        '[', 2475,
        'e', 2594,
        'p', 861,
        '{', 2567,
        0x221e, 2660,
        0x2659, 2628,
        0x265f, 860,
        'O', 28,
        'o', 28,
        'Z', 903,
        'z', 903,
        0x2e40, 2651,
        0xff1d, 2651,
        '+', 29,
        0x16ed, 29,
        0x2795, 29,
        '/', 30,
        0x2044, 30,
        0x2215, 30,
        0x27cb, 30,
        0x29f8, 30,
      );
      if (('a' <= lookahead && lookahead <= 'h')) ADVANCE(2595);
      if (lookahead == '-' ||
          (0x2010 <= lookahead && lookahead <= 0x2014) ||
          lookahead == 0x2212 ||
          lookahead == 0x2796) ADVANCE(2654);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(920);
      if (lookahead == 'B' ||
          lookahead == 'K' ||
          lookahead == 'Q' ||
          (0x2654 <= lookahead && lookahead <= 0x265e)) ADVANCE(2611);
      if (set_contains(aux_sym_result_code_token22_character_set_1, 11, lookahead)) ADVANCE(924);
      if (set_contains(aux_sym_annotation_token1_character_set_1, 54, lookahead)) ADVANCE(2659);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 925:
      if (lookahead == '\n') ADVANCE(1184);
      if (lookahead == '\r') SKIP(1185);
      if (lookahead == '!') ADVANCE(2657);
      if (lookahead == '$') ADVANCE(907);
      if (lookahead == '&') ADVANCE(2);
      if (lookahead == '(') ADVANCE(2563);
      if (lookahead == '0') ADVANCE(919);
      if (lookahead == ';') ADVANCE(2464);
      if (lookahead == '<') ADVANCE(542);
      if (lookahead == '=') ADVANCE(2652);
      if (lookahead == '?') ADVANCE(2657);
      if (lookahead == '@') ADVANCE(2633);
      if (lookahead == 'N') ADVANCE(2612);
      if (lookahead == 'P') ADVANCE(2625);
      if (lookahead == 'R') ADVANCE(2610);
      if (lookahead == 'T') ADVANCE(548);
      if (lookahead == '[') ADVANCE(2475);
      if (lookahead == 'e') ADVANCE(2594);
      if (lookahead == 'p') ADVANCE(861);
      if (lookahead == '{') ADVANCE(2567);
      if (lookahead == 0x221e) ADVANCE(2660);
      if (lookahead == 0x2659) ADVANCE(2628);
      if (lookahead == 0x265f) ADVANCE(860);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(28);
      if (lookahead == 'Z' ||
          lookahead == 'z') ADVANCE(903);
      if (lookahead == 0x2e40 ||
          lookahead == 0xff1d) ADVANCE(2651);
      if (lookahead == '+' ||
          lookahead == 0x16ed ||
          lookahead == 0x2795) ADVANCE(29);
      if (lookahead == '/' ||
          lookahead == 0x2044 ||
          lookahead == 0x2215 ||
          lookahead == 0x27cb ||
          lookahead == 0x29f8) ADVANCE(30);
      if (('a' <= lookahead && lookahead <= 'h')) ADVANCE(2595);
      if (lookahead == '-' ||
          (0x2010 <= lookahead && lookahead <= 0x2014) ||
          lookahead == 0x2212 ||
          lookahead == 0x2796) ADVANCE(2654);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(920);
      if (lookahead == 'B' ||
          lookahead == 'K' ||
          lookahead == 'Q' ||
          (0x2654 <= lookahead && lookahead <= 0x265e)) ADVANCE(2611);
      if (set_contains(aux_sym_result_code_token22_character_set_1, 11, lookahead)) ADVANCE(924);
      if (set_contains(aux_sym_annotation_token1_character_set_1, 54, lookahead)) ADVANCE(2659);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 926:
      if (lookahead == '\n') ADVANCE(1244);
      if (lookahead == '\r') ADVANCE(927);
      if (lookahead == '&') ADVANCE(6);
      if (lookahead == '=' ||
          lookahead == 0x2e40 ||
          lookahead == 0xff1d) ADVANCE(2659);
      if (set_contains(aux_sym_annotation_token1_character_set_7, 14, lookahead)) ADVANCE(926);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 927:
      if (lookahead == '\n') ADVANCE(1244);
      if (lookahead == '&') ADVANCE(1206);
      if (lookahead == '=' ||
          lookahead == 0x2e40 ||
          lookahead == 0xff1d) ADVANCE(2649);
      if (set_contains(aux_sym_annotation_token1_character_set_7, 14, lookahead)) ADVANCE(1246);
      END_STATE();
    case 928:
      if (lookahead == '\n') ADVANCE(2472);
      END_STATE();
    case 929:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      END_STATE();
    case 930:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(929);
      END_STATE();
    case 931:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(930);
      END_STATE();
    case 932:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(931);
      END_STATE();
    case 933:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(932);
      END_STATE();
    case 934:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(933);
      END_STATE();
    case 935:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(934);
      END_STATE();
    case 936:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(935);
      END_STATE();
    case 937:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(936);
      END_STATE();
    case 938:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(937);
      END_STATE();
    case 939:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(938);
      END_STATE();
    case 940:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(939);
      END_STATE();
    case 941:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(940);
      END_STATE();
    case 942:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(941);
      END_STATE();
    case 943:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(942);
      END_STATE();
    case 944:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(943);
      END_STATE();
    case 945:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(944);
      END_STATE();
    case 946:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(945);
      END_STATE();
    case 947:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(946);
      END_STATE();
    case 948:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(947);
      END_STATE();
    case 949:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(948);
      END_STATE();
    case 950:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(949);
      END_STATE();
    case 951:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(950);
      END_STATE();
    case 952:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(951);
      END_STATE();
    case 953:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(952);
      END_STATE();
    case 954:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(953);
      END_STATE();
    case 955:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(954);
      END_STATE();
    case 956:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(955);
      END_STATE();
    case 957:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(956);
      END_STATE();
    case 958:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(957);
      END_STATE();
    case 959:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(958);
      END_STATE();
    case 960:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(959);
      END_STATE();
    case 961:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(960);
      END_STATE();
    case 962:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(961);
      END_STATE();
    case 963:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(962);
      END_STATE();
    case 964:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(963);
      END_STATE();
    case 965:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(964);
      END_STATE();
    case 966:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(965);
      END_STATE();
    case 967:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(966);
      END_STATE();
    case 968:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(967);
      END_STATE();
    case 969:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(968);
      END_STATE();
    case 970:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(969);
      END_STATE();
    case 971:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(970);
      END_STATE();
    case 972:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(971);
      END_STATE();
    case 973:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(972);
      END_STATE();
    case 974:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(973);
      END_STATE();
    case 975:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(974);
      END_STATE();
    case 976:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(975);
      END_STATE();
    case 977:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(976);
      END_STATE();
    case 978:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(977);
      END_STATE();
    case 979:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(978);
      END_STATE();
    case 980:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(979);
      END_STATE();
    case 981:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(980);
      END_STATE();
    case 982:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(981);
      END_STATE();
    case 983:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(982);
      END_STATE();
    case 984:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(983);
      END_STATE();
    case 985:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(984);
      END_STATE();
    case 986:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(985);
      END_STATE();
    case 987:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(986);
      END_STATE();
    case 988:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(987);
      END_STATE();
    case 989:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(988);
      END_STATE();
    case 990:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(989);
      END_STATE();
    case 991:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(990);
      END_STATE();
    case 992:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(991);
      END_STATE();
    case 993:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(992);
      END_STATE();
    case 994:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(993);
      END_STATE();
    case 995:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(994);
      END_STATE();
    case 996:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(995);
      END_STATE();
    case 997:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(996);
      END_STATE();
    case 998:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(997);
      END_STATE();
    case 999:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(998);
      END_STATE();
    case 1000:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(999);
      END_STATE();
    case 1001:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(1000);
      END_STATE();
    case 1002:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(1001);
      END_STATE();
    case 1003:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(1002);
      END_STATE();
    case 1004:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(1003);
      END_STATE();
    case 1005:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(1004);
      END_STATE();
    case 1006:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(1005);
      END_STATE();
    case 1007:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(1006);
      END_STATE();
    case 1008:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(1007);
      END_STATE();
    case 1009:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(1008);
      END_STATE();
    case 1010:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(1009);
      END_STATE();
    case 1011:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(1010);
      END_STATE();
    case 1012:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(1011);
      END_STATE();
    case 1013:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(1012);
      END_STATE();
    case 1014:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(1013);
      END_STATE();
    case 1015:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(1014);
      END_STATE();
    case 1016:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(1015);
      END_STATE();
    case 1017:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(1016);
      END_STATE();
    case 1018:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(1017);
      END_STATE();
    case 1019:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(1018);
      END_STATE();
    case 1020:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(1019);
      END_STATE();
    case 1021:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(1020);
      END_STATE();
    case 1022:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(1021);
      END_STATE();
    case 1023:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(1022);
      END_STATE();
    case 1024:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(1023);
      END_STATE();
    case 1025:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(1024);
      END_STATE();
    case 1026:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(1025);
      END_STATE();
    case 1027:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(1026);
      END_STATE();
    case 1028:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(1027);
      END_STATE();
    case 1029:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(1028);
      END_STATE();
    case 1030:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(1029);
      END_STATE();
    case 1031:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(1030);
      END_STATE();
    case 1032:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(1031);
      END_STATE();
    case 1033:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(1032);
      END_STATE();
    case 1034:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(1033);
      END_STATE();
    case 1035:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(1034);
      END_STATE();
    case 1036:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(1035);
      END_STATE();
    case 1037:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(1036);
      END_STATE();
    case 1038:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(1037);
      END_STATE();
    case 1039:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(1038);
      END_STATE();
    case 1040:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(1039);
      END_STATE();
    case 1041:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(1040);
      END_STATE();
    case 1042:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(1041);
      END_STATE();
    case 1043:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(1042);
      END_STATE();
    case 1044:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(1043);
      END_STATE();
    case 1045:
      if (lookahead == '\n') ADVANCE(2472);
      if (lookahead == '\r') ADVANCE(928);
      if (lookahead == '-') ADVANCE(1044);
      END_STATE();
    case 1046:
      if (lookahead == '\n') ADVANCE(2473);
      END_STATE();
    case 1047:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1163);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1048:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1047);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1049:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1048);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1050:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1049);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1051:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1050);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1052:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1051);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1053:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1052);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1054:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1053);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1055:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1054);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1056:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1055);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1057:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1056);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1058:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1057);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1059:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1058);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1060:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1059);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1061:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1060);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1062:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1061);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1063:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1062);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1064:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1063);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1065:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1064);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1066:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1065);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1067:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1066);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1068:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1067);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1069:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1068);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1070:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1069);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1071:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1070);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1072:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1071);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1073:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1072);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1074:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1073);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1075:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1074);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1076:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1075);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1077:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1076);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1078:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1077);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1079:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1078);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1080:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1079);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1081:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1080);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1082:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1081);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1083:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1082);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1084:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1083);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1085:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1084);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1086:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1085);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1087:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1086);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1088:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1087);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1089:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1088);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1090:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1089);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1091:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1090);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1092:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1091);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1093:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1092);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1094:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1093);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1095:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1094);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1096:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1095);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1097:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1096);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1098:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1097);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1099:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1098);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1100:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1099);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1101:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1100);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1102:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1101);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1103:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1102);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1104:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1103);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1105:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1104);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1106:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1105);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1107:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1106);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1108:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1107);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1109:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1108);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1110:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1109);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1111:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1110);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1112:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1111);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1113:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1112);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1114:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1113);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1115:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1114);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1116:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1115);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1117:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1116);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1118:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1117);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1119:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1118);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1120:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1119);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1121:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1120);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1122:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1121);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1123:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1122);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1124:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1123);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1125:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1124);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1126:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1125);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1127:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1126);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1128:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1127);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1129:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1128);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1130:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1129);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1131:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1130);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1132:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1131);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1133:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1132);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1134:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1133);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1135:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1134);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1136:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1135);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1137:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1136);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1138:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1137);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1139:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1138);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1140:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1139);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1141:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1140);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1142:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1141);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1143:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1142);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1144:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1143);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1145:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1144);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1146:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1145);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1147:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1146);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1148:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1147);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1149:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1148);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1150:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1149);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1151:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1150);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1152:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1151);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1153:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1152);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1154:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1153);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1155:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1154);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1156:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1155);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1157:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1156);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1158:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1157);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1159:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1158);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1160:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1159);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1161:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1160);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1162:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead == '-') ADVANCE(1161);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1163:
      if (lookahead == '\n') ADVANCE(2473);
      if (lookahead == '\r') ADVANCE(1046);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1164:
      ADVANCE_MAP(
        '\n', 1186,
        '\r', 1165,
        '!', 2657,
        '$', 907,
        '&', 18,
        '(', 2563,
        ')', 2565,
        '*', 2721,
        '0', 2695,
        '1', 2671,
        ';', 2464,
        '<', 542,
        '=', 2652,
        '?', 2657,
        '@', 2633,
        'N', 2612,
        'O', 2691,
        'P', 2625,
        'R', 2610,
        'T', 548,
        '[', 2475,
        'e', 2594,
        'o', 2700,
        'p', 861,
        '{', 2567,
        '}', 2569,
        0xbd, 2715,
        0x66d, 2737,
        0x204e, 2733,
        0x2217, 2725,
        0x221e, 2660,
        0x2659, 2628,
        0x265f, 860,
        0x2731, 2729,
        'Z', 903,
        'z', 903,
        0x2e40, 2651,
        0xff1d, 2651,
        '+', 29,
        0x16ed, 29,
        0x2795, 29,
        '/', 30,
        0x2044, 30,
        0x2215, 30,
        0x27cb, 30,
        0x29f8, 30,
      );
      if (('a' <= lookahead && lookahead <= 'h')) ADVANCE(2595);
      if (lookahead == '-' ||
          (0x2010 <= lookahead && lookahead <= 0x2014) ||
          lookahead == 0x2212 ||
          lookahead == 0x2796) ADVANCE(2654);
      if (('2' <= lookahead && lookahead <= '9')) ADVANCE(920);
      if (lookahead == 'B' ||
          lookahead == 'K' ||
          lookahead == 'Q' ||
          (0x2654 <= lookahead && lookahead <= 0x265e)) ADVANCE(2611);
      if (set_contains(aux_sym_result_code_token23_character_set_1, 12, lookahead)) ADVANCE(1164);
      if (set_contains(aux_sym_annotation_token1_character_set_1, 54, lookahead)) ADVANCE(2659);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1165:
      if (lookahead == '\n') ADVANCE(1186);
      if (lookahead == '\r') SKIP(1187);
      if (lookahead == '!') ADVANCE(2657);
      if (lookahead == '$') ADVANCE(907);
      if (lookahead == '&') ADVANCE(18);
      if (lookahead == '(') ADVANCE(2563);
      if (lookahead == ')') ADVANCE(2565);
      if (lookahead == '*') ADVANCE(2721);
      if (lookahead == '0') ADVANCE(2695);
      if (lookahead == '1') ADVANCE(2671);
      if (lookahead == ';') ADVANCE(2464);
      if (lookahead == '<') ADVANCE(542);
      if (lookahead == '=') ADVANCE(2652);
      if (lookahead == '?') ADVANCE(2657);
      if (lookahead == '@') ADVANCE(2633);
      if (lookahead == 'N') ADVANCE(2612);
      if (lookahead == 'O') ADVANCE(2691);
      if (lookahead == 'P') ADVANCE(2625);
      if (lookahead == 'R') ADVANCE(2610);
      if (lookahead == 'T') ADVANCE(548);
      if (lookahead == '[') ADVANCE(2475);
      if (lookahead == 'e') ADVANCE(2594);
      if (lookahead == 'o') ADVANCE(2700);
      if (lookahead == 'p') ADVANCE(861);
      if (lookahead == '{') ADVANCE(2567);
      if (lookahead == '}') ADVANCE(2569);
      if (lookahead == 0xbd) ADVANCE(2715);
      if (lookahead == 0x66d) ADVANCE(2737);
      if (lookahead == 0x204e) ADVANCE(2733);
      if (lookahead == 0x2217) ADVANCE(2725);
      if (lookahead == 0x221e) ADVANCE(2660);
      if (lookahead == 0x2659) ADVANCE(2628);
      if (lookahead == 0x265f) ADVANCE(860);
      if (lookahead == 0x2731) ADVANCE(2729);
      if (lookahead == 'Z' ||
          lookahead == 'z') ADVANCE(903);
      if (lookahead == 0x2e40 ||
          lookahead == 0xff1d) ADVANCE(2651);
      if (lookahead == '+' ||
          lookahead == 0x16ed ||
          lookahead == 0x2795) ADVANCE(29);
      if (lookahead == '/' ||
          lookahead == 0x2044 ||
          lookahead == 0x2215 ||
          lookahead == 0x27cb ||
          lookahead == 0x29f8) ADVANCE(30);
      if (('a' <= lookahead && lookahead <= 'h')) ADVANCE(2595);
      if (lookahead == '-' ||
          (0x2010 <= lookahead && lookahead <= 0x2014) ||
          lookahead == 0x2212 ||
          lookahead == 0x2796) ADVANCE(2654);
      if (('2' <= lookahead && lookahead <= '9')) ADVANCE(920);
      if (lookahead == 'B' ||
          lookahead == 'K' ||
          lookahead == 'Q' ||
          (0x2654 <= lookahead && lookahead <= 0x265e)) ADVANCE(2611);
      if (set_contains(aux_sym_result_code_token23_character_set_1, 12, lookahead)) ADVANCE(1164);
      if (set_contains(aux_sym_annotation_token1_character_set_1, 54, lookahead)) ADVANCE(2659);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1166:
      if (lookahead == '\n') ADVANCE(1274);
      if (lookahead == '\r') ADVANCE(914);
      if (lookahead == '1') ADVANCE(2743);
      if (lookahead == '0' ||
          lookahead == 'O' ||
          lookahead == 'o') ADVANCE(2638);
      if (set_contains(aux_sym_result_code_token21_character_set_1, 11, lookahead)) ADVANCE(160);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1167:
      if (lookahead == '\n') ADVANCE(1274);
      if (lookahead == '\r') ADVANCE(914);
      if (lookahead == '1') ADVANCE(2743);
      if (set_contains(aux_sym_result_code_token21_character_set_1, 11, lookahead)) ADVANCE(160);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1168:
      if (lookahead == '\n') ADVANCE(1276);
      if (lookahead == '\r') ADVANCE(916);
      if (lookahead == '2') ADVANCE(1182);
      if (set_contains(aux_sym_result_code_token22_character_set_1, 11, lookahead)) ADVANCE(258);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1169:
      if (lookahead == '\n') ADVANCE(1278);
      if (lookahead == '\r') ADVANCE(918);
      if (lookahead == '0' ||
          lookahead == 'O' ||
          lookahead == 'o') ADVANCE(2741);
      if (set_contains(aux_sym_result_code_token20_character_set_2, 13, lookahead)) ADVANCE(906);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1170:
      if (lookahead == '\n') ADVANCE(1239);
      if (lookahead == '\r') ADVANCE(909);
      if (lookahead == '&') ADVANCE(12);
      if (lookahead == 0xbd) ADVANCE(2747);
      if (set_contains(aux_sym_result_code_token23_character_set_1, 12, lookahead)) ADVANCE(33);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1171:
      ADVANCE_MAP(
        '\n', 1256,
        '\r', 911,
        '&', 22,
        '/', 1177,
        0x2044, 1177,
        0x2215, 1177,
        0x27cb, 1177,
        0x29f8, 1177,
      );
      if (set_contains(aux_sym_annotation_token1_character_set_4, 16, lookahead)) ADVANCE(36);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1172:
      ADVANCE_MAP(
        '\n', 2461,
        '\r', 1178,
        '!', 2668,
        '$', 2446,
        '&', 1207,
        '(', 2562,
        '*', 2720,
        '0', 2696,
        '1', 2672,
        ';', 2463,
        '<', 1984,
        '=', 2663,
        '?', 2668,
        '@', 2632,
        'N', 2614,
        'O', 2692,
        'P', 2626,
        'R', 2613,
        'T', 1990,
        '[', 2474,
        ']', 2478,
        'e', 2596,
        'o', 2701,
        'p', 2379,
        '{', 2566,
        0xbd, 2716,
        0x66d, 2736,
        0x204e, 2732,
        0x2217, 2724,
        0x221e, 2661,
        0x2659, 2627,
        0x265f, 2378,
        0x2731, 2728,
        'Z', 2443,
        'z', 2443,
        0x2e40, 2662,
        0xff1d, 2662,
        '+', 1248,
        0x16ed, 1248,
        0x2795, 1248,
        '/', 1245,
        0x2044, 1245,
        0x2215, 1245,
        0x27cb, 1245,
        0x29f8, 1245,
      );
      if (('a' <= lookahead && lookahead <= 'h')) ADVANCE(2593);
      if (lookahead == '-' ||
          (0x2010 <= lookahead && lookahead <= 0x2014) ||
          lookahead == 0x2212 ||
          lookahead == 0x2796) ADVANCE(2664);
      if (('2' <= lookahead && lookahead <= '9')) ADVANCE(2444);
      if (lookahead == 'B' ||
          lookahead == 'K' ||
          lookahead == 'Q' ||
          (0x2654 <= lookahead && lookahead <= 0x265e)) ADVANCE(2609);
      if (set_contains(aux_sym_result_code_token23_character_set_1, 12, lookahead)) SKIP(1178);
      if (set_contains(aux_sym_annotation_token1_character_set_1, 54, lookahead)) ADVANCE(2649);
      END_STATE();
    case 1173:
      ADVANCE_MAP(
        '\n', 2461,
        '\r', 1172,
        '!', 2668,
        '$', 2446,
        '&', 1207,
        '(', 2562,
        '*', 2720,
        '0', 2696,
        '1', 2672,
        ';', 2463,
        '<', 1984,
        '=', 2663,
        '?', 2668,
        '@', 2632,
        'N', 2614,
        'O', 2692,
        'P', 2626,
        'R', 2613,
        'T', 1990,
        '[', 2474,
        ']', 2478,
        'e', 2596,
        'o', 2701,
        'p', 2379,
        '{', 2566,
        0xbd, 2716,
        0x66d, 2736,
        0x204e, 2732,
        0x2217, 2724,
        0x221e, 2661,
        0x2659, 2627,
        0x265f, 2378,
        0x2731, 2728,
        'Z', 2443,
        'z', 2443,
        0x2e40, 2662,
        0xff1d, 2662,
        '+', 1248,
        0x16ed, 1248,
        0x2795, 1248,
        '/', 1245,
        0x2044, 1245,
        0x2215, 1245,
        0x27cb, 1245,
        0x29f8, 1245,
      );
      if (('a' <= lookahead && lookahead <= 'h')) ADVANCE(2593);
      if (lookahead == '-' ||
          (0x2010 <= lookahead && lookahead <= 0x2014) ||
          lookahead == 0x2212 ||
          lookahead == 0x2796) ADVANCE(2664);
      if (('2' <= lookahead && lookahead <= '9')) ADVANCE(2444);
      if (lookahead == 'B' ||
          lookahead == 'K' ||
          lookahead == 'Q' ||
          (0x2654 <= lookahead && lookahead <= 0x265e)) ADVANCE(2609);
      if (set_contains(aux_sym_result_code_token23_character_set_1, 12, lookahead)) SKIP(1178);
      if (set_contains(aux_sym_annotation_token1_character_set_1, 54, lookahead)) ADVANCE(2649);
      END_STATE();
    case 1174:
      ADVANCE_MAP(
        '\n', 2466,
        '\r', 1174,
        '!', 2657,
        '$', 907,
        '&', 18,
        '(', 2563,
        ')', 2565,
        '*', 2721,
        '0', 2695,
        '1', 2671,
        ';', 2464,
        '<', 542,
        '=', 2652,
        '?', 2657,
        '@', 2633,
        'N', 2612,
        'O', 2691,
        'P', 2625,
        'R', 2610,
        'T', 548,
        '[', 2475,
        'e', 2594,
        'o', 2700,
        'p', 861,
        '{', 2567,
        '}', 2569,
        0xbd, 2715,
        0x66d, 2737,
        0x204e, 2733,
        0x2217, 2725,
        0x221e, 2660,
        0x2659, 2628,
        0x265f, 860,
        0x2731, 2729,
        'Z', 903,
        'z', 903,
        0x2e40, 2651,
        0xff1d, 2651,
        '+', 29,
        0x16ed, 29,
        0x2795, 29,
        '/', 30,
        0x2044, 30,
        0x2215, 30,
        0x27cb, 30,
        0x29f8, 30,
      );
      if (('a' <= lookahead && lookahead <= 'h')) ADVANCE(2595);
      if (lookahead == '-' ||
          (0x2010 <= lookahead && lookahead <= 0x2014) ||
          lookahead == 0x2212 ||
          lookahead == 0x2796) ADVANCE(2654);
      if (('2' <= lookahead && lookahead <= '9')) ADVANCE(920);
      if (lookahead == 'B' ||
          lookahead == 'K' ||
          lookahead == 'Q' ||
          (0x2654 <= lookahead && lookahead <= 0x265e)) ADVANCE(2611);
      if (set_contains(aux_sym_result_code_token23_character_set_1, 12, lookahead)) ADVANCE(1174);
      if (set_contains(aux_sym_annotation_token1_character_set_1, 54, lookahead)) ADVANCE(2659);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1175:
      ADVANCE_MAP(
        '\n', 2467,
        '\r', 1175,
        '!', 2668,
        '$', 2446,
        '&', 1207,
        '(', 2562,
        ')', 2564,
        '*', 2720,
        '0', 2696,
        '1', 2672,
        ';', 2463,
        '<', 1984,
        '=', 2663,
        '?', 2668,
        '@', 2632,
        'N', 2614,
        'O', 2692,
        'P', 2626,
        'R', 2613,
        'T', 1990,
        'e', 2596,
        'o', 2701,
        'p', 2379,
        '{', 2566,
        '}', 2568,
        0xbd, 2716,
        0x66d, 2736,
        0x204e, 2732,
        0x2217, 2724,
        0x221e, 2661,
        0x2659, 2627,
        0x265f, 2378,
        0x2731, 2728,
        'Z', 2443,
        'z', 2443,
        0x2e40, 2662,
        0xff1d, 2662,
        '+', 1248,
        0x16ed, 1248,
        0x2795, 1248,
        '/', 1245,
        0x2044, 1245,
        0x2215, 1245,
        0x27cb, 1245,
        0x29f8, 1245,
      );
      if (('a' <= lookahead && lookahead <= 'h')) ADVANCE(2593);
      if (lookahead == '-' ||
          (0x2010 <= lookahead && lookahead <= 0x2014) ||
          lookahead == 0x2212 ||
          lookahead == 0x2796) ADVANCE(2664);
      if (('2' <= lookahead && lookahead <= '9')) ADVANCE(2444);
      if (lookahead == 'B' ||
          lookahead == 'K' ||
          lookahead == 'Q' ||
          (0x2654 <= lookahead && lookahead <= 0x265e)) ADVANCE(2609);
      if (set_contains(aux_sym_result_code_token23_character_set_1, 12, lookahead)) SKIP(1175);
      if (set_contains(aux_sym_annotation_token1_character_set_1, 54, lookahead)) ADVANCE(2649);
      END_STATE();
    case 1176:
      if (lookahead == '\n') ADVANCE(1275);
      if (lookahead == '\r') ADVANCE(915);
      if (lookahead == '1') ADVANCE(1171);
      if (set_contains(aux_sym_result_code_token21_character_set_1, 11, lookahead)) ADVANCE(161);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1177:
      if (lookahead == '\n') ADVANCE(1277);
      if (lookahead == '\r') ADVANCE(917);
      if (lookahead == '2') ADVANCE(2745);
      if (set_contains(aux_sym_result_code_token22_character_set_1, 11, lookahead)) ADVANCE(261);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1178:
      ADVANCE_MAP(
        '\n', 1173,
        '\r', 1178,
        '!', 2668,
        '$', 2446,
        '&', 1207,
        '(', 2562,
        '*', 2720,
        '0', 2696,
        '1', 2672,
        ';', 2463,
        '<', 1984,
        '=', 2663,
        '?', 2668,
        '@', 2632,
        'N', 2614,
        'O', 2692,
        'P', 2626,
        'R', 2613,
        'T', 1990,
        '[', 2474,
        ']', 2478,
        'e', 2596,
        'o', 2701,
        'p', 2379,
        '{', 2566,
        0xbd, 2716,
        0x66d, 2736,
        0x204e, 2732,
        0x2217, 2724,
        0x221e, 2661,
        0x2659, 2627,
        0x265f, 2378,
        0x2731, 2728,
        'Z', 2443,
        'z', 2443,
        0x2e40, 2662,
        0xff1d, 2662,
        '+', 1248,
        0x16ed, 1248,
        0x2795, 1248,
        '/', 1245,
        0x2044, 1245,
        0x2215, 1245,
        0x27cb, 1245,
        0x29f8, 1245,
      );
      if (('a' <= lookahead && lookahead <= 'h')) ADVANCE(2593);
      if (lookahead == '-' ||
          (0x2010 <= lookahead && lookahead <= 0x2014) ||
          lookahead == 0x2212 ||
          lookahead == 0x2796) ADVANCE(2664);
      if (('2' <= lookahead && lookahead <= '9')) ADVANCE(2444);
      if (lookahead == 'B' ||
          lookahead == 'K' ||
          lookahead == 'Q' ||
          (0x2654 <= lookahead && lookahead <= 0x265e)) ADVANCE(2609);
      if (set_contains(aux_sym_result_code_token23_character_set_1, 12, lookahead)) SKIP(1178);
      if (set_contains(aux_sym_annotation_token1_character_set_1, 54, lookahead)) ADVANCE(2649);
      END_STATE();
    case 1179:
      ADVANCE_MAP(
        '\n', 2462,
        '\r', 1181,
        '!', 2668,
        '$', 2446,
        '&', 1207,
        '(', 2562,
        '*', 2720,
        '0', 2696,
        '1', 2672,
        ';', 2463,
        '<', 1984,
        '=', 2663,
        '?', 2668,
        '@', 2632,
        'N', 2614,
        'O', 2692,
        'P', 2626,
        'R', 2613,
        'T', 1990,
        '[', 2474,
        'e', 2596,
        'o', 2701,
        'p', 2379,
        '{', 2566,
        0xbd, 2716,
        0x66d, 2736,
        0x204e, 2732,
        0x2217, 2724,
        0x221e, 2661,
        0x2659, 2627,
        0x265f, 2378,
        0x2731, 2728,
        'Z', 2443,
        'z', 2443,
        0x2e40, 2662,
        0xff1d, 2662,
        '+', 1248,
        0x16ed, 1248,
        0x2795, 1248,
        '/', 1245,
        0x2044, 1245,
        0x2215, 1245,
        0x27cb, 1245,
        0x29f8, 1245,
      );
      if (('a' <= lookahead && lookahead <= 'h')) ADVANCE(2593);
      if (lookahead == '-' ||
          (0x2010 <= lookahead && lookahead <= 0x2014) ||
          lookahead == 0x2212 ||
          lookahead == 0x2796) ADVANCE(2664);
      if (('2' <= lookahead && lookahead <= '9')) ADVANCE(2444);
      if (lookahead == 'B' ||
          lookahead == 'K' ||
          lookahead == 'Q' ||
          (0x2654 <= lookahead && lookahead <= 0x265e)) ADVANCE(2609);
      if (set_contains(aux_sym_result_code_token23_character_set_1, 12, lookahead)) SKIP(1181);
      if (set_contains(aux_sym_annotation_token1_character_set_1, 54, lookahead)) ADVANCE(2649);
      END_STATE();
    case 1180:
      ADVANCE_MAP(
        '\n', 2469,
        '\r', 1180,
        '!', 2657,
        '$', 907,
        '&', 2,
        '(', 2563,
        '0', 919,
        ';', 2464,
        '<', 542,
        '=', 2652,
        '?', 2657,
        '@', 2633,
        'N', 2612,
        'P', 2625,
        'R', 2610,
        'T', 548,
        '[', 2475,
        'e', 2594,
        'p', 861,
        '{', 2567,
        0x221e, 2660,
        0x2659, 2628,
        0x265f, 860,
        'O', 28,
        'o', 28,
        'Z', 903,
        'z', 903,
        0x2e40, 2651,
        0xff1d, 2651,
        '+', 29,
        0x16ed, 29,
        0x2795, 29,
        '/', 30,
        0x2044, 30,
        0x2215, 30,
        0x27cb, 30,
        0x29f8, 30,
      );
      if (('a' <= lookahead && lookahead <= 'h')) ADVANCE(2595);
      if (lookahead == '-' ||
          (0x2010 <= lookahead && lookahead <= 0x2014) ||
          lookahead == 0x2212 ||
          lookahead == 0x2796) ADVANCE(2654);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(920);
      if (lookahead == 'B' ||
          lookahead == 'K' ||
          lookahead == 'Q' ||
          (0x2654 <= lookahead && lookahead <= 0x265e)) ADVANCE(2611);
      if (set_contains(aux_sym_result_code_token22_character_set_1, 11, lookahead)) ADVANCE(1180);
      if (set_contains(aux_sym_annotation_token1_character_set_1, 54, lookahead)) ADVANCE(2659);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1181:
      ADVANCE_MAP(
        '\n', 2468,
        '\r', 1181,
        '!', 2668,
        '$', 2446,
        '&', 1207,
        '(', 2562,
        '*', 2720,
        '0', 2696,
        '1', 2672,
        ';', 2463,
        '<', 1984,
        '=', 2663,
        '?', 2668,
        '@', 2632,
        'N', 2614,
        'O', 2692,
        'P', 2626,
        'R', 2613,
        'T', 1990,
        '[', 2474,
        'e', 2596,
        'o', 2701,
        'p', 2379,
        '{', 2566,
        0xbd, 2716,
        0x66d, 2736,
        0x204e, 2732,
        0x2217, 2724,
        0x221e, 2661,
        0x2659, 2627,
        0x265f, 2378,
        0x2731, 2728,
        'Z', 2443,
        'z', 2443,
        0x2e40, 2662,
        0xff1d, 2662,
        '+', 1248,
        0x16ed, 1248,
        0x2795, 1248,
        '/', 1245,
        0x2044, 1245,
        0x2215, 1245,
        0x27cb, 1245,
        0x29f8, 1245,
      );
      if (('a' <= lookahead && lookahead <= 'h')) ADVANCE(2593);
      if (lookahead == '-' ||
          (0x2010 <= lookahead && lookahead <= 0x2014) ||
          lookahead == 0x2212 ||
          lookahead == 0x2796) ADVANCE(2664);
      if (('2' <= lookahead && lookahead <= '9')) ADVANCE(2444);
      if (lookahead == 'B' ||
          lookahead == 'K' ||
          lookahead == 'Q' ||
          (0x2654 <= lookahead && lookahead <= 0x265e)) ADVANCE(2609);
      if (set_contains(aux_sym_result_code_token23_character_set_1, 12, lookahead)) SKIP(1181);
      if (set_contains(aux_sym_annotation_token1_character_set_1, 54, lookahead)) ADVANCE(2649);
      END_STATE();
    case 1182:
      if (lookahead == '\n') ADVANCE(1261);
      if (lookahead == '\r') ADVANCE(913);
      if (lookahead == '&') ADVANCE(27);
      if (lookahead == '-' ||
          (0x2010 <= lookahead && lookahead <= 0x2014) ||
          lookahead == 0x2212 ||
          lookahead == 0x2796) ADVANCE(1176);
      if (set_contains(aux_sym_result_code_token20_character_set_1, 15, lookahead)) ADVANCE(39);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1183:
      ADVANCE_MAP(
        '\n', 2470,
        '\r', 1183,
        '!', 2668,
        '$', 2446,
        '&', 1223,
        '(', 2562,
        ')', 2564,
        '0', 1265,
        ';', 2463,
        '<', 1984,
        '=', 2663,
        '?', 2668,
        '@', 2632,
        'N', 2614,
        'P', 2626,
        'R', 2613,
        'T', 1990,
        'e', 2596,
        'p', 2379,
        '{', 2566,
        0x221e, 2661,
        0x2659, 2627,
        0x265f, 2378,
        'O', 1266,
        'o', 1266,
        'Z', 2443,
        'z', 2443,
        0x2e40, 2662,
        0xff1d, 2662,
        '+', 1248,
        0x16ed, 1248,
        0x2795, 1248,
        '/', 1245,
        0x2044, 1245,
        0x2215, 1245,
        0x27cb, 1245,
        0x29f8, 1245,
      );
      if (('a' <= lookahead && lookahead <= 'h')) ADVANCE(2593);
      if (lookahead == '-' ||
          (0x2010 <= lookahead && lookahead <= 0x2014) ||
          lookahead == 0x2212 ||
          lookahead == 0x2796) ADVANCE(2664);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(2444);
      if (lookahead == 'B' ||
          lookahead == 'K' ||
          lookahead == 'Q' ||
          (0x2654 <= lookahead && lookahead <= 0x265e)) ADVANCE(2609);
      if (set_contains(aux_sym_result_code_token22_character_set_1, 11, lookahead)) SKIP(1183);
      if (set_contains(aux_sym_annotation_token1_character_set_1, 54, lookahead)) ADVANCE(2649);
      END_STATE();
    case 1184:
      ADVANCE_MAP(
        '!', 2657,
        '$', 907,
        '&', 2,
        '(', 2563,
        '-', 2653,
        '0', 919,
        ';', 2464,
        '<', 542,
        '=', 2652,
        '?', 2657,
        '@', 2633,
        'N', 2612,
        'P', 2625,
        'R', 2610,
        'T', 548,
        '[', 2475,
        'e', 2594,
        'p', 861,
        '{', 2567,
        0x221e, 2660,
        0x2659, 2628,
        0x265f, 860,
      );
      if (lookahead == '\n' ||
          lookahead == '\r') SKIP(1185);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(28);
      if (lookahead == 'Z' ||
          lookahead == 'z') ADVANCE(903);
      if (lookahead == 0x2e40 ||
          lookahead == 0xff1d) ADVANCE(2651);
      if (lookahead == '+' ||
          lookahead == 0x16ed ||
          lookahead == 0x2795) ADVANCE(29);
      if (lookahead == '/' ||
          lookahead == 0x2044 ||
          lookahead == 0x2215 ||
          lookahead == 0x27cb ||
          lookahead == 0x29f8) ADVANCE(30);
      if (('a' <= lookahead && lookahead <= 'h')) ADVANCE(2595);
      if ((0x2010 <= lookahead && lookahead <= 0x2014) ||
          lookahead == 0x2212 ||
          lookahead == 0x2796) ADVANCE(2654);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(920);
      if (lookahead == 'B' ||
          lookahead == 'K' ||
          lookahead == 'Q' ||
          (0x2654 <= lookahead && lookahead <= 0x265e)) ADVANCE(2611);
      if (set_contains(aux_sym_result_code_token22_character_set_1, 11, lookahead)) ADVANCE(924);
      if (set_contains(aux_sym_annotation_token1_character_set_1, 54, lookahead)) ADVANCE(2659);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1185:
      ADVANCE_MAP(
        '!', 2657,
        '$', 907,
        '&', 2,
        '(', 2563,
        '0', 919,
        ';', 2464,
        '<', 542,
        '=', 2652,
        '?', 2657,
        '@', 2633,
        'N', 2612,
        'P', 2625,
        'R', 2610,
        'T', 548,
        '[', 2475,
        'e', 2594,
        'p', 861,
        '{', 2567,
        0x221e, 2660,
        0x2659, 2628,
        0x265f, 860,
      );
      if (lookahead == '\n' ||
          lookahead == '\r') SKIP(1185);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(28);
      if (lookahead == 'Z' ||
          lookahead == 'z') ADVANCE(903);
      if (lookahead == 0x2e40 ||
          lookahead == 0xff1d) ADVANCE(2651);
      if (lookahead == '+' ||
          lookahead == 0x16ed ||
          lookahead == 0x2795) ADVANCE(29);
      if (lookahead == '/' ||
          lookahead == 0x2044 ||
          lookahead == 0x2215 ||
          lookahead == 0x27cb ||
          lookahead == 0x29f8) ADVANCE(30);
      if (('a' <= lookahead && lookahead <= 'h')) ADVANCE(2595);
      if (lookahead == '-' ||
          (0x2010 <= lookahead && lookahead <= 0x2014) ||
          lookahead == 0x2212 ||
          lookahead == 0x2796) ADVANCE(2654);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(920);
      if (lookahead == 'B' ||
          lookahead == 'K' ||
          lookahead == 'Q' ||
          (0x2654 <= lookahead && lookahead <= 0x265e)) ADVANCE(2611);
      if (set_contains(aux_sym_result_code_token22_character_set_1, 11, lookahead)) ADVANCE(924);
      if (set_contains(aux_sym_annotation_token1_character_set_1, 54, lookahead)) ADVANCE(2659);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1186:
      ADVANCE_MAP(
        '!', 2657,
        '$', 907,
        '&', 18,
        '(', 2563,
        ')', 2565,
        '*', 2721,
        '-', 2653,
        '0', 2695,
        '1', 2671,
        ';', 2464,
        '<', 542,
        '=', 2652,
        '?', 2657,
        '@', 2633,
        'N', 2612,
        'O', 2691,
        'P', 2625,
        'R', 2610,
        'T', 548,
        '[', 2475,
        'e', 2594,
        'o', 2700,
        'p', 861,
        '{', 2567,
        '}', 2569,
        0xbd, 2715,
        0x66d, 2737,
        0x204e, 2733,
        0x2217, 2725,
        0x221e, 2660,
        0x2659, 2628,
        0x265f, 860,
        0x2731, 2729,
      );
      if (lookahead == '\n' ||
          lookahead == '\r') SKIP(1187);
      if (lookahead == 'Z' ||
          lookahead == 'z') ADVANCE(903);
      if (lookahead == 0x2e40 ||
          lookahead == 0xff1d) ADVANCE(2651);
      if (lookahead == '+' ||
          lookahead == 0x16ed ||
          lookahead == 0x2795) ADVANCE(29);
      if (lookahead == '/' ||
          lookahead == 0x2044 ||
          lookahead == 0x2215 ||
          lookahead == 0x27cb ||
          lookahead == 0x29f8) ADVANCE(30);
      if (('a' <= lookahead && lookahead <= 'h')) ADVANCE(2595);
      if ((0x2010 <= lookahead && lookahead <= 0x2014) ||
          lookahead == 0x2212 ||
          lookahead == 0x2796) ADVANCE(2654);
      if (('2' <= lookahead && lookahead <= '9')) ADVANCE(920);
      if (lookahead == 'B' ||
          lookahead == 'K' ||
          lookahead == 'Q' ||
          (0x2654 <= lookahead && lookahead <= 0x265e)) ADVANCE(2611);
      if (set_contains(aux_sym_result_code_token23_character_set_1, 12, lookahead)) ADVANCE(1164);
      if (set_contains(aux_sym_annotation_token1_character_set_1, 54, lookahead)) ADVANCE(2659);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1187:
      ADVANCE_MAP(
        '!', 2657,
        '$', 907,
        '&', 18,
        '(', 2563,
        ')', 2565,
        '*', 2721,
        '0', 2695,
        '1', 2671,
        ';', 2464,
        '<', 542,
        '=', 2652,
        '?', 2657,
        '@', 2633,
        'N', 2612,
        'O', 2691,
        'P', 2625,
        'R', 2610,
        'T', 548,
        '[', 2475,
        'e', 2594,
        'o', 2700,
        'p', 861,
        '{', 2567,
        '}', 2569,
        0xbd, 2715,
        0x66d, 2737,
        0x204e, 2733,
        0x2217, 2725,
        0x221e, 2660,
        0x2659, 2628,
        0x265f, 860,
        0x2731, 2729,
      );
      if (lookahead == '\n' ||
          lookahead == '\r') SKIP(1187);
      if (lookahead == 'Z' ||
          lookahead == 'z') ADVANCE(903);
      if (lookahead == 0x2e40 ||
          lookahead == 0xff1d) ADVANCE(2651);
      if (lookahead == '+' ||
          lookahead == 0x16ed ||
          lookahead == 0x2795) ADVANCE(29);
      if (lookahead == '/' ||
          lookahead == 0x2044 ||
          lookahead == 0x2215 ||
          lookahead == 0x27cb ||
          lookahead == 0x29f8) ADVANCE(30);
      if (('a' <= lookahead && lookahead <= 'h')) ADVANCE(2595);
      if (lookahead == '-' ||
          (0x2010 <= lookahead && lookahead <= 0x2014) ||
          lookahead == 0x2212 ||
          lookahead == 0x2796) ADVANCE(2654);
      if (('2' <= lookahead && lookahead <= '9')) ADVANCE(920);
      if (lookahead == 'B' ||
          lookahead == 'K' ||
          lookahead == 'Q' ||
          (0x2654 <= lookahead && lookahead <= 0x265e)) ADVANCE(2611);
      if (set_contains(aux_sym_result_code_token23_character_set_1, 12, lookahead)) ADVANCE(1164);
      if (set_contains(aux_sym_annotation_token1_character_set_1, 54, lookahead)) ADVANCE(2659);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 1188:
      ADVANCE_MAP(
        '!', 2668,
        '#', 2644,
        '$', 2446,
        '&', 1221,
        '(', 2562,
        ')', 2564,
        '0', 1265,
        ';', 2463,
        '<', 1984,
        '=', 2622,
        '?', 2668,
        '@', 2632,
        'N', 2608,
        'P', 2626,
        'R', 2607,
        'T', 1990,
        'e', 2596,
        'p', 2379,
        '{', 2566,
        0x221e, 2661,
        0x2659, 2627,
        0x265f, 2378,
        'O', 1266,
        'o', 1266,
        'Z', 2443,
        'z', 2443,
        0x2e40, 2621,
        0xff1d, 2621,
        '+', 2648,
        0x16ed, 2648,
        0x2795, 2648,
        '/', 1245,
        0x2044, 1245,
        0x2215, 1245,
        0x27cb, 1245,
        0x29f8, 1245,
      );
      if (('a' <= lookahead && lookahead <= 'h')) ADVANCE(2593);
      if (lookahead == '-' ||
          (0x2010 <= lookahead && lookahead <= 0x2014) ||
          lookahead == 0x2212 ||
          lookahead == 0x2796) ADVANCE(2664);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(2444);
      if (lookahead == 'B' ||
          lookahead == 'K' ||
          lookahead == 'Q' ||
          (0x2654 <= lookahead && lookahead <= 0x265e)) ADVANCE(2603);
      if (set_contains(aux_sym_result_code_token22_character_set_1, 11, lookahead)) SKIP(1196);
      if (set_contains(aux_sym_annotation_token1_character_set_1, 54, lookahead)) ADVANCE(2649);
      END_STATE();
    case 1189:
      ADVANCE_MAP(
        '!', 2668,
        '#', 2644,
        '$', 2446,
        '&', 1229,
        '(', 2562,
        ')', 2564,
        '*', 2720,
        '0', 2696,
        '1', 2672,
        ';', 2463,
        '<', 1984,
        '=', 2663,
        '?', 2668,
        '@', 2632,
        'N', 2614,
        'O', 2692,
        'P', 2626,
        'R', 2613,
        'T', 1990,
        'e', 2596,
        'o', 2701,
        'p', 2379,
        '{', 2566,
        '}', 2568,
        0xbd, 2716,
        0x66d, 2736,
        0x204e, 2732,
        0x2217, 2724,
        0x221e, 2661,
        0x2659, 2627,
        0x265f, 2378,
        0x2731, 2728,
        'Z', 2443,
        'z', 2443,
        0x2e40, 2662,
        0xff1d, 2662,
        '+', 2648,
        0x16ed, 2648,
        0x2795, 2648,
        '/', 1245,
        0x2044, 1245,
        0x2215, 1245,
        0x27cb, 1245,
        0x29f8, 1245,
      );
      if (('a' <= lookahead && lookahead <= 'h')) ADVANCE(2593);
      if (lookahead == '-' ||
          (0x2010 <= lookahead && lookahead <= 0x2014) ||
          lookahead == 0x2212 ||
          lookahead == 0x2796) ADVANCE(2664);
      if (('2' <= lookahead && lookahead <= '9')) ADVANCE(2444);
      if (lookahead == 'B' ||
          lookahead == 'K' ||
          lookahead == 'Q' ||
          (0x2654 <= lookahead && lookahead <= 0x265e)) ADVANCE(2609);
      if (set_contains(aux_sym_result_code_token23_character_set_1, 12, lookahead)) SKIP(1195);
      if (set_contains(aux_sym_annotation_token1_character_set_1, 54, lookahead)) ADVANCE(2649);
      END_STATE();
    case 1190:
      ADVANCE_MAP(
        '!', 2668,
        '#', 2644,
        '$', 2446,
        '&', 1229,
        '(', 2562,
        ')', 2564,
        '*', 2720,
        '0', 2696,
        '1', 2672,
        ';', 2463,
        '<', 1984,
        '=', 2663,
        '?', 2668,
        '@', 2632,
        'N', 2614,
        'O', 2692,
        'P', 2626,
        'R', 2613,
        'T', 1990,
        'e', 2600,
        'o', 2701,
        'p', 2379,
        '{', 2566,
        '}', 2568,
        0xbd, 2716,
        0x66d, 2736,
        0x204e, 2732,
        0x2217, 2724,
        0x221e, 2661,
        0x2659, 2627,
        0x265f, 2378,
        0x2731, 2728,
        'Z', 2443,
        'z', 2443,
        0x2e40, 2662,
        0xff1d, 2662,
        '+', 2648,
        0x16ed, 2648,
        0x2795, 2648,
        ':', 2615,
        'X', 2615,
        'x', 2615,
        '/', 1245,
        0x2044, 1245,
        0x2215, 1245,
        0x27cb, 1245,
        0x29f8, 1245,
      );
      if (('a' <= lookahead && lookahead <= 'h')) ADVANCE(2597);
      if (lookahead == '-' ||
          (0x2010 <= lookahead && lookahead <= 0x2014) ||
          lookahead == 0x2212 ||
          lookahead == 0x2796) ADVANCE(2664);
      if (('2' <= lookahead && lookahead <= '9')) ADVANCE(2444);
      if (lookahead == 'B' ||
          lookahead == 'K' ||
          lookahead == 'Q' ||
          (0x2654 <= lookahead && lookahead <= 0x265e)) ADVANCE(2609);
      if (set_contains(aux_sym_result_code_token23_character_set_1, 12, lookahead)) SKIP(1195);
      if (set_contains(aux_sym_annotation_token1_character_set_1, 54, lookahead)) ADVANCE(2649);
      END_STATE();
    case 1191:
      ADVANCE_MAP(
        '!', 2668,
        '#', 2644,
        '$', 2446,
        '&', 1225,
        '(', 2562,
        ')', 2564,
        '0', 1265,
        ';', 2463,
        '<', 1984,
        '=', 2663,
        '?', 2668,
        '@', 2632,
        'N', 2614,
        'P', 2626,
        'R', 2613,
        'T', 1990,
        'e', 2600,
        'p', 2379,
        '{', 2566,
        0x221e, 2661,
        0x2659, 2627,
        0x265f, 2378,
        'O', 1266,
        'o', 1266,
        'Z', 2443,
        'z', 2443,
        0x2e40, 2662,
        0xff1d, 2662,
        '+', 2648,
        0x16ed, 2648,
        0x2795, 2648,
        ':', 2615,
        'X', 2615,
        'x', 2615,
        '/', 1245,
        0x2044, 1245,
        0x2215, 1245,
        0x27cb, 1245,
        0x29f8, 1245,
      );
      if (('a' <= lookahead && lookahead <= 'h')) ADVANCE(2597);
      if (lookahead == '-' ||
          (0x2010 <= lookahead && lookahead <= 0x2014) ||
          lookahead == 0x2212 ||
          lookahead == 0x2796) ADVANCE(2636);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(2444);
      if (lookahead == 'B' ||
          lookahead == 'K' ||
          lookahead == 'Q' ||
          (0x2654 <= lookahead && lookahead <= 0x265e)) ADVANCE(2609);
      if (set_contains(aux_sym_result_code_token22_character_set_1, 11, lookahead)) SKIP(1196);
      if (set_contains(aux_sym_annotation_token1_character_set_1, 54, lookahead)) ADVANCE(2649);
      END_STATE();
    case 1192:
      ADVANCE_MAP(
        '!', 2668,
        '#', 2644,
        '$', 2446,
        '&', 1226,
        '(', 2562,
        ')', 2564,
        '0', 1265,
        ';', 2463,
        '<', 1984,
        '=', 2663,
        '?', 2668,
        '@', 2632,
        'N', 2614,
        'P', 2626,
        'R', 2613,
        'T', 1990,
        'e', 2600,
        'p', 2379,
        '{', 2566,
        0x221e, 2661,
        0x2659, 2627,
        0x265f, 2378,
        'O', 1266,
        'o', 1266,
        'Z', 2443,
        'z', 2443,
        0x2e40, 2662,
        0xff1d, 2662,
        '+', 2648,
        0x16ed, 2648,
        0x2795, 2648,
        ':', 2615,
        'X', 2615,
        'x', 2615,
        '/', 1245,
        0x2044, 1245,
        0x2215, 1245,
        0x27cb, 1245,
        0x29f8, 1245,
      );
      if (('a' <= lookahead && lookahead <= 'h')) ADVANCE(2597);
      if (lookahead == '-' ||
          (0x2010 <= lookahead && lookahead <= 0x2014) ||
          lookahead == 0x2212 ||
          lookahead == 0x2796) ADVANCE(2664);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(2444);
      if (lookahead == 'B' ||
          lookahead == 'K' ||
          lookahead == 'Q' ||
          (0x2654 <= lookahead && lookahead <= 0x265e)) ADVANCE(2609);
      if (set_contains(aux_sym_result_code_token22_character_set_1, 11, lookahead)) SKIP(1196);
      if (set_contains(aux_sym_annotation_token1_character_set_1, 54, lookahead)) ADVANCE(2649);
      END_STATE();
    case 1193:
      ADVANCE_MAP(
        '!', 2668,
        '#', 2644,
        '$', 2446,
        '&', 1232,
        '(', 2562,
        ')', 2564,
        '*', 2720,
        '0', 2696,
        '1', 2672,
        ';', 2463,
        '<', 1984,
        '=', 2663,
        '?', 2668,
        '@', 2632,
        'N', 2614,
        'O', 2692,
        'P', 2626,
        'R', 2613,
        'T', 1990,
        'e', 2600,
        'o', 2701,
        'p', 2379,
        '{', 2566,
        '}', 2568,
        0xbd, 2716,
        0x66d, 2736,
        0x204e, 2732,
        0x2217, 2724,
        0x221e, 2661,
        0x2659, 2627,
        0x265f, 2378,
        0x2731, 2728,
        'Z', 2443,
        'z', 2443,
        0x2e40, 2662,
        0xff1d, 2662,
        '+', 2648,
        0x16ed, 2648,
        0x2795, 2648,
        ':', 2615,
        'X', 2615,
        'x', 2615,
        '/', 1245,
        0x2044, 1245,
        0x2215, 1245,
        0x27cb, 1245,
        0x29f8, 1245,
      );
      if (('a' <= lookahead && lookahead <= 'h')) ADVANCE(2597);
      if (lookahead == '-' ||
          (0x2010 <= lookahead && lookahead <= 0x2014) ||
          lookahead == 0x2212 ||
          lookahead == 0x2796) ADVANCE(2636);
      if (('2' <= lookahead && lookahead <= '9')) ADVANCE(2444);
      if (lookahead == 'B' ||
          lookahead == 'K' ||
          lookahead == 'Q' ||
          (0x2654 <= lookahead && lookahead <= 0x265e)) ADVANCE(2609);
      if (set_contains(aux_sym_result_code_token23_character_set_1, 12, lookahead)) SKIP(1195);
      if (set_contains(aux_sym_annotation_token1_character_set_1, 54, lookahead)) ADVANCE(2649);
      END_STATE();
    case 1194:
      ADVANCE_MAP(
        '!', 2668,
        '#', 2644,
        '$', 2446,
        '&', 1234,
        '(', 2562,
        ')', 2564,
        '*', 2720,
        '0', 2696,
        '1', 2672,
        ';', 2463,
        '<', 1984,
        '=', 2622,
        '?', 2668,
        '@', 2632,
        'N', 2608,
        'O', 2692,
        'P', 2626,
        'R', 2607,
        'T', 1990,
        'e', 2596,
        'o', 2701,
        'p', 2379,
        '{', 2566,
        '}', 2568,
        0xbd, 2716,
        0x66d, 2736,
        0x204e, 2732,
        0x2217, 2724,
        0x221e, 2661,
        0x2659, 2627,
        0x265f, 2378,
        0x2731, 2728,
        'Z', 2443,
        'z', 2443,
        0x2e40, 2621,
        0xff1d, 2621,
        '+', 2648,
        0x16ed, 2648,
        0x2795, 2648,
        '/', 1245,
        0x2044, 1245,
        0x2215, 1245,
        0x27cb, 1245,
        0x29f8, 1245,
      );
      if (('a' <= lookahead && lookahead <= 'h')) ADVANCE(2593);
      if (lookahead == '-' ||
          (0x2010 <= lookahead && lookahead <= 0x2014) ||
          lookahead == 0x2212 ||
          lookahead == 0x2796) ADVANCE(2664);
      if (('2' <= lookahead && lookahead <= '9')) ADVANCE(2444);
      if (lookahead == 'B' ||
          lookahead == 'K' ||
          lookahead == 'Q' ||
          (0x2654 <= lookahead && lookahead <= 0x265e)) ADVANCE(2603);
      if (set_contains(aux_sym_result_code_token23_character_set_1, 12, lookahead)) SKIP(1195);
      if (set_contains(aux_sym_annotation_token1_character_set_1, 54, lookahead)) ADVANCE(2649);
      END_STATE();
    case 1195:
      ADVANCE_MAP(
        '!', 2668,
        '$', 2446,
        '&', 1207,
        '(', 2562,
        ')', 2564,
        '*', 2720,
        '0', 2696,
        '1', 2672,
        ';', 2463,
        '<', 1984,
        '=', 2663,
        '?', 2668,
        '@', 2632,
        'N', 2614,
        'O', 2692,
        'P', 2626,
        'R', 2613,
        'T', 1990,
        'e', 2596,
        'o', 2701,
        'p', 2379,
        '{', 2566,
        '}', 2568,
        0xbd, 2716,
        0x66d, 2736,
        0x204e, 2732,
        0x2217, 2724,
        0x221e, 2661,
        0x2659, 2627,
        0x265f, 2378,
        0x2731, 2728,
        'Z', 2443,
        'z', 2443,
        0x2e40, 2662,
        0xff1d, 2662,
        '+', 1248,
        0x16ed, 1248,
        0x2795, 1248,
        '/', 1245,
        0x2044, 1245,
        0x2215, 1245,
        0x27cb, 1245,
        0x29f8, 1245,
      );
      if (('a' <= lookahead && lookahead <= 'h')) ADVANCE(2593);
      if (lookahead == '-' ||
          (0x2010 <= lookahead && lookahead <= 0x2014) ||
          lookahead == 0x2212 ||
          lookahead == 0x2796) ADVANCE(2664);
      if (('2' <= lookahead && lookahead <= '9')) ADVANCE(2444);
      if (lookahead == 'B' ||
          lookahead == 'K' ||
          lookahead == 'Q' ||
          (0x2654 <= lookahead && lookahead <= 0x265e)) ADVANCE(2609);
      if (set_contains(aux_sym_result_code_token23_character_set_1, 12, lookahead)) SKIP(1195);
      if (set_contains(aux_sym_annotation_token1_character_set_1, 54, lookahead)) ADVANCE(2649);
      END_STATE();
    case 1196:
      ADVANCE_MAP(
        '!', 2668,
        '$', 2446,
        '&', 1223,
        '(', 2562,
        ')', 2564,
        '0', 1265,
        ';', 2463,
        '<', 1984,
        '=', 2663,
        '?', 2668,
        '@', 2632,
        'N', 2614,
        'P', 2626,
        'R', 2613,
        'T', 1990,
        'e', 2596,
        'p', 2379,
        '{', 2566,
        0x221e, 2661,
        0x2659, 2627,
        0x265f, 2378,
        'O', 1266,
        'o', 1266,
        'Z', 2443,
        'z', 2443,
        0x2e40, 2662,
        0xff1d, 2662,
        '+', 1248,
        0x16ed, 1248,
        0x2795, 1248,
        '/', 1245,
        0x2044, 1245,
        0x2215, 1245,
        0x27cb, 1245,
        0x29f8, 1245,
      );
      if (('a' <= lookahead && lookahead <= 'h')) ADVANCE(2593);
      if (lookahead == '-' ||
          (0x2010 <= lookahead && lookahead <= 0x2014) ||
          lookahead == 0x2212 ||
          lookahead == 0x2796) ADVANCE(2664);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(2444);
      if (lookahead == 'B' ||
          lookahead == 'K' ||
          lookahead == 'Q' ||
          (0x2654 <= lookahead && lookahead <= 0x265e)) ADVANCE(2609);
      if (set_contains(aux_sym_result_code_token22_character_set_1, 11, lookahead)) SKIP(1196);
      if (set_contains(aux_sym_annotation_token1_character_set_1, 54, lookahead)) ADVANCE(2649);
      END_STATE();
    case 1197:
      ADVANCE_MAP(
        '"', 2480,
        '&', 2515,
        ']', 2479,
        0xab, 2508,
        0xbb, 2510,
        0x2ba, 2500,
        0x2dd, 2498,
        0x2ee, 2504,
        0x2f6, 2502,
        0x5f2, 2506,
        0x5f4, 2496,
        0x201c, 2484,
        0x201d, 2486,
        0x201f, 2488,
        0x2033, 2490,
        0x2036, 2492,
        0x3003, 2494,
        0xff02, 2482,
      );
      if (lookahead == '\n' ||
          lookahead == '\r') SKIP(1199);
      if (set_contains(extras_character_set_2, 10, lookahead)) ADVANCE(2516);
      if (lookahead != 0) ADVANCE(2561);
      END_STATE();
    case 1198:
      ADVANCE_MAP(
        '"', 2480,
        '&', 2515,
        0xab, 2508,
        0xbb, 2510,
        0x2ba, 2500,
        0x2dd, 2498,
        0x2ee, 2504,
        0x2f6, 2502,
        0x5f2, 2506,
        0x5f4, 2496,
        0x201c, 2484,
        0x201d, 2486,
        0x201f, 2488,
        0x2033, 2490,
        0x2036, 2492,
        0x3003, 2494,
        0xff02, 2482,
      );
      if (lookahead == '\n' ||
          lookahead == '\r') SKIP(1200);
      if (set_contains(extras_character_set_2, 10, lookahead)) ADVANCE(2517);
      if (lookahead != 0) ADVANCE(2561);
      END_STATE();
    case 1199:
      ADVANCE_MAP(
        '"', 2480,
        '&', 1214,
        ']', 2478,
        0xab, 2508,
        0xbb, 2510,
        0x2ba, 2500,
        0x2dd, 2498,
        0x2ee, 2504,
        0x2f6, 2502,
        0x5f2, 2506,
        0x5f4, 2496,
        0x201c, 2484,
        0x201d, 2486,
        0x201f, 2488,
        0x2033, 2490,
        0x2036, 2492,
        0x3003, 2494,
        0xff02, 2482,
      );
      if (set_contains(extras_character_set_2, 10, lookahead)) SKIP(1199);
      END_STATE();
    case 1200:
      ADVANCE_MAP(
        '"', 2480,
        '&', 1214,
        0xab, 2508,
        0xbb, 2510,
        0x2ba, 2500,
        0x2dd, 2498,
        0x2ee, 2504,
        0x2f6, 2502,
        0x5f2, 2506,
        0x5f4, 2496,
        0x201c, 2484,
        0x201d, 2486,
        0x201f, 2488,
        0x2033, 2490,
        0x2036, 2492,
        0x3003, 2494,
        0xff02, 2482,
      );
      if (set_contains(extras_character_set_2, 10, lookahead)) SKIP(1200);
      END_STATE();
    case 1201:
      ADVANCE_MAP(
        '#', 1431,
        'a', 2278,
        'd', 2001,
        'e', 2257,
        'f', 2265,
        'h', 2003,
        'l', 2022,
        'm', 2053,
        'n', 2061,
        'p', 2162,
        'q', 2334,
        'r', 2043,
        's', 2221,
      );
      END_STATE();
    case 1202:
      if (lookahead == '#') ADVANCE(1435);
      if (lookahead == 'd') ADVANCE(2028);
      if (lookahead == 'h') ADVANCE(2369);
      if (lookahead == 'm') ADVANCE(2063);
      if (lookahead == 'n') ADVANCE(2062);
      END_STATE();
    case 1203:
      if (lookahead == '#') ADVANCE(1478);
      if (lookahead == 'p') ADVANCE(2179);
      END_STATE();
    case 1204:
      ADVANCE_MAP(
        '#', 1436,
        'a', 2278,
        'd', 2001,
        'f', 2265,
        'h', 2003,
        'l', 2022,
        'm', 2053,
        'n', 2061,
        'q', 2334,
        'r', 2043,
        's', 2221,
      );
      END_STATE();
    case 1205:
      if (lookahead == '#') ADVANCE(1459);
      if (lookahead == 'f') ADVANCE(2276);
      if (lookahead == 'h') ADVANCE(2025);
      END_STATE();
    case 1206:
      if (lookahead == '#') ADVANCE(1464);
      if (lookahead == 'e') ADVANCE(2262);
      END_STATE();
    case 1207:
      ADVANCE_MAP(
        '#', 1440,
        'D', 2095,
        'L', 2011,
        'M', 2155,
        'O', 2285,
        'P', 2163,
        'R', 2012,
        'S', 2120,
        'U', 2236,
        'a', 2278,
        'b', 2153,
        'c', 2151,
        'd', 2034,
        'e', 2243,
        'f', 2265,
        'h', 1997,
        'i', 2188,
        'l', 2082,
        'm', 2015,
        'n', 1999,
        'o', 2055,
        'p', 2085,
        'q', 2338,
        'r', 2006,
        's', 2165,
        'u', 2007,
        'x', 2218,
      );
      END_STATE();
    case 1208:
      if (lookahead == '#') ADVANCE(1469);
      if (lookahead == 'p') ADVANCE(2185);
      if (lookahead == 's') ADVANCE(2233);
      END_STATE();
    case 1209:
      if (lookahead == '#') ADVANCE(1454);
      if (lookahead == 'd') ADVANCE(2035);
      if (lookahead == 'e') ADVANCE(2262);
      if (lookahead == 'h') ADVANCE(2375);
      if (lookahead == 'm') ADVANCE(2075);
      if (lookahead == 'n') ADVANCE(2074);
      if (lookahead == 's') ADVANCE(2234);
      END_STATE();
    case 1210:
      if (lookahead == '#') ADVANCE(1843);
      if (lookahead == 'i') ADVANCE(2216);
      END_STATE();
    case 1211:
      if (lookahead == '#') ADVANCE(1813);
      if (lookahead == 'e') ADVANCE(2262);
      END_STATE();
    case 1212:
      if (lookahead == '#') ADVANCE(1714);
      if (lookahead == 'e') ADVANCE(2368);
      if (lookahead == 'q') ADVANCE(2363);
      END_STATE();
    case 1213:
      if (lookahead == '#') ADVANCE(1468);
      if (lookahead == 'e') ADVANCE(2262);
      if (lookahead == 'p') ADVANCE(2185);
      if (lookahead == 's') ADVANCE(2233);
      END_STATE();
    case 1214:
      if (lookahead == '#') ADVANCE(1443);
      if (lookahead == 'l') ADVANCE(2021);
      if (lookahead == 'q') ADVANCE(2334);
      if (lookahead == 'r') ADVANCE(2043);
      END_STATE();
    case 1215:
      if (lookahead == '#') ADVANCE(1466);
      if (lookahead == 's') ADVANCE(2229);
      END_STATE();
    case 1216:
      ADVANCE_MAP(
        '#', 1442,
        'D', 2095,
        'L', 2011,
        'M', 2155,
        'O', 2285,
        'P', 2163,
        'R', 2012,
        'S', 2120,
        'U', 2236,
        'b', 2153,
        'c', 2151,
        'd', 2034,
        'e', 2243,
        'f', 2277,
        'h', 2023,
        'i', 2188,
        'l', 2083,
        'm', 2016,
        'n', 1999,
        'o', 2055,
        'p', 2086,
        'q', 2338,
        'r', 2006,
        's', 2165,
        'u', 2007,
        'x', 2218,
      );
      END_STATE();
    case 1217:
      if (lookahead == '#') ADVANCE(1470);
      if (lookahead == 'd') ADVANCE(2036);
      if (lookahead == 'h') ADVANCE(2376);
      if (lookahead == 'm') ADVANCE(2077);
      if (lookahead == 'n') ADVANCE(2076);
      if (lookahead == 'p') ADVANCE(2185);
      if (lookahead == 's') ADVANCE(2235);
      END_STATE();
    case 1218:
      ADVANCE_MAP(
        '#', 1444,
        'a', 2278,
        'd', 2039,
        'e', 2257,
        'f', 2265,
        'h', 2004,
        'l', 2217,
        'm', 2081,
        'n', 2080,
      );
      END_STATE();
    case 1219:
      ADVANCE_MAP(
        '#', 1460,
        'd', 2035,
        'e', 2262,
        'h', 2375,
        'm', 2075,
        'n', 2074,
        'p', 2179,
        's', 2234,
      );
      END_STATE();
    case 1220:
      if (lookahead == '#') ADVANCE(1467);
      if (lookahead == 'd') ADVANCE(2032);
      if (lookahead == 'h') ADVANCE(2373);
      if (lookahead == 'm') ADVANCE(2071);
      if (lookahead == 'n') ADVANCE(2070);
      if (lookahead == 's') ADVANCE(2230);
      END_STATE();
    case 1221:
      ADVANCE_MAP(
        '#', 1451,
        'D', 2095,
        'L', 2011,
        'M', 2155,
        'O', 2285,
        'P', 2163,
        'R', 2012,
        'S', 2120,
        'U', 2236,
        'b', 2153,
        'c', 2151,
        'd', 2034,
        'e', 2244,
        'h', 2008,
        'i', 2188,
        'l', 2083,
        'm', 2016,
        'n', 1999,
        'o', 2055,
        'p', 2086,
        'q', 2338,
        'r', 2006,
        's', 2165,
        'u', 2007,
        'x', 2218,
      );
      END_STATE();
    case 1222:
      if (lookahead == '#') ADVANCE(1445);
      if (lookahead == 'a') ADVANCE(2278);
      if (lookahead == 'f') ADVANCE(2265);
      if (lookahead == 'h') ADVANCE(2002);
      if (lookahead == 'l') ADVANCE(2217);
      if (lookahead == 'm') ADVANCE(2152);
      END_STATE();
    case 1223:
      ADVANCE_MAP(
        '#', 1558,
        'D', 2095,
        'L', 2011,
        'M', 2155,
        'O', 2285,
        'P', 2163,
        'R', 2012,
        'S', 2120,
        'U', 2236,
        'b', 2153,
        'c', 2151,
        'd', 2034,
        'e', 2243,
        'h', 2008,
        'i', 2188,
        'l', 2083,
        'm', 2016,
        'n', 1999,
        'o', 2055,
        'p', 2085,
        'q', 2338,
        'r', 2006,
        's', 2165,
        'u', 2007,
        'x', 2218,
      );
      END_STATE();
    case 1224:
      ADVANCE_MAP(
        '#', 1569,
        'D', 2095,
        'L', 2011,
        'M', 2155,
        'O', 2285,
        'P', 2163,
        'R', 2012,
        'S', 2120,
        'U', 2236,
        'b', 2153,
        'c', 2151,
        'd', 2034,
        'e', 2243,
        'f', 2277,
        'h', 2023,
        'i', 2188,
        'l', 2083,
        'm', 2016,
        'n', 1999,
        'o', 2055,
        'p', 2085,
        'q', 2338,
        'r', 2006,
        's', 2165,
        'u', 2007,
        'x', 2218,
      );
      END_STATE();
    case 1225:
      ADVANCE_MAP(
        '#', 1562,
        'D', 2095,
        'L', 2011,
        'M', 2155,
        'O', 2285,
        'P', 2163,
        'R', 2012,
        'S', 2120,
        'U', 2236,
        'b', 2153,
        'c', 2151,
        'd', 2038,
        'e', 2243,
        'h', 2009,
        'i', 2188,
        'l', 2083,
        'm', 2018,
        'n', 2000,
        'o', 2055,
        'p', 2086,
        'q', 2338,
        'r', 2006,
        's', 2165,
        'u', 2007,
        'x', 2218,
      );
      END_STATE();
    case 1226:
      ADVANCE_MAP(
        '#', 1564,
        'D', 2095,
        'L', 2011,
        'M', 2155,
        'O', 2285,
        'P', 2163,
        'R', 2012,
        'S', 2120,
        'U', 2236,
        'b', 2153,
        'c', 2151,
        'd', 2034,
        'e', 2243,
        'h', 2008,
        'i', 2188,
        'l', 2083,
        'm', 2016,
        'n', 1999,
        'o', 2055,
        'p', 2086,
        'q', 2338,
        'r', 2006,
        's', 2165,
        'u', 2007,
        'x', 2218,
      );
      END_STATE();
    case 1227:
      if (lookahead == '#') ADVANCE(1556);
      if (lookahead == 'd') ADVANCE(2029);
      if (lookahead == 'h') ADVANCE(2370);
      if (lookahead == 'm') ADVANCE(2065);
      if (lookahead == 'n') ADVANCE(2064);
      END_STATE();
    case 1228:
      if (lookahead == '#') ADVANCE(1560);
      if (lookahead == 'p') ADVANCE(2185);
      END_STATE();
    case 1229:
      ADVANCE_MAP(
        '#', 1568,
        'D', 2095,
        'L', 2011,
        'M', 2155,
        'O', 2285,
        'P', 2163,
        'R', 2012,
        'S', 2120,
        'U', 2236,
        'a', 2278,
        'b', 2153,
        'c', 2151,
        'd', 2034,
        'e', 2243,
        'f', 2265,
        'h', 1997,
        'i', 2188,
        'l', 2082,
        'm', 2015,
        'n', 1999,
        'o', 2055,
        'p', 2086,
        'q', 2338,
        'r', 2006,
        's', 2165,
        'u', 2007,
        'x', 2218,
      );
      END_STATE();
    case 1230:
      if (lookahead == '#') ADVANCE(1559);
      if (lookahead == 's') ADVANCE(2232);
      END_STATE();
    case 1231:
      if (lookahead == '#') ADVANCE(1561);
      if (lookahead == 'd') ADVANCE(2030);
      if (lookahead == 'h') ADVANCE(2371);
      if (lookahead == 'm') ADVANCE(2067);
      if (lookahead == 'n') ADVANCE(2066);
      END_STATE();
    case 1232:
      ADVANCE_MAP(
        '#', 1570,
        'D', 2095,
        'L', 2011,
        'M', 2155,
        'O', 2285,
        'P', 2163,
        'R', 2012,
        'S', 2120,
        'U', 2236,
        'a', 2278,
        'b', 2153,
        'c', 2151,
        'd', 2038,
        'e', 2243,
        'f', 2265,
        'h', 1998,
        'i', 2188,
        'l', 2082,
        'm', 2017,
        'n', 2000,
        'o', 2055,
        'p', 2086,
        'q', 2338,
        'r', 2006,
        's', 2165,
        'u', 2007,
        'x', 2218,
      );
      END_STATE();
    case 1233:
      if (lookahead == '#') ADVANCE(1563);
      if (lookahead == 'd') ADVANCE(2031);
      if (lookahead == 'h') ADVANCE(2372);
      if (lookahead == 'm') ADVANCE(2069);
      if (lookahead == 'n') ADVANCE(2068);
      END_STATE();
    case 1234:
      ADVANCE_MAP(
        '#', 1571,
        'D', 2095,
        'L', 2011,
        'M', 2155,
        'O', 2285,
        'P', 2163,
        'R', 2012,
        'S', 2120,
        'U', 2236,
        'a', 2278,
        'b', 2153,
        'c', 2151,
        'd', 2034,
        'e', 2244,
        'f', 2265,
        'h', 1997,
        'i', 2188,
        'l', 2082,
        'm', 2015,
        'n', 1999,
        'o', 2055,
        'p', 2086,
        'q', 2338,
        'r', 2006,
        's', 2165,
        'u', 2007,
        'x', 2218,
      );
      END_STATE();
    case 1235:
      if (lookahead == '#') ADVANCE(1565);
      if (lookahead == 'd') ADVANCE(2033);
      if (lookahead == 'h') ADVANCE(2374);
      if (lookahead == 'm') ADVANCE(2073);
      if (lookahead == 'n') ADVANCE(2072);
      END_STATE();
    case 1236:
      if (lookahead == '#') ADVANCE(1566);
      if (lookahead == 'd') ADVANCE(2035);
      if (lookahead == 'h') ADVANCE(2375);
      if (lookahead == 'm') ADVANCE(2075);
      if (lookahead == 'n') ADVANCE(2074);
      END_STATE();
    case 1237:
      if (lookahead == '#') ADVANCE(1567);
      if (lookahead == 'd') ADVANCE(2037);
      if (lookahead == 'h') ADVANCE(2377);
      if (lookahead == 'm') ADVANCE(2079);
      if (lookahead == 'n') ADVANCE(2078);
      END_STATE();
    case 1238:
      if (lookahead == '&') ADVANCE(1205);
      if (lookahead == '-') ADVANCE(1268);
      if (lookahead == 0xbd) ADVANCE(2746);
      if (set_contains(aux_sym_result_code_token23_character_set_1, 12, lookahead)) ADVANCE(1240);
      END_STATE();
    case 1239:
      if (lookahead == '&') ADVANCE(1205);
      if (lookahead == '-') ADVANCE(1269);
      if (lookahead == 0xbd) ADVANCE(2746);
      END_STATE();
    case 1240:
      if (lookahead == '&') ADVANCE(1205);
      if (lookahead == 0xbd) ADVANCE(2746);
      END_STATE();
    case 1241:
      if (lookahead == '&') ADVANCE(1205);
      if (lookahead == 0xbd) ADVANCE(2746);
      if (set_contains(aux_sym_result_code_token23_character_set_1, 12, lookahead)) ADVANCE(1240);
      END_STATE();
    case 1242:
      if (lookahead == '&') ADVANCE(1215);
      if (lookahead == '-') ADVANCE(1269);
      if (lookahead == '/' ||
          lookahead == 0x2044 ||
          lookahead == 0x2215 ||
          lookahead == 0x27cb ||
          lookahead == 0x29f8) ADVANCE(1246);
      if (set_contains(aux_sym_annotation_token1_character_set_4, 16, lookahead)) ADVANCE(1243);
      END_STATE();
    case 1243:
      if (lookahead == '&') ADVANCE(1215);
      if (lookahead == '/' ||
          lookahead == 0x2044 ||
          lookahead == 0x2215 ||
          lookahead == 0x27cb ||
          lookahead == 0x29f8) ADVANCE(1246);
      if (set_contains(aux_sym_annotation_token1_character_set_4, 16, lookahead)) ADVANCE(1243);
      END_STATE();
    case 1244:
      if (lookahead == '&') ADVANCE(1206);
      if (lookahead == '-') ADVANCE(1269);
      if (lookahead == '=' ||
          lookahead == 0x2e40 ||
          lookahead == 0xff1d) ADVANCE(2649);
      if (set_contains(aux_sym_annotation_token1_character_set_7, 14, lookahead)) ADVANCE(1246);
      END_STATE();
    case 1245:
      if (lookahead == '&') ADVANCE(1206);
      if (lookahead == '=' ||
          lookahead == 0x2e40 ||
          lookahead == 0xff1d) ADVANCE(2649);
      END_STATE();
    case 1246:
      if (lookahead == '&') ADVANCE(1206);
      if (lookahead == '=' ||
          lookahead == 0x2e40 ||
          lookahead == 0xff1d) ADVANCE(2649);
      if (set_contains(aux_sym_annotation_token1_character_set_7, 14, lookahead)) ADVANCE(1246);
      END_STATE();
    case 1247:
      if (lookahead == '&') ADVANCE(1220);
      if (lookahead == '/' ||
          lookahead == 0x2044 ||
          lookahead == 0x2215 ||
          lookahead == 0x27cb ||
          lookahead == 0x29f8) ADVANCE(1580);
      if (lookahead == '-' ||
          (0x2010 <= lookahead && lookahead <= 0x2014) ||
          lookahead == 0x2212 ||
          lookahead == 0x2796) ADVANCE(2442);
      END_STATE();
    case 1248:
      if (lookahead == '&') ADVANCE(1209);
      if (lookahead == '/' ||
          lookahead == 0x2044 ||
          lookahead == 0x2215 ||
          lookahead == 0x27cb ||
          lookahead == 0x29f8) ADVANCE(1264);
      if (lookahead == '-' ||
          lookahead == '=' ||
          (0x2010 <= lookahead && lookahead <= 0x2014) ||
          lookahead == 0x2212 ||
          lookahead == 0x2796 ||
          lookahead == 0x2e40 ||
          lookahead == 0xff1d) ADVANCE(2649);
      END_STATE();
    case 1249:
      if (lookahead == '&') ADVANCE(1210);
      if (lookahead == 0x221e) ADVANCE(2649);
      END_STATE();
    case 1250:
      ADVANCE_MAP(
        '&', 1218,
        ')', 2564,
        '*', 2720,
        '0', 2698,
        '1', 2673,
        '2', 2713,
        '@', 2631,
        'O', 2693,
        'o', 2702,
        '}', 2568,
        0xbd, 2716,
        0x66d, 2736,
        0x204e, 2732,
        0x2217, 2724,
        0x2731, 2728,
        ':', 2615,
        'X', 2615,
        'x', 2615,
        '=', 2617,
        0x2e40, 2617,
        0xff1d, 2617,
      );
      if (lookahead == '-' ||
          (0x2010 <= lookahead && lookahead <= 0x2014) ||
          lookahead == 0x2212 ||
          lookahead == 0x2796) ADVANCE(2634);
      if (('a' <= lookahead && lookahead <= 'h')) ADVANCE(2597);
      if (lookahead == 'B' ||
          lookahead == 'K' ||
          lookahead == 'N' ||
          lookahead == 'Q' ||
          lookahead == 'R' ||
          (0x2654 <= lookahead && lookahead <= 0x2658) ||
          (0x265a <= lookahead && lookahead <= 0x265e)) ADVANCE(2603);
      if (set_contains(aux_sym_result_code_token23_character_set_1, 12, lookahead)) SKIP(1251);
      END_STATE();
    case 1251:
      ADVANCE_MAP(
        '&', 1222,
        ')', 2564,
        '*', 2720,
        '0', 2698,
        '1', 2673,
        '2', 2713,
        'O', 2693,
        'o', 2702,
        '}', 2568,
        0xbd, 2716,
        0x66d, 2736,
        0x204e, 2732,
        0x2217, 2724,
        0x2731, 2728,
      );
      if (set_contains(aux_sym_result_code_token23_character_set_1, 12, lookahead)) SKIP(1251);
      END_STATE();
    case 1252:
      if (lookahead == '&') ADVANCE(1211);
      END_STATE();
    case 1253:
      if (lookahead == '&') ADVANCE(1227);
      if (lookahead == '-') ADVANCE(1238);
      if ((0x2010 <= lookahead && lookahead <= 0x2014) ||
          lookahead == 0x2212 ||
          lookahead == 0x2796) ADVANCE(1241);
      END_STATE();
    case 1254:
      if (lookahead == '&') ADVANCE(1227);
      if (lookahead == '-' ||
          (0x2010 <= lookahead && lookahead <= 0x2014) ||
          lookahead == 0x2212 ||
          lookahead == 0x2796) ADVANCE(1241);
      END_STATE();
    case 1255:
      if (lookahead == '&') ADVANCE(1228);
      if (lookahead == '+' ||
          lookahead == 0x16ed ||
          lookahead == 0x2795) ADVANCE(2649);
      END_STATE();
    case 1256:
      if (lookahead == '&') ADVANCE(1230);
      if (lookahead == '-') ADVANCE(1269);
      if (lookahead == '/' ||
          lookahead == 0x2044 ||
          lookahead == 0x2215 ||
          lookahead == 0x27cb ||
          lookahead == 0x29f8) ADVANCE(1585);
      END_STATE();
    case 1257:
      if (lookahead == '&') ADVANCE(1230);
      if (lookahead == '/' ||
          lookahead == 0x2044 ||
          lookahead == 0x2215 ||
          lookahead == 0x27cb ||
          lookahead == 0x29f8) ADVANCE(1585);
      END_STATE();
    case 1258:
      if (lookahead == '&') ADVANCE(1230);
      if (lookahead == '/' ||
          lookahead == 0x2044 ||
          lookahead == 0x2215 ||
          lookahead == 0x27cb ||
          lookahead == 0x29f8) ADVANCE(1585);
      if (set_contains(aux_sym_annotation_token1_character_set_4, 16, lookahead)) ADVANCE(1257);
      END_STATE();
    case 1259:
      if (lookahead == '&') ADVANCE(1231);
      if (lookahead == '-') ADVANCE(1270);
      if ((0x2010 <= lookahead && lookahead <= 0x2014) ||
          lookahead == 0x2212 ||
          lookahead == 0x2796) ADVANCE(1434);
      END_STATE();
    case 1260:
      if (lookahead == '&') ADVANCE(1231);
      if (lookahead == '-' ||
          (0x2010 <= lookahead && lookahead <= 0x2014) ||
          lookahead == 0x2212 ||
          lookahead == 0x2796) ADVANCE(1434);
      END_STATE();
    case 1261:
      if (lookahead == '&') ADVANCE(1235);
      if (lookahead == '-') ADVANCE(1271);
      if ((0x2010 <= lookahead && lookahead <= 0x2014) ||
          lookahead == 0x2212 ||
          lookahead == 0x2796) ADVANCE(1450);
      END_STATE();
    case 1262:
      if (lookahead == '&') ADVANCE(1235);
      if (lookahead == '-' ||
          (0x2010 <= lookahead && lookahead <= 0x2014) ||
          lookahead == 0x2212 ||
          lookahead == 0x2796) ADVANCE(1450);
      END_STATE();
    case 1263:
      if (lookahead == '&') ADVANCE(1235);
      if (lookahead == '-' ||
          (0x2010 <= lookahead && lookahead <= 0x2014) ||
          lookahead == 0x2212 ||
          lookahead == 0x2796) ADVANCE(1450);
      if (set_contains(aux_sym_result_code_token20_character_set_1, 15, lookahead)) ADVANCE(1262);
      END_STATE();
    case 1264:
      if (lookahead == '&') ADVANCE(1236);
      if (lookahead == '-' ||
          (0x2010 <= lookahead && lookahead <= 0x2014) ||
          lookahead == 0x2212 ||
          lookahead == 0x2796) ADVANCE(2649);
      END_STATE();
    case 1265:
      if (lookahead == '&') ADVANCE(1237);
      if (lookahead == 'A' ||
          lookahead == 'B' ||
          lookahead == 'a' ||
          lookahead == 'b') ADVANCE(2445);
      if (lookahead == '-' ||
          (0x2010 <= lookahead && lookahead <= 0x2014) ||
          lookahead == 0x2212 ||
          lookahead == 0x2796) ADVANCE(2439);
      if (lookahead == '.' ||
          lookahead == 0x660 ||
          lookahead == 0x6f0 ||
          lookahead == 0x701 ||
          lookahead == 0x702 ||
          lookahead == 0x200e ||
          lookahead == 0x2024 ||
          lookahead == 0xa4f8 ||
          lookahead == 0xa60e ||
          lookahead == 0x1d16d) ADVANCE(2592);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(2444);
      if (set_contains(aux_sym_result_code_token22_character_set_1, 11, lookahead)) ADVANCE(2591);
      END_STATE();
    case 1266:
      if (lookahead == '&') ADVANCE(1237);
      if (lookahead == '-' ||
          (0x2010 <= lookahead && lookahead <= 0x2014) ||
          lookahead == 0x2212 ||
          lookahead == 0x2796) ADVANCE(2439);
      END_STATE();
    case 1267:
      if (lookahead == '-') ADVANCE(1045);
      END_STATE();
    case 1268:
      if (lookahead == '-') ADVANCE(1267);
      END_STATE();
    case 1269:
      if (lookahead == '-') ADVANCE(1268);
      END_STATE();
    case 1270:
      if (lookahead == '-') ADVANCE(1268);
      if (lookahead == '1') ADVANCE(2742);
      if (set_contains(aux_sym_result_code_token21_character_set_1, 11, lookahead)) ADVANCE(1432);
      END_STATE();
    case 1271:
      if (lookahead == '-') ADVANCE(1268);
      if (lookahead == '1') ADVANCE(1258);
      if (set_contains(aux_sym_result_code_token21_character_set_1, 11, lookahead)) ADVANCE(1449);
      END_STATE();
    case 1272:
      if (lookahead == '-') ADVANCE(1268);
      if (lookahead == '0' ||
          lookahead == 'O' ||
          lookahead == 'o') ADVANCE(2740);
      if (set_contains(aux_sym_result_code_token20_character_set_2, 13, lookahead)) ADVANCE(2441);
      END_STATE();
    case 1273:
      if (lookahead == '-') ADVANCE(1269);
      END_STATE();
    case 1274:
      if (lookahead == '-') ADVANCE(1269);
      if (lookahead == '1') ADVANCE(2742);
      END_STATE();
    case 1275:
      if (lookahead == '-') ADVANCE(1269);
      if (lookahead == '1') ADVANCE(1258);
      END_STATE();
    case 1276:
      if (lookahead == '-') ADVANCE(1269);
      if (lookahead == '2') ADVANCE(1263);
      END_STATE();
    case 1277:
      if (lookahead == '-') ADVANCE(1269);
      if (lookahead == '2') ADVANCE(2744);
      END_STATE();
    case 1278:
      if (lookahead == '-') ADVANCE(1269);
      if (lookahead == '0' ||
          lookahead == 'O' ||
          lookahead == 'o') ADVANCE(2740);
      END_STATE();
    case 1279:
      if (lookahead == '.') ADVANCE(2649);
      END_STATE();
    case 1280:
      if (lookahead == '0') ADVANCE(1298);
      if (lookahead == '1') ADVANCE(1844);
      if (lookahead == '2') ADVANCE(1574);
      if (lookahead == '5') ADVANCE(1575);
      if (lookahead == '6') ADVANCE(1758);
      if (lookahead == '7') ADVANCE(1465);
      if (lookahead == '8') ADVANCE(1827);
      END_STATE();
    case 1281:
      if (lookahead == '0') ADVANCE(1847);
      if (lookahead == '1') ADVANCE(1338);
      if (lookahead == '2') ADVANCE(1339);
      if (lookahead == '4') ADVANCE(1684);
      if (lookahead == '6') ADVANCE(1340);
      if (lookahead == '7') ADVANCE(1341);
      END_STATE();
    case 1282:
      ADVANCE_MAP(
        '0', 1437,
        '2', 1479,
        '7', 1705,
        '9', 2428,
        'A', 1918,
        'a', 1918,
        'B', 1910,
        'b', 1910,
        'D', 1920,
        'd', 1920,
        'E', 1761,
        'e', 1761,
        'F', 1799,
        'f', 1799,
      );
      END_STATE();
    case 1283:
      ADVANCE_MAP(
        '0', 1437,
        '2', 1479,
        '7', 1706,
        '9', 2428,
        'A', 1918,
        'a', 1918,
        'B', 2380,
        'b', 2380,
        'D', 1920,
        'd', 1920,
        'E', 2414,
        'e', 2414,
        'F', 1799,
        'f', 1799,
      );
      END_STATE();
    case 1284:
      if (lookahead == '0') ADVANCE(1461);
      END_STATE();
    case 1285:
      ADVANCE_MAP(
        '0', 1493,
        '2', 1439,
        '7', 1901,
        '9', 2430,
        'D', 1960,
        'd', 1960,
        'F', 1959,
        'f', 1959,
      );
      END_STATE();
    case 1286:
      if (lookahead == '0') ADVANCE(1287);
      if (lookahead == '1') ADVANCE(1331);
      if (lookahead == '6') ADVANCE(1758);
      if (lookahead == '7') ADVANCE(1831);
      if (lookahead == '8') ADVANCE(1884);
      END_STATE();
    case 1287:
      if (lookahead == '0') ADVANCE(1396);
      if (lookahead == '1') ADVANCE(1703);
      if (lookahead == '2') ADVANCE(1509);
      if (lookahead == '7') ADVANCE(1768);
      if (lookahead == '8') ADVANCE(1812);
      END_STATE();
    case 1288:
      if (lookahead == '0') ADVANCE(1396);
      if (lookahead == '1') ADVANCE(1711);
      if (lookahead == '2') ADVANCE(1509);
      if (lookahead == '7') ADVANCE(1768);
      if (lookahead == '8') ADVANCE(1812);
      END_STATE();
    case 1289:
      if (lookahead == '0') ADVANCE(1396);
      if (lookahead == '1') ADVANCE(1720);
      if (lookahead == '2') ADVANCE(1509);
      if (lookahead == '7') ADVANCE(1768);
      if (lookahead == '8') ADVANCE(1812);
      END_STATE();
    case 1290:
      if (lookahead == '0') ADVANCE(1806);
      if (lookahead == '1') ADVANCE(1631);
      if (lookahead == '6') ADVANCE(1741);
      if (lookahead == '9') ADVANCE(1786);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1782);
      END_STATE();
    case 1291:
      if (lookahead == '0') ADVANCE(1806);
      if (lookahead == '1') ADVANCE(1632);
      if (lookahead == '6') ADVANCE(1741);
      if (lookahead == '9') ADVANCE(1786);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1782);
      END_STATE();
    case 1292:
      if (lookahead == '0') ADVANCE(1806);
      if (lookahead == '1') ADVANCE(1638);
      if (lookahead == '6') ADVANCE(1741);
      if (lookahead == '9') ADVANCE(1786);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1782);
      END_STATE();
    case 1293:
      if (lookahead == '0') ADVANCE(1806);
      if (lookahead == '1') ADVANCE(1639);
      if (lookahead == '6') ADVANCE(1741);
      if (lookahead == '9') ADVANCE(1786);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1782);
      END_STATE();
    case 1294:
      ADVANCE_MAP(
        '0', 1489,
        '2', 1917,
        'B', 2380,
        'b', 2380,
        'D', 2405,
        'd', 2405,
        'E', 2414,
        'e', 2414,
        'F', 1798,
        'f', 1798,
      );
      END_STATE();
    case 1295:
      ADVANCE_MAP(
        '0', 2694,
        '@', 2631,
        'O', 2690,
        'o', 2699,
        '1', 2601,
        '8', 2601,
        ':', 2615,
        'X', 2615,
        'x', 2615,
      );
      if (('2' <= lookahead && lookahead <= '7')) ADVANCE(2602);
      if (('a' <= lookahead && lookahead <= 'h')) ADVANCE(2597);
      if (set_contains(aux_sym_result_code_token22_character_set_1, 11, lookahead)) SKIP(1296);
      END_STATE();
    case 1296:
      if (lookahead == '0') ADVANCE(2694);
      if (lookahead == 'O') ADVANCE(2690);
      if (lookahead == 'o') ADVANCE(2699);
      if (set_contains(aux_sym_result_code_token20_character_set_2, 13, lookahead)) SKIP(1296);
      END_STATE();
    case 1297:
      if (lookahead == '0') ADVANCE(1702);
      END_STATE();
    case 1298:
      if (lookahead == '0') ADVANCE(1702);
      if (lookahead == '1') ADVANCE(1677);
      if (lookahead == '7') ADVANCE(1757);
      END_STATE();
    case 1299:
      if (lookahead == '0') ADVANCE(1702);
      if (lookahead == '1') ADVANCE(1710);
      if (lookahead == '7') ADVANCE(1757);
      END_STATE();
    case 1300:
      if (lookahead == '0') ADVANCE(1702);
      if (lookahead == '1') ADVANCE(1726);
      END_STATE();
    case 1301:
      ADVANCE_MAP(
        '0', 1500,
        '1', 1882,
        '2', 1290,
        '3', 1495,
        '5', 1441,
        '6', 1512,
        '7', 1513,
        '9', 2432,
        'A', 1316,
        'a', 1316,
        'B', 1447,
        'b', 1447,
        'D', 1966,
        'd', 1966,
        'E', 1764,
        'e', 1764,
        'F', 1965,
        'f', 1965,
      );
      END_STATE();
    case 1302:
      ADVANCE_MAP(
        '0', 1500,
        '1', 1882,
        '2', 1290,
        '3', 1495,
        '5', 1441,
        '6', 1512,
        '7', 1514,
        '9', 2432,
        'A', 1316,
        'a', 1316,
        'B', 1448,
        'b', 1448,
        'D', 1966,
        'd', 1966,
        'E', 1764,
        'e', 1764,
        'F', 1965,
        'f', 1965,
      );
      END_STATE();
    case 1303:
      ADVANCE_MAP(
        '0', 1500,
        '1', 1882,
        '2', 1290,
        '3', 1495,
        '5', 1441,
        '6', 1512,
        '7', 1514,
        '9', 2432,
        'A', 1316,
        'a', 1316,
        'B', 1448,
        'b', 1448,
        'D', 1966,
        'd', 1966,
        'E', 1767,
        'e', 1767,
        'F', 1965,
        'f', 1965,
      );
      END_STATE();
    case 1304:
      if (lookahead == '0') ADVANCE(1482);
      END_STATE();
    case 1305:
      if (lookahead == '0') ADVANCE(1327);
      if (lookahead == '1') ADVANCE(1331);
      if (lookahead == '7') ADVANCE(1831);
      END_STATE();
    case 1306:
      if (lookahead == '0') ADVANCE(1327);
      if (lookahead == '1') ADVANCE(1331);
      if (lookahead == '7') ADVANCE(1831);
      if (lookahead == '8') ADVANCE(1891);
      END_STATE();
    case 1307:
      if (lookahead == '0') ADVANCE(1327);
      if (lookahead == '1') ADVANCE(1332);
      if (lookahead == '7') ADVANCE(1831);
      END_STATE();
    case 1308:
      ADVANCE_MAP(
        '0', 1501,
        '1', 1882,
        '2', 1291,
        '3', 1495,
        '5', 1441,
        '6', 1512,
        '7', 1517,
        '9', 2432,
        'A', 1315,
        'a', 1315,
        'B', 1448,
        'b', 1448,
        'D', 1966,
        'd', 1966,
        'E', 1764,
        'e', 1764,
        'F', 1965,
        'f', 1965,
      );
      END_STATE();
    case 1309:
      ADVANCE_MAP(
        '0', 1501,
        '1', 1882,
        '2', 1291,
        '3', 1495,
        '5', 1441,
        '6', 1512,
        '7', 1517,
        '9', 2432,
        'A', 1315,
        'a', 1315,
        'B', 1448,
        'b', 1448,
        'D', 1966,
        'd', 1966,
        'E', 1767,
        'e', 1767,
        'F', 1965,
        'f', 1965,
      );
      END_STATE();
    case 1310:
      ADVANCE_MAP(
        '0', 1501,
        '1', 1882,
        '2', 1291,
        '3', 1495,
        '5', 1441,
        '6', 1512,
        '7', 1516,
        '9', 2432,
        'A', 1315,
        'a', 1315,
        'B', 1447,
        'b', 1447,
        'D', 1966,
        'd', 1966,
        'E', 1764,
        'e', 1764,
        'F', 1965,
        'f', 1965,
      );
      END_STATE();
    case 1311:
      if (lookahead == '0') ADVANCE(1453);
      END_STATE();
    case 1312:
      if (lookahead == '0') ADVANCE(1452);
      END_STATE();
    case 1313:
      if (lookahead == '0') ADVANCE(1382);
      END_STATE();
    case 1314:
      if (lookahead == '0') ADVANCE(1382);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1911);
      END_STATE();
    case 1315:
      if (lookahead == '0') ADVANCE(1348);
      if (lookahead == '7') ADVANCE(1474);
      END_STATE();
    case 1316:
      if (lookahead == '0') ADVANCE(1348);
      if (lookahead == '7') ADVANCE(1474);
      if (lookahead == ';') ADVANCE(2722);
      END_STATE();
    case 1317:
      if (lookahead == '0') ADVANCE(1534);
      END_STATE();
    case 1318:
      ADVANCE_MAP(
        '0', 1527,
        '2', 1484,
        '7', 1707,
        'A', 1918,
        'a', 1918,
        'D', 1977,
        'd', 1977,
        'E', 1760,
        'e', 1760,
      );
      END_STATE();
    case 1319:
      if (lookahead == '0') ADVANCE(1759);
      if (lookahead == '2') ADVANCE(1523);
      if (lookahead == '7') ADVANCE(1704);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1918);
      END_STATE();
    case 1320:
      if (lookahead == '0') ADVANCE(1530);
      END_STATE();
    case 1321:
      if (lookahead == '0') ADVANCE(1438);
      if (lookahead == '2') ADVANCE(1490);
      if (lookahead == '7') ADVANCE(1881);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1912);
      END_STATE();
    case 1322:
      if (lookahead == '0') ADVANCE(1911);
      END_STATE();
    case 1323:
      if (lookahead == '0') ADVANCE(1300);
      if (lookahead == '1') ADVANCE(1844);
      if (lookahead == '6') ADVANCE(1758);
      if (lookahead == '8') ADVANCE(1884);
      END_STATE();
    case 1324:
      if (lookahead == '0') ADVANCE(1618);
      END_STATE();
    case 1325:
      if (lookahead == '0') ADVANCE(1618);
      if (lookahead == '1') ADVANCE(2403);
      END_STATE();
    case 1326:
      if (lookahead == '0') ADVANCE(1395);
      if (lookahead == '1') ADVANCE(1703);
      if (lookahead == '2') ADVANCE(1509);
      if (lookahead == '7') ADVANCE(1768);
      if (lookahead == '8') ADVANCE(1812);
      END_STATE();
    case 1327:
      if (lookahead == '0') ADVANCE(1395);
      if (lookahead == '1') ADVANCE(1711);
      if (lookahead == '2') ADVANCE(1509);
      if (lookahead == '7') ADVANCE(1768);
      if (lookahead == '8') ADVANCE(1812);
      END_STATE();
    case 1328:
      if (lookahead == '0') ADVANCE(1395);
      if (lookahead == '1') ADVANCE(1720);
      if (lookahead == '2') ADVANCE(1509);
      if (lookahead == '7') ADVANCE(1768);
      if (lookahead == '8') ADVANCE(1812);
      END_STATE();
    case 1329:
      if (lookahead == '0') ADVANCE(1927);
      if (lookahead == '8') ADVANCE(1928);
      END_STATE();
    case 1330:
      if (lookahead == '0') ADVANCE(1297);
      if (lookahead == '6') ADVANCE(1758);
      if (lookahead == '8') ADVANCE(1884);
      END_STATE();
    case 1331:
      if (lookahead == '0') ADVANCE(1588);
      if (lookahead == '8') ADVANCE(1764);
      END_STATE();
    case 1332:
      if (lookahead == '0') ADVANCE(1588);
      if (lookahead == '8') ADVANCE(1767);
      END_STATE();
    case 1333:
      ADVANCE_MAP(
        '0', 1929,
        '1', 1933,
        '2', 1934,
        '3', 1935,
        '4', 1936,
        'C', 1937,
        'c', 1937,
        'D', 1938,
        'd', 1938,
        'F', 1939,
        'f', 1939,
      );
      END_STATE();
    case 1334:
      if (lookahead == '0') ADVANCE(1912);
      if (lookahead == '1') ADVANCE(1912);
      if (lookahead == '2') ADVANCE(1912);
      END_STATE();
    case 1335:
      if (lookahead == '0') ADVANCE(1912);
      if (lookahead == '1') ADVANCE(1912);
      if (lookahead == '2') ADVANCE(1912);
      if (lookahead == '3') ADVANCE(1912);
      if (lookahead == '4') ADVANCE(1912);
      END_STATE();
    case 1336:
      if (lookahead == '0') ADVANCE(1913);
      if (lookahead == '1') ADVANCE(1913);
      if (lookahead == '2') ADVANCE(1913);
      END_STATE();
    case 1337:
      if (lookahead == '0') ADVANCE(1913);
      if (lookahead == '1') ADVANCE(1913);
      if (lookahead == '2') ADVANCE(1913);
      if (lookahead == '3') ADVANCE(1913);
      if (lookahead == '4') ADVANCE(1913);
      END_STATE();
    case 1338:
      if (lookahead == '0') ADVANCE(1934);
      if (lookahead == '1') ADVANCE(1935);
      if (lookahead == '2') ADVANCE(1936);
      END_STATE();
    case 1339:
      if (lookahead == '0') ADVANCE(1937);
      if (lookahead == '1') ADVANCE(1938);
      if (lookahead == '3') ADVANCE(1939);
      END_STATE();
    case 1340:
      if (lookahead == '0') ADVANCE(1942);
      END_STATE();
    case 1341:
      if (lookahead == '0') ADVANCE(1943);
      END_STATE();
    case 1342:
      if (lookahead == '0') ADVANCE(1914);
      if (lookahead == '1') ADVANCE(1914);
      if (lookahead == '2') ADVANCE(1914);
      END_STATE();
    case 1343:
      if (lookahead == '0') ADVANCE(1914);
      if (lookahead == '1') ADVANCE(1914);
      if (lookahead == '2') ADVANCE(1914);
      if (lookahead == '3') ADVANCE(1914);
      if (lookahead == '4') ADVANCE(1914);
      END_STATE();
    case 1344:
      if (lookahead == '0') ADVANCE(1916);
      if (lookahead == '1') ADVANCE(1916);
      if (lookahead == '2') ADVANCE(1916);
      END_STATE();
    case 1345:
      if (lookahead == '0') ADVANCE(1916);
      if (lookahead == '1') ADVANCE(1916);
      if (lookahead == '2') ADVANCE(1916);
      if (lookahead == '3') ADVANCE(1916);
      if (lookahead == '4') ADVANCE(1916);
      END_STATE();
    case 1346:
      if (lookahead == '0') ADVANCE(1953);
      END_STATE();
    case 1347:
      if (lookahead == '0') ADVANCE(1954);
      END_STATE();
    case 1348:
      if (lookahead == '0') ADVANCE(1954);
      if (lookahead == '1') ADVANCE(1954);
      END_STATE();
    case 1349:
      if (lookahead == '0') ADVANCE(1954);
      if (lookahead == '1') ADVANCE(1954);
      if (lookahead == '2') ADVANCE(1954);
      END_STATE();
    case 1350:
      if (lookahead == '0') ADVANCE(1954);
      if (lookahead == '1') ADVANCE(1954);
      if (lookahead == '2') ADVANCE(1954);
      if (lookahead == '3') ADVANCE(1954);
      if (lookahead == '4') ADVANCE(1954);
      END_STATE();
    case 1351:
      if (lookahead == '0') ADVANCE(1954);
      if (lookahead == '3') ADVANCE(1954);
      END_STATE();
    case 1352:
      if (lookahead == '0') ADVANCE(1960);
      if (lookahead == '1') ADVANCE(1960);
      if (lookahead == '2') ADVANCE(1960);
      END_STATE();
    case 1353:
      if (lookahead == '0') ADVANCE(1960);
      if (lookahead == '1') ADVANCE(1960);
      if (lookahead == '2') ADVANCE(1960);
      if (lookahead == '3') ADVANCE(1960);
      if (lookahead == '4') ADVANCE(1960);
      END_STATE();
    case 1354:
      if (lookahead == '0') ADVANCE(1959);
      END_STATE();
    case 1355:
      if (lookahead == '0') ADVANCE(1978);
      if (lookahead == '1') ADVANCE(1978);
      if (lookahead == '2') ADVANCE(1978);
      END_STATE();
    case 1356:
      if (lookahead == '0') ADVANCE(1978);
      if (lookahead == '1') ADVANCE(1978);
      if (lookahead == '2') ADVANCE(1978);
      if (lookahead == '3') ADVANCE(1978);
      if (lookahead == '4') ADVANCE(1978);
      END_STATE();
    case 1357:
      if (lookahead == '0') ADVANCE(1979);
      END_STATE();
    case 1358:
      if (lookahead == '0') ADVANCE(1970);
      if (lookahead == '1') ADVANCE(1980);
      if (lookahead == '3') ADVANCE(1971);
      if (lookahead == '5') ADVANCE(1728);
      END_STATE();
    case 1359:
      if (lookahead == '0') ADVANCE(1970);
      if (lookahead == '1') ADVANCE(1981);
      if (lookahead == '3') ADVANCE(1971);
      if (lookahead == '5') ADVANCE(1729);
      END_STATE();
    case 1360:
      if (lookahead == '0') ADVANCE(1966);
      if (lookahead == '1') ADVANCE(1966);
      if (lookahead == '2') ADVANCE(1966);
      END_STATE();
    case 1361:
      if (lookahead == '0') ADVANCE(1966);
      if (lookahead == '1') ADVANCE(1966);
      if (lookahead == '2') ADVANCE(1966);
      if (lookahead == '3') ADVANCE(1966);
      if (lookahead == '4') ADVANCE(1966);
      END_STATE();
    case 1362:
      if (lookahead == '0') ADVANCE(1965);
      if (lookahead == '3') ADVANCE(1954);
      if (lookahead == '4') ADVANCE(1954);
      if (lookahead == '5') ADVANCE(1954);
      END_STATE();
    case 1363:
      if (lookahead == '0') ADVANCE(1967);
      END_STATE();
    case 1364:
      if (lookahead == '0') ADVANCE(1982);
      END_STATE();
    case 1365:
      if (lookahead == '0') ADVANCE(1968);
      if (lookahead == '1') ADVANCE(1968);
      if (lookahead == '2') ADVANCE(1968);
      END_STATE();
    case 1366:
      if (lookahead == '0') ADVANCE(1968);
      if (lookahead == '1') ADVANCE(1968);
      if (lookahead == '2') ADVANCE(1968);
      if (lookahead == '3') ADVANCE(1968);
      if (lookahead == '4') ADVANCE(1968);
      END_STATE();
    case 1367:
      if (lookahead == '0') ADVANCE(1969);
      END_STATE();
    case 1368:
      if (lookahead == '0') ADVANCE(1962);
      END_STATE();
    case 1369:
      if (lookahead == '0') ADVANCE(1983);
      if (lookahead == '1') ADVANCE(1983);
      if (lookahead == '2') ADVANCE(1983);
      END_STATE();
    case 1370:
      if (lookahead == '0') ADVANCE(1983);
      if (lookahead == '1') ADVANCE(1983);
      if (lookahead == '2') ADVANCE(1983);
      if (lookahead == '3') ADVANCE(1983);
      if (lookahead == '4') ADVANCE(1983);
      END_STATE();
    case 1371:
      if (lookahead == '0') ADVANCE(1975);
      if (lookahead == '1') ADVANCE(1975);
      if (lookahead == '2') ADVANCE(1975);
      END_STATE();
    case 1372:
      if (lookahead == '0') ADVANCE(1975);
      if (lookahead == '1') ADVANCE(1975);
      if (lookahead == '2') ADVANCE(1975);
      if (lookahead == '3') ADVANCE(1975);
      if (lookahead == '4') ADVANCE(1975);
      END_STATE();
    case 1373:
      if (lookahead == '0') ADVANCE(1976);
      END_STATE();
    case 1374:
      if (lookahead == '0') ADVANCE(1977);
      if (lookahead == '1') ADVANCE(1977);
      if (lookahead == '2') ADVANCE(1977);
      END_STATE();
    case 1375:
      if (lookahead == '0') ADVANCE(1977);
      if (lookahead == '1') ADVANCE(1977);
      if (lookahead == '2') ADVANCE(1977);
      if (lookahead == '3') ADVANCE(1977);
      if (lookahead == '4') ADVANCE(1977);
      END_STATE();
    case 1376:
      if (lookahead == '0') ADVANCE(1299);
      if (lookahead == '2') ADVANCE(1574);
      if (lookahead == '5') ADVANCE(1575);
      if (lookahead == '6') ADVANCE(1758);
      if (lookahead == '7') ADVANCE(1465);
      if (lookahead == '8') ADVANCE(1827);
      END_STATE();
    case 1377:
      if (lookahead == '0') ADVANCE(1848);
      if (lookahead == '1') ADVANCE(1334);
      END_STATE();
    case 1378:
      if (lookahead == '0') ADVANCE(1883);
      END_STATE();
    case 1379:
      if (lookahead == '0') ADVANCE(1480);
      if (lookahead == '2') ADVANCE(1492);
      if (lookahead == '7') ADVANCE(1895);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1913);
      END_STATE();
    case 1380:
      if (lookahead == '0') ADVANCE(1849);
      if (lookahead == '1') ADVANCE(1336);
      END_STATE();
    case 1381:
      if (lookahead == '0') ADVANCE(1487);
      if (lookahead == '2') ADVANCE(1494);
      if (lookahead == '7') ADVANCE(1897);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1914);
      END_STATE();
    case 1382:
      if (lookahead == '0') ADVANCE(1686);
      END_STATE();
    case 1383:
      if (lookahead == '0') ADVANCE(1850);
      if (lookahead == '1') ADVANCE(1342);
      END_STATE();
    case 1384:
      if (lookahead == '0') ADVANCE(1491);
      if (lookahead == '2') ADVANCE(1498);
      if (lookahead == '7') ADVANCE(1898);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1916);
      END_STATE();
    case 1385:
      if (lookahead == '0') ADVANCE(1852);
      if (lookahead == '1') ADVANCE(1344);
      END_STATE();
    case 1386:
      if (lookahead == '0') ADVANCE(1887);
      END_STATE();
    case 1387:
      if (lookahead == '0') ADVANCE(1497);
      if (lookahead == '2') ADVANCE(1507);
      if (lookahead == '7') ADVANCE(1902);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1978);
      END_STATE();
    case 1388:
      if (lookahead == '0') ADVANCE(1858);
      if (lookahead == '1') ADVANCE(1352);
      if (lookahead == '6') ADVANCE(1354);
      END_STATE();
    case 1389:
      if (lookahead == '0') ADVANCE(1860);
      if (lookahead == '1') ADVANCE(1355);
      END_STATE();
    case 1390:
      if (lookahead == '0') ADVANCE(1862);
      if (lookahead == '1') ADVANCE(1360);
      if (lookahead == '5') ADVANCE(1622);
      if (lookahead == '6') ADVANCE(1362);
      END_STATE();
    case 1391:
      if (lookahead == '0') ADVANCE(1862);
      if (lookahead == '1') ADVANCE(1360);
      if (lookahead == '5') ADVANCE(1622);
      if (lookahead == '6') ADVANCE(1362);
      if (lookahead == '7') ADVANCE(1341);
      END_STATE();
    case 1392:
      if (lookahead == '0') ADVANCE(1889);
      END_STATE();
    case 1393:
      if (lookahead == '0') ADVANCE(1855);
      if (lookahead == '1') ADVANCE(1349);
      END_STATE();
    case 1394:
      if (lookahead == '0') ADVANCE(1855);
      if (lookahead == '1') ADVANCE(1349);
      if (lookahead == '6') ADVANCE(1364);
      END_STATE();
    case 1395:
      if (lookahead == '0') ADVANCE(1782);
      END_STATE();
    case 1396:
      if (lookahead == '0') ADVANCE(1782);
      if (lookahead == '3') ADVANCE(1685);
      END_STATE();
    case 1397:
      if (lookahead == '0') ADVANCE(1866);
      if (lookahead == '1') ADVANCE(1365);
      if (lookahead == '6') ADVANCE(1367);
      END_STATE();
    case 1398:
      if (lookahead == '0') ADVANCE(1868);
      if (lookahead == '1') ADVANCE(1369);
      END_STATE();
    case 1399:
      if (lookahead == '0') ADVANCE(1892);
      END_STATE();
    case 1400:
      if (lookahead == '0') ADVANCE(1869);
      if (lookahead == '1') ADVANCE(1371);
      if (lookahead == '5') ADVANCE(1622);
      if (lookahead == '6') ADVANCE(1362);
      END_STATE();
    case 1401:
      if (lookahead == '0') ADVANCE(1869);
      if (lookahead == '1') ADVANCE(1371);
      if (lookahead == '5') ADVANCE(1622);
      if (lookahead == '6') ADVANCE(1362);
      if (lookahead == '7') ADVANCE(1341);
      END_STATE();
    case 1402:
      if (lookahead == '0') ADVANCE(1870);
      if (lookahead == '1') ADVANCE(1374);
      if (lookahead == '7') ADVANCE(1341);
      END_STATE();
    case 1403:
      if (lookahead == '0') ADVANCE(1741);
      if (lookahead == '5') ADVANCE(1691);
      if (lookahead == '6') ADVANCE(1626);
      END_STATE();
    case 1404:
      ADVANCE_MAP(
        '0', 1505,
        '2', 1481,
        '7', 1904,
        '9', 2434,
        'D', 1954,
        'd', 1954,
        'E', 1762,
        'e', 1762,
        'F', 1982,
        'f', 1982,
      );
      END_STATE();
    case 1405:
      ADVANCE_MAP(
        '0', 1505,
        '2', 1481,
        '7', 1900,
        '9', 2434,
        'B', 1908,
        'b', 1908,
        'D', 1954,
        'd', 1954,
        'E', 1762,
        'e', 1762,
        'F', 1982,
        'f', 1982,
      );
      END_STATE();
    case 1406:
      ADVANCE_MAP(
        '0', 1524,
        '1', 1882,
        '2', 1292,
        '3', 1495,
        '5', 1441,
        '6', 1512,
        '7', 1515,
        '9', 2432,
        'A', 1316,
        'a', 1316,
        'B', 1448,
        'b', 1448,
        'D', 1975,
        'd', 1975,
        'E', 1764,
        'e', 1764,
        'F', 1965,
        'f', 1965,
      );
      END_STATE();
    case 1407:
      if (lookahead == '0') ADVANCE(1763);
      if (lookahead == '2') ADVANCE(1499);
      if (lookahead == '7') ADVANCE(2400);
      if (lookahead == '9') ADVANCE(2429);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(1953);
      END_STATE();
    case 1408:
      ADVANCE_MAP(
        '0', 1525,
        '1', 1882,
        '2', 1293,
        '3', 1495,
        '5', 1441,
        '6', 1512,
        '7', 1518,
        '9', 2432,
        'A', 1315,
        'a', 1315,
        'B', 1448,
        'b', 1448,
        'D', 1975,
        'd', 1975,
        'E', 1764,
        'e', 1764,
        'F', 1965,
        'f', 1965,
      );
      END_STATE();
    case 1409:
      if (lookahead == '0') ADVANCE(1531);
      END_STATE();
    case 1410:
      if (lookahead == '0') ADVANCE(1504);
      if (lookahead == '2') ADVANCE(1511);
      if (lookahead == '7') ADVANCE(1903);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1954);
      END_STATE();
    case 1411:
      ADVANCE_MAP(
        '0', 1510,
        '2', 1488,
        '7', 1896,
        '9', 2435,
        'B', 1954,
        'b', 1954,
        'D', 1968,
        'd', 1968,
        'F', 1969,
        'f', 1969,
      );
      END_STATE();
    case 1412:
      if (lookahead == '0') ADVANCE(1539);
      END_STATE();
    case 1413:
      if (lookahead == '0') ADVANCE(1520);
      if (lookahead == '2') ADVANCE(1526);
      if (lookahead == '7') ADVANCE(1905);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1983);
      END_STATE();
    case 1414:
      if (lookahead == '0') ADVANCE(1766);
      if (lookahead == '2') ADVANCE(1508);
      if (lookahead == '7') ADVANCE(2401);
      if (lookahead == '9') ADVANCE(2431);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(1979);
      END_STATE();
    case 1415:
      if (lookahead == '0') ADVANCE(1544);
      END_STATE();
    case 1416:
      ADVANCE_MAP(
        '0', 1769,
        '2', 1522,
        '7', 1907,
        '9', 2433,
        'B', 1954,
        'b', 1954,
        'F', 1967,
        'f', 1967,
      );
      END_STATE();
    case 1417:
      if (lookahead == '0') ADVANCE(1553);
      END_STATE();
    case 1418:
      if (lookahead == '0') ADVANCE(1554);
      END_STATE();
    case 1419:
      if (lookahead == '0') ADVANCE(1555);
      END_STATE();
    case 1420:
      if (lookahead == '0') ADVANCE(1532);
      END_STATE();
    case 1421:
      if (lookahead == '0') ADVANCE(1288);
      if (lookahead == '1') ADVANCE(1331);
      if (lookahead == '6') ADVANCE(1758);
      if (lookahead == '7') ADVANCE(1831);
      if (lookahead == '8') ADVANCE(1884);
      END_STATE();
    case 1422:
      if (lookahead == '0') ADVANCE(1288);
      if (lookahead == '1') ADVANCE(1332);
      if (lookahead == '6') ADVANCE(1758);
      if (lookahead == '7') ADVANCE(1831);
      if (lookahead == '8') ADVANCE(1884);
      END_STATE();
    case 1423:
      if (lookahead == '0') ADVANCE(1533);
      if (lookahead == '1') ADVANCE(1875);
      END_STATE();
    case 1424:
      if (lookahead == '0') ADVANCE(1326);
      if (lookahead == '1') ADVANCE(1331);
      if (lookahead == '7') ADVANCE(1831);
      END_STATE();
    case 1425:
      if (lookahead == '0') ADVANCE(1326);
      if (lookahead == '1') ADVANCE(1331);
      if (lookahead == '7') ADVANCE(1831);
      if (lookahead == '8') ADVANCE(1891);
      END_STATE();
    case 1426:
      if (lookahead == '0') ADVANCE(1545);
      if (lookahead == '1') ADVANCE(1875);
      END_STATE();
    case 1427:
      if (lookahead == '0') ADVANCE(1538);
      END_STATE();
    case 1428:
      if (lookahead == '0') ADVANCE(1289);
      if (lookahead == '1') ADVANCE(1331);
      if (lookahead == '6') ADVANCE(1758);
      if (lookahead == '7') ADVANCE(1831);
      if (lookahead == '8') ADVANCE(1884);
      END_STATE();
    case 1429:
      if (lookahead == '0') ADVANCE(1328);
      if (lookahead == '1') ADVANCE(1331);
      if (lookahead == '7') ADVANCE(1831);
      END_STATE();
    case 1430:
      if (lookahead == '1') ADVANCE(2670);
      if (set_contains(aux_sym_result_code_token21_character_set_1, 11, lookahead)) SKIP(1430);
      END_STATE();
    case 1431:
      ADVANCE_MAP(
        '1', 1280,
        '3', 1730,
        '4', 1595,
        '5', 1842,
        '6', 1462,
        '7', 1676,
        '8', 1573,
        'X', 1446,
        'x', 1446,
      );
      END_STATE();
    case 1432:
      if (lookahead == '1') ADVANCE(2742);
      END_STATE();
    case 1433:
      if (lookahead == '1') ADVANCE(2742);
      if (lookahead == '0' ||
          lookahead == 'O' ||
          lookahead == 'o') ADVANCE(2640);
      if (set_contains(aux_sym_result_code_token21_character_set_1, 11, lookahead)) ADVANCE(1432);
      END_STATE();
    case 1434:
      if (lookahead == '1') ADVANCE(2742);
      if (set_contains(aux_sym_result_code_token21_character_set_1, 11, lookahead)) ADVANCE(1432);
      END_STATE();
    case 1435:
      if (lookahead == '1') ADVANCE(1312);
      if (lookahead == '4') ADVANCE(1774);
      if (lookahead == '8') ADVANCE(1603);
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(1577);
      END_STATE();
    case 1436:
      ADVANCE_MAP(
        '1', 1376,
        '3', 1730,
        '4', 1599,
        '6', 1773,
        '7', 1676,
        '8', 1573,
        'X', 1601,
        'x', 1601,
      );
      END_STATE();
    case 1437:
      if (lookahead == '1') ADVANCE(1333);
      if (lookahead == '3') ADVANCE(1684);
      if (lookahead == '4') ADVANCE(1735);
      END_STATE();
    case 1438:
      if (lookahead == '1') ADVANCE(1335);
      END_STATE();
    case 1439:
      if (lookahead == '1') ADVANCE(1627);
      END_STATE();
    case 1440:
      ADVANCE_MAP(
        '1', 1286,
        '2', 1506,
        '3', 1693,
        '4', 1596,
        '5', 1876,
        '6', 1358,
        '8', 1586,
        '9', 1732,
        'X', 1535,
        'x', 1535,
      );
      END_STATE();
    case 1441:
      if (lookahead == '1') ADVANCE(1743);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1473);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(2388);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(2382);
      END_STATE();
    case 1442:
      ADVANCE_MAP(
        '1', 1306,
        '2', 1506,
        '3', 1693,
        '4', 1698,
        '5', 1878,
        '6', 1358,
        '8', 1589,
        '9', 1732,
        'X', 1546,
        'x', 1546,
      );
      END_STATE();
    case 1443:
      if (lookahead == '1') ADVANCE(1572);
      if (lookahead == '3') ADVANCE(1730);
      if (lookahead == '6') ADVANCE(1773);
      if (lookahead == '7') ADVANCE(1676);
      if (lookahead == '8') ADVANCE(1602);
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(1590);
      END_STATE();
    case 1444:
      if (lookahead == '1') ADVANCE(1323);
      if (lookahead == '4') ADVANCE(1600);
      if (lookahead == '6') ADVANCE(1463);
      if (lookahead == '8') ADVANCE(1593);
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(1591);
      END_STATE();
    case 1445:
      if (lookahead == '1') ADVANCE(1330);
      if (lookahead == '4') ADVANCE(1594);
      if (lookahead == '8') ADVANCE(1607);
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(1592);
      END_STATE();
    case 1446:
      ADVANCE_MAP(
        '1', 1795,
        '2', 1282,
        '3', 1314,
        '5', 2423,
        '6', 1796,
        'A', 2383,
        'a', 2383,
        'B', 2385,
        'b', 2385,
        'F', 2424,
        'f', 2424,
      );
      END_STATE();
    case 1447:
      if (lookahead == '1') ADVANCE(1622);
      if (lookahead == ';') ADVANCE(1248);
      END_STATE();
    case 1448:
      if (lookahead == '1') ADVANCE(1622);
      if (lookahead == ';') ADVANCE(2648);
      END_STATE();
    case 1449:
      if (lookahead == '1') ADVANCE(1258);
      END_STATE();
    case 1450:
      if (lookahead == '1') ADVANCE(1258);
      if (set_contains(aux_sym_result_code_token21_character_set_1, 11, lookahead)) ADVANCE(1449);
      END_STATE();
    case 1451:
      ADVANCE_MAP(
        '1', 1307,
        '2', 1506,
        '3', 1693,
        '4', 1698,
        '5', 1878,
        '6', 1359,
        '8', 1589,
        '9', 1732,
        'X', 1551,
        'x', 1551,
      );
      END_STATE();
    case 1452:
      if (lookahead == '1') ADVANCE(1701);
      END_STATE();
    case 1453:
      if (lookahead == '1') ADVANCE(1716);
      if (lookahead == '7') ADVANCE(1769);
      END_STATE();
    case 1454:
      if (lookahead == '1') ADVANCE(1423);
      if (lookahead == '4') ADVANCE(1785);
      if (lookahead == '6') ADVANCE(1475);
      if (lookahead == '8') ADVANCE(1664);
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(1587);
      END_STATE();
    case 1455:
      if (lookahead == '1') ADVANCE(1348);
      if (lookahead == '2') ADVANCE(1629);
      if (lookahead == '3') ADVANCE(1754);
      END_STATE();
    case 1456:
      if (lookahead == '1') ADVANCE(1348);
      if (lookahead == '2') ADVANCE(1636);
      if (lookahead == '3') ADVANCE(1754);
      END_STATE();
    case 1457:
      if (lookahead == '1') ADVANCE(1348);
      if (lookahead == '2') ADVANCE(1630);
      if (lookahead == '3') ADVANCE(1754);
      END_STATE();
    case 1458:
      if (lookahead == '1') ADVANCE(1348);
      if (lookahead == '2') ADVANCE(1637);
      if (lookahead == '3') ADVANCE(1754);
      END_STATE();
    case 1459:
      if (lookahead == '1') ADVANCE(1872);
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(2395);
      END_STATE();
    case 1460:
      if (lookahead == '1') ADVANCE(1426);
      if (lookahead == '4') ADVANCE(1683);
      if (lookahead == '5') ADVANCE(1874);
      if (lookahead == '6') ADVANCE(1475);
      if (lookahead == '8') ADVANCE(1664);
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(1529);
      END_STATE();
    case 1461:
      if (lookahead == '1') ADVANCE(1871);
      if (lookahead == '7') ADVANCE(1763);
      END_STATE();
    case 1462:
      if (lookahead == '1') ADVANCE(1911);
      if (lookahead == '5') ADVANCE(1606);
      if (lookahead == '9') ADVANCE(1846);
      END_STATE();
    case 1463:
      if (lookahead == '1') ADVANCE(1911);
      if (lookahead == '5') ADVANCE(1678);
      END_STATE();
    case 1464:
      if (lookahead == '1') ADVANCE(1557);
      if (lookahead == '6') ADVANCE(1475);
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(1604);
      END_STATE();
    case 1465:
      if (lookahead == '1') ADVANCE(1922);
      END_STATE();
    case 1466:
      if (lookahead == '1') ADVANCE(1284);
      if (lookahead == '4') ADVANCE(1830);
      if (lookahead == '8') ADVANCE(1609);
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(1578);
      END_STATE();
    case 1467:
      if (lookahead == '1') ADVANCE(1304);
      if (lookahead == '4') ADVANCE(1787);
      if (lookahead == '8') ADVANCE(1581);
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(1582);
      END_STATE();
    case 1468:
      if (lookahead == '1') ADVANCE(1311);
      if (lookahead == '4') ADVANCE(1692);
      if (lookahead == '5') ADVANCE(1877);
      if (lookahead == '6') ADVANCE(1473);
      if (lookahead == '8') ADVANCE(1671);
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(1541);
      END_STATE();
    case 1469:
      if (lookahead == '1') ADVANCE(1311);
      if (lookahead == '4') ADVANCE(1692);
      if (lookahead == '5') ADVANCE(1877);
      if (lookahead == '8') ADVANCE(1671);
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(1540);
      END_STATE();
    case 1470:
      if (lookahead == '1') ADVANCE(1317);
      if (lookahead == '4') ADVANCE(1690);
      if (lookahead == '5') ADVANCE(1877);
      if (lookahead == '8') ADVANCE(1669);
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(1542);
      END_STATE();
    case 1471:
      if (lookahead == '1') ADVANCE(1947);
      END_STATE();
    case 1472:
      if (lookahead == '1') ADVANCE(1951);
      END_STATE();
    case 1473:
      if (lookahead == '1') ADVANCE(1954);
      END_STATE();
    case 1474:
      if (lookahead == '1') ADVANCE(1954);
      if (lookahead == '2') ADVANCE(1954);
      END_STATE();
    case 1475:
      if (lookahead == '1') ADVANCE(1954);
      if (lookahead == '5') ADVANCE(1727);
      END_STATE();
    case 1476:
      if (lookahead == '1') ADVANCE(1954);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1924);
      END_STATE();
    case 1477:
      if (lookahead == '1') ADVANCE(1954);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1974);
      END_STATE();
    case 1478:
      if (lookahead == '1') ADVANCE(1320);
      if (lookahead == '4') ADVANCE(1681);
      if (lookahead == '5') ADVANCE(1874);
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(1528);
      END_STATE();
    case 1479:
      if (lookahead == '1') ADVANCE(1616);
      if (lookahead == ';') ADVANCE(2481);
      END_STATE();
    case 1480:
      if (lookahead == '1') ADVANCE(1337);
      END_STATE();
    case 1481:
      if (lookahead == '1') ADVANCE(1623);
      END_STATE();
    case 1482:
      if (lookahead == '1') ADVANCE(1721);
      if (lookahead == '7') ADVANCE(1765);
      END_STATE();
    case 1483:
      if (lookahead == '1') ADVANCE(2416);
      END_STATE();
    case 1484:
      if (lookahead == '1') ADVANCE(1640);
      END_STATE();
    case 1485:
      if (lookahead == '1') ADVANCE(1610);
      END_STATE();
    case 1486:
      if (lookahead == '1') ADVANCE(2403);
      END_STATE();
    case 1487:
      if (lookahead == '1') ADVANCE(1343);
      END_STATE();
    case 1488:
      if (lookahead == '1') ADVANCE(1633);
      END_STATE();
    case 1489:
      if (lookahead == '1') ADVANCE(2396);
      if (lookahead == '3') ADVANCE(1684);
      END_STATE();
    case 1490:
      if (lookahead == '1') ADVANCE(1613);
      END_STATE();
    case 1491:
      if (lookahead == '1') ADVANCE(1345);
      END_STATE();
    case 1492:
      if (lookahead == '1') ADVANCE(1614);
      END_STATE();
    case 1493:
      if (lookahead == '1') ADVANCE(1353);
      if (lookahead == '4') ADVANCE(1745);
      END_STATE();
    case 1494:
      if (lookahead == '1') ADVANCE(1617);
      END_STATE();
    case 1495:
      if (lookahead == '1') ADVANCE(1687);
      END_STATE();
    case 1496:
      if (lookahead == '1') ADVANCE(2409);
      END_STATE();
    case 1497:
      if (lookahead == '1') ADVANCE(1356);
      END_STATE();
    case 1498:
      if (lookahead == '1') ADVANCE(1619);
      END_STATE();
    case 1499:
      if (lookahead == '1') ADVANCE(1781);
      END_STATE();
    case 1500:
      if (lookahead == '1') ADVANCE(1361);
      if (lookahead == '3') ADVANCE(2397);
      if (lookahead == '4') ADVANCE(1750);
      END_STATE();
    case 1501:
      if (lookahead == '1') ADVANCE(1361);
      if (lookahead == '3') ADVANCE(2397);
      if (lookahead == '4') ADVANCE(1749);
      END_STATE();
    case 1502:
      if (lookahead == '1') ADVANCE(1620);
      END_STATE();
    case 1503:
      if (lookahead == '1') ADVANCE(2411);
      END_STATE();
    case 1504:
      if (lookahead == '1') ADVANCE(1350);
      END_STATE();
    case 1505:
      if (lookahead == '1') ADVANCE(1350);
      if (lookahead == '4') ADVANCE(1752);
      END_STATE();
    case 1506:
      if (lookahead == '1') ADVANCE(1805);
      if (lookahead == '4') ADVANCE(1854);
      END_STATE();
    case 1507:
      if (lookahead == '1') ADVANCE(1628);
      END_STATE();
    case 1508:
      if (lookahead == '1') ADVANCE(1789);
      END_STATE();
    case 1509:
      if (lookahead == '1') ADVANCE(1855);
      if (lookahead == '2') ADVANCE(1831);
      END_STATE();
    case 1510:
      if (lookahead == '1') ADVANCE(1366);
      if (lookahead == '4') ADVANCE(1753);
      END_STATE();
    case 1511:
      if (lookahead == '1') ADVANCE(1621);
      END_STATE();
    case 1512:
      if (lookahead == '1') ADVANCE(1621);
      if (lookahead == '4') ADVANCE(1621);
      END_STATE();
    case 1513:
      ADVANCE_MAP(
        '1', 1782,
        '3', 1471,
        '9', 1790,
        'C', 2391,
        'c', 2391,
        'E', 2381,
        'e', 2381,
        'F', 1687,
        'f', 1687,
      );
      END_STATE();
    case 1514:
      ADVANCE_MAP(
        '1', 1782,
        '3', 1471,
        '9', 1792,
        'C', 2391,
        'c', 2391,
        'E', 2381,
        'e', 2381,
        'F', 1687,
        'f', 1687,
      );
      END_STATE();
    case 1515:
      ADVANCE_MAP(
        '1', 1782,
        '3', 1471,
        '9', 1793,
        'C', 2391,
        'c', 2391,
        'E', 2381,
        'e', 2381,
        'F', 1687,
        'f', 1687,
      );
      END_STATE();
    case 1516:
      ADVANCE_MAP(
        '1', 1782,
        '9', 1790,
        'C', 2391,
        'c', 2391,
        'E', 2381,
        'e', 2381,
        'F', 1687,
        'f', 1687,
      );
      END_STATE();
    case 1517:
      ADVANCE_MAP(
        '1', 1782,
        '9', 1792,
        'C', 2391,
        'c', 2391,
        'E', 2381,
        'e', 2381,
        'F', 1687,
        'f', 1687,
      );
      END_STATE();
    case 1518:
      ADVANCE_MAP(
        '1', 1782,
        '9', 1793,
        'C', 2391,
        'c', 2391,
        'E', 2381,
        'e', 2381,
        'F', 1687,
        'f', 1687,
      );
      END_STATE();
    case 1519:
      if (lookahead == '1') ADVANCE(2413);
      END_STATE();
    case 1520:
      if (lookahead == '1') ADVANCE(1370);
      END_STATE();
    case 1521:
      if (lookahead == '1') ADVANCE(1634);
      END_STATE();
    case 1522:
      if (lookahead == '1') ADVANCE(1791);
      END_STATE();
    case 1523:
      if (lookahead == '1') ADVANCE(1828);
      END_STATE();
    case 1524:
      if (lookahead == '1') ADVANCE(1372);
      if (lookahead == '3') ADVANCE(2397);
      if (lookahead == '4') ADVANCE(1750);
      END_STATE();
    case 1525:
      if (lookahead == '1') ADVANCE(1372);
      if (lookahead == '3') ADVANCE(2397);
      if (lookahead == '4') ADVANCE(1749);
      END_STATE();
    case 1526:
      if (lookahead == '1') ADVANCE(1635);
      END_STATE();
    case 1527:
      if (lookahead == '1') ADVANCE(1375);
      if (lookahead == '4') ADVANCE(2415);
      END_STATE();
    case 1528:
      if (lookahead == '1') ADVANCE(1821);
      if (lookahead == '2') ADVANCE(1825);
      END_STATE();
    case 1529:
      if (lookahead == '1') ADVANCE(1821);
      if (lookahead == '2') ADVANCE(1405);
      if (lookahead == '3') ADVANCE(2409);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(2426);
      END_STATE();
    case 1530:
      if (lookahead == '1') ADVANCE(1700);
      END_STATE();
    case 1531:
      if (lookahead == '1') ADVANCE(1708);
      END_STATE();
    case 1532:
      if (lookahead == '1') ADVANCE(1873);
      if (lookahead == '7') ADVANCE(1766);
      END_STATE();
    case 1533:
      if (lookahead == '1') ADVANCE(1724);
      if (lookahead == '7') ADVANCE(1770);
      END_STATE();
    case 1534:
      if (lookahead == '1') ADVANCE(1709);
      if (lookahead == '7') ADVANCE(1771);
      END_STATE();
    case 1535:
      ADVANCE_MAP(
        '1', 1822,
        '2', 1301,
        '3', 2398,
        '6', 1796,
        'B', 1476,
        'b', 1476,
        'D', 1854,
        'd', 1854,
        'F', 1856,
        'f', 1856,
      );
      END_STATE();
    case 1536:
      ADVANCE_MAP(
        '1', 1822,
        '2', 1310,
        '3', 2398,
        'B', 1477,
        'b', 1477,
        'D', 1854,
        'd', 1854,
        'F', 1856,
        'f', 1856,
      );
      END_STATE();
    case 1537:
      ADVANCE_MAP(
        '1', 1822,
        '2', 1310,
        '3', 2398,
        'B', 1473,
        'b', 1473,
        'D', 1854,
        'd', 1854,
        'F', 1856,
        'f', 1856,
      );
      END_STATE();
    case 1538:
      if (lookahead == '1') ADVANCE(1713);
      END_STATE();
    case 1539:
      if (lookahead == '1') ADVANCE(1712);
      END_STATE();
    case 1540:
      if (lookahead == '1') ADVANCE(1823);
      if (lookahead == '2') ADVANCE(1416);
      END_STATE();
    case 1541:
      if (lookahead == '1') ADVANCE(1823);
      if (lookahead == '2') ADVANCE(1416);
      if (lookahead == '3') ADVANCE(2409);
      END_STATE();
    case 1542:
      if (lookahead == '1') ADVANCE(1823);
      if (lookahead == '2') ADVANCE(1411);
      END_STATE();
    case 1543:
      if (lookahead == '1') ADVANCE(1823);
      if (lookahead == '2') ADVANCE(1840);
      END_STATE();
    case 1544:
      if (lookahead == '1') ADVANCE(1719);
      END_STATE();
    case 1545:
      if (lookahead == '1') ADVANCE(1718);
      if (lookahead == '7') ADVANCE(1770);
      END_STATE();
    case 1546:
      ADVANCE_MAP(
        '1', 1824,
        '2', 1308,
        '3', 2398,
        'B', 1477,
        'b', 1477,
        'D', 1854,
        'd', 1854,
        'F', 1856,
        'f', 1856,
      );
      END_STATE();
    case 1547:
      ADVANCE_MAP(
        '1', 1824,
        '2', 1308,
        '3', 2398,
        'B', 1473,
        'b', 1473,
        'D', 1854,
        'd', 1854,
        'F', 1856,
        'f', 1856,
      );
      END_STATE();
    case 1548:
      ADVANCE_MAP(
        '1', 1824,
        '2', 1302,
        '3', 2398,
        '6', 1796,
        'B', 1476,
        'b', 1476,
        'D', 1854,
        'd', 1854,
        'F', 1856,
        'f', 1856,
      );
      END_STATE();
    case 1549:
      ADVANCE_MAP(
        '1', 1824,
        '2', 1408,
        '3', 2398,
        'B', 1473,
        'b', 1473,
        'D', 1854,
        'd', 1854,
        'F', 1856,
        'f', 1856,
      );
      END_STATE();
    case 1550:
      ADVANCE_MAP(
        '1', 1824,
        '2', 1406,
        '3', 2398,
        '6', 1796,
        'B', 1476,
        'b', 1476,
        'D', 1854,
        'd', 1854,
        'F', 1856,
        'f', 1856,
      );
      END_STATE();
    case 1551:
      ADVANCE_MAP(
        '1', 1824,
        '2', 1309,
        '3', 2399,
        'B', 1473,
        'b', 1473,
        'D', 1854,
        'd', 1854,
        'F', 1857,
        'f', 1857,
      );
      END_STATE();
    case 1552:
      ADVANCE_MAP(
        '1', 1824,
        '2', 1303,
        '3', 2399,
        '6', 1796,
        'B', 1476,
        'b', 1476,
        'D', 1854,
        'd', 1854,
        'F', 1857,
        'f', 1857,
      );
      END_STATE();
    case 1553:
      if (lookahead == '1') ADVANCE(1722);
      END_STATE();
    case 1554:
      if (lookahead == '1') ADVANCE(1723);
      END_STATE();
    case 1555:
      if (lookahead == '1') ADVANCE(1725);
      END_STATE();
    case 1556:
      if (lookahead == '1') ADVANCE(1409);
      if (lookahead == '4') ADVANCE(1775);
      if (lookahead == '8') ADVANCE(1667);
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(1642);
      END_STATE();
    case 1557:
      if (lookahead == '1') ADVANCE(1875);
      END_STATE();
    case 1558:
      ADVANCE_MAP(
        '1', 1424,
        '2', 1506,
        '3', 1693,
        '4', 1695,
        '5', 1876,
        '6', 1358,
        '8', 1589,
        '9', 1732,
        'X', 1537,
        'x', 1537,
      );
      END_STATE();
    case 1559:
      if (lookahead == '1') ADVANCE(1420);
      if (lookahead == '4') ADVANCE(1833);
      if (lookahead == '8') ADVANCE(1668);
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(1643);
      END_STATE();
    case 1560:
      if (lookahead == '1') ADVANCE(1427);
      if (lookahead == '4') ADVANCE(1687);
      if (lookahead == '5') ADVANCE(1877);
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(1543);
      END_STATE();
    case 1561:
      if (lookahead == '1') ADVANCE(1412);
      if (lookahead == '4') ADVANCE(1779);
      if (lookahead == '8') ADVANCE(1670);
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(1646);
      END_STATE();
    case 1562:
      ADVANCE_MAP(
        '1', 1429,
        '2', 1506,
        '3', 1693,
        '4', 1699,
        '5', 1878,
        '6', 1358,
        '8', 1666,
        '9', 1732,
        'X', 1549,
        'x', 1549,
      );
      END_STATE();
    case 1563:
      if (lookahead == '1') ADVANCE(1415);
      if (lookahead == '4') ADVANCE(1780);
      if (lookahead == '8') ADVANCE(1672);
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(1649);
      END_STATE();
    case 1564:
      ADVANCE_MAP(
        '1', 1305,
        '2', 1506,
        '3', 1693,
        '4', 1698,
        '5', 1878,
        '6', 1358,
        '8', 1589,
        '9', 1732,
        'X', 1547,
        'x', 1547,
      );
      END_STATE();
    case 1565:
      if (lookahead == '1') ADVANCE(1417);
      if (lookahead == '4') ADVANCE(1788);
      if (lookahead == '8') ADVANCE(1673);
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(1652);
      END_STATE();
    case 1566:
      if (lookahead == '1') ADVANCE(1418);
      if (lookahead == '4') ADVANCE(1782);
      if (lookahead == '8') ADVANCE(1674);
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(1654);
      END_STATE();
    case 1567:
      if (lookahead == '1') ADVANCE(1419);
      if (lookahead == '4') ADVANCE(1794);
      if (lookahead == '8') ADVANCE(1675);
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(1657);
      END_STATE();
    case 1568:
      ADVANCE_MAP(
        '1', 1421,
        '2', 1506,
        '3', 1693,
        '4', 1597,
        '5', 1878,
        '6', 1358,
        '8', 1586,
        '9', 1732,
        'X', 1548,
        'x', 1548,
      );
      END_STATE();
    case 1569:
      ADVANCE_MAP(
        '1', 1425,
        '2', 1506,
        '3', 1693,
        '4', 1695,
        '5', 1876,
        '6', 1358,
        '8', 1589,
        '9', 1732,
        'X', 1536,
        'x', 1536,
      );
      END_STATE();
    case 1570:
      ADVANCE_MAP(
        '1', 1428,
        '2', 1506,
        '3', 1693,
        '4', 1598,
        '5', 1878,
        '6', 1358,
        '8', 1665,
        '9', 1732,
        'X', 1550,
        'x', 1550,
      );
      END_STATE();
    case 1571:
      ADVANCE_MAP(
        '1', 1422,
        '2', 1506,
        '3', 1693,
        '4', 1597,
        '5', 1878,
        '6', 1359,
        '8', 1586,
        '9', 1732,
        'X', 1552,
        'x', 1552,
      );
      END_STATE();
    case 1572:
      if (lookahead == '2') ADVANCE(1574);
      if (lookahead == '5') ADVANCE(1575);
      if (lookahead == '7') ADVANCE(1465);
      if (lookahead == '8') ADVANCE(1826);
      END_STATE();
    case 1573:
      if (lookahead == '2') ADVANCE(1281);
      if (lookahead == '7') ADVANCE(1641);
      END_STATE();
    case 1574:
      if (lookahead == '2') ADVANCE(1894);
      END_STATE();
    case 1575:
      if (lookahead == '2') ADVANCE(1615);
      END_STATE();
    case 1576:
      if (lookahead == '2') ADVANCE(1339);
      if (lookahead == '4') ADVANCE(1684);
      END_STATE();
    case 1577:
      if (lookahead == '2') ADVANCE(1321);
      END_STATE();
    case 1578:
      if (lookahead == '2') ADVANCE(1407);
      END_STATE();
    case 1579:
      if (lookahead == '2') ADVANCE(1263);
      END_STATE();
    case 1580:
      if (lookahead == '2') ADVANCE(1263);
      if (set_contains(aux_sym_result_code_token22_character_set_1, 11, lookahead)) ADVANCE(1579);
      END_STATE();
    case 1581:
      if (lookahead == '2') ADVANCE(1388);
      if (lookahead == '7') ADVANCE(1583);
      END_STATE();
    case 1582:
      if (lookahead == '2') ADVANCE(1285);
      END_STATE();
    case 1583:
      if (lookahead == '2') ADVANCE(1627);
      END_STATE();
    case 1584:
      if (lookahead == '2') ADVANCE(2744);
      END_STATE();
    case 1585:
      if (lookahead == '2') ADVANCE(2744);
      if (set_contains(aux_sym_result_code_token22_character_set_1, 11, lookahead)) ADVANCE(1584);
      END_STATE();
    case 1586:
      if (lookahead == '2') ADVANCE(1391);
      if (lookahead == '5') ADVANCE(1893);
      if (lookahead == '6') ADVANCE(1731);
      if (lookahead == '7') ADVANCE(1457);
      if (lookahead == '8') ADVANCE(1403);
      if (lookahead == '9') ADVANCE(1839);
      END_STATE();
    case 1587:
      if (lookahead == '2') ADVANCE(1404);
      if (lookahead == '3') ADVANCE(2409);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(2426);
      END_STATE();
    case 1588:
      if (lookahead == '2') ADVANCE(1806);
      END_STATE();
    case 1589:
      if (lookahead == '2') ADVANCE(1390);
      if (lookahead == '5') ADVANCE(1893);
      if (lookahead == '6') ADVANCE(1731);
      if (lookahead == '7') ADVANCE(1455);
      if (lookahead == '8') ADVANCE(1403);
      if (lookahead == '9') ADVANCE(1839);
      END_STATE();
    case 1590:
      ADVANCE_MAP(
        '2', 1294,
        '3', 1313,
        '5', 2423,
        'A', 2383,
        'a', 2383,
        'B', 2384,
        'b', 2384,
        'F', 2425,
        'f', 2425,
      );
      END_STATE();
    case 1591:
      if (lookahead == '2') ADVANCE(1318);
      if (lookahead == '3') ADVANCE(2403);
      if (lookahead == '6') ADVANCE(1796);
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(2404);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(2436);
      END_STATE();
    case 1592:
      if (lookahead == '2') ADVANCE(1319);
      if (lookahead == '6') ADVANCE(1796);
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(2404);
      END_STATE();
    case 1593:
      if (lookahead == '2') ADVANCE(1402);
      if (lookahead == '7') ADVANCE(1645);
      END_STATE();
    case 1594:
      if (lookahead == '2') ADVANCE(1918);
      END_STATE();
    case 1595:
      if (lookahead == '2') ADVANCE(1918);
      if (lookahead == '3') ADVANCE(1909);
      if (lookahead == '5') ADVANCE(1919);
      if (lookahead == '7') ADVANCE(1921);
      END_STATE();
    case 1596:
      if (lookahead == '2') ADVANCE(1918);
      if (lookahead == '3') ADVANCE(1963);
      if (lookahead == '5') ADVANCE(1966);
      if (lookahead == '7') ADVANCE(1965);
      END_STATE();
    case 1597:
      if (lookahead == '2') ADVANCE(1918);
      if (lookahead == '3') ADVANCE(1972);
      if (lookahead == '5') ADVANCE(1966);
      if (lookahead == '7') ADVANCE(1965);
      END_STATE();
    case 1598:
      if (lookahead == '2') ADVANCE(1918);
      if (lookahead == '3') ADVANCE(1972);
      if (lookahead == '5') ADVANCE(1975);
      if (lookahead == '7') ADVANCE(1965);
      END_STATE();
    case 1599:
      if (lookahead == '2') ADVANCE(1918);
      if (lookahead == '5') ADVANCE(1919);
      if (lookahead == '7') ADVANCE(1921);
      END_STATE();
    case 1600:
      if (lookahead == '2') ADVANCE(1918);
      if (lookahead == '5') ADVANCE(1977);
      END_STATE();
    case 1601:
      ADVANCE_MAP(
        '2', 1283,
        '3', 1313,
        '5', 2423,
        '6', 1796,
        'A', 2383,
        'a', 2383,
        'B', 2385,
        'b', 2385,
        'F', 2425,
        'f', 2425,
      );
      END_STATE();
    case 1602:
      if (lookahead == '2') ADVANCE(1576);
      END_STATE();
    case 1603:
      if (lookahead == '2') ADVANCE(1377);
      if (lookahead == '7') ADVANCE(1648);
      END_STATE();
    case 1604:
      if (lookahead == '2') ADVANCE(2422);
      if (lookahead == '3') ADVANCE(2409);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(2426);
      END_STATE();
    case 1605:
      if (lookahead == '2') ADVANCE(1845);
      END_STATE();
    case 1606:
      if (lookahead == '2') ADVANCE(1845);
      if (lookahead == '3') ADVANCE(1378);
      END_STATE();
    case 1607:
      if (lookahead == '2') ADVANCE(1838);
      if (lookahead == '7') ADVANCE(1662);
      END_STATE();
    case 1608:
      if (lookahead == '2') ADVANCE(1625);
      if (lookahead == '4') ADVANCE(1805);
      if (lookahead == '9') ADVANCE(1741);
      END_STATE();
    case 1609:
      if (lookahead == '2') ADVANCE(1815);
      if (lookahead == '7') ADVANCE(1656);
      END_STATE();
    case 1610:
      if (lookahead == '2') ADVANCE(1924);
      END_STATE();
    case 1611:
      if (lookahead == '2') ADVANCE(1483);
      END_STATE();
    case 1612:
      if (lookahead == '2') ADVANCE(1611);
      END_STATE();
    case 1613:
      if (lookahead == '2') ADVANCE(1912);
      END_STATE();
    case 1614:
      if (lookahead == '2') ADVANCE(1913);
      END_STATE();
    case 1615:
      if (lookahead == '2') ADVANCE(1930);
      if (lookahead == '4') ADVANCE(1931);
      END_STATE();
    case 1616:
      if (lookahead == '2') ADVANCE(1944);
      if (lookahead == '5') ADVANCE(1945);
      if (lookahead == '7') ADVANCE(1946);
      END_STATE();
    case 1617:
      if (lookahead == '2') ADVANCE(1914);
      END_STATE();
    case 1618:
      if (lookahead == '2') ADVANCE(1952);
      END_STATE();
    case 1619:
      if (lookahead == '2') ADVANCE(1916);
      END_STATE();
    case 1620:
      if (lookahead == '2') ADVANCE(1915);
      END_STATE();
    case 1621:
      if (lookahead == '2') ADVANCE(1954);
      END_STATE();
    case 1622:
      if (lookahead == '2') ADVANCE(1954);
      if (lookahead == '3') ADVANCE(1954);
      END_STATE();
    case 1623:
      if (lookahead == '2') ADVANCE(1954);
      if (lookahead == '5') ADVANCE(1982);
      END_STATE();
    case 1624:
      if (lookahead == '2') ADVANCE(1954);
      if (lookahead == '6') ADVANCE(1954);
      END_STATE();
    case 1625:
      if (lookahead == '2') ADVANCE(1954);
      if (lookahead == '7') ADVANCE(1954);
      END_STATE();
    case 1626:
      if (lookahead == '2') ADVANCE(1954);
      if (lookahead == '9') ADVANCE(1954);
      END_STATE();
    case 1627:
      if (lookahead == '2') ADVANCE(1960);
      if (lookahead == '5') ADVANCE(1959);
      END_STATE();
    case 1628:
      if (lookahead == '2') ADVANCE(1978);
      END_STATE();
    case 1629:
      if (lookahead == '2') ADVANCE(1966);
      if (lookahead == '3') ADVANCE(1954);
      if (lookahead == '5') ADVANCE(1965);
      END_STATE();
    case 1630:
      if (lookahead == '2') ADVANCE(1966);
      if (lookahead == '3') ADVANCE(1954);
      if (lookahead == '5') ADVANCE(1965);
      if (lookahead == '7') ADVANCE(1946);
      END_STATE();
    case 1631:
      if (lookahead == '2') ADVANCE(1966);
      if (lookahead == '3') ADVANCE(1954);
      if (lookahead == '5') ADVANCE(1965);
      if (lookahead == '7') ADVANCE(1946);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1961);
      END_STATE();
    case 1632:
      if (lookahead == '2') ADVANCE(1966);
      if (lookahead == '3') ADVANCE(1954);
      if (lookahead == '5') ADVANCE(1965);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1961);
      END_STATE();
    case 1633:
      if (lookahead == '2') ADVANCE(1968);
      if (lookahead == '5') ADVANCE(1969);
      END_STATE();
    case 1634:
      if (lookahead == '2') ADVANCE(1974);
      END_STATE();
    case 1635:
      if (lookahead == '2') ADVANCE(1983);
      END_STATE();
    case 1636:
      if (lookahead == '2') ADVANCE(1975);
      if (lookahead == '3') ADVANCE(1954);
      if (lookahead == '5') ADVANCE(1965);
      END_STATE();
    case 1637:
      if (lookahead == '2') ADVANCE(1975);
      if (lookahead == '3') ADVANCE(1954);
      if (lookahead == '5') ADVANCE(1965);
      if (lookahead == '7') ADVANCE(1946);
      END_STATE();
    case 1638:
      if (lookahead == '2') ADVANCE(1975);
      if (lookahead == '3') ADVANCE(1954);
      if (lookahead == '5') ADVANCE(1965);
      if (lookahead == '7') ADVANCE(1946);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1961);
      END_STATE();
    case 1639:
      if (lookahead == '2') ADVANCE(1975);
      if (lookahead == '3') ADVANCE(1954);
      if (lookahead == '5') ADVANCE(1965);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1961);
      END_STATE();
    case 1640:
      if (lookahead == '2') ADVANCE(1977);
      if (lookahead == '7') ADVANCE(1946);
      END_STATE();
    case 1641:
      if (lookahead == '2') ADVANCE(1616);
      END_STATE();
    case 1642:
      if (lookahead == '2') ADVANCE(1379);
      END_STATE();
    case 1643:
      if (lookahead == '2') ADVANCE(1414);
      END_STATE();
    case 1644:
      if (lookahead == '2') ADVANCE(1623);
      END_STATE();
    case 1645:
      if (lookahead == '2') ADVANCE(1640);
      END_STATE();
    case 1646:
      if (lookahead == '2') ADVANCE(1381);
      END_STATE();
    case 1647:
      if (lookahead == '2') ADVANCE(1633);
      END_STATE();
    case 1648:
      if (lookahead == '2') ADVANCE(1613);
      END_STATE();
    case 1649:
      if (lookahead == '2') ADVANCE(1384);
      END_STATE();
    case 1650:
      if (lookahead == '2') ADVANCE(1473);
      if (lookahead == '3') ADVANCE(2427);
      END_STATE();
    case 1651:
      if (lookahead == '2') ADVANCE(1614);
      END_STATE();
    case 1652:
      if (lookahead == '2') ADVANCE(1387);
      END_STATE();
    case 1653:
      if (lookahead == '2') ADVANCE(1617);
      END_STATE();
    case 1654:
      if (lookahead == '2') ADVANCE(1410);
      END_STATE();
    case 1655:
      if (lookahead == '2') ADVANCE(1619);
      END_STATE();
    case 1656:
      if (lookahead == '2') ADVANCE(1781);
      END_STATE();
    case 1657:
      if (lookahead == '2') ADVANCE(1413);
      END_STATE();
    case 1658:
      if (lookahead == '2') ADVANCE(1628);
      END_STATE();
    case 1659:
      if (lookahead == '2') ADVANCE(1789);
      END_STATE();
    case 1660:
      if (lookahead == '2') ADVANCE(1621);
      END_STATE();
    case 1661:
      if (lookahead == '2') ADVANCE(1791);
      END_STATE();
    case 1662:
      if (lookahead == '2') ADVANCE(1828);
      END_STATE();
    case 1663:
      if (lookahead == '2') ADVANCE(1635);
      END_STATE();
    case 1664:
      if (lookahead == '2') ADVANCE(1394);
      if (lookahead == '7') ADVANCE(1644);
      END_STATE();
    case 1665:
      if (lookahead == '2') ADVANCE(1401);
      if (lookahead == '5') ADVANCE(1893);
      if (lookahead == '6') ADVANCE(1731);
      if (lookahead == '7') ADVANCE(1458);
      if (lookahead == '8') ADVANCE(1403);
      if (lookahead == '9') ADVANCE(1839);
      END_STATE();
    case 1666:
      if (lookahead == '2') ADVANCE(1400);
      if (lookahead == '5') ADVANCE(1893);
      if (lookahead == '6') ADVANCE(1731);
      if (lookahead == '7') ADVANCE(1456);
      if (lookahead == '8') ADVANCE(1403);
      if (lookahead == '9') ADVANCE(1839);
      END_STATE();
    case 1667:
      if (lookahead == '2') ADVANCE(1380);
      if (lookahead == '7') ADVANCE(1651);
      END_STATE();
    case 1668:
      if (lookahead == '2') ADVANCE(1818);
      if (lookahead == '7') ADVANCE(1659);
      END_STATE();
    case 1669:
      if (lookahead == '2') ADVANCE(1397);
      if (lookahead == '7') ADVANCE(1647);
      END_STATE();
    case 1670:
      if (lookahead == '2') ADVANCE(1383);
      if (lookahead == '7') ADVANCE(1653);
      END_STATE();
    case 1671:
      if (lookahead == '2') ADVANCE(1820);
      if (lookahead == '7') ADVANCE(1661);
      END_STATE();
    case 1672:
      if (lookahead == '2') ADVANCE(1385);
      if (lookahead == '7') ADVANCE(1655);
      END_STATE();
    case 1673:
      if (lookahead == '2') ADVANCE(1389);
      if (lookahead == '7') ADVANCE(1658);
      END_STATE();
    case 1674:
      if (lookahead == '2') ADVANCE(1393);
      if (lookahead == '7') ADVANCE(1660);
      END_STATE();
    case 1675:
      if (lookahead == '2') ADVANCE(1398);
      if (lookahead == '7') ADVANCE(1663);
      END_STATE();
    case 1676:
      if (lookahead == '3') ADVANCE(1680);
      if (lookahead == '5') ADVANCE(1329);
      END_STATE();
    case 1677:
      if (lookahead == '3') ADVANCE(1679);
      if (lookahead == '8') ADVANCE(1829);
      END_STATE();
    case 1678:
      if (lookahead == '3') ADVANCE(1378);
      END_STATE();
    case 1679:
      if (lookahead == '3') ADVANCE(1909);
      if (lookahead == '4') ADVANCE(1948);
      END_STATE();
    case 1680:
      if (lookahead == '3') ADVANCE(1926);
      END_STATE();
    case 1681:
      if (lookahead == '3') ADVANCE(1908);
      END_STATE();
    case 1682:
      if (lookahead == '3') ADVANCE(1908);
      if (lookahead == '4') ADVANCE(1954);
      END_STATE();
    case 1683:
      if (lookahead == '3') ADVANCE(1908);
      if (lookahead == '5') ADVANCE(1954);
      if (lookahead == '7') ADVANCE(1982);
      END_STATE();
    case 1684:
      if (lookahead == '3') ADVANCE(1940);
      if (lookahead == '6') ADVANCE(1941);
      END_STATE();
    case 1685:
      if (lookahead == '3') ADVANCE(1947);
      END_STATE();
    case 1686:
      if (lookahead == '3') ADVANCE(1951);
      END_STATE();
    case 1687:
      if (lookahead == '3') ADVANCE(1954);
      END_STATE();
    case 1688:
      if (lookahead == '3') ADVANCE(1954);
      if (lookahead == '4') ADVANCE(1954);
      END_STATE();
    case 1689:
      if (lookahead == '3') ADVANCE(1954);
      if (lookahead == '4') ADVANCE(1968);
      END_STATE();
    case 1690:
      if (lookahead == '3') ADVANCE(1954);
      if (lookahead == '5') ADVANCE(1968);
      if (lookahead == '7') ADVANCE(1969);
      END_STATE();
    case 1691:
      if (lookahead == '3') ADVANCE(1954);
      if (lookahead == '7') ADVANCE(1954);
      END_STATE();
    case 1692:
      if (lookahead == '3') ADVANCE(1954);
      if (lookahead == '7') ADVANCE(1967);
      END_STATE();
    case 1693:
      if (lookahead == '3') ADVANCE(1971);
      END_STATE();
    case 1694:
      if (lookahead == '3') ADVANCE(1963);
      if (lookahead == '4') ADVANCE(1966);
      END_STATE();
    case 1695:
      if (lookahead == '3') ADVANCE(1963);
      if (lookahead == '5') ADVANCE(1966);
      if (lookahead == '7') ADVANCE(1965);
      END_STATE();
    case 1696:
      if (lookahead == '3') ADVANCE(1972);
      if (lookahead == '4') ADVANCE(1966);
      END_STATE();
    case 1697:
      if (lookahead == '3') ADVANCE(1972);
      if (lookahead == '4') ADVANCE(1975);
      END_STATE();
    case 1698:
      if (lookahead == '3') ADVANCE(1972);
      if (lookahead == '5') ADVANCE(1966);
      if (lookahead == '7') ADVANCE(1965);
      END_STATE();
    case 1699:
      if (lookahead == '3') ADVANCE(1972);
      if (lookahead == '5') ADVANCE(1975);
      if (lookahead == '7') ADVANCE(1965);
      END_STATE();
    case 1700:
      if (lookahead == '3') ADVANCE(1681);
      END_STATE();
    case 1701:
      if (lookahead == '3') ADVANCE(1733);
      END_STATE();
    case 1702:
      if (lookahead == '3') ADVANCE(1685);
      END_STATE();
    case 1703:
      if (lookahead == '3') ADVANCE(1694);
      if (lookahead == '8') ADVANCE(1834);
      END_STATE();
    case 1704:
      if (lookahead == '3') ADVANCE(1471);
      END_STATE();
    case 1705:
      if (lookahead == '3') ADVANCE(1471);
      if (lookahead == '9') ADVANCE(1772);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(2386);
      END_STATE();
    case 1706:
      if (lookahead == '3') ADVANCE(1471);
      if (lookahead == '9') ADVANCE(1803);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(2386);
      END_STATE();
    case 1707:
      if (lookahead == '3') ADVANCE(1471);
      if (lookahead == '9') ADVANCE(1811);
      END_STATE();
    case 1708:
      if (lookahead == '3') ADVANCE(1734);
      END_STATE();
    case 1709:
      if (lookahead == '3') ADVANCE(1689);
      if (lookahead == '8') ADVANCE(1837);
      END_STATE();
    case 1710:
      if (lookahead == '3') ADVANCE(1737);
      if (lookahead == '8') ADVANCE(1829);
      END_STATE();
    case 1711:
      if (lookahead == '3') ADVANCE(1696);
      if (lookahead == '8') ADVANCE(1834);
      END_STATE();
    case 1712:
      if (lookahead == '3') ADVANCE(1736);
      END_STATE();
    case 1713:
      if (lookahead == '3') ADVANCE(1687);
      END_STATE();
    case 1714:
      if (lookahead == '3') ADVANCE(1687);
      if (lookahead == '6') ADVANCE(1687);
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(1650);
      END_STATE();
    case 1715:
      if (lookahead == '3') ADVANCE(1687);
      if (lookahead == '7') ADVANCE(1782);
      END_STATE();
    case 1716:
      if (lookahead == '3') ADVANCE(1687);
      if (lookahead == '8') ADVANCE(1835);
      END_STATE();
    case 1717:
      if (lookahead == '3') ADVANCE(2409);
      END_STATE();
    case 1718:
      if (lookahead == '3') ADVANCE(1682);
      if (lookahead == '8') ADVANCE(1836);
      END_STATE();
    case 1719:
      if (lookahead == '3') ADVANCE(1739);
      END_STATE();
    case 1720:
      if (lookahead == '3') ADVANCE(1697);
      if (lookahead == '8') ADVANCE(1834);
      END_STATE();
    case 1721:
      if (lookahead == '3') ADVANCE(1744);
      if (lookahead == '8') ADVANCE(1832);
      END_STATE();
    case 1722:
      if (lookahead == '3') ADVANCE(1746);
      END_STATE();
    case 1723:
      if (lookahead == '3') ADVANCE(1741);
      END_STATE();
    case 1724:
      if (lookahead == '3') ADVANCE(1741);
      if (lookahead == '8') ADVANCE(1836);
      END_STATE();
    case 1725:
      if (lookahead == '3') ADVANCE(1755);
      END_STATE();
    case 1726:
      if (lookahead == '3') ADVANCE(1756);
      END_STATE();
    case 1727:
      if (lookahead == '3') ADVANCE(1386);
      END_STATE();
    case 1728:
      if (lookahead == '3') ADVANCE(1392);
      END_STATE();
    case 1729:
      if (lookahead == '3') ADVANCE(1399);
      END_STATE();
    case 1730:
      if (lookahead == '4') ADVANCE(1917);
      END_STATE();
    case 1731:
      if (lookahead == '4') ADVANCE(1807);
      if (lookahead == '6') ADVANCE(1351);
      END_STATE();
    case 1732:
      if (lookahead == '4') ADVANCE(1879);
      if (lookahead == '6') ADVANCE(1715);
      if (lookahead == '7') ADVANCE(1608);
      END_STATE();
    case 1733:
      if (lookahead == '4') ADVANCE(1912);
      END_STATE();
    case 1734:
      if (lookahead == '4') ADVANCE(1913);
      END_STATE();
    case 1735:
      if (lookahead == '4') ADVANCE(1942);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1943);
      END_STATE();
    case 1736:
      if (lookahead == '4') ADVANCE(1914);
      END_STATE();
    case 1737:
      if (lookahead == '4') ADVANCE(1948);
      END_STATE();
    case 1738:
      if (lookahead == '4') ADVANCE(1950);
      END_STATE();
    case 1739:
      if (lookahead == '4') ADVANCE(1916);
      END_STATE();
    case 1740:
      if (lookahead == '4') ADVANCE(1953);
      END_STATE();
    case 1741:
      if (lookahead == '4') ADVANCE(1954);
      END_STATE();
    case 1742:
      if (lookahead == '4') ADVANCE(1954);
      if (lookahead == '7') ADVANCE(1954);
      END_STATE();
    case 1743:
      if (lookahead == '4') ADVANCE(1954);
      if (lookahead == '8') ADVANCE(1954);
      END_STATE();
    case 1744:
      if (lookahead == '4') ADVANCE(1960);
      END_STATE();
    case 1745:
      if (lookahead == '4') ADVANCE(1959);
      END_STATE();
    case 1746:
      if (lookahead == '4') ADVANCE(1978);
      END_STATE();
    case 1747:
      if (lookahead == '4') ADVANCE(1979);
      END_STATE();
    case 1748:
      if (lookahead == '4') ADVANCE(1965);
      END_STATE();
    case 1749:
      if (lookahead == '4') ADVANCE(1965);
      if (lookahead == '7') ADVANCE(1954);
      if (lookahead == '8') ADVANCE(1954);
      if (lookahead == '9') ADVANCE(1954);
      END_STATE();
    case 1750:
      if (lookahead == '4') ADVANCE(1965);
      if (lookahead == '7') ADVANCE(1954);
      if (lookahead == '8') ADVANCE(1954);
      if (lookahead == '9') ADVANCE(1954);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1943);
      END_STATE();
    case 1751:
      if (lookahead == '4') ADVANCE(1967);
      END_STATE();
    case 1752:
      if (lookahead == '4') ADVANCE(1982);
      END_STATE();
    case 1753:
      if (lookahead == '4') ADVANCE(1969);
      END_STATE();
    case 1754:
      if (lookahead == '4') ADVANCE(1961);
      END_STATE();
    case 1755:
      if (lookahead == '4') ADVANCE(1983);
      END_STATE();
    case 1756:
      if (lookahead == '4') ADVANCE(1977);
      END_STATE();
    case 1757:
      if (lookahead == '4') ADVANCE(1738);
      END_STATE();
    case 1758:
      if (lookahead == '4') ADVANCE(1778);
      END_STATE();
    case 1759:
      if (lookahead == '4') ADVANCE(2415);
      END_STATE();
    case 1760:
      if (lookahead == '4') ADVANCE(1322);
      END_STATE();
    case 1761:
      if (lookahead == '4') ADVANCE(1322);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1927);
      END_STATE();
    case 1762:
      if (lookahead == '4') ADVANCE(1347);
      END_STATE();
    case 1763:
      if (lookahead == '4') ADVANCE(1740);
      END_STATE();
    case 1764:
      if (lookahead == '4') ADVANCE(1368);
      END_STATE();
    case 1765:
      if (lookahead == '4') ADVANCE(1745);
      END_STATE();
    case 1766:
      if (lookahead == '4') ADVANCE(1747);
      END_STATE();
    case 1767:
      if (lookahead == '4') ADVANCE(1373);
      END_STATE();
    case 1768:
      if (lookahead == '4') ADVANCE(1748);
      if (lookahead == '5') ADVANCE(1622);
      END_STATE();
    case 1769:
      if (lookahead == '4') ADVANCE(1751);
      END_STATE();
    case 1770:
      if (lookahead == '4') ADVANCE(1752);
      END_STATE();
    case 1771:
      if (lookahead == '4') ADVANCE(1753);
      END_STATE();
    case 1772:
      if (lookahead == '5') ADVANCE(1909);
      if (lookahead == '6') ADVANCE(1948);
      END_STATE();
    case 1773:
      if (lookahead == '5') ADVANCE(1605);
      if (lookahead == '9') ADVANCE(1846);
      END_STATE();
    case 1774:
      if (lookahead == '5') ADVANCE(1912);
      END_STATE();
    case 1775:
      if (lookahead == '5') ADVANCE(1913);
      END_STATE();
    case 1776:
      if (lookahead == '5') ADVANCE(1908);
      END_STATE();
    case 1777:
      if (lookahead == '5') ADVANCE(1908);
      if (lookahead == '6') ADVANCE(1954);
      END_STATE();
    case 1778:
      if (lookahead == '5') ADVANCE(1932);
      END_STATE();
    case 1779:
      if (lookahead == '5') ADVANCE(1914);
      END_STATE();
    case 1780:
      if (lookahead == '5') ADVANCE(1916);
      END_STATE();
    case 1781:
      if (lookahead == '5') ADVANCE(1953);
      END_STATE();
    case 1782:
      if (lookahead == '5') ADVANCE(1954);
      END_STATE();
    case 1783:
      if (lookahead == '5') ADVANCE(1954);
      if (lookahead == '6') ADVANCE(1954);
      END_STATE();
    case 1784:
      if (lookahead == '5') ADVANCE(1954);
      if (lookahead == '6') ADVANCE(1968);
      END_STATE();
    case 1785:
      if (lookahead == '5') ADVANCE(1954);
      if (lookahead == '7') ADVANCE(1982);
      END_STATE();
    case 1786:
      if (lookahead == '5') ADVANCE(1954);
      if (lookahead == '9') ADVANCE(1954);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1954);
      END_STATE();
    case 1787:
      if (lookahead == '5') ADVANCE(1960);
      if (lookahead == '7') ADVANCE(1959);
      END_STATE();
    case 1788:
      if (lookahead == '5') ADVANCE(1978);
      END_STATE();
    case 1789:
      if (lookahead == '5') ADVANCE(1979);
      END_STATE();
    case 1790:
      if (lookahead == '5') ADVANCE(1963);
      if (lookahead == '6') ADVANCE(1966);
      END_STATE();
    case 1791:
      if (lookahead == '5') ADVANCE(1967);
      END_STATE();
    case 1792:
      if (lookahead == '5') ADVANCE(1972);
      if (lookahead == '6') ADVANCE(1966);
      END_STATE();
    case 1793:
      if (lookahead == '5') ADVANCE(1972);
      if (lookahead == '6') ADVANCE(1975);
      END_STATE();
    case 1794:
      if (lookahead == '5') ADVANCE(1983);
      END_STATE();
    case 1795:
      if (lookahead == '6') ADVANCE(2417);
      END_STATE();
    case 1796:
      if (lookahead == '6') ADVANCE(2407);
      END_STATE();
    case 1797:
      if (lookahead == '6') ADVANCE(1880);
      END_STATE();
    case 1798:
      if (lookahead == '6') ADVANCE(1928);
      END_STATE();
    case 1799:
      if (lookahead == '6') ADVANCE(1928);
      if (lookahead == ';') ADVANCE(2704);
      END_STATE();
    case 1800:
      if (lookahead == '6') ADVANCE(1912);
      END_STATE();
    case 1801:
      if (lookahead == '6') ADVANCE(1913);
      END_STATE();
    case 1802:
      if (lookahead == '6') ADVANCE(1914);
      END_STATE();
    case 1803:
      if (lookahead == '6') ADVANCE(1948);
      END_STATE();
    case 1804:
      if (lookahead == '6') ADVANCE(1916);
      END_STATE();
    case 1805:
      if (lookahead == '6') ADVANCE(1954);
      END_STATE();
    case 1806:
      if (lookahead == '6') ADVANCE(1954);
      if (lookahead == '7') ADVANCE(1954);
      END_STATE();
    case 1807:
      if (lookahead == '6') ADVANCE(1954);
      if (lookahead == '8') ADVANCE(1954);
      END_STATE();
    case 1808:
      if (lookahead == '6') ADVANCE(1960);
      END_STATE();
    case 1809:
      if (lookahead == '6') ADVANCE(1978);
      END_STATE();
    case 1810:
      if (lookahead == '6') ADVANCE(1983);
      END_STATE();
    case 1811:
      if (lookahead == '6') ADVANCE(1977);
      END_STATE();
    case 1812:
      if (lookahead == '6') ADVANCE(1783);
      END_STATE();
    case 1813:
      if (lookahead == '6') ADVANCE(1473);
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(1717);
      END_STATE();
    case 1814:
      if (lookahead == '6') ADVANCE(1885);
      END_STATE();
    case 1815:
      if (lookahead == '6') ADVANCE(1346);
      END_STATE();
    case 1816:
      if (lookahead == '6') ADVANCE(1887);
      END_STATE();
    case 1817:
      if (lookahead == '6') ADVANCE(1888);
      END_STATE();
    case 1818:
      if (lookahead == '6') ADVANCE(1357);
      END_STATE();
    case 1819:
      if (lookahead == '6') ADVANCE(1890);
      END_STATE();
    case 1820:
      if (lookahead == '6') ADVANCE(1363);
      END_STATE();
    case 1821:
      if (lookahead == '6') ADVANCE(2418);
      END_STATE();
    case 1822:
      if (lookahead == '6') ADVANCE(2420);
      END_STATE();
    case 1823:
      if (lookahead == '6') ADVANCE(2419);
      END_STATE();
    case 1824:
      if (lookahead == '6') ADVANCE(2421);
      END_STATE();
    case 1825:
      if (lookahead == '7') ADVANCE(1899);
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(1908);
      END_STATE();
    case 1826:
      if (lookahead == '7') ADVANCE(1923);
      END_STATE();
    case 1827:
      if (lookahead == '7') ADVANCE(1923);
      if (lookahead == '9') ADVANCE(1924);
      END_STATE();
    case 1828:
      if (lookahead == '7') ADVANCE(1946);
      END_STATE();
    case 1829:
      if (lookahead == '7') ADVANCE(1949);
      END_STATE();
    case 1830:
      if (lookahead == '7') ADVANCE(1953);
      END_STATE();
    case 1831:
      if (lookahead == '7') ADVANCE(1954);
      END_STATE();
    case 1832:
      if (lookahead == '7') ADVANCE(1959);
      END_STATE();
    case 1833:
      if (lookahead == '7') ADVANCE(1979);
      END_STATE();
    case 1834:
      if (lookahead == '7') ADVANCE(1965);
      END_STATE();
    case 1835:
      if (lookahead == '7') ADVANCE(1967);
      END_STATE();
    case 1836:
      if (lookahead == '7') ADVANCE(1982);
      END_STATE();
    case 1837:
      if (lookahead == '7') ADVANCE(1969);
      END_STATE();
    case 1838:
      if (lookahead == '7') ADVANCE(1341);
      END_STATE();
    case 1839:
      if (lookahead == '7') ADVANCE(1887);
      END_STATE();
    case 1840:
      if (lookahead == '7') ADVANCE(1906);
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(1954);
      END_STATE();
    case 1841:
      if (lookahead == '7') ADVANCE(1723);
      END_STATE();
    case 1842:
      if (lookahead == '8') ADVANCE(1797);
      END_STATE();
    case 1843:
      if (lookahead == '8') ADVANCE(1841);
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(1612);
      END_STATE();
    case 1844:
      if (lookahead == '8') ADVANCE(1760);
      END_STATE();
    case 1845:
      if (lookahead == '8') ADVANCE(1618);
      END_STATE();
    case 1846:
      if (lookahead == '8') ADVANCE(1925);
      END_STATE();
    case 1847:
      if (lookahead == '8') ADVANCE(1929);
      if (lookahead == '9') ADVANCE(1933);
      END_STATE();
    case 1848:
      if (lookahead == '8') ADVANCE(1912);
      if (lookahead == '9') ADVANCE(1912);
      END_STATE();
    case 1849:
      if (lookahead == '8') ADVANCE(1913);
      if (lookahead == '9') ADVANCE(1913);
      END_STATE();
    case 1850:
      if (lookahead == '8') ADVANCE(1914);
      if (lookahead == '9') ADVANCE(1914);
      END_STATE();
    case 1851:
      if (lookahead == '8') ADVANCE(1950);
      END_STATE();
    case 1852:
      if (lookahead == '8') ADVANCE(1916);
      if (lookahead == '9') ADVANCE(1916);
      END_STATE();
    case 1853:
      if (lookahead == '8') ADVANCE(1953);
      END_STATE();
    case 1854:
      if (lookahead == '8') ADVANCE(1954);
      END_STATE();
    case 1855:
      if (lookahead == '8') ADVANCE(1954);
      if (lookahead == '9') ADVANCE(1954);
      END_STATE();
    case 1856:
      if (lookahead == '8') ADVANCE(1954);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(1503);
      END_STATE();
    case 1857:
      if (lookahead == '8') ADVANCE(1954);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(1519);
      END_STATE();
    case 1858:
      if (lookahead == '8') ADVANCE(1960);
      if (lookahead == '9') ADVANCE(1960);
      END_STATE();
    case 1859:
      if (lookahead == '8') ADVANCE(1959);
      END_STATE();
    case 1860:
      if (lookahead == '8') ADVANCE(1978);
      if (lookahead == '9') ADVANCE(1978);
      END_STATE();
    case 1861:
      if (lookahead == '8') ADVANCE(1979);
      END_STATE();
    case 1862:
      if (lookahead == '8') ADVANCE(1966);
      if (lookahead == '9') ADVANCE(1966);
      END_STATE();
    case 1863:
      if (lookahead == '8') ADVANCE(1965);
      END_STATE();
    case 1864:
      if (lookahead == '8') ADVANCE(1967);
      END_STATE();
    case 1865:
      if (lookahead == '8') ADVANCE(1982);
      END_STATE();
    case 1866:
      if (lookahead == '8') ADVANCE(1968);
      if (lookahead == '9') ADVANCE(1968);
      END_STATE();
    case 1867:
      if (lookahead == '8') ADVANCE(1969);
      END_STATE();
    case 1868:
      if (lookahead == '8') ADVANCE(1983);
      if (lookahead == '9') ADVANCE(1983);
      END_STATE();
    case 1869:
      if (lookahead == '8') ADVANCE(1975);
      if (lookahead == '9') ADVANCE(1975);
      END_STATE();
    case 1870:
      if (lookahead == '8') ADVANCE(1977);
      if (lookahead == '9') ADVANCE(1977);
      END_STATE();
    case 1871:
      if (lookahead == '8') ADVANCE(1830);
      END_STATE();
    case 1872:
      if (lookahead == '8') ADVANCE(1886);
      END_STATE();
    case 1873:
      if (lookahead == '8') ADVANCE(1833);
      END_STATE();
    case 1874:
      if (lookahead == '8') ADVANCE(1814);
      END_STATE();
    case 1875:
      if (lookahead == '8') ADVANCE(1762);
      END_STATE();
    case 1876:
      if (lookahead == '8') ADVANCE(1817);
      END_STATE();
    case 1877:
      if (lookahead == '8') ADVANCE(1816);
      END_STATE();
    case 1878:
      if (lookahead == '8') ADVANCE(1819);
      END_STATE();
    case 1879:
      if (lookahead == '9') ADVANCE(1624);
      END_STATE();
    case 1880:
      if (lookahead == '9') ADVANCE(1909);
      END_STATE();
    case 1881:
      if (lookahead == '9') ADVANCE(1800);
      END_STATE();
    case 1882:
      if (lookahead == '9') ADVANCE(1474);
      if (lookahead == ';') ADVANCE(2665);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(1807);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1742);
      END_STATE();
    case 1883:
      if (lookahead == '9') ADVANCE(1911);
      END_STATE();
    case 1884:
      if (lookahead == '9') ADVANCE(1924);
      END_STATE();
    case 1885:
      if (lookahead == '9') ADVANCE(1908);
      END_STATE();
    case 1886:
      if (lookahead == '9') ADVANCE(1915);
      END_STATE();
    case 1887:
      if (lookahead == '9') ADVANCE(1954);
      END_STATE();
    case 1888:
      if (lookahead == '9') ADVANCE(1963);
      END_STATE();
    case 1889:
      if (lookahead == '9') ADVANCE(1962);
      END_STATE();
    case 1890:
      if (lookahead == '9') ADVANCE(1972);
      END_STATE();
    case 1891:
      if (lookahead == '9') ADVANCE(1974);
      END_STATE();
    case 1892:
      if (lookahead == '9') ADVANCE(1976);
      END_STATE();
    case 1893:
      if (lookahead == '9') ADVANCE(1688);
      END_STATE();
    case 1894:
      if (lookahead == '9') ADVANCE(1472);
      END_STATE();
    case 1895:
      if (lookahead == '9') ADVANCE(1801);
      END_STATE();
    case 1896:
      if (lookahead == '9') ADVANCE(1784);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(2394);
      END_STATE();
    case 1897:
      if (lookahead == '9') ADVANCE(1802);
      END_STATE();
    case 1898:
      if (lookahead == '9') ADVANCE(1804);
      END_STATE();
    case 1899:
      if (lookahead == '9') ADVANCE(1776);
      END_STATE();
    case 1900:
      if (lookahead == '9') ADVANCE(1777);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(2393);
      END_STATE();
    case 1901:
      if (lookahead == '9') ADVANCE(1808);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(2389);
      END_STATE();
    case 1902:
      if (lookahead == '9') ADVANCE(1809);
      END_STATE();
    case 1903:
      if (lookahead == '9') ADVANCE(1805);
      END_STATE();
    case 1904:
      if (lookahead == '9') ADVANCE(1805);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(2393);
      END_STATE();
    case 1905:
      if (lookahead == '9') ADVANCE(1810);
      END_STATE();
    case 1906:
      if (lookahead == '9') ADVANCE(1782);
      END_STATE();
    case 1907:
      if (lookahead == '9') ADVANCE(1782);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(2392);
      END_STATE();
    case 1908:
      if (lookahead == ';') ADVANCE(2644);
      END_STATE();
    case 1909:
      if (lookahead == ';') ADVANCE(2647);
      END_STATE();
    case 1910:
      if (lookahead == ';') ADVANCE(2647);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1925);
      END_STATE();
    case 1911:
      if (lookahead == ';') ADVANCE(2617);
      END_STATE();
    case 1912:
      if (lookahead == ';') ADVANCE(1433);
      END_STATE();
    case 1913:
      if (lookahead == ';') ADVANCE(1241);
      END_STATE();
    case 1914:
      if (lookahead == ';') ADVANCE(1434);
      END_STATE();
    case 1915:
      if (lookahead == ';') ADVANCE(2746);
      END_STATE();
    case 1916:
      if (lookahead == ';') ADVANCE(2440);
      END_STATE();
    case 1917:
      if (lookahead == ';') ADVANCE(2481);
      END_STATE();
    case 1918:
      if (lookahead == ';') ADVANCE(2722);
      END_STATE();
    case 1919:
      if (lookahead == ';') ADVANCE(2675);
      END_STATE();
    case 1920:
      if (lookahead == ';') ADVANCE(2675);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1926);
      END_STATE();
    case 1921:
      if (lookahead == ';') ADVANCE(2704);
      END_STATE();
    case 1922:
      if (lookahead == ';') ADVANCE(2509);
      END_STATE();
    case 1923:
      if (lookahead == ';') ADVANCE(2511);
      END_STATE();
    case 1924:
      if (lookahead == ';') ADVANCE(2719);
      END_STATE();
    case 1925:
      if (lookahead == ';') ADVANCE(2501);
      END_STATE();
    case 1926:
      if (lookahead == ';') ADVANCE(2499);
      END_STATE();
    case 1927:
      if (lookahead == ';') ADVANCE(2505);
      END_STATE();
    case 1928:
      if (lookahead == ';') ADVANCE(2503);
      END_STATE();
    case 1929:
      if (lookahead == ';') ADVANCE(2679);
      END_STATE();
    case 1930:
      if (lookahead == ';') ADVANCE(2507);
      END_STATE();
    case 1931:
      if (lookahead == ';') ADVANCE(2497);
      END_STATE();
    case 1932:
      if (lookahead == ';') ADVANCE(2738);
      END_STATE();
    case 1933:
      if (lookahead == ';') ADVANCE(2681);
      END_STATE();
    case 1934:
      if (lookahead == ';') ADVANCE(2683);
      END_STATE();
    case 1935:
      if (lookahead == ';') ADVANCE(2685);
      END_STATE();
    case 1936:
      if (lookahead == ';') ADVANCE(2687);
      END_STATE();
    case 1937:
      if (lookahead == ';') ADVANCE(2485);
      END_STATE();
    case 1938:
      if (lookahead == ';') ADVANCE(2487);
      END_STATE();
    case 1939:
      if (lookahead == ';') ADVANCE(2489);
      END_STATE();
    case 1940:
      if (lookahead == ';') ADVANCE(2491);
      END_STATE();
    case 1941:
      if (lookahead == ';') ADVANCE(2493);
      END_STATE();
    case 1942:
      if (lookahead == ';') ADVANCE(2708);
      END_STATE();
    case 1943:
      if (lookahead == ';') ADVANCE(2734);
      END_STATE();
    case 1944:
      if (lookahead == ';') ADVANCE(2677);
      END_STATE();
    case 1945:
      if (lookahead == ';') ADVANCE(2706);
      END_STATE();
    case 1946:
      if (lookahead == ';') ADVANCE(2726);
      END_STATE();
    case 1947:
      if (lookahead == ';') ADVANCE(2730);
      END_STATE();
    case 1948:
      if (lookahead == ';') ADVANCE(2689);
      END_STATE();
    case 1949:
      if (lookahead == ';') ADVANCE(2710);
      END_STATE();
    case 1950:
      if (lookahead == ';') ADVANCE(2712);
      END_STATE();
    case 1951:
      if (lookahead == ';') ADVANCE(2495);
      END_STATE();
    case 1952:
      if (lookahead == ';') ADVANCE(2483);
      END_STATE();
    case 1953:
      if (lookahead == ';') ADVANCE(1246);
      END_STATE();
    case 1954:
      if (lookahead == ';') ADVANCE(2649);
      END_STATE();
    case 1955:
      if (lookahead == ';') ADVANCE(2649);
      if (lookahead == 'a') ADVANCE(2270);
      END_STATE();
    case 1956:
      if (lookahead == ';') ADVANCE(2649);
      if (lookahead == 'f') ADVANCE(2324);
      if (lookahead == 'q') ADVANCE(1954);
      END_STATE();
    case 1957:
      if (lookahead == ';') ADVANCE(2649);
      if (lookahead == 'o') ADVANCE(2367);
      END_STATE();
    case 1958:
      if (lookahead == ';') ADVANCE(2649);
      if (lookahead == 't') ADVANCE(2219);
      END_STATE();
    case 1959:
      if (lookahead == ';') ADVANCE(1580);
      END_STATE();
    case 1960:
      if (lookahead == ';') ADVANCE(2442);
      END_STATE();
    case 1961:
      if (lookahead == ';') ADVANCE(2661);
      END_STATE();
    case 1962:
      if (lookahead == ';') ADVANCE(2662);
      END_STATE();
    case 1963:
      if (lookahead == ';') ADVANCE(1248);
      END_STATE();
    case 1964:
      if (lookahead == ';') ADVANCE(1248);
      if (lookahead == 'b') ADVANCE(1954);
      if (lookahead == 'e') ADVANCE(1954);
      if (lookahead == 'm') ADVANCE(2196);
      END_STATE();
    case 1965:
      if (lookahead == ';') ADVANCE(1245);
      END_STATE();
    case 1966:
      if (lookahead == ';') ADVANCE(2664);
      END_STATE();
    case 1967:
      if (lookahead == ';') ADVANCE(1249);
      END_STATE();
    case 1968:
      if (lookahead == ';') ADVANCE(2641);
      END_STATE();
    case 1969:
      if (lookahead == ';') ADVANCE(1255);
      END_STATE();
    case 1970:
      if (lookahead == ';') ADVANCE(1252);
      END_STATE();
    case 1971:
      if (lookahead == ';') ADVANCE(2665);
      END_STATE();
    case 1972:
      if (lookahead == ';') ADVANCE(2648);
      END_STATE();
    case 1973:
      if (lookahead == ';') ADVANCE(2648);
      if (lookahead == 'b') ADVANCE(1954);
      if (lookahead == 'e') ADVANCE(1954);
      if (lookahead == 'm') ADVANCE(2196);
      END_STATE();
    case 1974:
      if (lookahead == ';') ADVANCE(2717);
      END_STATE();
    case 1975:
      if (lookahead == ';') ADVANCE(2636);
      END_STATE();
    case 1976:
      if (lookahead == ';') ADVANCE(2621);
      END_STATE();
    case 1977:
      if (lookahead == ';') ADVANCE(2634);
      END_STATE();
    case 1978:
      if (lookahead == ';') ADVANCE(1450);
      END_STATE();
    case 1979:
      if (lookahead == ';') ADVANCE(1585);
      END_STATE();
    case 1980:
      if (lookahead == ';') ADVANCE(2666);
      END_STATE();
    case 1981:
      if (lookahead == ';') ADVANCE(2623);
      END_STATE();
    case 1982:
      if (lookahead == ';') ADVANCE(1264);
      END_STATE();
    case 1983:
      if (lookahead == ';') ADVANCE(2439);
      END_STATE();
    case 1984:
      if (lookahead == '=') ADVANCE(2649);
      END_STATE();
    case 1985:
      if (lookahead == 'A') ADVANCE(2272);
      END_STATE();
    case 1986:
      if (lookahead == 'A') ADVANCE(2272);
      if (lookahead == 'R') ADVANCE(2150);
      END_STATE();
    case 1987:
      if (lookahead == 'A') ADVANCE(2272);
      if (lookahead == 'T') ADVANCE(2087);
      if (lookahead == 'p') ADVANCE(2088);
      END_STATE();
    case 1988:
      if (lookahead == 'L') ADVANCE(2090);
      if (lookahead == 'R') ADVANCE(2150);
      if (lookahead == 'U') ADVANCE(2240);
      END_STATE();
    case 1989:
      if (lookahead == 'M') ADVANCE(2159);
      END_STATE();
    case 1990:
      if (lookahead == 'N') ADVANCE(2649);
      END_STATE();
    case 1991:
      if (lookahead == 'P') ADVANCE(2185);
      END_STATE();
    case 1992:
      if (lookahead == 'R') ADVANCE(2150);
      END_STATE();
    case 1993:
      if (lookahead == '[') ADVANCE(2572);
      if (lookahead == '{') ADVANCE(2566);
      if (lookahead == '}') ADVANCE(2568);
      if (set_contains(extras_character_set_2, 10, lookahead)) ADVANCE(2573);
      if (lookahead != 0) ADVANCE(2571);
      END_STATE();
    case 1994:
      if (lookahead == '[') ADVANCE(2477);
      if (set_contains(extras_character_set_2, 10, lookahead)) ADVANCE(2512);
      if (lookahead != 0 &&
          lookahead != '%') ADVANCE(2514);
      END_STATE();
    case 1995:
      if (lookahead == 'a') ADVANCE(2278);
      END_STATE();
    case 1996:
      if (lookahead == 'a') ADVANCE(2048);
      END_STATE();
    case 1997:
      if (lookahead == 'a') ADVANCE(2161);
      if (lookahead == 'y') ADVANCE(2251);
      END_STATE();
    case 1998:
      if (lookahead == 'a') ADVANCE(2161);
      if (lookahead == 'y') ADVANCE(2255);
      END_STATE();
    case 1999:
      if (lookahead == 'a') ADVANCE(2047);
      if (lookahead == 'd') ADVANCE(2034);
      if (lookahead == 'e') ADVANCE(2026);
      END_STATE();
    case 2000:
      if (lookahead == 'a') ADVANCE(2047);
      if (lookahead == 'd') ADVANCE(2038);
      if (lookahead == 'e') ADVANCE(2026);
      END_STATE();
    case 2001:
      if (lookahead == 'a') ADVANCE(2279);
      END_STATE();
    case 2002:
      if (lookahead == 'a') ADVANCE(2160);
      END_STATE();
    case 2003:
      if (lookahead == 'a') ADVANCE(2160);
      if (lookahead == 'y') ADVANCE(2238);
      END_STATE();
    case 2004:
      if (lookahead == 'a') ADVANCE(2160);
      if (lookahead == 'y') ADVANCE(2256);
      END_STATE();
    case 2005:
      if (lookahead == 'a') ADVANCE(2266);
      END_STATE();
    case 2006:
      if (lookahead == 'a') ADVANCE(2266);
      if (lookahead == 'i') ADVANCE(2118);
      END_STATE();
    case 2007:
      if (lookahead == 'a') ADVANCE(2266);
      if (lookahead == 'p') ADVANCE(2013);
      END_STATE();
    case 2008:
      if (lookahead == 'a') ADVANCE(2266);
      if (lookahead == 'y') ADVANCE(2251);
      END_STATE();
    case 2009:
      if (lookahead == 'a') ADVANCE(2266);
      if (lookahead == 'y') ADVANCE(2255);
      END_STATE();
    case 2010:
      if (lookahead == 'a') ADVANCE(2181);
      END_STATE();
    case 2011:
      if (lookahead == 'a') ADVANCE(2189);
      if (lookahead == 'e') ADVANCE(2106);
      END_STATE();
    case 2012:
      if (lookahead == 'a') ADVANCE(2189);
      if (lookahead == 'i') ADVANCE(2115);
      END_STATE();
    case 2013:
      if (lookahead == 'a') ADVANCE(2272);
      END_STATE();
    case 2014:
      if (lookahead == 'a') ADVANCE(2272);
      if (lookahead == 'r') ADVANCE(2158);
      END_STATE();
    case 2015:
      if (lookahead == 'a') ADVANCE(2166);
      if (lookahead == 'd') ADVANCE(2034);
      if (lookahead == 'i') ADVANCE(2058);
      if (lookahead == 'n') ADVANCE(2242);
      if (lookahead == 'p') ADVANCE(1954);
      END_STATE();
    case 2016:
      if (lookahead == 'a') ADVANCE(2166);
      if (lookahead == 'd') ADVANCE(2034);
      if (lookahead == 'i') ADVANCE(2212);
      if (lookahead == 'n') ADVANCE(2242);
      if (lookahead == 'p') ADVANCE(1954);
      END_STATE();
    case 2017:
      if (lookahead == 'a') ADVANCE(2166);
      if (lookahead == 'd') ADVANCE(2038);
      if (lookahead == 'i') ADVANCE(2059);
      if (lookahead == 'n') ADVANCE(2242);
      if (lookahead == 'p') ADVANCE(1954);
      END_STATE();
    case 2018:
      if (lookahead == 'a') ADVANCE(2166);
      if (lookahead == 'd') ADVANCE(2038);
      if (lookahead == 'i') ADVANCE(2215);
      if (lookahead == 'n') ADVANCE(2242);
      if (lookahead == 'p') ADVANCE(1954);
      END_STATE();
    case 2019:
      if (lookahead == 'a') ADVANCE(2270);
      END_STATE();
    case 2020:
      if (lookahead == 'a') ADVANCE(1954);
      END_STATE();
    case 2021:
      if (lookahead == 'a') ADVANCE(2258);
      if (lookahead == 'd') ADVANCE(2259);
      END_STATE();
    case 2022:
      if (lookahead == 'a') ADVANCE(2258);
      if (lookahead == 'd') ADVANCE(2259);
      if (lookahead == 'o') ADVANCE(2366);
      END_STATE();
    case 2023:
      if (lookahead == 'a') ADVANCE(2180);
      if (lookahead == 'y') ADVANCE(2251);
      END_STATE();
    case 2024:
      if (lookahead == 'a') ADVANCE(2304);
      END_STATE();
    case 2025:
      if (lookahead == 'a') ADVANCE(2178);
      END_STATE();
    case 2026:
      if (lookahead == 'a') ADVANCE(2273);
      END_STATE();
    case 2027:
      if (lookahead == 'a') ADVANCE(2306);
      END_STATE();
    case 2028:
      if (lookahead == 'a') ADVANCE(2308);
      END_STATE();
    case 2029:
      if (lookahead == 'a') ADVANCE(2310);
      END_STATE();
    case 2030:
      if (lookahead == 'a') ADVANCE(2311);
      END_STATE();
    case 2031:
      if (lookahead == 'a') ADVANCE(2312);
      END_STATE();
    case 2032:
      if (lookahead == 'a') ADVANCE(2313);
      END_STATE();
    case 2033:
      if (lookahead == 'a') ADVANCE(2314);
      END_STATE();
    case 2034:
      if (lookahead == 'a') ADVANCE(2315);
      END_STATE();
    case 2035:
      if (lookahead == 'a') ADVANCE(2316);
      END_STATE();
    case 2036:
      if (lookahead == 'a') ADVANCE(2317);
      END_STATE();
    case 2037:
      if (lookahead == 'a') ADVANCE(2318);
      END_STATE();
    case 2038:
      if (lookahead == 'a') ADVANCE(2319);
      END_STATE();
    case 2039:
      if (lookahead == 'a') ADVANCE(2320);
      END_STATE();
    case 2040:
      if (lookahead == 'a') ADVANCE(2305);
      END_STATE();
    case 2041:
      if (lookahead == 'a') ADVANCE(2182);
      END_STATE();
    case 2042:
      if (lookahead == 'a') ADVANCE(2183);
      END_STATE();
    case 2043:
      if (lookahead == 'a') ADVANCE(2260);
      if (lookahead == 'd') ADVANCE(2261);
      END_STATE();
    case 2044:
      if (lookahead == 'a') ADVANCE(2184);
      END_STATE();
    case 2045:
      if (lookahead == 'a') ADVANCE(2051);
      END_STATE();
    case 2046:
      if (lookahead == 'a') ADVANCE(2052);
      END_STATE();
    case 2047:
      if (lookahead == 'b') ADVANCE(2167);
      END_STATE();
    case 2048:
      if (lookahead == 'c') ADVANCE(1485);
      END_STATE();
    case 2049:
      if (lookahead == 'c') ADVANCE(2169);
      END_STATE();
    case 2050:
      if (lookahead == 'c') ADVANCE(2173);
      END_STATE();
    case 2051:
      if (lookahead == 'c') ADVANCE(1502);
      END_STATE();
    case 2052:
      if (lookahead == 'c') ADVANCE(1521);
      END_STATE();
    case 2053:
      if (lookahead == 'd') ADVANCE(2024);
      if (lookahead == 'i') ADVANCE(2057);
      END_STATE();
    case 2054:
      if (lookahead == 'd') ADVANCE(2231);
      if (lookahead == 'p') ADVANCE(2185);
      END_STATE();
    case 2055:
      if (lookahead == 'd') ADVANCE(2231);
      if (lookahead == 'p') ADVANCE(2185);
      if (lookahead == 's') ADVANCE(2186);
      END_STATE();
    case 2056:
      if (lookahead == 'd') ADVANCE(1995);
      END_STATE();
    case 2057:
      if (lookahead == 'd') ADVANCE(1995);
      if (lookahead == 'n') ADVANCE(2345);
      END_STATE();
    case 2058:
      if (lookahead == 'd') ADVANCE(1995);
      if (lookahead == 'n') ADVANCE(2357);
      END_STATE();
    case 2059:
      if (lookahead == 'd') ADVANCE(1995);
      if (lookahead == 'n') ADVANCE(2360);
      END_STATE();
    case 2060:
      if (lookahead == 'd') ADVANCE(1995);
      if (lookahead == 'n') ADVANCE(2361);
      END_STATE();
    case 2061:
      if (lookahead == 'd') ADVANCE(2027);
      END_STATE();
    case 2062:
      if (lookahead == 'd') ADVANCE(2028);
      END_STATE();
    case 2063:
      if (lookahead == 'd') ADVANCE(2028);
      if (lookahead == 'i') ADVANCE(2205);
      END_STATE();
    case 2064:
      if (lookahead == 'd') ADVANCE(2029);
      END_STATE();
    case 2065:
      if (lookahead == 'd') ADVANCE(2029);
      if (lookahead == 'i') ADVANCE(2206);
      END_STATE();
    case 2066:
      if (lookahead == 'd') ADVANCE(2030);
      END_STATE();
    case 2067:
      if (lookahead == 'd') ADVANCE(2030);
      if (lookahead == 'i') ADVANCE(2207);
      END_STATE();
    case 2068:
      if (lookahead == 'd') ADVANCE(2031);
      END_STATE();
    case 2069:
      if (lookahead == 'd') ADVANCE(2031);
      if (lookahead == 'i') ADVANCE(2208);
      END_STATE();
    case 2070:
      if (lookahead == 'd') ADVANCE(2032);
      END_STATE();
    case 2071:
      if (lookahead == 'd') ADVANCE(2032);
      if (lookahead == 'i') ADVANCE(2209);
      END_STATE();
    case 2072:
      if (lookahead == 'd') ADVANCE(2033);
      END_STATE();
    case 2073:
      if (lookahead == 'd') ADVANCE(2033);
      if (lookahead == 'i') ADVANCE(2210);
      END_STATE();
    case 2074:
      if (lookahead == 'd') ADVANCE(2035);
      END_STATE();
    case 2075:
      if (lookahead == 'd') ADVANCE(2035);
      if (lookahead == 'i') ADVANCE(2211);
      END_STATE();
    case 2076:
      if (lookahead == 'd') ADVANCE(2036);
      END_STATE();
    case 2077:
      if (lookahead == 'd') ADVANCE(2036);
      if (lookahead == 'i') ADVANCE(2213);
      END_STATE();
    case 2078:
      if (lookahead == 'd') ADVANCE(2037);
      END_STATE();
    case 2079:
      if (lookahead == 'd') ADVANCE(2037);
      if (lookahead == 'i') ADVANCE(2214);
      END_STATE();
    case 2080:
      if (lookahead == 'd') ADVANCE(2039);
      END_STATE();
    case 2081:
      if (lookahead == 'd') ADVANCE(2039);
      if (lookahead == 'i') ADVANCE(2060);
      END_STATE();
    case 2082:
      if (lookahead == 'e') ADVANCE(1956);
      if (lookahead == 'l') ADVANCE(2328);
      if (lookahead == 'o') ADVANCE(2366);
      if (lookahead == 'r') ADVANCE(2005);
      if (lookahead == 't') ADVANCE(1970);
      END_STATE();
    case 2083:
      if (lookahead == 'e') ADVANCE(1956);
      if (lookahead == 'l') ADVANCE(2328);
      if (lookahead == 'r') ADVANCE(2005);
      if (lookahead == 't') ADVANCE(1970);
      END_STATE();
    case 2084:
      if (lookahead == 'e') ADVANCE(2191);
      END_STATE();
    case 2085:
      if (lookahead == 'e') ADVANCE(2268);
      if (lookahead == 'l') ADVANCE(2340);
      if (lookahead == 'm') ADVANCE(1954);
      if (lookahead == 'r') ADVANCE(2222);
      END_STATE();
    case 2086:
      if (lookahead == 'e') ADVANCE(2268);
      if (lookahead == 'l') ADVANCE(2343);
      if (lookahead == 'm') ADVANCE(1954);
      if (lookahead == 'r') ADVANCE(2222);
      END_STATE();
    case 2087:
      if (lookahead == 'e') ADVANCE(2089);
      END_STATE();
    case 2088:
      if (lookahead == 'e') ADVANCE(2263);
      END_STATE();
    case 2089:
      if (lookahead == 'e') ADVANCE(1954);
      END_STATE();
    case 2090:
      if (lookahead == 'e') ADVANCE(2108);
      END_STATE();
    case 2091:
      if (lookahead == 'e') ADVANCE(2192);
      END_STATE();
    case 2092:
      if (lookahead == 'e') ADVANCE(2193);
      END_STATE();
    case 2093:
      if (lookahead == 'e') ADVANCE(2194);
      END_STATE();
    case 2094:
      if (lookahead == 'e') ADVANCE(2195);
      END_STATE();
    case 2095:
      if (lookahead == 'e') ADVANCE(2169);
      END_STATE();
    case 2096:
      if (lookahead == 'e') ADVANCE(2197);
      END_STATE();
    case 2097:
      if (lookahead == 'e') ADVANCE(2198);
      END_STATE();
    case 2098:
      if (lookahead == 'e') ADVANCE(2199);
      END_STATE();
    case 2099:
      if (lookahead == 'e') ADVANCE(2196);
      END_STATE();
    case 2100:
      if (lookahead == 'e') ADVANCE(2200);
      END_STATE();
    case 2101:
      if (lookahead == 'e') ADVANCE(2202);
      END_STATE();
    case 2102:
      if (lookahead == 'e') ADVANCE(2203);
      END_STATE();
    case 2103:
      if (lookahead == 'e') ADVANCE(2204);
      END_STATE();
    case 2104:
      if (lookahead == 'e') ADVANCE(2309);
      END_STATE();
    case 2105:
      if (lookahead == 'e') ADVANCE(2307);
      END_STATE();
    case 2106:
      if (lookahead == 'f') ADVANCE(2323);
      END_STATE();
    case 2107:
      if (lookahead == 'f') ADVANCE(2156);
      END_STATE();
    case 2108:
      if (lookahead == 'f') ADVANCE(2325);
      END_STATE();
    case 2109:
      if (lookahead == 'f') ADVANCE(2287);
      END_STATE();
    case 2110:
      if (lookahead == 'f') ADVANCE(1924);
      END_STATE();
    case 2111:
      if (lookahead == 'f') ADVANCE(1915);
      END_STATE();
    case 2112:
      if (lookahead == 'f') ADVANCE(1954);
      END_STATE();
    case 2113:
      if (lookahead == 'f') ADVANCE(1974);
      END_STATE();
    case 2114:
      if (lookahead == 'f') ADVANCE(2157);
      END_STATE();
    case 2115:
      if (lookahead == 'g') ADVANCE(2121);
      END_STATE();
    case 2116:
      if (lookahead == 'g') ADVANCE(2218);
      END_STATE();
    case 2117:
      if (lookahead == 'g') ADVANCE(1954);
      END_STATE();
    case 2118:
      if (lookahead == 'g') ADVANCE(2122);
      END_STATE();
    case 2119:
      if (lookahead == 'h') ADVANCE(2084);
      END_STATE();
    case 2120:
      if (lookahead == 'h') ADVANCE(2223);
      if (lookahead == 'q') ADVANCE(2342);
      END_STATE();
    case 2121:
      if (lookahead == 'h') ADVANCE(2325);
      END_STATE();
    case 2122:
      if (lookahead == 'h') ADVANCE(2332);
      END_STATE();
    case 2123:
      if (lookahead == 'h') ADVANCE(1929);
      END_STATE();
    case 2124:
      if (lookahead == 'h') ADVANCE(1912);
      END_STATE();
    case 2125:
      if (lookahead == 'h') ADVANCE(1913);
      END_STATE();
    case 2126:
      if (lookahead == 'h') ADVANCE(1935);
      END_STATE();
    case 2127:
      if (lookahead == 'h') ADVANCE(1936);
      END_STATE();
    case 2128:
      if (lookahead == 'h') ADVANCE(1914);
      END_STATE();
    case 2129:
      if (lookahead == 'h') ADVANCE(1916);
      END_STATE();
    case 2130:
      if (lookahead == 'h') ADVANCE(1954);
      END_STATE();
    case 2131:
      if (lookahead == 'h') ADVANCE(1960);
      END_STATE();
    case 2132:
      if (lookahead == 'h') ADVANCE(1978);
      END_STATE();
    case 2133:
      if (lookahead == 'h') ADVANCE(1966);
      END_STATE();
    case 2134:
      if (lookahead == 'h') ADVANCE(1968);
      END_STATE();
    case 2135:
      if (lookahead == 'h') ADVANCE(1983);
      END_STATE();
    case 2136:
      if (lookahead == 'h') ADVANCE(1975);
      END_STATE();
    case 2137:
      if (lookahead == 'h') ADVANCE(1977);
      END_STATE();
    case 2138:
      if (lookahead == 'h') ADVANCE(2091);
      END_STATE();
    case 2139:
      if (lookahead == 'h') ADVANCE(2092);
      END_STATE();
    case 2140:
      if (lookahead == 'h') ADVANCE(2093);
      END_STATE();
    case 2141:
      if (lookahead == 'h') ADVANCE(2094);
      END_STATE();
    case 2142:
      if (lookahead == 'h') ADVANCE(2096);
      END_STATE();
    case 2143:
      if (lookahead == 'h') ADVANCE(2097);
      END_STATE();
    case 2144:
      if (lookahead == 'h') ADVANCE(2098);
      END_STATE();
    case 2145:
      if (lookahead == 'h') ADVANCE(2099);
      END_STATE();
    case 2146:
      if (lookahead == 'h') ADVANCE(2100);
      END_STATE();
    case 2147:
      if (lookahead == 'h') ADVANCE(2101);
      END_STATE();
    case 2148:
      if (lookahead == 'h') ADVANCE(2102);
      END_STATE();
    case 2149:
      if (lookahead == 'h') ADVANCE(2103);
      END_STATE();
    case 2150:
      if (lookahead == 'i') ADVANCE(2115);
      END_STATE();
    case 2151:
      if (lookahead == 'i') ADVANCE(2274);
      END_STATE();
    case 2152:
      if (lookahead == 'i') ADVANCE(2056);
      END_STATE();
    case 2153:
      if (lookahead == 'i') ADVANCE(2116);
      if (lookahead == 'o') ADVANCE(2322);
      END_STATE();
    case 2154:
      if (lookahead == 'i') ADVANCE(1954);
      END_STATE();
    case 2155:
      if (lookahead == 'i') ADVANCE(2190);
      END_STATE();
    case 2156:
      if (lookahead == 'i') ADVANCE(2201);
      END_STATE();
    case 2157:
      if (lookahead == 'i') ADVANCE(2196);
      END_STATE();
    case 2158:
      if (lookahead == 'i') ADVANCE(2118);
      END_STATE();
    case 2159:
      if (lookahead == 'i') ADVANCE(2211);
      END_STATE();
    case 2160:
      if (lookahead == 'l') ADVANCE(2110);
      END_STATE();
    case 2161:
      if (lookahead == 'l') ADVANCE(2110);
      if (lookahead == 'r') ADVANCE(2274);
      END_STATE();
    case 2162:
      if (lookahead == 'l') ADVANCE(2335);
      END_STATE();
    case 2163:
      if (lookahead == 'l') ADVANCE(2339);
      END_STATE();
    case 2164:
      if (lookahead == 'l') ADVANCE(1921);
      END_STATE();
    case 2165:
      if (lookahead == 'l') ADVANCE(2005);
      if (lookahead == 'o') ADVANCE(2174);
      if (lookahead == 'q') ADVANCE(2333);
      if (lookahead == 'r') ADVANCE(2005);
      END_STATE();
    case 2166:
      if (lookahead == 'l') ADVANCE(2089);
      END_STATE();
    case 2167:
      if (lookahead == 'l') ADVANCE(2020);
      END_STATE();
    case 2168:
      if (lookahead == 'l') ADVANCE(1953);
      END_STATE();
    case 2169:
      if (lookahead == 'l') ADVANCE(1954);
      END_STATE();
    case 2170:
      if (lookahead == 'l') ADVANCE(1954);
      if (lookahead == 'r') ADVANCE(1954);
      END_STATE();
    case 2171:
      if (lookahead == 'l') ADVANCE(1959);
      END_STATE();
    case 2172:
      if (lookahead == 'l') ADVANCE(1979);
      END_STATE();
    case 2173:
      if (lookahead == 'l') ADVANCE(1971);
      END_STATE();
    case 2174:
      if (lookahead == 'l') ADVANCE(1965);
      END_STATE();
    case 2175:
      if (lookahead == 'l') ADVANCE(1967);
      END_STATE();
    case 2176:
      if (lookahead == 'l') ADVANCE(1982);
      END_STATE();
    case 2177:
      if (lookahead == 'l') ADVANCE(1969);
      END_STATE();
    case 2178:
      if (lookahead == 'l') ADVANCE(2111);
      END_STATE();
    case 2179:
      if (lookahead == 'l') ADVANCE(2347);
      END_STATE();
    case 2180:
      if (lookahead == 'l') ADVANCE(2113);
      if (lookahead == 'r') ADVANCE(2274);
      END_STATE();
    case 2181:
      if (lookahead == 'l') ADVANCE(2286);
      END_STATE();
    case 2182:
      if (lookahead == 'l') ADVANCE(2294);
      END_STATE();
    case 2183:
      if (lookahead == 'l') ADVANCE(2298);
      END_STATE();
    case 2184:
      if (lookahead == 'l') ADVANCE(2302);
      END_STATE();
    case 2185:
      if (lookahead == 'l') ADVANCE(2354);
      END_STATE();
    case 2186:
      if (lookahead == 'l') ADVANCE(2035);
      END_STATE();
    case 2187:
      if (lookahead == 'm') ADVANCE(1954);
      END_STATE();
    case 2188:
      if (lookahead == 'n') ADVANCE(2107);
      END_STATE();
    case 2189:
      if (lookahead == 'n') ADVANCE(2117);
      END_STATE();
    case 2190:
      if (lookahead == 'n') ADVANCE(2341);
      END_STATE();
    case 2191:
      if (lookahead == 'n') ADVANCE(1929);
      END_STATE();
    case 2192:
      if (lookahead == 'n') ADVANCE(1912);
      END_STATE();
    case 2193:
      if (lookahead == 'n') ADVANCE(1913);
      END_STATE();
    case 2194:
      if (lookahead == 'n') ADVANCE(1914);
      END_STATE();
    case 2195:
      if (lookahead == 'n') ADVANCE(1916);
      END_STATE();
    case 2196:
      if (lookahead == 'n') ADVANCE(1954);
      END_STATE();
    case 2197:
      if (lookahead == 'n') ADVANCE(1960);
      END_STATE();
    case 2198:
      if (lookahead == 'n') ADVANCE(1978);
      END_STATE();
    case 2199:
      if (lookahead == 'n') ADVANCE(1966);
      END_STATE();
    case 2200:
      if (lookahead == 'n') ADVANCE(1968);
      END_STATE();
    case 2201:
      if (lookahead == 'n') ADVANCE(1961);
      END_STATE();
    case 2202:
      if (lookahead == 'n') ADVANCE(1983);
      END_STATE();
    case 2203:
      if (lookahead == 'n') ADVANCE(1975);
      END_STATE();
    case 2204:
      if (lookahead == 'n') ADVANCE(1977);
      END_STATE();
    case 2205:
      if (lookahead == 'n') ADVANCE(2350);
      END_STATE();
    case 2206:
      if (lookahead == 'n') ADVANCE(2351);
      END_STATE();
    case 2207:
      if (lookahead == 'n') ADVANCE(2352);
      END_STATE();
    case 2208:
      if (lookahead == 'n') ADVANCE(2353);
      END_STATE();
    case 2209:
      if (lookahead == 'n') ADVANCE(2355);
      END_STATE();
    case 2210:
      if (lookahead == 'n') ADVANCE(2356);
      END_STATE();
    case 2211:
      if (lookahead == 'n') ADVANCE(2354);
      END_STATE();
    case 2212:
      if (lookahead == 'n') ADVANCE(2357);
      END_STATE();
    case 2213:
      if (lookahead == 'n') ADVANCE(2358);
      END_STATE();
    case 2214:
      if (lookahead == 'n') ADVANCE(2359);
      END_STATE();
    case 2215:
      if (lookahead == 'n') ADVANCE(2360);
      END_STATE();
    case 2216:
      if (lookahead == 'n') ADVANCE(2114);
      END_STATE();
    case 2217:
      if (lookahead == 'o') ADVANCE(2366);
      END_STATE();
    case 2218:
      if (lookahead == 'o') ADVANCE(2054);
      END_STATE();
    case 2219:
      if (lookahead == 'o') ADVANCE(2187);
      END_STATE();
    case 2220:
      if (lookahead == 'o') ADVANCE(2367);
      END_STATE();
    case 2221:
      if (lookahead == 'o') ADVANCE(2164);
      END_STATE();
    case 2222:
      if (lookahead == 'o') ADVANCE(2109);
      END_STATE();
    case 2223:
      if (lookahead == 'o') ADVANCE(2269);
      END_STATE();
    case 2224:
      if (lookahead == 'o') ADVANCE(1922);
      END_STATE();
    case 2225:
      if (lookahead == 'o') ADVANCE(1923);
      END_STATE();
    case 2226:
      if (lookahead == 'o') ADVANCE(1937);
      END_STATE();
    case 2227:
      if (lookahead == 'o') ADVANCE(1938);
      END_STATE();
    case 2228:
      if (lookahead == 'o') ADVANCE(2321);
      END_STATE();
    case 2229:
      if (lookahead == 'o') ADVANCE(2168);
      END_STATE();
    case 2230:
      if (lookahead == 'o') ADVANCE(2171);
      END_STATE();
    case 2231:
      if (lookahead == 'o') ADVANCE(2330);
      END_STATE();
    case 2232:
      if (lookahead == 'o') ADVANCE(2172);
      END_STATE();
    case 2233:
      if (lookahead == 'o') ADVANCE(2175);
      END_STATE();
    case 2234:
      if (lookahead == 'o') ADVANCE(2176);
      END_STATE();
    case 2235:
      if (lookahead == 'o') ADVANCE(2177);
      END_STATE();
    case 2236:
      if (lookahead == 'p') ADVANCE(1987);
      END_STATE();
    case 2237:
      if (lookahead == 'p') ADVANCE(1279);
      END_STATE();
    case 2238:
      if (lookahead == 'p') ADVANCE(2119);
      END_STATE();
    case 2239:
      if (lookahead == 'p') ADVANCE(1954);
      END_STATE();
    case 2240:
      if (lookahead == 'p') ADVANCE(2013);
      END_STATE();
    case 2241:
      if (lookahead == 'p') ADVANCE(2138);
      END_STATE();
    case 2242:
      if (lookahead == 'p') ADVANCE(2185);
      END_STATE();
    case 2243:
      if (lookahead == 'p') ADVANCE(2185);
      if (lookahead == 'q') ADVANCE(2364);
      if (lookahead == 'x') ADVANCE(2050);
      END_STATE();
    case 2244:
      if (lookahead == 'p') ADVANCE(2185);
      if (lookahead == 'q') ADVANCE(2365);
      if (lookahead == 'x') ADVANCE(2050);
      END_STATE();
    case 2245:
      if (lookahead == 'p') ADVANCE(2185);
      if (lookahead == 'u') ADVANCE(2170);
      END_STATE();
    case 2246:
      if (lookahead == 'p') ADVANCE(2139);
      END_STATE();
    case 2247:
      if (lookahead == 'p') ADVANCE(2140);
      END_STATE();
    case 2248:
      if (lookahead == 'p') ADVANCE(2141);
      END_STATE();
    case 2249:
      if (lookahead == 'p') ADVANCE(2142);
      END_STATE();
    case 2250:
      if (lookahead == 'p') ADVANCE(2143);
      END_STATE();
    case 2251:
      if (lookahead == 'p') ADVANCE(2144);
      END_STATE();
    case 2252:
      if (lookahead == 'p') ADVANCE(2145);
      END_STATE();
    case 2253:
      if (lookahead == 'p') ADVANCE(2146);
      END_STATE();
    case 2254:
      if (lookahead == 'p') ADVANCE(2147);
      END_STATE();
    case 2255:
      if (lookahead == 'p') ADVANCE(2148);
      END_STATE();
    case 2256:
      if (lookahead == 'p') ADVANCE(2149);
      END_STATE();
    case 2257:
      if (lookahead == 'q') ADVANCE(2336);
      END_STATE();
    case 2258:
      if (lookahead == 'q') ADVANCE(2337);
      END_STATE();
    case 2259:
      if (lookahead == 'q') ADVANCE(2346);
      END_STATE();
    case 2260:
      if (lookahead == 'q') ADVANCE(2348);
      END_STATE();
    case 2261:
      if (lookahead == 'q') ADVANCE(2349);
      END_STATE();
    case 2262:
      if (lookahead == 'q') ADVANCE(2362);
      END_STATE();
    case 2263:
      if (lookahead == 'r') ADVANCE(1992);
      END_STATE();
    case 2264:
      if (lookahead == 'r') ADVANCE(1957);
      END_STATE();
    case 2265:
      if (lookahead == 'r') ADVANCE(1996);
      END_STATE();
    case 2266:
      if (lookahead == 'r') ADVANCE(2274);
      END_STATE();
    case 2267:
      if (lookahead == 'r') ADVANCE(2154);
      END_STATE();
    case 2268:
      if (lookahead == 'r') ADVANCE(2239);
      END_STATE();
    case 2269:
      if (lookahead == 'r') ADVANCE(2326);
      END_STATE();
    case 2270:
      if (lookahead == 'r') ADVANCE(2089);
      END_STATE();
    case 2271:
      if (lookahead == 'r') ADVANCE(2220);
      END_STATE();
    case 2272:
      if (lookahead == 'r') ADVANCE(2271);
      END_STATE();
    case 2273:
      if (lookahead == 'r') ADVANCE(2264);
      END_STATE();
    case 2274:
      if (lookahead == 'r') ADVANCE(1954);
      END_STATE();
    case 2275:
      if (lookahead == 'r') ADVANCE(2112);
      END_STATE();
    case 2276:
      if (lookahead == 'r') ADVANCE(2045);
      END_STATE();
    case 2277:
      if (lookahead == 'r') ADVANCE(2046);
      END_STATE();
    case 2278:
      if (lookahead == 's') ADVANCE(2327);
      END_STATE();
    case 2279:
      if (lookahead == 's') ADVANCE(2123);
      END_STATE();
    case 2280:
      if (lookahead == 's') ADVANCE(1989);
      END_STATE();
    case 2281:
      if (lookahead == 's') ADVANCE(1964);
      END_STATE();
    case 2282:
      if (lookahead == 's') ADVANCE(1991);
      END_STATE();
    case 2283:
      if (lookahead == 's') ADVANCE(1973);
      END_STATE();
    case 2284:
      if (lookahead == 's') ADVANCE(1909);
      END_STATE();
    case 2285:
      if (lookahead == 's') ADVANCE(2186);
      END_STATE();
    case 2286:
      if (lookahead == 's') ADVANCE(1911);
      END_STATE();
    case 2287:
      if (lookahead == 's') ADVANCE(2344);
      END_STATE();
    case 2288:
      if (lookahead == 's') ADVANCE(1912);
      END_STATE();
    case 2289:
      if (lookahead == 's') ADVANCE(1913);
      END_STATE();
    case 2290:
      if (lookahead == 's') ADVANCE(1908);
      END_STATE();
    case 2291:
      if (lookahead == 's') ADVANCE(1944);
      END_STATE();
    case 2292:
      if (lookahead == 's') ADVANCE(1914);
      END_STATE();
    case 2293:
      if (lookahead == 's') ADVANCE(1916);
      END_STATE();
    case 2294:
      if (lookahead == 's') ADVANCE(1954);
      END_STATE();
    case 2295:
      if (lookahead == 's') ADVANCE(1960);
      END_STATE();
    case 2296:
      if (lookahead == 's') ADVANCE(1978);
      END_STATE();
    case 2297:
      if (lookahead == 's') ADVANCE(1966);
      END_STATE();
    case 2298:
      if (lookahead == 's') ADVANCE(1980);
      END_STATE();
    case 2299:
      if (lookahead == 's') ADVANCE(1968);
      END_STATE();
    case 2300:
      if (lookahead == 's') ADVANCE(1983);
      END_STATE();
    case 2301:
      if (lookahead == 's') ADVANCE(1975);
      END_STATE();
    case 2302:
      if (lookahead == 's') ADVANCE(1981);
      END_STATE();
    case 2303:
      if (lookahead == 's') ADVANCE(1977);
      END_STATE();
    case 2304:
      if (lookahead == 's') ADVANCE(2127);
      END_STATE();
    case 2305:
      if (lookahead == 's') ADVANCE(2329);
      END_STATE();
    case 2306:
      if (lookahead == 's') ADVANCE(2126);
      END_STATE();
    case 2307:
      if (lookahead == 's') ADVANCE(2330);
      END_STATE();
    case 2308:
      if (lookahead == 's') ADVANCE(2124);
      END_STATE();
    case 2309:
      if (lookahead == 's') ADVANCE(2331);
      END_STATE();
    case 2310:
      if (lookahead == 's') ADVANCE(2125);
      END_STATE();
    case 2311:
      if (lookahead == 's') ADVANCE(2128);
      END_STATE();
    case 2312:
      if (lookahead == 's') ADVANCE(2129);
      END_STATE();
    case 2313:
      if (lookahead == 's') ADVANCE(2131);
      END_STATE();
    case 2314:
      if (lookahead == 's') ADVANCE(2132);
      END_STATE();
    case 2315:
      if (lookahead == 's') ADVANCE(2133);
      END_STATE();
    case 2316:
      if (lookahead == 's') ADVANCE(2130);
      END_STATE();
    case 2317:
      if (lookahead == 's') ADVANCE(2134);
      END_STATE();
    case 2318:
      if (lookahead == 's') ADVANCE(2135);
      END_STATE();
    case 2319:
      if (lookahead == 's') ADVANCE(2136);
      END_STATE();
    case 2320:
      if (lookahead == 's') ADVANCE(2137);
      END_STATE();
    case 2321:
      if (lookahead == 't') ADVANCE(1917);
      END_STATE();
    case 2322:
      if (lookahead == 't') ADVANCE(1958);
      if (lookahead == 'x') ADVANCE(2245);
      END_STATE();
    case 2323:
      if (lookahead == 't') ADVANCE(1986);
      END_STATE();
    case 2324:
      if (lookahead == 't') ADVANCE(2014);
      END_STATE();
    case 2325:
      if (lookahead == 't') ADVANCE(1985);
      END_STATE();
    case 2326:
      if (lookahead == 't') ADVANCE(1988);
      END_STATE();
    case 2327:
      if (lookahead == 't') ADVANCE(1918);
      END_STATE();
    case 2328:
      if (lookahead == 't') ADVANCE(2267);
      END_STATE();
    case 2329:
      if (lookahead == 't') ADVANCE(1946);
      END_STATE();
    case 2330:
      if (lookahead == 't') ADVANCE(1954);
      END_STATE();
    case 2331:
      if (lookahead == 't') ADVANCE(1971);
      END_STATE();
    case 2332:
      if (lookahead == 't') ADVANCE(2013);
      END_STATE();
    case 2333:
      if (lookahead == 'u') ADVANCE(1955);
      END_STATE();
    case 2334:
      if (lookahead == 'u') ADVANCE(2228);
      END_STATE();
    case 2335:
      if (lookahead == 'u') ADVANCE(2284);
      END_STATE();
    case 2336:
      if (lookahead == 'u') ADVANCE(2010);
      END_STATE();
    case 2337:
      if (lookahead == 'u') ADVANCE(2224);
      END_STATE();
    case 2338:
      if (lookahead == 'u') ADVANCE(2104);
      END_STATE();
    case 2339:
      if (lookahead == 'u') ADVANCE(2280);
      END_STATE();
    case 2340:
      if (lookahead == 'u') ADVANCE(2281);
      END_STATE();
    case 2341:
      if (lookahead == 'u') ADVANCE(2282);
      END_STATE();
    case 2342:
      if (lookahead == 'u') ADVANCE(2019);
      END_STATE();
    case 2343:
      if (lookahead == 'u') ADVANCE(2283);
      END_STATE();
    case 2344:
      if (lookahead == 'u') ADVANCE(2275);
      END_STATE();
    case 2345:
      if (lookahead == 'u') ADVANCE(2291);
      END_STATE();
    case 2346:
      if (lookahead == 'u') ADVANCE(2226);
      END_STATE();
    case 2347:
      if (lookahead == 'u') ADVANCE(2290);
      END_STATE();
    case 2348:
      if (lookahead == 'u') ADVANCE(2225);
      END_STATE();
    case 2349:
      if (lookahead == 'u') ADVANCE(2227);
      END_STATE();
    case 2350:
      if (lookahead == 'u') ADVANCE(2288);
      END_STATE();
    case 2351:
      if (lookahead == 'u') ADVANCE(2289);
      END_STATE();
    case 2352:
      if (lookahead == 'u') ADVANCE(2292);
      END_STATE();
    case 2353:
      if (lookahead == 'u') ADVANCE(2293);
      END_STATE();
    case 2354:
      if (lookahead == 'u') ADVANCE(2294);
      END_STATE();
    case 2355:
      if (lookahead == 'u') ADVANCE(2295);
      END_STATE();
    case 2356:
      if (lookahead == 'u') ADVANCE(2296);
      END_STATE();
    case 2357:
      if (lookahead == 'u') ADVANCE(2297);
      END_STATE();
    case 2358:
      if (lookahead == 'u') ADVANCE(2299);
      END_STATE();
    case 2359:
      if (lookahead == 'u') ADVANCE(2300);
      END_STATE();
    case 2360:
      if (lookahead == 'u') ADVANCE(2301);
      END_STATE();
    case 2361:
      if (lookahead == 'u') ADVANCE(2303);
      END_STATE();
    case 2362:
      if (lookahead == 'u') ADVANCE(2041);
      END_STATE();
    case 2363:
      if (lookahead == 'u') ADVANCE(2105);
      END_STATE();
    case 2364:
      if (lookahead == 'u') ADVANCE(2042);
      END_STATE();
    case 2365:
      if (lookahead == 'u') ADVANCE(2044);
      END_STATE();
    case 2366:
      if (lookahead == 'w') ADVANCE(2040);
      END_STATE();
    case 2367:
      if (lookahead == 'w') ADVANCE(1954);
      END_STATE();
    case 2368:
      if (lookahead == 'x') ADVANCE(2049);
      END_STATE();
    case 2369:
      if (lookahead == 'y') ADVANCE(2241);
      END_STATE();
    case 2370:
      if (lookahead == 'y') ADVANCE(2246);
      END_STATE();
    case 2371:
      if (lookahead == 'y') ADVANCE(2247);
      END_STATE();
    case 2372:
      if (lookahead == 'y') ADVANCE(2248);
      END_STATE();
    case 2373:
      if (lookahead == 'y') ADVANCE(2249);
      END_STATE();
    case 2374:
      if (lookahead == 'y') ADVANCE(2250);
      END_STATE();
    case 2375:
      if (lookahead == 'y') ADVANCE(2252);
      END_STATE();
    case 2376:
      if (lookahead == 'y') ADVANCE(2253);
      END_STATE();
    case 2377:
      if (lookahead == 'y') ADVANCE(2254);
      END_STATE();
    case 2378:
      if (lookahead == 0xfe0e) ADVANCE(2629);
      END_STATE();
    case 2379:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(2438);
      END_STATE();
    case 2380:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1925);
      END_STATE();
    case 2381:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1954);
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(1954);
      END_STATE();
    case 2382:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1954);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(1954);
      END_STATE();
    case 2383:
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(1922);
      END_STATE();
    case 2384:
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(1923);
      END_STATE();
    case 2385:
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(1923);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1924);
      END_STATE();
    case 2386:
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(1949);
      END_STATE();
    case 2387:
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(1953);
      END_STATE();
    case 2388:
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(1954);
      END_STATE();
    case 2389:
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(1959);
      END_STATE();
    case 2390:
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(1979);
      END_STATE();
    case 2391:
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(1965);
      END_STATE();
    case 2392:
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(1967);
      END_STATE();
    case 2393:
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(1982);
      END_STATE();
    case 2394:
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(1969);
      END_STATE();
    case 2395:
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(2408);
      END_STATE();
    case 2396:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(1937);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1938);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(1939);
      END_STATE();
    case 2397:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(1954);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1954);
      END_STATE();
    case 2398:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(1970);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1980);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(1971);
      END_STATE();
    case 2399:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(1970);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1981);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(1971);
      END_STATE();
    case 2400:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(2387);
      END_STATE();
    case 2401:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(2390);
      END_STATE();
    case 2402:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1909);
      END_STATE();
    case 2403:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1911);
      END_STATE();
    case 2404:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1924);
      END_STATE();
    case 2405:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1926);
      END_STATE();
    case 2406:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1908);
      END_STATE();
    case 2407:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1932);
      END_STATE();
    case 2408:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1915);
      END_STATE();
    case 2409:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1954);
      END_STATE();
    case 2410:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1963);
      END_STATE();
    case 2411:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1962);
      END_STATE();
    case 2412:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1972);
      END_STATE();
    case 2413:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1976);
      END_STATE();
    case 2414:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1927);
      END_STATE();
    case 2415:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1943);
      END_STATE();
    case 2416:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1954);
      END_STATE();
    case 2417:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(2402);
      END_STATE();
    case 2418:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(2406);
      END_STATE();
    case 2419:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(2409);
      END_STATE();
    case 2420:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(2410);
      END_STATE();
    case 2421:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(2412);
      END_STATE();
    case 2422:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1762);
      END_STATE();
    case 2423:
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(1615);
      END_STATE();
    case 2424:
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(1325);
      END_STATE();
    case 2425:
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(1324);
      END_STATE();
    case 2426:
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(1496);
      END_STATE();
    case 2427:
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(1954);
      END_STATE();
    case 2428:
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(1851);
      END_STATE();
    case 2429:
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(1853);
      END_STATE();
    case 2430:
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(1859);
      END_STATE();
    case 2431:
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(1861);
      END_STATE();
    case 2432:
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(1863);
      END_STATE();
    case 2433:
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(1864);
      END_STATE();
    case 2434:
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(1865);
      END_STATE();
    case 2435:
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(1867);
      END_STATE();
    case 2436:
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(1486);
      END_STATE();
    case 2437:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(2641);
      END_STATE();
    case 2438:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(2437);
      END_STATE();
    case 2439:
      if (lookahead == '0' ||
          lookahead == 'O' ||
          lookahead == 'o') ADVANCE(2640);
      END_STATE();
    case 2440:
      if (lookahead == '0' ||
          lookahead == 'O' ||
          lookahead == 'o') ADVANCE(2637);
      END_STATE();
    case 2441:
      if (lookahead == '0' ||
          lookahead == 'O' ||
          lookahead == 'o') ADVANCE(2740);
      END_STATE();
    case 2442:
      if (lookahead == '0' ||
          lookahead == 'O' ||
          lookahead == 'o') ADVANCE(2740);
      if (set_contains(aux_sym_result_code_token20_character_set_2, 13, lookahead)) ADVANCE(2441);
      END_STATE();
    case 2443:
      if (lookahead == '0' ||
          lookahead == 'O' ||
          lookahead == 'o') ADVANCE(2641);
      END_STATE();
    case 2444:
      if (lookahead == 'A' ||
          lookahead == 'B' ||
          lookahead == 'a' ||
          lookahead == 'b') ADVANCE(2445);
      if (lookahead == '.' ||
          lookahead == 0x660 ||
          lookahead == 0x6f0 ||
          lookahead == 0x701 ||
          lookahead == 0x702 ||
          lookahead == 0x200e ||
          lookahead == 0x2024 ||
          lookahead == 0xa4f8 ||
          lookahead == 0xa60e ||
          lookahead == 0x1d16d) ADVANCE(2592);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(2444);
      if (set_contains(aux_sym_result_code_token22_character_set_1, 11, lookahead)) ADVANCE(2591);
      END_STATE();
    case 2445:
      if (lookahead == '.' ||
          lookahead == 0x660 ||
          lookahead == 0x6f0 ||
          lookahead == 0x701 ||
          lookahead == 0x702 ||
          lookahead == 0x200e ||
          lookahead == 0x2024 ||
          lookahead == 0xa4f8 ||
          lookahead == 0xa60e ||
          lookahead == 0x1d16d) ADVANCE(2592);
      if (set_contains(sym_move_number_character_set_2, 19, lookahead)) ADVANCE(2591);
      END_STATE();
    case 2446:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(2669);
      END_STATE();
    case 2447:
      if (set_contains(extras_character_set_2, 10, lookahead)) SKIP(2447);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2574);
      END_STATE();
    case 2448:
      if (set_contains(extras_character_set_2, 10, lookahead)) ADVANCE(2513);
      if (lookahead != 0 &&
          lookahead != '%') ADVANCE(2514);
      END_STATE();
    case 2449:
      if (eof) ADVANCE(2460);
      ADVANCE_MAP(
        '\n', 2466,
        '\r', 1174,
        '!', 2657,
        '$', 907,
        '&', 18,
        '(', 2563,
        ')', 2565,
        '*', 2721,
        '0', 2695,
        '1', 2671,
        ';', 2464,
        '<', 542,
        '=', 2652,
        '?', 2657,
        '@', 2633,
        'N', 2612,
        'O', 2691,
        'P', 2625,
        'R', 2610,
        'T', 548,
        '[', 2475,
        'e', 2594,
        'o', 2700,
        'p', 861,
        '{', 2567,
        '}', 2569,
        0xbd, 2715,
        0x66d, 2737,
        0x204e, 2733,
        0x2217, 2725,
        0x221e, 2660,
        0x2659, 2628,
        0x265f, 860,
        0x2731, 2729,
        'Z', 903,
        'z', 903,
        0x2e40, 2651,
        0xff1d, 2651,
        '+', 29,
        0x16ed, 29,
        0x2795, 29,
        '/', 30,
        0x2044, 30,
        0x2215, 30,
        0x27cb, 30,
        0x29f8, 30,
      );
      if (('a' <= lookahead && lookahead <= 'h')) ADVANCE(2595);
      if (lookahead == '-' ||
          (0x2010 <= lookahead && lookahead <= 0x2014) ||
          lookahead == 0x2212 ||
          lookahead == 0x2796) ADVANCE(2654);
      if (('2' <= lookahead && lookahead <= '9')) ADVANCE(920);
      if (lookahead == 'B' ||
          lookahead == 'K' ||
          lookahead == 'Q' ||
          (0x2654 <= lookahead && lookahead <= 0x265e)) ADVANCE(2611);
      if (set_contains(aux_sym_result_code_token23_character_set_1, 12, lookahead)) ADVANCE(1174);
      if (set_contains(aux_sym_annotation_token1_character_set_1, 54, lookahead)) ADVANCE(2659);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 2450:
      if (eof) ADVANCE(2460);
      ADVANCE_MAP(
        '\n', 2469,
        '\r', 1180,
        '!', 2657,
        '$', 907,
        '&', 2,
        '(', 2563,
        '0', 919,
        ';', 2464,
        '<', 542,
        '=', 2652,
        '?', 2657,
        '@', 2633,
        'N', 2612,
        'P', 2625,
        'R', 2610,
        'T', 548,
        '[', 2475,
        'e', 2594,
        'p', 861,
        '{', 2567,
        0x221e, 2660,
        0x2659, 2628,
        0x265f, 860,
        'O', 28,
        'o', 28,
        'Z', 903,
        'z', 903,
        0x2e40, 2651,
        0xff1d, 2651,
        '+', 29,
        0x16ed, 29,
        0x2795, 29,
        '/', 30,
        0x2044, 30,
        0x2215, 30,
        0x27cb, 30,
        0x29f8, 30,
      );
      if (('a' <= lookahead && lookahead <= 'h')) ADVANCE(2595);
      if (lookahead == '-' ||
          (0x2010 <= lookahead && lookahead <= 0x2014) ||
          lookahead == 0x2212 ||
          lookahead == 0x2796) ADVANCE(2654);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(920);
      if (lookahead == 'B' ||
          lookahead == 'K' ||
          lookahead == 'Q' ||
          (0x2654 <= lookahead && lookahead <= 0x265e)) ADVANCE(2611);
      if (set_contains(aux_sym_result_code_token22_character_set_1, 11, lookahead)) ADVANCE(1180);
      if (set_contains(aux_sym_annotation_token1_character_set_1, 54, lookahead)) ADVANCE(2659);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 2451:
      if (eof) ADVANCE(2460);
      ADVANCE_MAP(
        '!', 2657,
        '#', 2646,
        '$', 907,
        '&', 13,
        '(', 2563,
        ')', 2565,
        '*', 2721,
        '0', 2695,
        '1', 2671,
        ';', 2464,
        '<', 542,
        '=', 2652,
        '?', 2657,
        '@', 2633,
        'N', 2612,
        'O', 2691,
        'P', 2625,
        'R', 2610,
        'T', 548,
        '[', 2475,
        'e', 2594,
        'o', 2700,
        'p', 861,
        '{', 2567,
        '}', 2569,
        0xbd, 2715,
        0x66d, 2737,
        0x204e, 2733,
        0x2217, 2725,
        0x221e, 2660,
        0x2659, 2628,
        0x265f, 860,
        0x2731, 2729,
      );
      if (lookahead == '\n' ||
          lookahead == '\r') SKIP(2456);
      if (lookahead == 'Z' ||
          lookahead == 'z') ADVANCE(903);
      if (lookahead == 0x2e40 ||
          lookahead == 0xff1d) ADVANCE(2651);
      if (lookahead == '+' ||
          lookahead == 0x16ed ||
          lookahead == 0x2795) ADVANCE(2645);
      if (lookahead == '/' ||
          lookahead == 0x2044 ||
          lookahead == 0x2215 ||
          lookahead == 0x27cb ||
          lookahead == 0x29f8) ADVANCE(30);
      if (('a' <= lookahead && lookahead <= 'h')) ADVANCE(2595);
      if (lookahead == '-' ||
          (0x2010 <= lookahead && lookahead <= 0x2014) ||
          lookahead == 0x2212 ||
          lookahead == 0x2796) ADVANCE(2654);
      if (('2' <= lookahead && lookahead <= '9')) ADVANCE(920);
      if (lookahead == 'B' ||
          lookahead == 'K' ||
          lookahead == 'Q' ||
          (0x2654 <= lookahead && lookahead <= 0x265e)) ADVANCE(2611);
      if (set_contains(aux_sym_result_code_token23_character_set_1, 12, lookahead)) ADVANCE(1164);
      if (set_contains(aux_sym_annotation_token1_character_set_1, 54, lookahead)) ADVANCE(2659);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 2452:
      if (eof) ADVANCE(2460);
      ADVANCE_MAP(
        '!', 2657,
        '#', 2646,
        '$', 907,
        '&', 13,
        '(', 2563,
        ')', 2565,
        '*', 2721,
        '0', 2695,
        '1', 2671,
        ';', 2464,
        '<', 542,
        '=', 2652,
        '?', 2657,
        '@', 2633,
        'N', 2612,
        'O', 2691,
        'P', 2625,
        'R', 2610,
        'T', 548,
        '[', 2475,
        'e', 2598,
        'o', 2700,
        'p', 861,
        '{', 2567,
        '}', 2569,
        0xbd, 2715,
        0x66d, 2737,
        0x204e, 2733,
        0x2217, 2725,
        0x221e, 2660,
        0x2659, 2628,
        0x265f, 860,
        0x2731, 2729,
      );
      if (lookahead == '\n' ||
          lookahead == '\r') SKIP(2456);
      if (lookahead == 'Z' ||
          lookahead == 'z') ADVANCE(903);
      if (lookahead == 0x2e40 ||
          lookahead == 0xff1d) ADVANCE(2651);
      if (lookahead == '+' ||
          lookahead == 0x16ed ||
          lookahead == 0x2795) ADVANCE(2645);
      if (lookahead == ':' ||
          lookahead == 'X' ||
          lookahead == 'x') ADVANCE(2616);
      if (lookahead == '/' ||
          lookahead == 0x2044 ||
          lookahead == 0x2215 ||
          lookahead == 0x27cb ||
          lookahead == 0x29f8) ADVANCE(30);
      if (('a' <= lookahead && lookahead <= 'h')) ADVANCE(2599);
      if (lookahead == '-' ||
          (0x2010 <= lookahead && lookahead <= 0x2014) ||
          lookahead == 0x2212 ||
          lookahead == 0x2796) ADVANCE(2654);
      if (('2' <= lookahead && lookahead <= '9')) ADVANCE(920);
      if (lookahead == 'B' ||
          lookahead == 'K' ||
          lookahead == 'Q' ||
          (0x2654 <= lookahead && lookahead <= 0x265e)) ADVANCE(2611);
      if (set_contains(aux_sym_result_code_token23_character_set_1, 12, lookahead)) ADVANCE(1164);
      if (set_contains(aux_sym_annotation_token1_character_set_1, 54, lookahead)) ADVANCE(2659);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 2453:
      if (eof) ADVANCE(2460);
      ADVANCE_MAP(
        '!', 2657,
        '#', 2646,
        '$', 907,
        '&', 19,
        '(', 2563,
        ')', 2565,
        '*', 2721,
        '0', 2695,
        '1', 2671,
        ';', 2464,
        '<', 542,
        '=', 2619,
        '?', 2657,
        '@', 2633,
        'N', 2606,
        'O', 2691,
        'P', 2625,
        'R', 2604,
        'T', 548,
        '[', 2475,
        'e', 2594,
        'o', 2700,
        'p', 861,
        '{', 2567,
        '}', 2569,
        0xbd, 2715,
        0x66d, 2737,
        0x204e, 2733,
        0x2217, 2725,
        0x221e, 2660,
        0x2659, 2628,
        0x265f, 860,
        0x2731, 2729,
      );
      if (lookahead == '\n' ||
          lookahead == '\r') SKIP(2456);
      if (lookahead == 'Z' ||
          lookahead == 'z') ADVANCE(903);
      if (lookahead == 0x2e40 ||
          lookahead == 0xff1d) ADVANCE(2618);
      if (lookahead == '+' ||
          lookahead == 0x16ed ||
          lookahead == 0x2795) ADVANCE(2645);
      if (lookahead == '/' ||
          lookahead == 0x2044 ||
          lookahead == 0x2215 ||
          lookahead == 0x27cb ||
          lookahead == 0x29f8) ADVANCE(30);
      if (('a' <= lookahead && lookahead <= 'h')) ADVANCE(2595);
      if (lookahead == '-' ||
          (0x2010 <= lookahead && lookahead <= 0x2014) ||
          lookahead == 0x2212 ||
          lookahead == 0x2796) ADVANCE(2654);
      if (('2' <= lookahead && lookahead <= '9')) ADVANCE(920);
      if (lookahead == 'B' ||
          lookahead == 'K' ||
          lookahead == 'Q' ||
          (0x2654 <= lookahead && lookahead <= 0x265e)) ADVANCE(2605);
      if (set_contains(aux_sym_result_code_token23_character_set_1, 12, lookahead)) ADVANCE(1164);
      if (set_contains(aux_sym_annotation_token1_character_set_1, 54, lookahead)) ADVANCE(2659);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 2454:
      if (eof) ADVANCE(2460);
      ADVANCE_MAP(
        '!', 2657,
        '#', 2646,
        '$', 907,
        '&', 20,
        '(', 2563,
        ')', 2565,
        '*', 2721,
        '0', 2695,
        '1', 2671,
        ';', 2464,
        '<', 542,
        '=', 2652,
        '?', 2657,
        '@', 2633,
        'N', 2612,
        'O', 2691,
        'P', 2625,
        'R', 2610,
        'T', 548,
        '[', 2475,
        'e', 2598,
        'o', 2700,
        'p', 861,
        '{', 2567,
        '}', 2569,
        0xbd, 2715,
        0x66d, 2737,
        0x204e, 2733,
        0x2217, 2725,
        0x221e, 2660,
        0x2659, 2628,
        0x265f, 860,
        0x2731, 2729,
      );
      if (lookahead == '\n' ||
          lookahead == '\r') SKIP(2456);
      if (lookahead == 'Z' ||
          lookahead == 'z') ADVANCE(903);
      if (lookahead == 0x2e40 ||
          lookahead == 0xff1d) ADVANCE(2651);
      if (lookahead == '+' ||
          lookahead == 0x16ed ||
          lookahead == 0x2795) ADVANCE(2645);
      if (lookahead == ':' ||
          lookahead == 'X' ||
          lookahead == 'x') ADVANCE(2616);
      if (lookahead == '/' ||
          lookahead == 0x2044 ||
          lookahead == 0x2215 ||
          lookahead == 0x27cb ||
          lookahead == 0x29f8) ADVANCE(30);
      if (('a' <= lookahead && lookahead <= 'h')) ADVANCE(2599);
      if (lookahead == '-' ||
          (0x2010 <= lookahead && lookahead <= 0x2014) ||
          lookahead == 0x2212 ||
          lookahead == 0x2796) ADVANCE(2635);
      if (('2' <= lookahead && lookahead <= '9')) ADVANCE(920);
      if (lookahead == 'B' ||
          lookahead == 'K' ||
          lookahead == 'Q' ||
          (0x2654 <= lookahead && lookahead <= 0x265e)) ADVANCE(2611);
      if (set_contains(aux_sym_result_code_token23_character_set_1, 12, lookahead)) ADVANCE(1164);
      if (set_contains(aux_sym_annotation_token1_character_set_1, 54, lookahead)) ADVANCE(2659);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 2455:
      if (eof) ADVANCE(2460);
      ADVANCE_MAP(
        '!', 2657,
        '$', 907,
        '&', 2,
        '(', 2563,
        '0', 919,
        ';', 2464,
        '<', 542,
        '=', 2652,
        '?', 2657,
        '@', 2633,
        'N', 2612,
        'P', 2625,
        'R', 2610,
        'T', 548,
        '[', 2475,
        'e', 2594,
        'p', 861,
        '{', 2567,
        0x221e, 2660,
        0x2659, 2628,
        0x265f, 860,
      );
      if (lookahead == '\n' ||
          lookahead == '\r') SKIP(2455);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(28);
      if (lookahead == 'Z' ||
          lookahead == 'z') ADVANCE(903);
      if (lookahead == 0x2e40 ||
          lookahead == 0xff1d) ADVANCE(2651);
      if (lookahead == '+' ||
          lookahead == 0x16ed ||
          lookahead == 0x2795) ADVANCE(29);
      if (lookahead == '/' ||
          lookahead == 0x2044 ||
          lookahead == 0x2215 ||
          lookahead == 0x27cb ||
          lookahead == 0x29f8) ADVANCE(30);
      if (('a' <= lookahead && lookahead <= 'h')) ADVANCE(2595);
      if (lookahead == '-' ||
          (0x2010 <= lookahead && lookahead <= 0x2014) ||
          lookahead == 0x2212 ||
          lookahead == 0x2796) ADVANCE(2654);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(920);
      if (lookahead == 'B' ||
          lookahead == 'K' ||
          lookahead == 'Q' ||
          (0x2654 <= lookahead && lookahead <= 0x265e)) ADVANCE(2611);
      if (set_contains(aux_sym_result_code_token22_character_set_1, 11, lookahead)) ADVANCE(924);
      if (set_contains(aux_sym_annotation_token1_character_set_1, 54, lookahead)) ADVANCE(2659);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 2456:
      if (eof) ADVANCE(2460);
      ADVANCE_MAP(
        '!', 2657,
        '$', 907,
        '&', 18,
        '(', 2563,
        ')', 2565,
        '*', 2721,
        '0', 2695,
        '1', 2671,
        ';', 2464,
        '<', 542,
        '=', 2652,
        '?', 2657,
        '@', 2633,
        'N', 2612,
        'O', 2691,
        'P', 2625,
        'R', 2610,
        'T', 548,
        '[', 2475,
        'e', 2594,
        'o', 2700,
        'p', 861,
        '{', 2567,
        '}', 2569,
        0xbd, 2715,
        0x66d, 2737,
        0x204e, 2733,
        0x2217, 2725,
        0x221e, 2660,
        0x2659, 2628,
        0x265f, 860,
        0x2731, 2729,
      );
      if (lookahead == '\n' ||
          lookahead == '\r') SKIP(2456);
      if (lookahead == 'Z' ||
          lookahead == 'z') ADVANCE(903);
      if (lookahead == 0x2e40 ||
          lookahead == 0xff1d) ADVANCE(2651);
      if (lookahead == '+' ||
          lookahead == 0x16ed ||
          lookahead == 0x2795) ADVANCE(29);
      if (lookahead == '/' ||
          lookahead == 0x2044 ||
          lookahead == 0x2215 ||
          lookahead == 0x27cb ||
          lookahead == 0x29f8) ADVANCE(30);
      if (('a' <= lookahead && lookahead <= 'h')) ADVANCE(2595);
      if (lookahead == '-' ||
          (0x2010 <= lookahead && lookahead <= 0x2014) ||
          lookahead == 0x2212 ||
          lookahead == 0x2796) ADVANCE(2654);
      if (('2' <= lookahead && lookahead <= '9')) ADVANCE(920);
      if (lookahead == 'B' ||
          lookahead == 'K' ||
          lookahead == 'Q' ||
          (0x2654 <= lookahead && lookahead <= 0x265e)) ADVANCE(2611);
      if (set_contains(aux_sym_result_code_token23_character_set_1, 12, lookahead)) ADVANCE(1164);
      if (set_contains(aux_sym_annotation_token1_character_set_1, 54, lookahead)) ADVANCE(2659);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 2457:
      if (eof) ADVANCE(2460);
      ADVANCE_MAP(
        '!', 2668,
        '#', 2644,
        '$', 2446,
        '&', 1216,
        '(', 2562,
        ')', 2564,
        '0', 1265,
        ';', 2463,
        '<', 1984,
        '=', 2663,
        '?', 2668,
        '@', 2632,
        'N', 2614,
        'P', 2626,
        'R', 2613,
        'T', 1990,
        '[', 2474,
        'e', 2596,
        'p', 2379,
        '{', 2566,
        0xbd, 2714,
        0x221e, 2661,
        0x2659, 2627,
        0x265f, 2378,
        'O', 1266,
        'o', 1266,
        'Z', 2443,
        'z', 2443,
        0x2e40, 2662,
        0xff1d, 2662,
        '+', 2648,
        0x16ed, 2648,
        0x2795, 2648,
        '/', 1245,
        0x2044, 1245,
        0x2215, 1245,
        0x27cb, 1245,
        0x29f8, 1245,
      );
      if (('a' <= lookahead && lookahead <= 'h')) ADVANCE(2593);
      if (lookahead == '-' ||
          (0x2010 <= lookahead && lookahead <= 0x2014) ||
          lookahead == 0x2212 ||
          lookahead == 0x2796) ADVANCE(2664);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(2444);
      if (lookahead == 'B' ||
          lookahead == 'K' ||
          lookahead == 'Q' ||
          (0x2654 <= lookahead && lookahead <= 0x265e)) ADVANCE(2609);
      if (set_contains(aux_sym_result_code_token23_character_set_1, 12, lookahead)) SKIP(2458);
      if (set_contains(aux_sym_annotation_token1_character_set_1, 54, lookahead)) ADVANCE(2649);
      END_STATE();
    case 2458:
      if (eof) ADVANCE(2460);
      ADVANCE_MAP(
        '!', 2668,
        '$', 2446,
        '&', 1224,
        '(', 2562,
        ')', 2564,
        '0', 1265,
        ';', 2463,
        '<', 1984,
        '=', 2663,
        '?', 2668,
        '@', 2632,
        'N', 2614,
        'P', 2626,
        'R', 2613,
        'T', 1990,
        '[', 2474,
        'e', 2596,
        'p', 2379,
        '{', 2566,
        0xbd, 2714,
        0x221e, 2661,
        0x2659, 2627,
        0x265f, 2378,
        'O', 1266,
        'o', 1266,
        'Z', 2443,
        'z', 2443,
        0x2e40, 2662,
        0xff1d, 2662,
        '+', 1248,
        0x16ed, 1248,
        0x2795, 1248,
        '/', 1245,
        0x2044, 1245,
        0x2215, 1245,
        0x27cb, 1245,
        0x29f8, 1245,
      );
      if (('a' <= lookahead && lookahead <= 'h')) ADVANCE(2593);
      if (lookahead == '-' ||
          (0x2010 <= lookahead && lookahead <= 0x2014) ||
          lookahead == 0x2212 ||
          lookahead == 0x2796) ADVANCE(2664);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(2444);
      if (lookahead == 'B' ||
          lookahead == 'K' ||
          lookahead == 'Q' ||
          (0x2654 <= lookahead && lookahead <= 0x265e)) ADVANCE(2609);
      if (set_contains(aux_sym_result_code_token23_character_set_1, 12, lookahead)) SKIP(2458);
      if (set_contains(aux_sym_annotation_token1_character_set_1, 54, lookahead)) ADVANCE(2649);
      END_STATE();
    case 2459:
      if (eof) ADVANCE(2460);
      ADVANCE_MAP(
        '"', 2480,
        '%', 2465,
        '&', 1204,
        '(', 2562,
        ')', 2564,
        '*', 2720,
        '-', 2674,
        '/', 2703,
        '0', 2697,
        '1', 2670,
        '2', 2713,
        ';', 2463,
        '@', 2632,
        'O', 2692,
        'P', 2624,
        '[', 2476,
        ']', 2478,
        'o', 2701,
        '{', 2566,
        '}', 2568,
        0xab, 2508,
        0xbb, 2510,
        0xbd, 2716,
        0x2ba, 2500,
        0x2dd, 2498,
        0x2ee, 2504,
        0x2f6, 2502,
        0x5f2, 2506,
        0x5f4, 2496,
        0x66d, 2736,
        0x2010, 2678,
        0x2011, 2680,
        0x2012, 2682,
        0x2013, 2684,
        0x2014, 2686,
        0x201c, 2484,
        0x201d, 2486,
        0x201f, 2488,
        0x2033, 2490,
        0x2036, 2492,
        0x2044, 2707,
        0x204e, 2732,
        0x2212, 2676,
        0x2215, 2705,
        0x2217, 2724,
        0x2659, 2627,
        0x265f, 2378,
        0x2731, 2728,
        0x2796, 2688,
        0x27cb, 2709,
        0x29f8, 2711,
        0x3003, 2494,
        0xff02, 2482,
      );
      if (('a' <= lookahead && lookahead <= 'h')) ADVANCE(2593);
      if (lookahead == 'B' ||
          lookahead == 'K' ||
          ('N' <= lookahead && lookahead <= 'R') ||
          (0x2654 <= lookahead && lookahead <= 0x265e)) ADVANCE(2609);
      if (set_contains(aux_sym_result_code_token23_character_set_1, 12, lookahead)) SKIP(2459);
      END_STATE();
    case 2460:
      ACCEPT_TOKEN(ts_builtin_sym_end);
      END_STATE();
    case 2461:
      ACCEPT_TOKEN(sym__empty_line);
      if (lookahead == '\n') ADVANCE(2461);
      if (lookahead == '\r') ADVANCE(1172);
      END_STATE();
    case 2462:
      ACCEPT_TOKEN(sym__empty_line);
      if (lookahead == '\n') ADVANCE(2462);
      if (lookahead == '\r') ADVANCE(1179);
      END_STATE();
    case 2463:
      ACCEPT_TOKEN(anon_sym_SEMI);
      END_STATE();
    case 2464:
      ACCEPT_TOKEN(anon_sym_SEMI);
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 2465:
      ACCEPT_TOKEN(anon_sym_PERCENT);
      END_STATE();
    case 2466:
      ACCEPT_TOKEN(aux_sym_rest_of_line_comment_token1);
      if (lookahead == '\n') ADVANCE(2466);
      if (lookahead == '\r') ADVANCE(1174);
      if (set_contains(extras_character_set_2, 10, lookahead)) ADVANCE(1174);
      END_STATE();
    case 2467:
      ACCEPT_TOKEN(aux_sym_rest_of_line_comment_token1);
      if (lookahead == '\n') ADVANCE(2467);
      if (lookahead == '\r') ADVANCE(1175);
      END_STATE();
    case 2468:
      ACCEPT_TOKEN(aux_sym_rest_of_line_comment_token1);
      if (lookahead == '\n') ADVANCE(2462);
      if (lookahead == '\r') ADVANCE(1179);
      END_STATE();
    case 2469:
      ACCEPT_TOKEN(aux_sym_rest_of_line_comment_token1);
      if (lookahead == '\n') ADVANCE(2469);
      if (lookahead == '\r') ADVANCE(1180);
      if (set_contains(extras_character_set_2, 10, lookahead)) ADVANCE(1180);
      END_STATE();
    case 2470:
      ACCEPT_TOKEN(aux_sym_rest_of_line_comment_token1);
      if (lookahead == '\n') ADVANCE(2470);
      if (lookahead == '\r') ADVANCE(1183);
      END_STATE();
    case 2471:
      ACCEPT_TOKEN(sym_rest_of_line_comment_text);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '\r') ADVANCE(2471);
      END_STATE();
    case 2472:
      ACCEPT_TOKEN(sym_old_style_twic_section_comment);
      END_STATE();
    case 2473:
      ACCEPT_TOKEN(sym_old_style_twic_section_comment);
      if (lookahead == '-') ADVANCE(1269);
      END_STATE();
    case 2474:
      ACCEPT_TOKEN(anon_sym_LBRACK);
      END_STATE();
    case 2475:
      ACCEPT_TOKEN(anon_sym_LBRACK);
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 2476:
      ACCEPT_TOKEN(anon_sym_LBRACK);
      if (lookahead == '%') ADVANCE(2570);
      END_STATE();
    case 2477:
      ACCEPT_TOKEN(anon_sym_LBRACK);
      if ((!eof && set_contains(sym_tagpair_key_character_set_1, 11, lookahead))) ADVANCE(2514);
      END_STATE();
    case 2478:
      ACCEPT_TOKEN(anon_sym_RBRACK);
      END_STATE();
    case 2479:
      ACCEPT_TOKEN(anon_sym_RBRACK);
      if ((!eof && set_contains(aux_sym_tagpair_value_contents_token1_character_set_1, 18, lookahead))) ADVANCE(2561);
      END_STATE();
    case 2480:
      ACCEPT_TOKEN(anon_sym_DQUOTE);
      END_STATE();
    case 2481:
      ACCEPT_TOKEN(aux_sym_double_quote_token1);
      END_STATE();
    case 2482:
      ACCEPT_TOKEN(anon_sym_uff02);
      END_STATE();
    case 2483:
      ACCEPT_TOKEN(aux_sym_double_quote_token2);
      END_STATE();
    case 2484:
      ACCEPT_TOKEN(anon_sym_u201c);
      END_STATE();
    case 2485:
      ACCEPT_TOKEN(aux_sym_double_quote_token3);
      END_STATE();
    case 2486:
      ACCEPT_TOKEN(anon_sym_u201d);
      END_STATE();
    case 2487:
      ACCEPT_TOKEN(aux_sym_double_quote_token4);
      END_STATE();
    case 2488:
      ACCEPT_TOKEN(anon_sym_u201f);
      END_STATE();
    case 2489:
      ACCEPT_TOKEN(aux_sym_double_quote_token5);
      END_STATE();
    case 2490:
      ACCEPT_TOKEN(anon_sym_u2033);
      END_STATE();
    case 2491:
      ACCEPT_TOKEN(aux_sym_double_quote_token6);
      END_STATE();
    case 2492:
      ACCEPT_TOKEN(anon_sym_u2036);
      END_STATE();
    case 2493:
      ACCEPT_TOKEN(aux_sym_double_quote_token7);
      END_STATE();
    case 2494:
      ACCEPT_TOKEN(anon_sym_u3003);
      END_STATE();
    case 2495:
      ACCEPT_TOKEN(aux_sym_double_quote_token8);
      END_STATE();
    case 2496:
      ACCEPT_TOKEN(anon_sym_u05f4);
      END_STATE();
    case 2497:
      ACCEPT_TOKEN(aux_sym_double_quote_token9);
      END_STATE();
    case 2498:
      ACCEPT_TOKEN(anon_sym_u02dd);
      END_STATE();
    case 2499:
      ACCEPT_TOKEN(aux_sym_double_quote_token10);
      END_STATE();
    case 2500:
      ACCEPT_TOKEN(anon_sym_u02ba);
      END_STATE();
    case 2501:
      ACCEPT_TOKEN(aux_sym_double_quote_token11);
      END_STATE();
    case 2502:
      ACCEPT_TOKEN(anon_sym_u02f6);
      END_STATE();
    case 2503:
      ACCEPT_TOKEN(aux_sym_double_quote_token12);
      END_STATE();
    case 2504:
      ACCEPT_TOKEN(anon_sym_u02ee);
      END_STATE();
    case 2505:
      ACCEPT_TOKEN(aux_sym_double_quote_token13);
      END_STATE();
    case 2506:
      ACCEPT_TOKEN(anon_sym_u05f2);
      END_STATE();
    case 2507:
      ACCEPT_TOKEN(aux_sym_double_quote_token14);
      END_STATE();
    case 2508:
      ACCEPT_TOKEN(anon_sym_u00ab);
      END_STATE();
    case 2509:
      ACCEPT_TOKEN(aux_sym_double_quote_token15);
      END_STATE();
    case 2510:
      ACCEPT_TOKEN(anon_sym_u00bb);
      END_STATE();
    case 2511:
      ACCEPT_TOKEN(aux_sym_double_quote_token16);
      END_STATE();
    case 2512:
      ACCEPT_TOKEN(sym_tagpair_key);
      if (lookahead == '%') ADVANCE(2514);
      if (lookahead == '[') ADVANCE(2477);
      if (set_contains(extras_character_set_2, 10, lookahead)) ADVANCE(2512);
      if (lookahead != 0) ADVANCE(2514);
      END_STATE();
    case 2513:
      ACCEPT_TOKEN(sym_tagpair_key);
      if (lookahead == '%') ADVANCE(2514);
      if (set_contains(extras_character_set_2, 10, lookahead)) ADVANCE(2513);
      if (lookahead != 0) ADVANCE(2514);
      END_STATE();
    case 2514:
      ACCEPT_TOKEN(sym_tagpair_key);
      if ((!eof && set_contains(sym_tagpair_key_character_set_1, 11, lookahead))) ADVANCE(2514);
      END_STATE();
    case 2515:
      ACCEPT_TOKEN(aux_sym_tagpair_value_contents_token1);
      if (lookahead == '#') ADVANCE(2524);
      if (lookahead == 'l') ADVANCE(2547);
      if (lookahead == 'q') ADVANCE(2552);
      if (lookahead == 'r') ADVANCE(2547);
      if ((!eof && set_contains(aux_sym_tagpair_value_contents_token1_character_set_1, 18, lookahead))) ADVANCE(2561);
      END_STATE();
    case 2516:
      ACCEPT_TOKEN(aux_sym_tagpair_value_contents_token1);
      if (lookahead == '&') ADVANCE(2515);
      if (lookahead == ']') ADVANCE(2479);
      if (set_contains(extras_character_set_1, 11, lookahead)) ADVANCE(2516);
      if ((!eof && set_contains(aux_sym_tagpair_value_contents_token1_character_set_1, 18, lookahead))) ADVANCE(2561);
      END_STATE();
    case 2517:
      ACCEPT_TOKEN(aux_sym_tagpair_value_contents_token1);
      if (lookahead == '&') ADVANCE(2515);
      if (set_contains(extras_character_set_1, 11, lookahead)) ADVANCE(2517);
      if ((!eof && set_contains(aux_sym_tagpair_value_contents_token1_character_set_1, 18, lookahead))) ADVANCE(2561);
      END_STATE();
    case 2518:
      ACCEPT_TOKEN(aux_sym_tagpair_value_contents_token1);
      if (lookahead == '0') ADVANCE(2546);
      if (lookahead == '1') ADVANCE(2546);
      if (lookahead == '3') ADVANCE(2546);
      if ((!eof && set_contains(aux_sym_tagpair_value_contents_token1_character_set_1, 18, lookahead))) ADVANCE(2561);
      END_STATE();
    case 2519:
      ACCEPT_TOKEN(aux_sym_tagpair_value_contents_token1);
      if (lookahead == '0') ADVANCE(2546);
      if (lookahead == '8') ADVANCE(2546);
      if ((!eof && set_contains(aux_sym_tagpair_value_contents_token1_character_set_1, 18, lookahead))) ADVANCE(2561);
      END_STATE();
    case 2520:
      ACCEPT_TOKEN(aux_sym_tagpair_value_contents_token1);
      if (lookahead == '0') ADVANCE(2537);
      if ((!eof && set_contains(aux_sym_tagpair_value_contents_token1_character_set_1, 18, lookahead))) ADVANCE(2561);
      END_STATE();
    case 2521:
      ACCEPT_TOKEN(aux_sym_tagpair_value_contents_token1);
      ADVANCE_MAP(
        '0', 2526,
        '2', 2546,
        'B', 2554,
        'b', 2554,
        'D', 2557,
        'd', 2557,
        'E', 2558,
        'e', 2558,
        'F', 2541,
        'f', 2541,
      );
      if ((!eof && set_contains(aux_sym_tagpair_value_contents_token1_character_set_1, 18, lookahead))) ADVANCE(2561);
      END_STATE();
    case 2522:
      ACCEPT_TOKEN(aux_sym_tagpair_value_contents_token1);
      if (lookahead == '0') ADVANCE(2520);
      if ((!eof && set_contains(aux_sym_tagpair_value_contents_token1_character_set_1, 18, lookahead))) ADVANCE(2561);
      END_STATE();
    case 2523:
      ACCEPT_TOKEN(aux_sym_tagpair_value_contents_token1);
      if (lookahead == '0') ADVANCE(2528);
      if ((!eof && set_contains(aux_sym_tagpair_value_contents_token1_character_set_1, 18, lookahead))) ADVANCE(2561);
      END_STATE();
    case 2524:
      ACCEPT_TOKEN(aux_sym_tagpair_value_contents_token1);
      if (lookahead == '1') ADVANCE(2533);
      if (lookahead == '3') ADVANCE(2539);
      if (lookahead == '6') ADVANCE(2540);
      if (lookahead == '7') ADVANCE(2538);
      if (lookahead == '8') ADVANCE(2529);
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(2530);
      if ((!eof && set_contains(aux_sym_tagpair_value_contents_token1_character_set_1, 18, lookahead))) ADVANCE(2561);
      END_STATE();
    case 2525:
      ACCEPT_TOKEN(aux_sym_tagpair_value_contents_token1);
      if (lookahead == '1') ADVANCE(2546);
      if ((!eof && set_contains(aux_sym_tagpair_value_contents_token1_character_set_1, 18, lookahead))) ADVANCE(2561);
      END_STATE();
    case 2526:
      ACCEPT_TOKEN(aux_sym_tagpair_value_contents_token1);
      if (lookahead == '1') ADVANCE(2556);
      if (lookahead == '3') ADVANCE(2536);
      if ((!eof && set_contains(aux_sym_tagpair_value_contents_token1_character_set_1, 18, lookahead))) ADVANCE(2561);
      END_STATE();
    case 2527:
      ACCEPT_TOKEN(aux_sym_tagpair_value_contents_token1);
      if (lookahead == '2') ADVANCE(2546);
      if (lookahead == '4') ADVANCE(2546);
      if ((!eof && set_contains(aux_sym_tagpair_value_contents_token1_character_set_1, 18, lookahead))) ADVANCE(2561);
      END_STATE();
    case 2528:
      ACCEPT_TOKEN(aux_sym_tagpair_value_contents_token1);
      if (lookahead == '2') ADVANCE(2546);
      if ((!eof && set_contains(aux_sym_tagpair_value_contents_token1_character_set_1, 18, lookahead))) ADVANCE(2561);
      END_STATE();
    case 2529:
      ACCEPT_TOKEN(aux_sym_tagpair_value_contents_token1);
      if (lookahead == '2') ADVANCE(2532);
      if ((!eof && set_contains(aux_sym_tagpair_value_contents_token1_character_set_1, 18, lookahead))) ADVANCE(2561);
      END_STATE();
    case 2530:
      ACCEPT_TOKEN(aux_sym_tagpair_value_contents_token1);
      ADVANCE_MAP(
        '2', 2521,
        '3', 2522,
        '5', 2559,
        'A', 2555,
        'a', 2555,
        'B', 2555,
        'b', 2555,
        'F', 2560,
        'f', 2560,
      );
      if ((!eof && set_contains(aux_sym_tagpair_value_contents_token1_character_set_1, 18, lookahead))) ADVANCE(2561);
      END_STATE();
    case 2531:
      ACCEPT_TOKEN(aux_sym_tagpair_value_contents_token1);
      if (lookahead == '2') ADVANCE(2545);
      if ((!eof && set_contains(aux_sym_tagpair_value_contents_token1_character_set_1, 18, lookahead))) ADVANCE(2561);
      END_STATE();
    case 2532:
      ACCEPT_TOKEN(aux_sym_tagpair_value_contents_token1);
      if (lookahead == '2') ADVANCE(2518);
      if (lookahead == '4') ADVANCE(2536);
      if ((!eof && set_contains(aux_sym_tagpair_value_contents_token1_character_set_1, 18, lookahead))) ADVANCE(2561);
      END_STATE();
    case 2533:
      ACCEPT_TOKEN(aux_sym_tagpair_value_contents_token1);
      if (lookahead == '2') ADVANCE(2531);
      if (lookahead == '5') ADVANCE(2535);
      if (lookahead == '7') ADVANCE(2525);
      if (lookahead == '8') ADVANCE(2542);
      if ((!eof && set_contains(aux_sym_tagpair_value_contents_token1_character_set_1, 18, lookahead))) ADVANCE(2561);
      END_STATE();
    case 2534:
      ACCEPT_TOKEN(aux_sym_tagpair_value_contents_token1);
      if (lookahead == '2') ADVANCE(2544);
      if ((!eof && set_contains(aux_sym_tagpair_value_contents_token1_character_set_1, 18, lookahead))) ADVANCE(2561);
      END_STATE();
    case 2535:
      ACCEPT_TOKEN(aux_sym_tagpair_value_contents_token1);
      if (lookahead == '2') ADVANCE(2527);
      if ((!eof && set_contains(aux_sym_tagpair_value_contents_token1_character_set_1, 18, lookahead))) ADVANCE(2561);
      END_STATE();
    case 2536:
      ACCEPT_TOKEN(aux_sym_tagpair_value_contents_token1);
      if (lookahead == '3') ADVANCE(2546);
      if (lookahead == '6') ADVANCE(2546);
      if ((!eof && set_contains(aux_sym_tagpair_value_contents_token1_character_set_1, 18, lookahead))) ADVANCE(2561);
      END_STATE();
    case 2537:
      ACCEPT_TOKEN(aux_sym_tagpair_value_contents_token1);
      if (lookahead == '3') ADVANCE(2546);
      if ((!eof && set_contains(aux_sym_tagpair_value_contents_token1_character_set_1, 18, lookahead))) ADVANCE(2561);
      END_STATE();
    case 2538:
      ACCEPT_TOKEN(aux_sym_tagpair_value_contents_token1);
      if (lookahead == '3') ADVANCE(2537);
      if (lookahead == '5') ADVANCE(2519);
      if ((!eof && set_contains(aux_sym_tagpair_value_contents_token1_character_set_1, 18, lookahead))) ADVANCE(2561);
      END_STATE();
    case 2539:
      ACCEPT_TOKEN(aux_sym_tagpair_value_contents_token1);
      if (lookahead == '4') ADVANCE(2546);
      if ((!eof && set_contains(aux_sym_tagpair_value_contents_token1_character_set_1, 18, lookahead))) ADVANCE(2561);
      END_STATE();
    case 2540:
      ACCEPT_TOKEN(aux_sym_tagpair_value_contents_token1);
      if (lookahead == '5') ADVANCE(2534);
      if (lookahead == '9') ADVANCE(2543);
      if ((!eof && set_contains(aux_sym_tagpair_value_contents_token1_character_set_1, 18, lookahead))) ADVANCE(2561);
      END_STATE();
    case 2541:
      ACCEPT_TOKEN(aux_sym_tagpair_value_contents_token1);
      if (lookahead == '6') ADVANCE(2546);
      if ((!eof && set_contains(aux_sym_tagpair_value_contents_token1_character_set_1, 18, lookahead))) ADVANCE(2561);
      END_STATE();
    case 2542:
      ACCEPT_TOKEN(aux_sym_tagpair_value_contents_token1);
      if (lookahead == '7') ADVANCE(2546);
      if ((!eof && set_contains(aux_sym_tagpair_value_contents_token1_character_set_1, 18, lookahead))) ADVANCE(2561);
      END_STATE();
    case 2543:
      ACCEPT_TOKEN(aux_sym_tagpair_value_contents_token1);
      if (lookahead == '8') ADVANCE(2546);
      if ((!eof && set_contains(aux_sym_tagpair_value_contents_token1_character_set_1, 18, lookahead))) ADVANCE(2561);
      END_STATE();
    case 2544:
      ACCEPT_TOKEN(aux_sym_tagpair_value_contents_token1);
      if (lookahead == '8') ADVANCE(2528);
      if ((!eof && set_contains(aux_sym_tagpair_value_contents_token1_character_set_1, 18, lookahead))) ADVANCE(2561);
      END_STATE();
    case 2545:
      ACCEPT_TOKEN(aux_sym_tagpair_value_contents_token1);
      if (lookahead == '9') ADVANCE(2525);
      if ((!eof && set_contains(aux_sym_tagpair_value_contents_token1_character_set_1, 18, lookahead))) ADVANCE(2561);
      END_STATE();
    case 2546:
      ACCEPT_TOKEN(aux_sym_tagpair_value_contents_token1);
      if (lookahead == ';') ADVANCE(2561);
      if ((!eof && set_contains(aux_sym_tagpair_value_contents_token1_character_set_1, 18, lookahead))) ADVANCE(2561);
      END_STATE();
    case 2547:
      ACCEPT_TOKEN(aux_sym_tagpair_value_contents_token1);
      if (lookahead == 'a') ADVANCE(2550);
      if (lookahead == 'd') ADVANCE(2550);
      if ((!eof && set_contains(aux_sym_tagpair_value_contents_token1_character_set_1, 18, lookahead))) ADVANCE(2561);
      END_STATE();
    case 2548:
      ACCEPT_TOKEN(aux_sym_tagpair_value_contents_token1);
      if (lookahead == 'o') ADVANCE(2546);
      if ((!eof && set_contains(aux_sym_tagpair_value_contents_token1_character_set_1, 18, lookahead))) ADVANCE(2561);
      END_STATE();
    case 2549:
      ACCEPT_TOKEN(aux_sym_tagpair_value_contents_token1);
      if (lookahead == 'o') ADVANCE(2551);
      if ((!eof && set_contains(aux_sym_tagpair_value_contents_token1_character_set_1, 18, lookahead))) ADVANCE(2561);
      END_STATE();
    case 2550:
      ACCEPT_TOKEN(aux_sym_tagpair_value_contents_token1);
      if (lookahead == 'q') ADVANCE(2553);
      if ((!eof && set_contains(aux_sym_tagpair_value_contents_token1_character_set_1, 18, lookahead))) ADVANCE(2561);
      END_STATE();
    case 2551:
      ACCEPT_TOKEN(aux_sym_tagpair_value_contents_token1);
      if (lookahead == 't') ADVANCE(2546);
      if ((!eof && set_contains(aux_sym_tagpair_value_contents_token1_character_set_1, 18, lookahead))) ADVANCE(2561);
      END_STATE();
    case 2552:
      ACCEPT_TOKEN(aux_sym_tagpair_value_contents_token1);
      if (lookahead == 'u') ADVANCE(2549);
      if ((!eof && set_contains(aux_sym_tagpair_value_contents_token1_character_set_1, 18, lookahead))) ADVANCE(2561);
      END_STATE();
    case 2553:
      ACCEPT_TOKEN(aux_sym_tagpair_value_contents_token1);
      if (lookahead == 'u') ADVANCE(2548);
      if ((!eof && set_contains(aux_sym_tagpair_value_contents_token1_character_set_1, 18, lookahead))) ADVANCE(2561);
      END_STATE();
    case 2554:
      ACCEPT_TOKEN(aux_sym_tagpair_value_contents_token1);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(2546);
      if ((!eof && set_contains(aux_sym_tagpair_value_contents_token1_character_set_1, 18, lookahead))) ADVANCE(2561);
      END_STATE();
    case 2555:
      ACCEPT_TOKEN(aux_sym_tagpair_value_contents_token1);
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(2546);
      if ((!eof && set_contains(aux_sym_tagpair_value_contents_token1_character_set_1, 18, lookahead))) ADVANCE(2561);
      END_STATE();
    case 2556:
      ACCEPT_TOKEN(aux_sym_tagpair_value_contents_token1);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(2546);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(2546);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(2546);
      if ((!eof && set_contains(aux_sym_tagpair_value_contents_token1_character_set_1, 18, lookahead))) ADVANCE(2561);
      END_STATE();
    case 2557:
      ACCEPT_TOKEN(aux_sym_tagpair_value_contents_token1);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(2546);
      if ((!eof && set_contains(aux_sym_tagpair_value_contents_token1_character_set_1, 18, lookahead))) ADVANCE(2561);
      END_STATE();
    case 2558:
      ACCEPT_TOKEN(aux_sym_tagpair_value_contents_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(2546);
      if ((!eof && set_contains(aux_sym_tagpair_value_contents_token1_character_set_1, 18, lookahead))) ADVANCE(2561);
      END_STATE();
    case 2559:
      ACCEPT_TOKEN(aux_sym_tagpair_value_contents_token1);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(2527);
      if ((!eof && set_contains(aux_sym_tagpair_value_contents_token1_character_set_1, 18, lookahead))) ADVANCE(2561);
      END_STATE();
    case 2560:
      ACCEPT_TOKEN(aux_sym_tagpair_value_contents_token1);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(2523);
      if ((!eof && set_contains(aux_sym_tagpair_value_contents_token1_character_set_1, 18, lookahead))) ADVANCE(2561);
      END_STATE();
    case 2561:
      ACCEPT_TOKEN(aux_sym_tagpair_value_contents_token1);
      if ((!eof && set_contains(aux_sym_tagpair_value_contents_token1_character_set_1, 18, lookahead))) ADVANCE(2561);
      END_STATE();
    case 2562:
      ACCEPT_TOKEN(sym_variation_delimiter_open);
      END_STATE();
    case 2563:
      ACCEPT_TOKEN(sym_variation_delimiter_open);
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 2564:
      ACCEPT_TOKEN(anon_sym_RPAREN);
      END_STATE();
    case 2565:
      ACCEPT_TOKEN(anon_sym_RPAREN);
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 2566:
      ACCEPT_TOKEN(anon_sym_LBRACE);
      END_STATE();
    case 2567:
      ACCEPT_TOKEN(anon_sym_LBRACE);
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 2568:
      ACCEPT_TOKEN(anon_sym_RBRACE);
      END_STATE();
    case 2569:
      ACCEPT_TOKEN(anon_sym_RBRACE);
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 2570:
      ACCEPT_TOKEN(sym_command_delimiter_open);
      END_STATE();
    case 2571:
      ACCEPT_TOKEN(aux_sym_inline_comment_text_token1);
      END_STATE();
    case 2572:
      ACCEPT_TOKEN(aux_sym_inline_comment_text_token1);
      if (lookahead == '%') ADVANCE(2570);
      END_STATE();
    case 2573:
      ACCEPT_TOKEN(aux_sym_inline_comment_text_token1);
      if (lookahead == '[') ADVANCE(2572);
      if (set_contains(extras_character_set_2, 10, lookahead)) ADVANCE(2573);
      if (lookahead != 0 &&
          lookahead != '{' &&
          lookahead != '}') ADVANCE(2571);
      END_STATE();
    case 2574:
      ACCEPT_TOKEN(sym_command_name);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2574);
      END_STATE();
    case 2575:
      ACCEPT_TOKEN(sym_command_parameters);
      if (set_contains(extras_character_set_2, 10, lookahead)) ADVANCE(2575);
      if (lookahead != 0 &&
          lookahead != ']' &&
          lookahead != '{' &&
          lookahead != '}') ADVANCE(2576);
      END_STATE();
    case 2576:
      ACCEPT_TOKEN(sym_command_parameters);
      if (lookahead != 0 &&
          lookahead != ']' &&
          lookahead != '{' &&
          lookahead != '}') ADVANCE(2576);
      END_STATE();
    case 2577:
      ACCEPT_TOKEN(sym_move_number);
      ADVANCE_MAP(
        '\n', 2589,
        '\r', 2582,
        '&', 17,
        '/', 1168,
        0x2044, 1168,
        0x2215, 1168,
        0x27cb, 1168,
        0x29f8, 1168,
      );
      if (lookahead == '-' ||
          (0x2010 <= lookahead && lookahead <= 0x2014) ||
          lookahead == 0x2212 ||
          lookahead == 0x2796) ADVANCE(1169);
      if (lookahead == '.' ||
          lookahead == 0x660 ||
          lookahead == 0x6f0 ||
          lookahead == 0x701 ||
          lookahead == 0x702 ||
          lookahead == 0x200e ||
          lookahead == 0x2024 ||
          lookahead == 0xa4f8 ||
          lookahead == 0xa60e ||
          lookahead == 0x1d16d) ADVANCE(2583);
      if (set_contains(aux_sym_result_code_token20_character_set_1, 15, lookahead)) ADVANCE(2579);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 2578:
      ACCEPT_TOKEN(sym_move_number);
      if (lookahead == '\n') ADVANCE(2589);
      if (lookahead == '\r') ADVANCE(2582);
      if (lookahead == '&') ADVANCE(26);
      if (lookahead == '-' ||
          (0x2010 <= lookahead && lookahead <= 0x2014) ||
          lookahead == 0x2212 ||
          lookahead == 0x2796) ADVANCE(1167);
      if (lookahead == '.' ||
          lookahead == 0x660 ||
          lookahead == 0x6f0 ||
          lookahead == 0x701 ||
          lookahead == 0x702 ||
          lookahead == 0x200e ||
          lookahead == 0x2024 ||
          lookahead == 0xa4f8 ||
          lookahead == 0xa60e ||
          lookahead == 0x1d16d) ADVANCE(2583);
      if (set_contains(aux_sym_result_code_token20_character_set_1, 15, lookahead)) ADVANCE(2579);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 2579:
      ACCEPT_TOKEN(sym_move_number);
      if (lookahead == '\n') ADVANCE(2589);
      if (lookahead == '\r') ADVANCE(2582);
      if (lookahead == '.' ||
          lookahead == 0x660 ||
          lookahead == 0x6f0 ||
          lookahead == 0x701 ||
          lookahead == 0x702 ||
          lookahead == 0x200e ||
          lookahead == 0x2024 ||
          lookahead == 0xa4f8 ||
          lookahead == 0xa60e ||
          lookahead == 0x1d16d) ADVANCE(2583);
      if (set_contains(sym_move_number_character_set_2, 19, lookahead)) ADVANCE(2579);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 2580:
      ACCEPT_TOKEN(sym_move_number);
      if (lookahead == '\n') ADVANCE(2589);
      if (lookahead == '&') ADVANCE(1220);
      if (lookahead == '/' ||
          lookahead == 0x2044 ||
          lookahead == 0x2215 ||
          lookahead == 0x27cb ||
          lookahead == 0x29f8) ADVANCE(1580);
      if (lookahead == '-' ||
          (0x2010 <= lookahead && lookahead <= 0x2014) ||
          lookahead == 0x2212 ||
          lookahead == 0x2796) ADVANCE(2442);
      if (lookahead == '.' ||
          lookahead == 0x660 ||
          lookahead == 0x6f0 ||
          lookahead == 0x701 ||
          lookahead == 0x702 ||
          lookahead == 0x200e ||
          lookahead == 0x2024 ||
          lookahead == 0xa4f8 ||
          lookahead == 0xa60e ||
          lookahead == 0x1d16d) ADVANCE(2592);
      if (set_contains(aux_sym_result_code_token20_character_set_1, 15, lookahead)) ADVANCE(2591);
      END_STATE();
    case 2581:
      ACCEPT_TOKEN(sym_move_number);
      if (lookahead == '\n') ADVANCE(2589);
      if (lookahead == '&') ADVANCE(1231);
      if (lookahead == '-' ||
          (0x2010 <= lookahead && lookahead <= 0x2014) ||
          lookahead == 0x2212 ||
          lookahead == 0x2796) ADVANCE(1434);
      if (lookahead == '.' ||
          lookahead == 0x660 ||
          lookahead == 0x6f0 ||
          lookahead == 0x701 ||
          lookahead == 0x702 ||
          lookahead == 0x200e ||
          lookahead == 0x2024 ||
          lookahead == 0xa4f8 ||
          lookahead == 0xa60e ||
          lookahead == 0x1d16d) ADVANCE(2592);
      if (set_contains(aux_sym_result_code_token20_character_set_1, 15, lookahead)) ADVANCE(2591);
      END_STATE();
    case 2582:
      ACCEPT_TOKEN(sym_move_number);
      if (lookahead == '\n') ADVANCE(2589);
      if (lookahead == '.' ||
          lookahead == 0x660 ||
          lookahead == 0x6f0 ||
          lookahead == 0x701 ||
          lookahead == 0x702 ||
          lookahead == 0x200e ||
          lookahead == 0x2024 ||
          lookahead == 0xa4f8 ||
          lookahead == 0xa60e ||
          lookahead == 0x1d16d) ADVANCE(2592);
      if (set_contains(sym_move_number_character_set_2, 19, lookahead)) ADVANCE(2591);
      END_STATE();
    case 2583:
      ACCEPT_TOKEN(sym_move_number);
      if (lookahead == '\n') ADVANCE(2590);
      if (lookahead == '\r') ADVANCE(2584);
      if (set_contains(sym_move_number_character_set_2, 19, lookahead)) ADVANCE(2583);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 2584:
      ACCEPT_TOKEN(sym_move_number);
      if (lookahead == '\n') ADVANCE(2590);
      if (set_contains(sym_move_number_character_set_2, 19, lookahead)) ADVANCE(2592);
      END_STATE();
    case 2585:
      ACCEPT_TOKEN(sym_move_number);
      if (lookahead == '&') ADVANCE(1220);
      if (lookahead == '-') ADVANCE(1272);
      if (lookahead == '/' ||
          lookahead == 0x2044 ||
          lookahead == 0x2215 ||
          lookahead == 0x27cb ||
          lookahead == 0x29f8) ADVANCE(1580);
      if ((0x2010 <= lookahead && lookahead <= 0x2014) ||
          lookahead == 0x2212 ||
          lookahead == 0x2796) ADVANCE(2442);
      if (lookahead == '.' ||
          lookahead == 0x660 ||
          lookahead == 0x6f0 ||
          lookahead == 0x701 ||
          lookahead == 0x702 ||
          lookahead == 0x200e ||
          lookahead == 0x2024 ||
          lookahead == 0xa4f8 ||
          lookahead == 0xa60e ||
          lookahead == 0x1d16d) ADVANCE(2592);
      if (set_contains(aux_sym_result_code_token20_character_set_1, 15, lookahead)) ADVANCE(2591);
      END_STATE();
    case 2586:
      ACCEPT_TOKEN(sym_move_number);
      if (lookahead == '&') ADVANCE(1220);
      if (lookahead == '/' ||
          lookahead == 0x2044 ||
          lookahead == 0x2215 ||
          lookahead == 0x27cb ||
          lookahead == 0x29f8) ADVANCE(1580);
      if (lookahead == '-' ||
          (0x2010 <= lookahead && lookahead <= 0x2014) ||
          lookahead == 0x2212 ||
          lookahead == 0x2796) ADVANCE(2442);
      if (lookahead == '.' ||
          lookahead == 0x660 ||
          lookahead == 0x6f0 ||
          lookahead == 0x701 ||
          lookahead == 0x702 ||
          lookahead == 0x200e ||
          lookahead == 0x2024 ||
          lookahead == 0xa4f8 ||
          lookahead == 0xa60e ||
          lookahead == 0x1d16d) ADVANCE(2592);
      if (set_contains(aux_sym_result_code_token20_character_set_1, 15, lookahead)) ADVANCE(2591);
      END_STATE();
    case 2587:
      ACCEPT_TOKEN(sym_move_number);
      if (lookahead == '&') ADVANCE(1231);
      if (lookahead == '-') ADVANCE(1270);
      if ((0x2010 <= lookahead && lookahead <= 0x2014) ||
          lookahead == 0x2212 ||
          lookahead == 0x2796) ADVANCE(1434);
      if (lookahead == '.' ||
          lookahead == 0x660 ||
          lookahead == 0x6f0 ||
          lookahead == 0x701 ||
          lookahead == 0x702 ||
          lookahead == 0x200e ||
          lookahead == 0x2024 ||
          lookahead == 0xa4f8 ||
          lookahead == 0xa60e ||
          lookahead == 0x1d16d) ADVANCE(2592);
      if (set_contains(aux_sym_result_code_token20_character_set_1, 15, lookahead)) ADVANCE(2591);
      END_STATE();
    case 2588:
      ACCEPT_TOKEN(sym_move_number);
      if (lookahead == '&') ADVANCE(1231);
      if (lookahead == '-' ||
          (0x2010 <= lookahead && lookahead <= 0x2014) ||
          lookahead == 0x2212 ||
          lookahead == 0x2796) ADVANCE(1434);
      if (lookahead == '.' ||
          lookahead == 0x660 ||
          lookahead == 0x6f0 ||
          lookahead == 0x701 ||
          lookahead == 0x702 ||
          lookahead == 0x200e ||
          lookahead == 0x2024 ||
          lookahead == 0xa4f8 ||
          lookahead == 0xa60e ||
          lookahead == 0x1d16d) ADVANCE(2592);
      if (set_contains(aux_sym_result_code_token20_character_set_1, 15, lookahead)) ADVANCE(2591);
      END_STATE();
    case 2589:
      ACCEPT_TOKEN(sym_move_number);
      if (lookahead == '-') ADVANCE(1269);
      if (lookahead == '.' ||
          lookahead == 0x660 ||
          lookahead == 0x6f0 ||
          lookahead == 0x701 ||
          lookahead == 0x702 ||
          lookahead == 0x200e ||
          lookahead == 0x2024 ||
          lookahead == 0xa4f8 ||
          lookahead == 0xa60e ||
          lookahead == 0x1d16d) ADVANCE(2592);
      if (set_contains(sym_move_number_character_set_2, 19, lookahead)) ADVANCE(2591);
      END_STATE();
    case 2590:
      ACCEPT_TOKEN(sym_move_number);
      if (lookahead == '-') ADVANCE(1269);
      if (set_contains(sym_move_number_character_set_2, 19, lookahead)) ADVANCE(2592);
      END_STATE();
    case 2591:
      ACCEPT_TOKEN(sym_move_number);
      if (lookahead == '.' ||
          lookahead == 0x660 ||
          lookahead == 0x6f0 ||
          lookahead == 0x701 ||
          lookahead == 0x702 ||
          lookahead == 0x200e ||
          lookahead == 0x2024 ||
          lookahead == 0xa4f8 ||
          lookahead == 0xa60e ||
          lookahead == 0x1d16d) ADVANCE(2592);
      if (set_contains(sym_move_number_character_set_2, 19, lookahead)) ADVANCE(2591);
      END_STATE();
    case 2592:
      ACCEPT_TOKEN(sym_move_number);
      if (set_contains(sym_move_number_character_set_2, 19, lookahead)) ADVANCE(2592);
      END_STATE();
    case 2593:
      ACCEPT_TOKEN(sym__san_file);
      END_STATE();
    case 2594:
      ACCEPT_TOKEN(sym__san_file);
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '.') ADVANCE(745);
      if (lookahead == 'p') ADVANCE(2659);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 2595:
      ACCEPT_TOKEN(sym__san_file);
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 2596:
      ACCEPT_TOKEN(sym__san_file);
      if (lookahead == '.') ADVANCE(2237);
      if (lookahead == 'p') ADVANCE(2649);
      END_STATE();
    case 2597:
      ACCEPT_TOKEN(sym__san_file_immediate);
      END_STATE();
    case 2598:
      ACCEPT_TOKEN(sym__san_file_immediate);
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '.') ADVANCE(745);
      if (lookahead == 'p') ADVANCE(2659);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 2599:
      ACCEPT_TOKEN(sym__san_file_immediate);
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 2600:
      ACCEPT_TOKEN(sym__san_file_immediate);
      if (lookahead == '.') ADVANCE(2237);
      if (lookahead == 'p') ADVANCE(2649);
      END_STATE();
    case 2601:
      ACCEPT_TOKEN(sym__san_rank_promoting);
      END_STATE();
    case 2602:
      ACCEPT_TOKEN(sym__san_rank_nonpromoting);
      END_STATE();
    case 2603:
      ACCEPT_TOKEN(sym__san_promotable_piece);
      END_STATE();
    case 2604:
      ACCEPT_TOKEN(sym__san_promotable_piece);
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'R') ADVANCE(2659);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 2605:
      ACCEPT_TOKEN(sym__san_promotable_piece);
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 2606:
      ACCEPT_TOKEN(sym__san_promotable_piece);
      if (lookahead == '\n') ADVANCE(2667);
      if (lookahead == '\r') ADVANCE(2650);
      if (set_contains(extras_character_set_2, 10, lookahead)) ADVANCE(2659);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 2607:
      ACCEPT_TOKEN(sym__san_promotable_piece);
      if (lookahead == 'R') ADVANCE(2649);
      END_STATE();
    case 2608:
      ACCEPT_TOKEN(sym__san_promotable_piece);
      if (set_contains(extras_character_set_2, 10, lookahead)) ADVANCE(2649);
      END_STATE();
    case 2609:
      ACCEPT_TOKEN(sym__san_major_or_minor_piece);
      END_STATE();
    case 2610:
      ACCEPT_TOKEN(sym__san_major_or_minor_piece);
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'R') ADVANCE(2659);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 2611:
      ACCEPT_TOKEN(sym__san_major_or_minor_piece);
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 2612:
      ACCEPT_TOKEN(sym__san_major_or_minor_piece);
      if (lookahead == '\n') ADVANCE(2667);
      if (lookahead == '\r') ADVANCE(2650);
      if (set_contains(extras_character_set_2, 10, lookahead)) ADVANCE(2659);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 2613:
      ACCEPT_TOKEN(sym__san_major_or_minor_piece);
      if (lookahead == 'R') ADVANCE(2649);
      END_STATE();
    case 2614:
      ACCEPT_TOKEN(sym__san_major_or_minor_piece);
      if (set_contains(extras_character_set_2, 10, lookahead)) ADVANCE(2649);
      END_STATE();
    case 2615:
      ACCEPT_TOKEN(sym__san_capture_symbol);
      END_STATE();
    case 2616:
      ACCEPT_TOKEN(sym__san_capture_symbol);
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 2617:
      ACCEPT_TOKEN(sym__san_promotion_symbol);
      END_STATE();
    case 2618:
      ACCEPT_TOKEN(sym__san_promotion_symbol);
      ADVANCE_MAP(
        '\n', 1273,
        '\r', 1,
        '&', 4,
        '+', 2659,
        0x16ed, 2659,
        0x2795, 2659,
        '/', 31,
        0x2044, 31,
        0x2215, 31,
        0x27cb, 31,
        0x29f8, 31,
      );
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 2619:
      ACCEPT_TOKEN(sym__san_promotion_symbol);
      ADVANCE_MAP(
        '\n', 1273,
        '\r', 1,
        '&', 4,
        '+', 2659,
        '=', 2659,
        0x16ed, 2659,
        0x2795, 2659,
        '/', 31,
        0x2044, 31,
        0x2215, 31,
        0x27cb, 31,
        0x29f8, 31,
      );
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 2620:
      ACCEPT_TOKEN(sym__san_promotion_symbol);
      ADVANCE_MAP(
        '\n', 1273,
        '\r', 1,
        '&', 11,
        '+', 2659,
        0x16ed, 2659,
        0x2795, 2659,
        '/', 31,
        0x2044, 31,
        0x2215, 31,
        0x27cb, 31,
        0x29f8, 31,
      );
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 2621:
      ACCEPT_TOKEN(sym__san_promotion_symbol);
      ADVANCE_MAP(
        '&', 1208,
        '+', 2649,
        0x16ed, 2649,
        0x2795, 2649,
        '/', 1249,
        0x2044, 1249,
        0x2215, 1249,
        0x27cb, 1249,
        0x29f8, 1249,
      );
      END_STATE();
    case 2622:
      ACCEPT_TOKEN(sym__san_promotion_symbol);
      ADVANCE_MAP(
        '&', 1208,
        '+', 2649,
        '=', 2649,
        0x16ed, 2649,
        0x2795, 2649,
        '/', 1249,
        0x2044, 1249,
        0x2215, 1249,
        0x27cb, 1249,
        0x29f8, 1249,
      );
      END_STATE();
    case 2623:
      ACCEPT_TOKEN(sym__san_promotion_symbol);
      ADVANCE_MAP(
        '&', 1213,
        '+', 2649,
        0x16ed, 2649,
        0x2795, 2649,
        '/', 1249,
        0x2044, 1249,
        0x2215, 1249,
        0x27cb, 1249,
        0x29f8, 1249,
      );
      END_STATE();
    case 2624:
      ACCEPT_TOKEN(anon_sym_P);
      END_STATE();
    case 2625:
      ACCEPT_TOKEN(anon_sym_P);
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(902);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 2626:
      ACCEPT_TOKEN(anon_sym_P);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(2438);
      END_STATE();
    case 2627:
      ACCEPT_TOKEN(anon_sym_u2659);
      END_STATE();
    case 2628:
      ACCEPT_TOKEN(anon_sym_u2659);
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 2629:
      ACCEPT_TOKEN(anon_sym_u265fufe0e);
      END_STATE();
    case 2630:
      ACCEPT_TOKEN(anon_sym_u265fufe0e);
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 2631:
      ACCEPT_TOKEN(anon_sym_AT);
      END_STATE();
    case 2632:
      ACCEPT_TOKEN(anon_sym_AT2);
      END_STATE();
    case 2633:
      ACCEPT_TOKEN(anon_sym_AT2);
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 2634:
      ACCEPT_TOKEN(aux_sym__lan_move_by_coordinates_token1);
      END_STATE();
    case 2635:
      ACCEPT_TOKEN(aux_sym__lan_move_by_coordinates_token1);
      ADVANCE_MAP(
        '\n', 1273,
        '\r', 1,
        '&', 15,
        '+', 2659,
        0x16ed, 2659,
        0x2795, 2659,
        '/', 32,
        0x2044, 32,
        0x2215, 32,
        0x27cb, 32,
        0x29f8, 32,
      );
      if (lookahead == '-' ||
          (0x2010 <= lookahead && lookahead <= 0x2014) ||
          lookahead == 0x2212 ||
          lookahead == 0x2796) ADVANCE(2643);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 2636:
      ACCEPT_TOKEN(aux_sym__lan_move_by_coordinates_token1);
      ADVANCE_MAP(
        '&', 1217,
        '+', 2649,
        0x16ed, 2649,
        0x2795, 2649,
        '/', 1255,
        0x2044, 1255,
        0x2215, 1255,
        0x27cb, 1255,
        0x29f8, 1255,
      );
      if (lookahead == '-' ||
          (0x2010 <= lookahead && lookahead <= 0x2014) ||
          lookahead == 0x2212 ||
          lookahead == 0x2796) ADVANCE(2641);
      END_STATE();
    case 2637:
      ACCEPT_TOKEN(sym__san_move_castle);
      END_STATE();
    case 2638:
      ACCEPT_TOKEN(sym__san_move_castle);
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '&') ADVANCE(23);
      if (lookahead == '-' ||
          (0x2010 <= lookahead && lookahead <= 0x2014) ||
          lookahead == 0x2212 ||
          lookahead == 0x2796) ADVANCE(905);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 2639:
      ACCEPT_TOKEN(sym__san_move_castle);
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 2640:
      ACCEPT_TOKEN(sym__san_move_castle);
      if (lookahead == '&') ADVANCE(1233);
      if (lookahead == '-' ||
          (0x2010 <= lookahead && lookahead <= 0x2014) ||
          lookahead == 0x2212 ||
          lookahead == 0x2796) ADVANCE(2440);
      END_STATE();
    case 2641:
      ACCEPT_TOKEN(sym__san_null_move);
      END_STATE();
    case 2642:
      ACCEPT_TOKEN(sym__san_null_move);
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '-') ADVANCE(40);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 2643:
      ACCEPT_TOKEN(sym__san_null_move);
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 2644:
      ACCEPT_TOKEN(sym_check_or_mate_condition);
      END_STATE();
    case 2645:
      ACCEPT_TOKEN(sym_check_or_mate_condition);
      ADVANCE_MAP(
        '\n', 1273,
        '\r', 1,
        '&', 16,
        '+', 2646,
        0x16ed, 2646,
        0x2795, 2646,
        '/', 35,
        0x2044, 35,
        0x2215, 35,
        0x27cb, 35,
        0x29f8, 35,
      );
      if (lookahead == '-' ||
          lookahead == '=' ||
          (0x2010 <= lookahead && lookahead <= 0x2014) ||
          lookahead == 0x2212 ||
          lookahead == 0x2796 ||
          lookahead == 0x2e40 ||
          lookahead == 0xff1d) ADVANCE(2659);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 2646:
      ACCEPT_TOKEN(sym_check_or_mate_condition);
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 2647:
      ACCEPT_TOKEN(sym_check_or_mate_condition);
      if (lookahead == '&') ADVANCE(1203);
      if (lookahead == '+' ||
          lookahead == 0x16ed ||
          lookahead == 0x2795) ADVANCE(2644);
      END_STATE();
    case 2648:
      ACCEPT_TOKEN(sym_check_or_mate_condition);
      ADVANCE_MAP(
        '&', 1219,
        '+', 2644,
        0x16ed, 2644,
        0x2795, 2644,
        '/', 1264,
        0x2044, 1264,
        0x2215, 1264,
        0x27cb, 1264,
        0x29f8, 1264,
      );
      if (lookahead == '-' ||
          lookahead == '=' ||
          (0x2010 <= lookahead && lookahead <= 0x2014) ||
          lookahead == 0x2212 ||
          lookahead == 0x2796 ||
          lookahead == 0x2e40 ||
          lookahead == 0xff1d) ADVANCE(2649);
      END_STATE();
    case 2649:
      ACCEPT_TOKEN(aux_sym_annotation_token1);
      END_STATE();
    case 2650:
      ACCEPT_TOKEN(aux_sym_annotation_token1);
      if (lookahead == '\n') ADVANCE(1273);
      END_STATE();
    case 2651:
      ACCEPT_TOKEN(aux_sym_annotation_token1);
      ADVANCE_MAP(
        '\n', 1273,
        '\r', 1,
        '&', 4,
        '+', 2659,
        0x16ed, 2659,
        0x2795, 2659,
        '/', 31,
        0x2044, 31,
        0x2215, 31,
        0x27cb, 31,
        0x29f8, 31,
      );
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 2652:
      ACCEPT_TOKEN(aux_sym_annotation_token1);
      ADVANCE_MAP(
        '\n', 1273,
        '\r', 1,
        '&', 4,
        '+', 2659,
        '=', 2659,
        0x16ed, 2659,
        0x2795, 2659,
        '/', 31,
        0x2044, 31,
        0x2215, 31,
        0x27cb, 31,
        0x29f8, 31,
      );
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 2653:
      ACCEPT_TOKEN(aux_sym_annotation_token1);
      ADVANCE_MAP(
        '\n', 1273,
        '\r', 1,
        '&', 15,
        '-', 2642,
        '+', 2659,
        0x16ed, 2659,
        0x2795, 2659,
        '/', 32,
        0x2044, 32,
        0x2215, 32,
        0x27cb, 32,
        0x29f8, 32,
      );
      if ((0x2010 <= lookahead && lookahead <= 0x2014) ||
          lookahead == 0x2212 ||
          lookahead == 0x2796) ADVANCE(2643);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 2654:
      ACCEPT_TOKEN(aux_sym_annotation_token1);
      ADVANCE_MAP(
        '\n', 1273,
        '\r', 1,
        '&', 15,
        '+', 2659,
        0x16ed, 2659,
        0x2795, 2659,
        '/', 32,
        0x2044, 32,
        0x2215, 32,
        0x27cb, 32,
        0x29f8, 32,
      );
      if (lookahead == '-' ||
          (0x2010 <= lookahead && lookahead <= 0x2014) ||
          lookahead == 0x2212 ||
          lookahead == 0x2796) ADVANCE(2643);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 2655:
      ACCEPT_TOKEN(aux_sym_annotation_token1);
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '&') ADVANCE(10);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 2656:
      ACCEPT_TOKEN(aux_sym_annotation_token1);
      ADVANCE_MAP(
        '\n', 1273,
        '\r', 1,
        '&', 11,
        '+', 2659,
        0x16ed, 2659,
        0x2795, 2659,
        '/', 31,
        0x2044, 31,
        0x2215, 31,
        0x27cb, 31,
        0x29f8, 31,
      );
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 2657:
      ACCEPT_TOKEN(aux_sym_annotation_token1);
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '!' ||
          lookahead == '?') ADVANCE(2659);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 2658:
      ACCEPT_TOKEN(aux_sym_annotation_token1);
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(2658);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 2659:
      ACCEPT_TOKEN(aux_sym_annotation_token1);
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 2660:
      ACCEPT_TOKEN(aux_sym_annotation_token1);
      ADVANCE_MAP(
        '\n', 1242,
        '\r', 923,
        '&', 14,
        '/', 926,
        0x2044, 926,
        0x2215, 926,
        0x27cb, 926,
        0x29f8, 926,
      );
      if (set_contains(aux_sym_annotation_token1_character_set_4, 16, lookahead)) ADVANCE(922);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 2661:
      ACCEPT_TOKEN(aux_sym_annotation_token1);
      if (lookahead == '&') ADVANCE(1215);
      if (lookahead == '/' ||
          lookahead == 0x2044 ||
          lookahead == 0x2215 ||
          lookahead == 0x27cb ||
          lookahead == 0x29f8) ADVANCE(1246);
      if (set_contains(aux_sym_annotation_token1_character_set_4, 16, lookahead)) ADVANCE(1243);
      END_STATE();
    case 2662:
      ACCEPT_TOKEN(aux_sym_annotation_token1);
      ADVANCE_MAP(
        '&', 1208,
        '+', 2649,
        0x16ed, 2649,
        0x2795, 2649,
        '/', 1249,
        0x2044, 1249,
        0x2215, 1249,
        0x27cb, 1249,
        0x29f8, 1249,
      );
      END_STATE();
    case 2663:
      ACCEPT_TOKEN(aux_sym_annotation_token1);
      ADVANCE_MAP(
        '&', 1208,
        '+', 2649,
        '=', 2649,
        0x16ed, 2649,
        0x2795, 2649,
        '/', 1249,
        0x2044, 1249,
        0x2215, 1249,
        0x27cb, 1249,
        0x29f8, 1249,
      );
      END_STATE();
    case 2664:
      ACCEPT_TOKEN(aux_sym_annotation_token1);
      ADVANCE_MAP(
        '&', 1217,
        '+', 2649,
        0x16ed, 2649,
        0x2795, 2649,
        '/', 1255,
        0x2044, 1255,
        0x2215, 1255,
        0x27cb, 1255,
        0x29f8, 1255,
      );
      if (lookahead == '-' ||
          (0x2010 <= lookahead && lookahead <= 0x2014) ||
          lookahead == 0x2212 ||
          lookahead == 0x2796) ADVANCE(2641);
      END_STATE();
    case 2665:
      ACCEPT_TOKEN(aux_sym_annotation_token1);
      if (lookahead == '&') ADVANCE(1212);
      END_STATE();
    case 2666:
      ACCEPT_TOKEN(aux_sym_annotation_token1);
      ADVANCE_MAP(
        '&', 1213,
        '+', 2649,
        0x16ed, 2649,
        0x2795, 2649,
        '/', 1249,
        0x2044, 1249,
        0x2215, 1249,
        0x27cb, 1249,
        0x29f8, 1249,
      );
      END_STATE();
    case 2667:
      ACCEPT_TOKEN(aux_sym_annotation_token1);
      if (lookahead == '-') ADVANCE(1269);
      END_STATE();
    case 2668:
      ACCEPT_TOKEN(aux_sym_annotation_token1);
      if (lookahead == '!' ||
          lookahead == '?') ADVANCE(2649);
      END_STATE();
    case 2669:
      ACCEPT_TOKEN(aux_sym_annotation_token1);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(2669);
      END_STATE();
    case 2670:
      ACCEPT_TOKEN(anon_sym_1);
      END_STATE();
    case 2671:
      ACCEPT_TOKEN(anon_sym_1);
      ADVANCE_MAP(
        '\n', 2585,
        '\r', 2580,
        '&', 17,
        'A', 921,
        'B', 921,
        'a', 921,
        'b', 921,
        '/', 1168,
        0x2044, 1168,
        0x2215, 1168,
        0x27cb, 1168,
        0x29f8, 1168,
      );
      if (lookahead == '-' ||
          (0x2010 <= lookahead && lookahead <= 0x2014) ||
          lookahead == 0x2212 ||
          lookahead == 0x2796) ADVANCE(1169);
      if (lookahead == '.' ||
          lookahead == 0x660 ||
          lookahead == 0x6f0 ||
          lookahead == 0x701 ||
          lookahead == 0x702 ||
          lookahead == 0x200e ||
          lookahead == 0x2024 ||
          lookahead == 0xa4f8 ||
          lookahead == 0xa60e ||
          lookahead == 0x1d16d) ADVANCE(2583);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(920);
      if (set_contains(aux_sym_result_code_token22_character_set_1, 11, lookahead)) ADVANCE(2577);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 2672:
      ACCEPT_TOKEN(anon_sym_1);
      ADVANCE_MAP(
        '&', 1220,
        'A', 2445,
        'B', 2445,
        'a', 2445,
        'b', 2445,
        '/', 1580,
        0x2044, 1580,
        0x2215, 1580,
        0x27cb, 1580,
        0x29f8, 1580,
      );
      if (lookahead == '-' ||
          (0x2010 <= lookahead && lookahead <= 0x2014) ||
          lookahead == 0x2212 ||
          lookahead == 0x2796) ADVANCE(2442);
      if (lookahead == '.' ||
          lookahead == 0x660 ||
          lookahead == 0x6f0 ||
          lookahead == 0x701 ||
          lookahead == 0x702 ||
          lookahead == 0x200e ||
          lookahead == 0x2024 ||
          lookahead == 0xa4f8 ||
          lookahead == 0xa60e ||
          lookahead == 0x1d16d) ADVANCE(2592);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(2444);
      if (set_contains(aux_sym_result_code_token22_character_set_1, 11, lookahead)) ADVANCE(2586);
      END_STATE();
    case 2673:
      ACCEPT_TOKEN(anon_sym_1);
      if (lookahead == '&') ADVANCE(1220);
      if (lookahead == '/' ||
          lookahead == 0x2044 ||
          lookahead == 0x2215 ||
          lookahead == 0x27cb ||
          lookahead == 0x29f8) ADVANCE(1580);
      if (lookahead == '-' ||
          (0x2010 <= lookahead && lookahead <= 0x2014) ||
          lookahead == 0x2212 ||
          lookahead == 0x2796) ADVANCE(2442);
      if (set_contains(aux_sym_result_code_token20_character_set_1, 15, lookahead)) ADVANCE(1247);
      END_STATE();
    case 2674:
      ACCEPT_TOKEN(anon_sym_DASH);
      END_STATE();
    case 2675:
      ACCEPT_TOKEN(aux_sym_result_code_token1);
      END_STATE();
    case 2676:
      ACCEPT_TOKEN(anon_sym_u2212);
      END_STATE();
    case 2677:
      ACCEPT_TOKEN(aux_sym_result_code_token2);
      END_STATE();
    case 2678:
      ACCEPT_TOKEN(anon_sym_u2010);
      END_STATE();
    case 2679:
      ACCEPT_TOKEN(aux_sym_result_code_token3);
      END_STATE();
    case 2680:
      ACCEPT_TOKEN(anon_sym_u2011);
      END_STATE();
    case 2681:
      ACCEPT_TOKEN(aux_sym_result_code_token4);
      END_STATE();
    case 2682:
      ACCEPT_TOKEN(anon_sym_u2012);
      END_STATE();
    case 2683:
      ACCEPT_TOKEN(aux_sym_result_code_token5);
      END_STATE();
    case 2684:
      ACCEPT_TOKEN(anon_sym_u2013);
      END_STATE();
    case 2685:
      ACCEPT_TOKEN(aux_sym_result_code_token6);
      END_STATE();
    case 2686:
      ACCEPT_TOKEN(anon_sym_u2014);
      END_STATE();
    case 2687:
      ACCEPT_TOKEN(aux_sym_result_code_token7);
      END_STATE();
    case 2688:
      ACCEPT_TOKEN(anon_sym_u2796);
      END_STATE();
    case 2689:
      ACCEPT_TOKEN(aux_sym_result_code_token8);
      END_STATE();
    case 2690:
      ACCEPT_TOKEN(anon_sym_O);
      END_STATE();
    case 2691:
      ACCEPT_TOKEN(anon_sym_O);
      if (lookahead == '\n') ADVANCE(1259);
      if (lookahead == '\r') ADVANCE(912);
      if (lookahead == '&') ADVANCE(24);
      if (lookahead == '-' ||
          (0x2010 <= lookahead && lookahead <= 0x2014) ||
          lookahead == 0x2212 ||
          lookahead == 0x2796) ADVANCE(1166);
      if (set_contains(aux_sym_result_code_token20_character_set_1, 15, lookahead)) ADVANCE(38);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 2692:
      ACCEPT_TOKEN(anon_sym_O);
      if (lookahead == '&') ADVANCE(1202);
      if (lookahead == '-' ||
          (0x2010 <= lookahead && lookahead <= 0x2014) ||
          lookahead == 0x2212 ||
          lookahead == 0x2796) ADVANCE(1433);
      if (set_contains(aux_sym_result_code_token20_character_set_1, 15, lookahead)) ADVANCE(1260);
      END_STATE();
    case 2693:
      ACCEPT_TOKEN(anon_sym_O);
      if (lookahead == '&') ADVANCE(1231);
      if (lookahead == '-' ||
          (0x2010 <= lookahead && lookahead <= 0x2014) ||
          lookahead == 0x2212 ||
          lookahead == 0x2796) ADVANCE(1434);
      if (set_contains(aux_sym_result_code_token20_character_set_1, 15, lookahead)) ADVANCE(1260);
      END_STATE();
    case 2694:
      ACCEPT_TOKEN(anon_sym_0);
      END_STATE();
    case 2695:
      ACCEPT_TOKEN(anon_sym_0);
      if (lookahead == '\n') ADVANCE(2587);
      if (lookahead == '\r') ADVANCE(2581);
      if (lookahead == '&') ADVANCE(24);
      if (lookahead == 'A' ||
          lookahead == 'B' ||
          lookahead == 'a' ||
          lookahead == 'b') ADVANCE(921);
      if (lookahead == '-' ||
          (0x2010 <= lookahead && lookahead <= 0x2014) ||
          lookahead == 0x2212 ||
          lookahead == 0x2796) ADVANCE(1166);
      if (lookahead == '.' ||
          lookahead == 0x660 ||
          lookahead == 0x6f0 ||
          lookahead == 0x701 ||
          lookahead == 0x702 ||
          lookahead == 0x200e ||
          lookahead == 0x2024 ||
          lookahead == 0xa4f8 ||
          lookahead == 0xa60e ||
          lookahead == 0x1d16d) ADVANCE(2583);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(920);
      if (set_contains(aux_sym_result_code_token22_character_set_1, 11, lookahead)) ADVANCE(2578);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 2696:
      ACCEPT_TOKEN(anon_sym_0);
      if (lookahead == '&') ADVANCE(1202);
      if (lookahead == 'A' ||
          lookahead == 'B' ||
          lookahead == 'a' ||
          lookahead == 'b') ADVANCE(2445);
      if (lookahead == '-' ||
          (0x2010 <= lookahead && lookahead <= 0x2014) ||
          lookahead == 0x2212 ||
          lookahead == 0x2796) ADVANCE(1433);
      if (lookahead == '.' ||
          lookahead == 0x660 ||
          lookahead == 0x6f0 ||
          lookahead == 0x701 ||
          lookahead == 0x702 ||
          lookahead == 0x200e ||
          lookahead == 0x2024 ||
          lookahead == 0xa4f8 ||
          lookahead == 0xa60e ||
          lookahead == 0x1d16d) ADVANCE(2592);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(2444);
      if (set_contains(aux_sym_result_code_token22_character_set_1, 11, lookahead)) ADVANCE(2588);
      END_STATE();
    case 2697:
      ACCEPT_TOKEN(anon_sym_0);
      if (lookahead == '&') ADVANCE(1202);
      if (lookahead == '-' ||
          (0x2010 <= lookahead && lookahead <= 0x2014) ||
          lookahead == 0x2212 ||
          lookahead == 0x2796) ADVANCE(1433);
      if (set_contains(aux_sym_result_code_token20_character_set_1, 15, lookahead)) ADVANCE(1260);
      END_STATE();
    case 2698:
      ACCEPT_TOKEN(anon_sym_0);
      if (lookahead == '&') ADVANCE(1231);
      if (lookahead == '-' ||
          (0x2010 <= lookahead && lookahead <= 0x2014) ||
          lookahead == 0x2212 ||
          lookahead == 0x2796) ADVANCE(1434);
      if (set_contains(aux_sym_result_code_token20_character_set_1, 15, lookahead)) ADVANCE(1260);
      END_STATE();
    case 2699:
      ACCEPT_TOKEN(anon_sym_o);
      END_STATE();
    case 2700:
      ACCEPT_TOKEN(anon_sym_o);
      if (lookahead == '\n') ADVANCE(1259);
      if (lookahead == '\r') ADVANCE(912);
      if (lookahead == '&') ADVANCE(24);
      if (lookahead == '-' ||
          (0x2010 <= lookahead && lookahead <= 0x2014) ||
          lookahead == 0x2212 ||
          lookahead == 0x2796) ADVANCE(1166);
      if (set_contains(aux_sym_result_code_token20_character_set_1, 15, lookahead)) ADVANCE(38);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 2701:
      ACCEPT_TOKEN(anon_sym_o);
      if (lookahead == '&') ADVANCE(1202);
      if (lookahead == '-' ||
          (0x2010 <= lookahead && lookahead <= 0x2014) ||
          lookahead == 0x2212 ||
          lookahead == 0x2796) ADVANCE(1433);
      if (set_contains(aux_sym_result_code_token20_character_set_1, 15, lookahead)) ADVANCE(1260);
      END_STATE();
    case 2702:
      ACCEPT_TOKEN(anon_sym_o);
      if (lookahead == '&') ADVANCE(1231);
      if (lookahead == '-' ||
          (0x2010 <= lookahead && lookahead <= 0x2014) ||
          lookahead == 0x2212 ||
          lookahead == 0x2796) ADVANCE(1434);
      if (set_contains(aux_sym_result_code_token20_character_set_1, 15, lookahead)) ADVANCE(1260);
      END_STATE();
    case 2703:
      ACCEPT_TOKEN(anon_sym_SLASH);
      END_STATE();
    case 2704:
      ACCEPT_TOKEN(aux_sym_result_code_token9);
      END_STATE();
    case 2705:
      ACCEPT_TOKEN(anon_sym_u2215);
      END_STATE();
    case 2706:
      ACCEPT_TOKEN(aux_sym_result_code_token10);
      END_STATE();
    case 2707:
      ACCEPT_TOKEN(anon_sym_u2044);
      END_STATE();
    case 2708:
      ACCEPT_TOKEN(aux_sym_result_code_token11);
      END_STATE();
    case 2709:
      ACCEPT_TOKEN(anon_sym_u27cb);
      END_STATE();
    case 2710:
      ACCEPT_TOKEN(aux_sym_result_code_token12);
      END_STATE();
    case 2711:
      ACCEPT_TOKEN(anon_sym_u29f8);
      END_STATE();
    case 2712:
      ACCEPT_TOKEN(aux_sym_result_code_token13);
      END_STATE();
    case 2713:
      ACCEPT_TOKEN(anon_sym_2);
      END_STATE();
    case 2714:
      ACCEPT_TOKEN(anon_sym_u00bd);
      END_STATE();
    case 2715:
      ACCEPT_TOKEN(anon_sym_u00bd);
      if (lookahead == '\n') ADVANCE(1253);
      if (lookahead == '\r') ADVANCE(910);
      if (lookahead == '&') ADVANCE(25);
      if (lookahead == '-' ||
          (0x2010 <= lookahead && lookahead <= 0x2014) ||
          lookahead == 0x2212 ||
          lookahead == 0x2796) ADVANCE(1170);
      if (set_contains(aux_sym_result_code_token20_character_set_1, 15, lookahead)) ADVANCE(37);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 2716:
      ACCEPT_TOKEN(anon_sym_u00bd);
      if (lookahead == '&') ADVANCE(1227);
      if (lookahead == '-' ||
          (0x2010 <= lookahead && lookahead <= 0x2014) ||
          lookahead == 0x2212 ||
          lookahead == 0x2796) ADVANCE(1241);
      if (set_contains(aux_sym_result_code_token20_character_set_1, 15, lookahead)) ADVANCE(1254);
      END_STATE();
    case 2717:
      ACCEPT_TOKEN(aux_sym_result_code_token14);
      END_STATE();
    case 2718:
      ACCEPT_TOKEN(aux_sym_result_code_token14);
      if (lookahead == '\n') ADVANCE(1253);
      if (lookahead == '\r') ADVANCE(910);
      if (lookahead == '&') ADVANCE(25);
      if (lookahead == '-' ||
          (0x2010 <= lookahead && lookahead <= 0x2014) ||
          lookahead == 0x2212 ||
          lookahead == 0x2796) ADVANCE(1170);
      if (set_contains(aux_sym_result_code_token20_character_set_1, 15, lookahead)) ADVANCE(37);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 2719:
      ACCEPT_TOKEN(aux_sym_result_code_token14);
      if (lookahead == '&') ADVANCE(1227);
      if (lookahead == '-' ||
          (0x2010 <= lookahead && lookahead <= 0x2014) ||
          lookahead == 0x2212 ||
          lookahead == 0x2796) ADVANCE(1241);
      if (set_contains(aux_sym_result_code_token20_character_set_1, 15, lookahead)) ADVANCE(1254);
      END_STATE();
    case 2720:
      ACCEPT_TOKEN(anon_sym_STAR);
      END_STATE();
    case 2721:
      ACCEPT_TOKEN(anon_sym_STAR);
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 2722:
      ACCEPT_TOKEN(aux_sym_result_code_token15);
      END_STATE();
    case 2723:
      ACCEPT_TOKEN(aux_sym_result_code_token15);
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 2724:
      ACCEPT_TOKEN(anon_sym_u2217);
      END_STATE();
    case 2725:
      ACCEPT_TOKEN(anon_sym_u2217);
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 2726:
      ACCEPT_TOKEN(aux_sym_result_code_token16);
      END_STATE();
    case 2727:
      ACCEPT_TOKEN(aux_sym_result_code_token16);
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 2728:
      ACCEPT_TOKEN(anon_sym_u2731);
      END_STATE();
    case 2729:
      ACCEPT_TOKEN(anon_sym_u2731);
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 2730:
      ACCEPT_TOKEN(aux_sym_result_code_token17);
      END_STATE();
    case 2731:
      ACCEPT_TOKEN(aux_sym_result_code_token17);
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 2732:
      ACCEPT_TOKEN(anon_sym_u204e);
      END_STATE();
    case 2733:
      ACCEPT_TOKEN(anon_sym_u204e);
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 2734:
      ACCEPT_TOKEN(aux_sym_result_code_token18);
      END_STATE();
    case 2735:
      ACCEPT_TOKEN(aux_sym_result_code_token18);
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 2736:
      ACCEPT_TOKEN(anon_sym_u066d);
      END_STATE();
    case 2737:
      ACCEPT_TOKEN(anon_sym_u066d);
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 2738:
      ACCEPT_TOKEN(aux_sym_result_code_token19);
      END_STATE();
    case 2739:
      ACCEPT_TOKEN(aux_sym_result_code_token19);
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 2740:
      ACCEPT_TOKEN(aux_sym_result_code_token20);
      END_STATE();
    case 2741:
      ACCEPT_TOKEN(aux_sym_result_code_token20);
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 2742:
      ACCEPT_TOKEN(aux_sym_result_code_token21);
      END_STATE();
    case 2743:
      ACCEPT_TOKEN(aux_sym_result_code_token21);
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 2744:
      ACCEPT_TOKEN(aux_sym_result_code_token22);
      END_STATE();
    case 2745:
      ACCEPT_TOKEN(aux_sym_result_code_token22);
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    case 2746:
      ACCEPT_TOKEN(aux_sym_result_code_token23);
      END_STATE();
    case 2747:
      ACCEPT_TOKEN(aux_sym_result_code_token23);
      if (lookahead == '\n') ADVANCE(1273);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead != 0) ADVANCE(908);
      END_STATE();
    default:
      return false;
  }
}

static const TSLexerMode ts_lex_modes[STATE_COUNT] = {
  [0] = {.lex_state = 0, .external_lex_state = 1},
  [1] = {.lex_state = 2455, .external_lex_state = 1},
  [2] = {.lex_state = 2451, .external_lex_state = 1},
  [3] = {.lex_state = 2451, .external_lex_state = 1},
  [4] = {.lex_state = 1178, .external_lex_state = 1},
  [5] = {.lex_state = 1189, .external_lex_state = 1},
  [6] = {.lex_state = 1189, .external_lex_state = 1},
  [7] = {.lex_state = 1189, .external_lex_state = 1},
  [8] = {.lex_state = 2455, .external_lex_state = 1},
  [9] = {.lex_state = 2455, .external_lex_state = 1},
  [10] = {.lex_state = 2453, .external_lex_state = 1},
  [11] = {.lex_state = 2453, .external_lex_state = 1},
  [12] = {.lex_state = 2454, .external_lex_state = 1},
  [13] = {.lex_state = 2452, .external_lex_state = 1},
  [14] = {.lex_state = 2451, .external_lex_state = 1},
  [15] = {.lex_state = 1178, .external_lex_state = 1},
  [16] = {.lex_state = 1178, .external_lex_state = 1},
  [17] = {.lex_state = 1178, .external_lex_state = 1},
  [18] = {.lex_state = 2451, .external_lex_state = 1},
  [19] = {.lex_state = 2453, .external_lex_state = 1},
  [20] = {.lex_state = 2457, .external_lex_state = 1},
  [21] = {.lex_state = 2457, .external_lex_state = 1},
  [22] = {.lex_state = 2451, .external_lex_state = 1},
  [23] = {.lex_state = 2457, .external_lex_state = 1},
  [24] = {.lex_state = 1193, .external_lex_state = 1},
  [25] = {.lex_state = 2449, .external_lex_state = 1},
  [26] = {.lex_state = 2451, .external_lex_state = 1},
  [27] = {.lex_state = 1190, .external_lex_state = 1},
  [28] = {.lex_state = 2451, .external_lex_state = 1},
  [29] = {.lex_state = 1194, .external_lex_state = 1},
  [30] = {.lex_state = 2451, .external_lex_state = 1},
  [31] = {.lex_state = 2451, .external_lex_state = 1},
  [32] = {.lex_state = 2451, .external_lex_state = 1},
  [33] = {.lex_state = 2451, .external_lex_state = 1},
  [34] = {.lex_state = 2451, .external_lex_state = 1},
  [35] = {.lex_state = 2451, .external_lex_state = 1},
  [36] = {.lex_state = 2451, .external_lex_state = 1},
  [37] = {.lex_state = 2451, .external_lex_state = 1},
  [38] = {.lex_state = 2451, .external_lex_state = 1},
  [39] = {.lex_state = 2451, .external_lex_state = 1},
  [40] = {.lex_state = 2451, .external_lex_state = 1},
  [41] = {.lex_state = 2451, .external_lex_state = 1},
  [42] = {.lex_state = 2451, .external_lex_state = 1},
  [43] = {.lex_state = 2451, .external_lex_state = 1},
  [44] = {.lex_state = 2451, .external_lex_state = 1},
  [45] = {.lex_state = 1194, .external_lex_state = 1},
  [46] = {.lex_state = 2451, .external_lex_state = 1},
  [47] = {.lex_state = 2451, .external_lex_state = 1},
  [48] = {.lex_state = 2451, .external_lex_state = 1},
  [49] = {.lex_state = 2451, .external_lex_state = 1},
  [50] = {.lex_state = 2451, .external_lex_state = 1},
  [51] = {.lex_state = 1194, .external_lex_state = 1},
  [52] = {.lex_state = 2451, .external_lex_state = 1},
  [53] = {.lex_state = 2451, .external_lex_state = 1},
  [54] = {.lex_state = 2451, .external_lex_state = 1},
  [55] = {.lex_state = 2451, .external_lex_state = 1},
  [56] = {.lex_state = 2451, .external_lex_state = 1},
  [57] = {.lex_state = 2449, .external_lex_state = 1},
  [58] = {.lex_state = 2451, .external_lex_state = 1},
  [59] = {.lex_state = 2451, .external_lex_state = 1},
  [60] = {.lex_state = 2451, .external_lex_state = 1},
  [61] = {.lex_state = 2451, .external_lex_state = 1},
  [62] = {.lex_state = 2451, .external_lex_state = 1},
  [63] = {.lex_state = 2451, .external_lex_state = 1},
  [64] = {.lex_state = 2451, .external_lex_state = 1},
  [65] = {.lex_state = 2451, .external_lex_state = 1},
  [66] = {.lex_state = 2451, .external_lex_state = 1},
  [67] = {.lex_state = 2451, .external_lex_state = 1},
  [68] = {.lex_state = 1178, .external_lex_state = 1},
  [69] = {.lex_state = 1178, .external_lex_state = 1},
  [70] = {.lex_state = 2451, .external_lex_state = 1},
  [71] = {.lex_state = 2451, .external_lex_state = 1},
  [72] = {.lex_state = 2451, .external_lex_state = 1},
  [73] = {.lex_state = 1189, .external_lex_state = 1},
  [74] = {.lex_state = 1189, .external_lex_state = 1},
  [75] = {.lex_state = 1189, .external_lex_state = 1},
  [76] = {.lex_state = 1189, .external_lex_state = 1},
  [77] = {.lex_state = 1189, .external_lex_state = 1},
  [78] = {.lex_state = 1189, .external_lex_state = 1},
  [79] = {.lex_state = 1189, .external_lex_state = 1},
  [80] = {.lex_state = 1189, .external_lex_state = 1},
  [81] = {.lex_state = 1189, .external_lex_state = 1},
  [82] = {.lex_state = 1189, .external_lex_state = 1},
  [83] = {.lex_state = 1189, .external_lex_state = 1},
  [84] = {.lex_state = 1189, .external_lex_state = 1},
  [85] = {.lex_state = 1175, .external_lex_state = 1},
  [86] = {.lex_state = 1189, .external_lex_state = 1},
  [87] = {.lex_state = 1189, .external_lex_state = 1},
  [88] = {.lex_state = 1189, .external_lex_state = 1},
  [89] = {.lex_state = 1189, .external_lex_state = 1},
  [90] = {.lex_state = 1189, .external_lex_state = 1},
  [91] = {.lex_state = 1189, .external_lex_state = 1},
  [92] = {.lex_state = 1181, .external_lex_state = 1},
  [93] = {.lex_state = 1189, .external_lex_state = 1},
  [94] = {.lex_state = 1178, .external_lex_state = 1},
  [95] = {.lex_state = 2457, .external_lex_state = 1},
  [96] = {.lex_state = 1178, .external_lex_state = 1},
  [97] = {.lex_state = 1189, .external_lex_state = 1},
  [98] = {.lex_state = 1189, .external_lex_state = 1},
  [99] = {.lex_state = 1189, .external_lex_state = 1},
  [100] = {.lex_state = 1189, .external_lex_state = 1},
  [101] = {.lex_state = 1189, .external_lex_state = 1},
  [102] = {.lex_state = 1189, .external_lex_state = 1},
  [103] = {.lex_state = 1189, .external_lex_state = 1},
  [104] = {.lex_state = 1189, .external_lex_state = 1},
  [105] = {.lex_state = 1189, .external_lex_state = 1},
  [106] = {.lex_state = 1189, .external_lex_state = 1},
  [107] = {.lex_state = 1189, .external_lex_state = 1},
  [108] = {.lex_state = 1178, .external_lex_state = 1},
  [109] = {.lex_state = 2457, .external_lex_state = 1},
  [110] = {.lex_state = 1189, .external_lex_state = 1},
  [111] = {.lex_state = 2457, .external_lex_state = 1},
  [112] = {.lex_state = 1189, .external_lex_state = 1},
  [113] = {.lex_state = 1189, .external_lex_state = 1},
  [114] = {.lex_state = 1178, .external_lex_state = 1},
  [115] = {.lex_state = 1189, .external_lex_state = 1},
  [116] = {.lex_state = 1189, .external_lex_state = 1},
  [117] = {.lex_state = 1198},
  [118] = {.lex_state = 2457, .external_lex_state = 1},
  [119] = {.lex_state = 2457, .external_lex_state = 1},
  [120] = {.lex_state = 1197},
  [121] = {.lex_state = 0},
  [122] = {.lex_state = 1198},
  [123] = {.lex_state = 1198},
  [124] = {.lex_state = 0},
  [125] = {.lex_state = 1198},
  [126] = {.lex_state = 0},
  [127] = {.lex_state = 1250},
  [128] = {.lex_state = 2455, .external_lex_state = 1},
  [129] = {.lex_state = 1250},
  [130] = {.lex_state = 1250},
  [131] = {.lex_state = 2455, .external_lex_state = 1},
  [132] = {.lex_state = 2455, .external_lex_state = 1},
  [133] = {.lex_state = 2455, .external_lex_state = 1},
  [134] = {.lex_state = 1250},
  [135] = {.lex_state = 1250},
  [136] = {.lex_state = 1250},
  [137] = {.lex_state = 1188, .external_lex_state = 1},
  [138] = {.lex_state = 1188, .external_lex_state = 1},
  [139] = {.lex_state = 1191, .external_lex_state = 1},
  [140] = {.lex_state = 1192, .external_lex_state = 1},
  [141] = {.lex_state = 1188, .external_lex_state = 1},
  [142] = {.lex_state = 2450, .external_lex_state = 1},
  [143] = {.lex_state = 2455, .external_lex_state = 1},
  [144] = {.lex_state = 2455, .external_lex_state = 1},
  [145] = {.lex_state = 2455, .external_lex_state = 1},
  [146] = {.lex_state = 2455, .external_lex_state = 1},
  [147] = {.lex_state = 2455, .external_lex_state = 1},
  [148] = {.lex_state = 2455, .external_lex_state = 1},
  [149] = {.lex_state = 2455, .external_lex_state = 1},
  [150] = {.lex_state = 2455, .external_lex_state = 1},
  [151] = {.lex_state = 2455, .external_lex_state = 1},
  [152] = {.lex_state = 2455, .external_lex_state = 1},
  [153] = {.lex_state = 2455, .external_lex_state = 1},
  [154] = {.lex_state = 2455, .external_lex_state = 1},
  [155] = {.lex_state = 2455, .external_lex_state = 1},
  [156] = {.lex_state = 2455, .external_lex_state = 1},
  [157] = {.lex_state = 2455, .external_lex_state = 1},
  [158] = {.lex_state = 2455, .external_lex_state = 1},
  [159] = {.lex_state = 2450, .external_lex_state = 1},
  [160] = {.lex_state = 2455, .external_lex_state = 1},
  [161] = {.lex_state = 2457, .external_lex_state = 1},
  [162] = {.lex_state = 2455, .external_lex_state = 1},
  [163] = {.lex_state = 2457, .external_lex_state = 1},
  [164] = {.lex_state = 2457, .external_lex_state = 1},
  [165] = {.lex_state = 2457, .external_lex_state = 1},
  [166] = {.lex_state = 2457, .external_lex_state = 1},
  [167] = {.lex_state = 2457, .external_lex_state = 1},
  [168] = {.lex_state = 1183, .external_lex_state = 1},
  [169] = {.lex_state = 2457, .external_lex_state = 1},
  [170] = {.lex_state = 2457, .external_lex_state = 1},
  [171] = {.lex_state = 2457, .external_lex_state = 1},
  [172] = {.lex_state = 2457, .external_lex_state = 1},
  [173] = {.lex_state = 2457, .external_lex_state = 1},
  [174] = {.lex_state = 2457, .external_lex_state = 1},
  [175] = {.lex_state = 2457, .external_lex_state = 1},
  [176] = {.lex_state = 2457, .external_lex_state = 1},
  [177] = {.lex_state = 2457, .external_lex_state = 1},
  [178] = {.lex_state = 2457, .external_lex_state = 1},
  [179] = {.lex_state = 2457, .external_lex_state = 1},
  [180] = {.lex_state = 2457, .external_lex_state = 1},
  [181] = {.lex_state = 2457, .external_lex_state = 1},
  [182] = {.lex_state = 2455, .external_lex_state = 1},
  [183] = {.lex_state = 2455, .external_lex_state = 1},
  [184] = {.lex_state = 2455, .external_lex_state = 1},
  [185] = {.lex_state = 2457, .external_lex_state = 1},
  [186] = {.lex_state = 2457, .external_lex_state = 1},
  [187] = {.lex_state = 2457, .external_lex_state = 1},
  [188] = {.lex_state = 2457, .external_lex_state = 1},
  [189] = {.lex_state = 2457, .external_lex_state = 1},
  [190] = {.lex_state = 0},
  [191] = {.lex_state = 0},
  [192] = {.lex_state = 2457, .external_lex_state = 1},
  [193] = {.lex_state = 2457, .external_lex_state = 1},
  [194] = {.lex_state = 2457, .external_lex_state = 1},
  [195] = {.lex_state = 2457, .external_lex_state = 1},
  [196] = {.lex_state = 2457, .external_lex_state = 1},
  [197] = {.lex_state = 2457, .external_lex_state = 1},
  [198] = {.lex_state = 2457, .external_lex_state = 1},
  [199] = {.lex_state = 0},
  [200] = {.lex_state = 2457, .external_lex_state = 1},
  [201] = {.lex_state = 2457, .external_lex_state = 1},
  [202] = {.lex_state = 2457, .external_lex_state = 1},
  [203] = {.lex_state = 2457, .external_lex_state = 1},
  [204] = {.lex_state = 0},
  [205] = {.lex_state = 1993},
  [206] = {.lex_state = 1993},
  [207] = {.lex_state = 1993},
  [208] = {.lex_state = 1993},
  [209] = {.lex_state = 1993},
  [210] = {.lex_state = 1993},
  [211] = {.lex_state = 1993},
  [212] = {.lex_state = 1993},
  [213] = {.lex_state = 1993},
  [214] = {.lex_state = 1993},
  [215] = {.lex_state = 1993},
  [216] = {.lex_state = 1295},
  [217] = {.lex_state = 1295},
  [218] = {.lex_state = 1295},
  [219] = {.lex_state = 1295},
  [220] = {.lex_state = 1295},
  [221] = {.lex_state = 1295},
  [222] = {.lex_state = 1295},
  [223] = {.lex_state = 1295},
  [224] = {.lex_state = 1295},
  [225] = {.lex_state = 1193},
  [226] = {.lex_state = 1193},
  [227] = {.lex_state = 1193},
  [228] = {.lex_state = 1250},
  [229] = {.lex_state = 1993},
  [230] = {.lex_state = 1993},
  [231] = {.lex_state = 1993},
  [232] = {.lex_state = 1993},
  [233] = {.lex_state = 1993},
  [234] = {.lex_state = 0},
  [235] = {.lex_state = 1994},
  [236] = {.lex_state = 1295},
  [237] = {.lex_state = 0},
  [238] = {.lex_state = 0},
  [239] = {.lex_state = 0},
  [240] = {.lex_state = 0},
  [241] = {.lex_state = 0},
  [242] = {.lex_state = 0},
  [243] = {.lex_state = 0},
  [244] = {.lex_state = 0},
  [245] = {.lex_state = 1295},
  [246] = {.lex_state = 0},
  [247] = {.lex_state = 0},
  [248] = {.lex_state = 1193},
  [249] = {.lex_state = 0},
  [250] = {.lex_state = 0},
  [251] = {.lex_state = 0},
  [252] = {.lex_state = 0},
  [253] = {.lex_state = 0},
  [254] = {.lex_state = 0},
  [255] = {.lex_state = 0},
  [256] = {.lex_state = 0},
  [257] = {.lex_state = 1295},
  [258] = {.lex_state = 0},
  [259] = {.lex_state = 0},
  [260] = {.lex_state = 1994},
  [261] = {.lex_state = 1295},
  [262] = {.lex_state = 0},
  [263] = {.lex_state = 0},
  [264] = {.lex_state = 0},
  [265] = {.lex_state = 0},
  [266] = {.lex_state = 0},
  [267] = {.lex_state = 0},
  [268] = {.lex_state = 0},
  [269] = {.lex_state = 0},
  [270] = {.lex_state = 0},
  [271] = {.lex_state = 0},
  [272] = {.lex_state = 2457},
  [273] = {.lex_state = 0},
  [274] = {.lex_state = 1295},
  [275] = {.lex_state = 0},
  [276] = {.lex_state = 2447},
  [277] = {.lex_state = 0},
  [278] = {.lex_state = 0},
  [279] = {.lex_state = 0},
  [280] = {.lex_state = 0},
  [281] = {.lex_state = 0},
  [282] = {.lex_state = 0},
  [283] = {.lex_state = 0},
  [284] = {.lex_state = 0},
  [285] = {.lex_state = 1295},
  [286] = {.lex_state = 0},
  [287] = {.lex_state = 0},
  [288] = {.lex_state = 0},
  [289] = {.lex_state = 0},
  [290] = {.lex_state = 0},
  [291] = {.lex_state = 0},
  [292] = {.lex_state = 1295},
  [293] = {.lex_state = 0},
  [294] = {.lex_state = 0},
  [295] = {.lex_state = 0},
  [296] = {.lex_state = 1295},
  [297] = {.lex_state = 1295},
  [298] = {.lex_state = 1295},
  [299] = {.lex_state = 0},
  [300] = {.lex_state = 0},
  [301] = {.lex_state = 1430},
  [302] = {.lex_state = 2471},
  [303] = {.lex_state = 0},
  [304] = {.lex_state = 1250},
  [305] = {.lex_state = 0},
  [306] = {.lex_state = 2471},
  [307] = {.lex_state = 0},
  [308] = {.lex_state = 0},
  [309] = {.lex_state = 1430},
  [310] = {.lex_state = 2471},
  [311] = {.lex_state = 1250},
  [312] = {.lex_state = 0},
  [313] = {.lex_state = 0},
  [314] = {.lex_state = 0},
  [315] = {.lex_state = 2471},
  [316] = {.lex_state = 2448},
  [317] = {.lex_state = 2471},
  [318] = {.lex_state = 2471},
  [319] = {.lex_state = 1250},
  [320] = {.lex_state = 2471},
  [321] = {.lex_state = 2471},
  [322] = {.lex_state = 0},
  [323] = {.lex_state = 2575},
  [324] = {.lex_state = 2471},
  [325] = {.lex_state = 1250},
  [326] = {.lex_state = 1250},
};

static const uint16_t ts_parse_table[LARGE_STATE_COUNT][SYMBOL_COUNT] = {
  [STATE(0)] = {
    [ts_builtin_sym_end] = ACTIONS(1),
    [anon_sym_SEMI] = ACTIONS(1),
    [anon_sym_PERCENT] = ACTIONS(1),
    [anon_sym_LBRACK] = ACTIONS(1),
    [anon_sym_RBRACK] = ACTIONS(1),
    [anon_sym_DQUOTE] = ACTIONS(1),
    [aux_sym_double_quote_token1] = ACTIONS(1),
    [anon_sym_uff02] = ACTIONS(1),
    [aux_sym_double_quote_token2] = ACTIONS(1),
    [anon_sym_u201c] = ACTIONS(1),
    [aux_sym_double_quote_token3] = ACTIONS(1),
    [anon_sym_u201d] = ACTIONS(1),
    [aux_sym_double_quote_token4] = ACTIONS(1),
    [anon_sym_u201f] = ACTIONS(1),
    [aux_sym_double_quote_token5] = ACTIONS(1),
    [anon_sym_u2033] = ACTIONS(1),
    [aux_sym_double_quote_token6] = ACTIONS(1),
    [anon_sym_u2036] = ACTIONS(1),
    [aux_sym_double_quote_token7] = ACTIONS(1),
    [anon_sym_u3003] = ACTIONS(1),
    [aux_sym_double_quote_token8] = ACTIONS(1),
    [anon_sym_u05f4] = ACTIONS(1),
    [aux_sym_double_quote_token9] = ACTIONS(1),
    [anon_sym_u02dd] = ACTIONS(1),
    [aux_sym_double_quote_token10] = ACTIONS(1),
    [anon_sym_u02ba] = ACTIONS(1),
    [aux_sym_double_quote_token11] = ACTIONS(1),
    [anon_sym_u02f6] = ACTIONS(1),
    [aux_sym_double_quote_token12] = ACTIONS(1),
    [anon_sym_u02ee] = ACTIONS(1),
    [aux_sym_double_quote_token13] = ACTIONS(1),
    [anon_sym_u05f2] = ACTIONS(1),
    [aux_sym_double_quote_token14] = ACTIONS(1),
    [anon_sym_u00ab] = ACTIONS(1),
    [aux_sym_double_quote_token15] = ACTIONS(1),
    [anon_sym_u00bb] = ACTIONS(1),
    [aux_sym_double_quote_token16] = ACTIONS(1),
    [sym_variation_delimiter_open] = ACTIONS(1),
    [anon_sym_RPAREN] = ACTIONS(1),
    [anon_sym_LBRACE] = ACTIONS(1),
    [anon_sym_RBRACE] = ACTIONS(1),
    [sym_command_delimiter_open] = ACTIONS(1),
    [sym__san_file] = ACTIONS(1),
    [sym__san_file_immediate] = ACTIONS(1),
    [sym__san_rank_promoting] = ACTIONS(1),
    [sym__san_rank_nonpromoting] = ACTIONS(1),
    [sym__san_promotable_piece] = ACTIONS(1),
    [sym__san_major_or_minor_piece] = ACTIONS(1),
    [sym__san_capture_symbol] = ACTIONS(1),
    [sym__san_promotion_symbol] = ACTIONS(1),
    [anon_sym_P] = ACTIONS(1),
    [anon_sym_u2659] = ACTIONS(1),
    [anon_sym_u265fufe0e] = ACTIONS(1),
    [anon_sym_AT] = ACTIONS(1),
    [anon_sym_AT2] = ACTIONS(1),
    [sym__san_move_castle] = ACTIONS(1),
    [sym_check_or_mate_condition] = ACTIONS(1),
    [anon_sym_1] = ACTIONS(1),
    [anon_sym_DASH] = ACTIONS(1),
    [aux_sym_result_code_token1] = ACTIONS(1),
    [anon_sym_u2212] = ACTIONS(1),
    [aux_sym_result_code_token2] = ACTIONS(1),
    [anon_sym_u2010] = ACTIONS(1),
    [aux_sym_result_code_token3] = ACTIONS(1),
    [anon_sym_u2011] = ACTIONS(1),
    [aux_sym_result_code_token4] = ACTIONS(1),
    [anon_sym_u2012] = ACTIONS(1),
    [aux_sym_result_code_token5] = ACTIONS(1),
    [anon_sym_u2013] = ACTIONS(1),
    [aux_sym_result_code_token6] = ACTIONS(1),
    [anon_sym_u2014] = ACTIONS(1),
    [aux_sym_result_code_token7] = ACTIONS(1),
    [anon_sym_u2796] = ACTIONS(1),
    [aux_sym_result_code_token8] = ACTIONS(1),
    [anon_sym_O] = ACTIONS(1),
    [anon_sym_0] = ACTIONS(1),
    [anon_sym_o] = ACTIONS(1),
    [anon_sym_SLASH] = ACTIONS(1),
    [aux_sym_result_code_token9] = ACTIONS(1),
    [anon_sym_u2215] = ACTIONS(1),
    [aux_sym_result_code_token10] = ACTIONS(1),
    [anon_sym_u2044] = ACTIONS(1),
    [aux_sym_result_code_token11] = ACTIONS(1),
    [anon_sym_u27cb] = ACTIONS(1),
    [aux_sym_result_code_token12] = ACTIONS(1),
    [anon_sym_u29f8] = ACTIONS(1),
    [aux_sym_result_code_token13] = ACTIONS(1),
    [anon_sym_2] = ACTIONS(1),
    [anon_sym_u00bd] = ACTIONS(1),
    [aux_sym_result_code_token14] = ACTIONS(1),
    [anon_sym_STAR] = ACTIONS(1),
    [aux_sym_result_code_token15] = ACTIONS(1),
    [anon_sym_u2217] = ACTIONS(1),
    [aux_sym_result_code_token16] = ACTIONS(1),
    [anon_sym_u2731] = ACTIONS(1),
    [aux_sym_result_code_token17] = ACTIONS(1),
    [anon_sym_u204e] = ACTIONS(1),
    [aux_sym_result_code_token18] = ACTIONS(1),
    [anon_sym_u066d] = ACTIONS(1),
    [aux_sym_result_code_token19] = ACTIONS(1),
    [aux_sym_result_code_token21] = ACTIONS(1),
    [aux_sym_result_code_token23] = ACTIONS(1),
    [sym__full_line_comment_delimiter_bol_assertion] = ACTIONS(1),
    [sym__novelty_glyph_before_punctuation] = ACTIONS(1),
  },
  [STATE(1)] = {
    [sym_series_of_games] = STATE(314),
    [sym_game] = STATE(154),
    [sym_freestanding_comment] = STATE(20),
    [sym_rest_of_line_comment_delimiter_open] = STATE(306),
    [sym_rest_of_line_comment] = STATE(61),
    [sym_header] = STATE(4),
    [sym_tagpair_delimiter_open] = STATE(316),
    [sym_tagpair] = STATE(15),
    [sym_movetext] = STATE(127),
    [sym_inline_comment_delimiter_open] = STATE(205),
    [sym__movetext_element] = STATE(113),
    [sym_variation] = STATE(113),
    [sym_inline_comment] = STATE(61),
    [sym_san_move] = STATE(116),
    [sym__san_move_piece] = STATE(83),
    [sym_lan_move] = STATE(98),
    [sym__san_square_any] = STATE(225),
    [sym__san_square_promoting] = STATE(249),
    [sym__san_square_nonpromoting] = STATE(83),
    [sym__san_move_pawn] = STATE(83),
    [sym__san_drop_pawn] = STATE(83),
    [sym__san_move_major_or_minor_piece] = STATE(83),
    [sym__san_drop_major_or_minor_piece] = STATE(83),
    [sym__lan_move_by_coordinates] = STATE(84),
    [sym_annotation] = STATE(103),
    [aux_sym_series_of_games_repeat1] = STATE(8),
    [aux_sym_freestanding_comment_repeat1] = STATE(131),
    [aux_sym_tagpair_delimiter_open_repeat1] = STATE(260),
    [aux_sym_movetext_repeat1] = STATE(6),
    [ts_builtin_sym_end] = ACTIONS(3),
    [anon_sym_SEMI] = ACTIONS(5),
    [sym_old_style_twic_section_comment] = ACTIONS(7),
    [anon_sym_LBRACK] = ACTIONS(9),
    [sym_variation_delimiter_open] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(13),
    [sym_move_number] = ACTIONS(15),
    [sym__san_file] = ACTIONS(17),
    [sym__san_major_or_minor_piece] = ACTIONS(19),
    [anon_sym_P] = ACTIONS(21),
    [anon_sym_u2659] = ACTIONS(21),
    [anon_sym_u265fufe0e] = ACTIONS(21),
    [anon_sym_AT2] = ACTIONS(23),
    [sym__san_move_castle] = ACTIONS(25),
    [sym__san_null_move] = ACTIONS(25),
    [aux_sym_annotation_token1] = ACTIONS(27),
    [sym__full_line_comment_delimiter_bol_assertion] = ACTIONS(29),
    [sym__novelty_glyph_before_punctuation] = ACTIONS(31),
  },
};

static const uint16_t ts_small_parse_table[] = {
  [0] = 26,
    ACTIONS(5), 1,
      anon_sym_SEMI,
    ACTIONS(13), 1,
      anon_sym_LBRACE,
    ACTIONS(29), 1,
      sym__full_line_comment_delimiter_bol_assertion,
    ACTIONS(37), 1,
      sym_variation_delimiter_open,
    ACTIONS(39), 1,
      sym_move_number,
    ACTIONS(41), 1,
      sym__san_file,
    ACTIONS(43), 1,
      sym__san_major_or_minor_piece,
    ACTIONS(47), 1,
      anon_sym_AT2,
    ACTIONS(51), 1,
      aux_sym_annotation_token1,
    ACTIONS(53), 1,
      sym__novelty_glyph_before_punctuation,
    STATE(3), 1,
      aux_sym_movetext_repeat1,
    STATE(22), 1,
      sym__lan_move_by_coordinates,
    STATE(55), 1,
      sym_san_move,
    STATE(59), 1,
      sym_lan_move,
    STATE(60), 1,
      sym_annotation,
    STATE(205), 1,
      sym_inline_comment_delimiter_open,
    STATE(226), 1,
      sym__san_square_any,
    STATE(252), 1,
      sym__san_square_promoting,
    STATE(306), 1,
      sym_rest_of_line_comment_delimiter_open,
    ACTIONS(33), 2,
      ts_builtin_sym_end,
      sym_old_style_twic_section_comment,
    ACTIONS(49), 2,
      sym__san_move_castle,
      sym__san_null_move,
    STATE(47), 2,
      sym_rest_of_line_comment,
      sym_inline_comment,
    STATE(52), 2,
      sym__movetext_element,
      sym_variation,
    ACTIONS(45), 3,
      anon_sym_P,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
    STATE(26), 6,
      sym__san_move_piece,
      sym__san_square_nonpromoting,
      sym__san_move_pawn,
      sym__san_drop_pawn,
      sym__san_move_major_or_minor_piece,
      sym__san_drop_major_or_minor_piece,
    ACTIONS(35), 23,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_1,
      anon_sym_O,
      anon_sym_0,
      anon_sym_o,
      anon_sym_u00bd,
      aux_sym_result_code_token14,
      anon_sym_STAR,
      aux_sym_result_code_token15,
      anon_sym_u2217,
      aux_sym_result_code_token16,
      anon_sym_u2731,
      aux_sym_result_code_token17,
      anon_sym_u204e,
      aux_sym_result_code_token18,
      anon_sym_u066d,
      aux_sym_result_code_token19,
      aux_sym_result_code_token20,
      aux_sym_result_code_token21,
      aux_sym_result_code_token22,
      aux_sym_result_code_token23,
  [112] = 26,
    ACTIONS(57), 1,
      anon_sym_SEMI,
    ACTIONS(62), 1,
      sym_variation_delimiter_open,
    ACTIONS(65), 1,
      anon_sym_LBRACE,
    ACTIONS(68), 1,
      sym_move_number,
    ACTIONS(71), 1,
      sym__san_file,
    ACTIONS(74), 1,
      sym__san_major_or_minor_piece,
    ACTIONS(80), 1,
      anon_sym_AT2,
    ACTIONS(86), 1,
      aux_sym_annotation_token1,
    ACTIONS(89), 1,
      sym__full_line_comment_delimiter_bol_assertion,
    ACTIONS(92), 1,
      sym__novelty_glyph_before_punctuation,
    STATE(3), 1,
      aux_sym_movetext_repeat1,
    STATE(22), 1,
      sym__lan_move_by_coordinates,
    STATE(55), 1,
      sym_san_move,
    STATE(59), 1,
      sym_lan_move,
    STATE(60), 1,
      sym_annotation,
    STATE(205), 1,
      sym_inline_comment_delimiter_open,
    STATE(226), 1,
      sym__san_square_any,
    STATE(252), 1,
      sym__san_square_promoting,
    STATE(306), 1,
      sym_rest_of_line_comment_delimiter_open,
    ACTIONS(55), 2,
      ts_builtin_sym_end,
      sym_old_style_twic_section_comment,
    ACTIONS(83), 2,
      sym__san_move_castle,
      sym__san_null_move,
    STATE(47), 2,
      sym_rest_of_line_comment,
      sym_inline_comment,
    STATE(52), 2,
      sym__movetext_element,
      sym_variation,
    ACTIONS(77), 3,
      anon_sym_P,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
    STATE(26), 6,
      sym__san_move_piece,
      sym__san_square_nonpromoting,
      sym__san_move_pawn,
      sym__san_drop_pawn,
      sym__san_move_major_or_minor_piece,
      sym__san_drop_major_or_minor_piece,
    ACTIONS(60), 23,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_1,
      anon_sym_O,
      anon_sym_0,
      anon_sym_o,
      anon_sym_u00bd,
      aux_sym_result_code_token14,
      anon_sym_STAR,
      aux_sym_result_code_token15,
      anon_sym_u2217,
      aux_sym_result_code_token16,
      anon_sym_u2731,
      aux_sym_result_code_token17,
      anon_sym_u204e,
      aux_sym_result_code_token18,
      anon_sym_u066d,
      aux_sym_result_code_token19,
      aux_sym_result_code_token20,
      aux_sym_result_code_token21,
      aux_sym_result_code_token22,
      aux_sym_result_code_token23,
  [224] = 31,
    ACTIONS(5), 1,
      anon_sym_SEMI,
    ACTIONS(13), 1,
      anon_sym_LBRACE,
    ACTIONS(29), 1,
      sym__full_line_comment_delimiter_bol_assertion,
    ACTIONS(37), 1,
      sym_variation_delimiter_open,
    ACTIONS(39), 1,
      sym_move_number,
    ACTIONS(41), 1,
      sym__san_file,
    ACTIONS(43), 1,
      sym__san_major_or_minor_piece,
    ACTIONS(47), 1,
      anon_sym_AT2,
    ACTIONS(51), 1,
      aux_sym_annotation_token1,
    ACTIONS(53), 1,
      sym__novelty_glyph_before_punctuation,
    ACTIONS(95), 1,
      sym__empty_line,
    ACTIONS(97), 1,
      anon_sym_1,
    STATE(2), 1,
      aux_sym_movetext_repeat1,
    STATE(14), 1,
      sym_movetext,
    STATE(22), 1,
      sym__lan_move_by_coordinates,
    STATE(55), 1,
      sym_san_move,
    STATE(59), 1,
      sym_lan_move,
    STATE(60), 1,
      sym_annotation,
    STATE(153), 1,
      sym_result_code,
    STATE(205), 1,
      sym_inline_comment_delimiter_open,
    STATE(226), 1,
      sym__san_square_any,
    STATE(252), 1,
      sym__san_square_promoting,
    STATE(306), 1,
      sym_rest_of_line_comment_delimiter_open,
    ACTIONS(49), 2,
      sym__san_move_castle,
      sym__san_null_move,
    ACTIONS(101), 2,
      anon_sym_u00bd,
      aux_sym_result_code_token14,
    STATE(47), 2,
      sym_rest_of_line_comment,
      sym_inline_comment,
    STATE(52), 2,
      sym__movetext_element,
      sym_variation,
    ACTIONS(45), 3,
      anon_sym_P,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
    ACTIONS(99), 3,
      anon_sym_O,
      anon_sym_0,
      anon_sym_o,
    STATE(26), 6,
      sym__san_move_piece,
      sym__san_square_nonpromoting,
      sym__san_move_pawn,
      sym__san_drop_pawn,
      sym__san_move_major_or_minor_piece,
      sym__san_drop_major_or_minor_piece,
    ACTIONS(103), 14,
      anon_sym_STAR,
      aux_sym_result_code_token15,
      anon_sym_u2217,
      aux_sym_result_code_token16,
      anon_sym_u2731,
      aux_sym_result_code_token17,
      anon_sym_u204e,
      aux_sym_result_code_token18,
      anon_sym_u066d,
      aux_sym_result_code_token19,
      aux_sym_result_code_token20,
      aux_sym_result_code_token21,
      aux_sym_result_code_token22,
      aux_sym_result_code_token23,
  [344] = 31,
    ACTIONS(29), 1,
      sym__full_line_comment_delimiter_bol_assertion,
    ACTIONS(39), 1,
      sym_move_number,
    ACTIONS(41), 1,
      sym__san_file,
    ACTIONS(43), 1,
      sym__san_major_or_minor_piece,
    ACTIONS(45), 1,
      anon_sym_P,
    ACTIONS(51), 1,
      aux_sym_annotation_token1,
    ACTIONS(53), 1,
      sym__novelty_glyph_before_punctuation,
    ACTIONS(97), 1,
      anon_sym_1,
    ACTIONS(105), 1,
      anon_sym_SEMI,
    ACTIONS(107), 1,
      sym_variation_delimiter_open,
    ACTIONS(109), 1,
      anon_sym_LBRACE,
    ACTIONS(113), 1,
      anon_sym_AT2,
    STATE(2), 1,
      aux_sym_movetext_repeat1,
    STATE(18), 1,
      sym_movetext,
    STATE(22), 1,
      sym__lan_move_by_coordinates,
    STATE(55), 1,
      sym_san_move,
    STATE(59), 1,
      sym_lan_move,
    STATE(60), 1,
      sym_annotation,
    STATE(144), 1,
      sym_result_code,
    STATE(205), 1,
      sym_inline_comment_delimiter_open,
    STATE(226), 1,
      sym__san_square_any,
    STATE(252), 1,
      sym__san_square_promoting,
    STATE(306), 1,
      sym_rest_of_line_comment_delimiter_open,
    ACTIONS(101), 2,
      anon_sym_u00bd,
      aux_sym_result_code_token14,
    ACTIONS(111), 2,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
    ACTIONS(115), 2,
      sym__san_move_castle,
      sym__san_null_move,
    STATE(47), 2,
      sym_rest_of_line_comment,
      sym_inline_comment,
    STATE(52), 2,
      sym__movetext_element,
      sym_variation,
    ACTIONS(99), 3,
      anon_sym_O,
      anon_sym_0,
      anon_sym_o,
    STATE(26), 6,
      sym__san_move_piece,
      sym__san_square_nonpromoting,
      sym__san_move_pawn,
      sym__san_drop_pawn,
      sym__san_move_major_or_minor_piece,
      sym__san_drop_major_or_minor_piece,
    ACTIONS(117), 14,
      anon_sym_STAR,
      aux_sym_result_code_token15,
      anon_sym_u2217,
      aux_sym_result_code_token16,
      anon_sym_u2731,
      aux_sym_result_code_token17,
      anon_sym_u204e,
      aux_sym_result_code_token18,
      anon_sym_u066d,
      aux_sym_result_code_token19,
      aux_sym_result_code_token20,
      aux_sym_result_code_token21,
      aux_sym_result_code_token22,
      aux_sym_result_code_token23,
  [463] = 27,
    ACTIONS(15), 1,
      sym_move_number,
    ACTIONS(17), 1,
      sym__san_file,
    ACTIONS(19), 1,
      sym__san_major_or_minor_piece,
    ACTIONS(21), 1,
      anon_sym_P,
    ACTIONS(27), 1,
      aux_sym_annotation_token1,
    ACTIONS(29), 1,
      sym__full_line_comment_delimiter_bol_assertion,
    ACTIONS(31), 1,
      sym__novelty_glyph_before_punctuation,
    ACTIONS(105), 1,
      anon_sym_SEMI,
    ACTIONS(109), 1,
      anon_sym_LBRACE,
    ACTIONS(119), 1,
      sym_variation_delimiter_open,
    ACTIONS(123), 1,
      anon_sym_AT2,
    STATE(7), 1,
      aux_sym_movetext_repeat1,
    STATE(84), 1,
      sym__lan_move_by_coordinates,
    STATE(98), 1,
      sym_lan_move,
    STATE(103), 1,
      sym_annotation,
    STATE(116), 1,
      sym_san_move,
    STATE(207), 1,
      sym_inline_comment_delimiter_open,
    STATE(225), 1,
      sym__san_square_any,
    STATE(249), 1,
      sym__san_square_promoting,
    STATE(317), 1,
      sym_rest_of_line_comment_delimiter_open,
    ACTIONS(121), 2,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
    ACTIONS(125), 2,
      sym__san_move_castle,
      sym__san_null_move,
    STATE(110), 2,
      sym_rest_of_line_comment,
      sym_inline_comment,
    STATE(113), 2,
      sym__movetext_element,
      sym_variation,
    ACTIONS(35), 6,
      anon_sym_1,
      anon_sym_O,
      anon_sym_0,
      anon_sym_o,
      anon_sym_u00bd,
      aux_sym_result_code_token14,
    STATE(83), 6,
      sym__san_move_piece,
      sym__san_square_nonpromoting,
      sym__san_move_pawn,
      sym__san_drop_pawn,
      sym__san_move_major_or_minor_piece,
      sym__san_drop_major_or_minor_piece,
    ACTIONS(33), 16,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_STAR,
      aux_sym_result_code_token15,
      anon_sym_u2217,
      aux_sym_result_code_token16,
      anon_sym_u2731,
      aux_sym_result_code_token17,
      anon_sym_u204e,
      aux_sym_result_code_token18,
      anon_sym_u066d,
      aux_sym_result_code_token19,
      aux_sym_result_code_token20,
      aux_sym_result_code_token21,
      aux_sym_result_code_token22,
      aux_sym_result_code_token23,
  [574] = 27,
    ACTIONS(89), 1,
      sym__full_line_comment_delimiter_bol_assertion,
    ACTIONS(127), 1,
      anon_sym_SEMI,
    ACTIONS(130), 1,
      sym_variation_delimiter_open,
    ACTIONS(133), 1,
      anon_sym_LBRACE,
    ACTIONS(136), 1,
      sym_move_number,
    ACTIONS(139), 1,
      sym__san_file,
    ACTIONS(142), 1,
      sym__san_major_or_minor_piece,
    ACTIONS(145), 1,
      anon_sym_P,
    ACTIONS(151), 1,
      anon_sym_AT2,
    ACTIONS(157), 1,
      aux_sym_annotation_token1,
    ACTIONS(160), 1,
      sym__novelty_glyph_before_punctuation,
    STATE(7), 1,
      aux_sym_movetext_repeat1,
    STATE(84), 1,
      sym__lan_move_by_coordinates,
    STATE(98), 1,
      sym_lan_move,
    STATE(103), 1,
      sym_annotation,
    STATE(116), 1,
      sym_san_move,
    STATE(207), 1,
      sym_inline_comment_delimiter_open,
    STATE(225), 1,
      sym__san_square_any,
    STATE(249), 1,
      sym__san_square_promoting,
    STATE(317), 1,
      sym_rest_of_line_comment_delimiter_open,
    ACTIONS(148), 2,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
    ACTIONS(154), 2,
      sym__san_move_castle,
      sym__san_null_move,
    STATE(110), 2,
      sym_rest_of_line_comment,
      sym_inline_comment,
    STATE(113), 2,
      sym__movetext_element,
      sym_variation,
    ACTIONS(60), 6,
      anon_sym_1,
      anon_sym_O,
      anon_sym_0,
      anon_sym_o,
      anon_sym_u00bd,
      aux_sym_result_code_token14,
    STATE(83), 6,
      sym__san_move_piece,
      sym__san_square_nonpromoting,
      sym__san_move_pawn,
      sym__san_drop_pawn,
      sym__san_move_major_or_minor_piece,
      sym__san_drop_major_or_minor_piece,
    ACTIONS(55), 16,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_STAR,
      aux_sym_result_code_token15,
      anon_sym_u2217,
      aux_sym_result_code_token16,
      anon_sym_u2731,
      aux_sym_result_code_token17,
      anon_sym_u204e,
      aux_sym_result_code_token18,
      anon_sym_u066d,
      aux_sym_result_code_token19,
      aux_sym_result_code_token20,
      aux_sym_result_code_token21,
      aux_sym_result_code_token22,
      aux_sym_result_code_token23,
  [685] = 36,
    ACTIONS(5), 1,
      anon_sym_SEMI,
    ACTIONS(7), 1,
      sym_old_style_twic_section_comment,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(11), 1,
      sym_variation_delimiter_open,
    ACTIONS(13), 1,
      anon_sym_LBRACE,
    ACTIONS(15), 1,
      sym_move_number,
    ACTIONS(17), 1,
      sym__san_file,
    ACTIONS(19), 1,
      sym__san_major_or_minor_piece,
    ACTIONS(23), 1,
      anon_sym_AT2,
    ACTIONS(27), 1,
      aux_sym_annotation_token1,
    ACTIONS(29), 1,
      sym__full_line_comment_delimiter_bol_assertion,
    ACTIONS(31), 1,
      sym__novelty_glyph_before_punctuation,
    ACTIONS(163), 1,
      ts_builtin_sym_end,
    STATE(4), 1,
      sym_header,
    STATE(6), 1,
      aux_sym_movetext_repeat1,
    STATE(9), 1,
      aux_sym_series_of_games_repeat1,
    STATE(15), 1,
      sym_tagpair,
    STATE(21), 1,
      sym_freestanding_comment,
    STATE(84), 1,
      sym__lan_move_by_coordinates,
    STATE(98), 1,
      sym_lan_move,
    STATE(103), 1,
      sym_annotation,
    STATE(116), 1,
      sym_san_move,
    STATE(127), 1,
      sym_movetext,
    STATE(131), 1,
      aux_sym_freestanding_comment_repeat1,
    STATE(154), 1,
      sym_game,
    STATE(205), 1,
      sym_inline_comment_delimiter_open,
    STATE(225), 1,
      sym__san_square_any,
    STATE(249), 1,
      sym__san_square_promoting,
    STATE(260), 1,
      aux_sym_tagpair_delimiter_open_repeat1,
    STATE(306), 1,
      sym_rest_of_line_comment_delimiter_open,
    STATE(316), 1,
      sym_tagpair_delimiter_open,
    ACTIONS(25), 2,
      sym__san_move_castle,
      sym__san_null_move,
    STATE(61), 2,
      sym_rest_of_line_comment,
      sym_inline_comment,
    STATE(113), 2,
      sym__movetext_element,
      sym_variation,
    ACTIONS(21), 3,
      anon_sym_P,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
    STATE(83), 6,
      sym__san_move_piece,
      sym__san_square_nonpromoting,
      sym__san_move_pawn,
      sym__san_drop_pawn,
      sym__san_move_major_or_minor_piece,
      sym__san_drop_major_or_minor_piece,
  [804] = 36,
    ACTIONS(165), 1,
      ts_builtin_sym_end,
    ACTIONS(167), 1,
      anon_sym_SEMI,
    ACTIONS(170), 1,
      sym_old_style_twic_section_comment,
    ACTIONS(173), 1,
      anon_sym_LBRACK,
    ACTIONS(176), 1,
      sym_variation_delimiter_open,
    ACTIONS(179), 1,
      anon_sym_LBRACE,
    ACTIONS(182), 1,
      sym_move_number,
    ACTIONS(185), 1,
      sym__san_file,
    ACTIONS(188), 1,
      sym__san_major_or_minor_piece,
    ACTIONS(194), 1,
      anon_sym_AT2,
    ACTIONS(200), 1,
      aux_sym_annotation_token1,
    ACTIONS(203), 1,
      sym__full_line_comment_delimiter_bol_assertion,
    ACTIONS(206), 1,
      sym__novelty_glyph_before_punctuation,
    STATE(4), 1,
      sym_header,
    STATE(6), 1,
      aux_sym_movetext_repeat1,
    STATE(9), 1,
      aux_sym_series_of_games_repeat1,
    STATE(15), 1,
      sym_tagpair,
    STATE(23), 1,
      sym_freestanding_comment,
    STATE(84), 1,
      sym__lan_move_by_coordinates,
    STATE(98), 1,
      sym_lan_move,
    STATE(103), 1,
      sym_annotation,
    STATE(116), 1,
      sym_san_move,
    STATE(127), 1,
      sym_movetext,
    STATE(133), 1,
      aux_sym_freestanding_comment_repeat1,
    STATE(154), 1,
      sym_game,
    STATE(209), 1,
      sym_inline_comment_delimiter_open,
    STATE(225), 1,
      sym__san_square_any,
    STATE(249), 1,
      sym__san_square_promoting,
    STATE(260), 1,
      aux_sym_tagpair_delimiter_open_repeat1,
    STATE(316), 1,
      sym_tagpair_delimiter_open,
    STATE(321), 1,
      sym_rest_of_line_comment_delimiter_open,
    ACTIONS(197), 2,
      sym__san_move_castle,
      sym__san_null_move,
    STATE(71), 2,
      sym_rest_of_line_comment,
      sym_inline_comment,
    STATE(113), 2,
      sym__movetext_element,
      sym_variation,
    ACTIONS(191), 3,
      anon_sym_P,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
    STATE(83), 6,
      sym__san_move_piece,
      sym__san_square_nonpromoting,
      sym__san_move_pawn,
      sym__san_drop_pawn,
      sym__san_move_major_or_minor_piece,
      sym__san_drop_major_or_minor_piece,
  [923] = 5,
    ACTIONS(213), 1,
      sym__san_promotable_piece,
    ACTIONS(215), 1,
      sym__san_promotion_symbol,
    STATE(43), 1,
      sym__san_promotion,
    ACTIONS(209), 4,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      ts_builtin_sym_end,
      sym_old_style_twic_section_comment,
    ACTIONS(211), 37,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      sym_check_or_mate_condition,
      aux_sym_annotation_token1,
      anon_sym_1,
      anon_sym_O,
      anon_sym_0,
      anon_sym_o,
      anon_sym_u00bd,
      aux_sym_result_code_token14,
      anon_sym_STAR,
      aux_sym_result_code_token15,
      anon_sym_u2217,
      aux_sym_result_code_token16,
      anon_sym_u2731,
      aux_sym_result_code_token17,
      anon_sym_u204e,
      aux_sym_result_code_token18,
      anon_sym_u066d,
      aux_sym_result_code_token19,
      aux_sym_result_code_token20,
      aux_sym_result_code_token21,
      aux_sym_result_code_token22,
      aux_sym_result_code_token23,
  [978] = 5,
    ACTIONS(215), 1,
      sym__san_promotion_symbol,
    ACTIONS(217), 1,
      sym__san_promotable_piece,
    STATE(42), 1,
      sym__san_promotion,
    ACTIONS(209), 4,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      ts_builtin_sym_end,
      sym_old_style_twic_section_comment,
    ACTIONS(211), 37,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      sym_check_or_mate_condition,
      aux_sym_annotation_token1,
      anon_sym_1,
      anon_sym_O,
      anon_sym_0,
      anon_sym_o,
      anon_sym_u00bd,
      aux_sym_result_code_token14,
      anon_sym_STAR,
      aux_sym_result_code_token15,
      anon_sym_u2217,
      aux_sym_result_code_token16,
      anon_sym_u2731,
      aux_sym_result_code_token17,
      anon_sym_u204e,
      aux_sym_result_code_token18,
      anon_sym_u066d,
      aux_sym_result_code_token19,
      aux_sym_result_code_token20,
      aux_sym_result_code_token21,
      aux_sym_result_code_token22,
      aux_sym_result_code_token23,
  [1033] = 3,
    ACTIONS(223), 3,
      sym__san_file_immediate,
      sym__san_capture_symbol,
      aux_sym__lan_move_by_coordinates_token1,
    ACTIONS(219), 4,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      ts_builtin_sym_end,
      sym_old_style_twic_section_comment,
    ACTIONS(221), 37,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      sym_check_or_mate_condition,
      aux_sym_annotation_token1,
      anon_sym_1,
      anon_sym_O,
      anon_sym_0,
      anon_sym_o,
      anon_sym_u00bd,
      aux_sym_result_code_token14,
      anon_sym_STAR,
      aux_sym_result_code_token15,
      anon_sym_u2217,
      aux_sym_result_code_token16,
      anon_sym_u2731,
      aux_sym_result_code_token17,
      anon_sym_u204e,
      aux_sym_result_code_token18,
      anon_sym_u066d,
      aux_sym_result_code_token19,
      aux_sym_result_code_token20,
      aux_sym_result_code_token21,
      aux_sym_result_code_token22,
      aux_sym_result_code_token23,
  [1084] = 5,
    ACTIONS(229), 1,
      sym__san_file_immediate,
    ACTIONS(231), 1,
      sym__san_capture_symbol,
    STATE(41), 1,
      sym__san_square_any_immediate,
    ACTIONS(225), 4,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      ts_builtin_sym_end,
      sym_old_style_twic_section_comment,
    ACTIONS(227), 37,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      sym_check_or_mate_condition,
      aux_sym_annotation_token1,
      anon_sym_1,
      anon_sym_O,
      anon_sym_0,
      anon_sym_o,
      anon_sym_u00bd,
      aux_sym_result_code_token14,
      anon_sym_STAR,
      aux_sym_result_code_token15,
      anon_sym_u2217,
      aux_sym_result_code_token16,
      anon_sym_u2731,
      aux_sym_result_code_token17,
      anon_sym_u204e,
      aux_sym_result_code_token18,
      anon_sym_u066d,
      aux_sym_result_code_token19,
      aux_sym_result_code_token20,
      aux_sym_result_code_token21,
      aux_sym_result_code_token22,
      aux_sym_result_code_token23,
  [1139] = 10,
    ACTIONS(97), 1,
      anon_sym_1,
    STATE(129), 1,
      aux_sym_trailing_garbage_repeat1,
    STATE(136), 1,
      sym_trailing_garbage,
    STATE(146), 1,
      sym_result_code,
    ACTIONS(101), 2,
      anon_sym_u00bd,
      aux_sym_result_code_token14,
    ACTIONS(237), 2,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    ACTIONS(99), 3,
      anon_sym_O,
      anon_sym_0,
      anon_sym_o,
    ACTIONS(233), 4,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      ts_builtin_sym_end,
      sym_old_style_twic_section_comment,
    ACTIONS(103), 14,
      anon_sym_STAR,
      aux_sym_result_code_token15,
      anon_sym_u2217,
      aux_sym_result_code_token16,
      anon_sym_u2731,
      aux_sym_result_code_token17,
      anon_sym_u204e,
      aux_sym_result_code_token18,
      anon_sym_u066d,
      aux_sym_result_code_token19,
      aux_sym_result_code_token20,
      aux_sym_result_code_token21,
      aux_sym_result_code_token22,
      aux_sym_result_code_token23,
    ACTIONS(235), 14,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      sym_variation_delimiter_open,
      anon_sym_LBRACE,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      aux_sym_annotation_token1,
  [1203] = 12,
    ACTIONS(5), 1,
      anon_sym_SEMI,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      sym__full_line_comment_delimiter_bol_assertion,
    ACTIONS(239), 1,
      sym__empty_line,
    ACTIONS(243), 1,
      sym__novelty_glyph_before_punctuation,
    STATE(16), 1,
      aux_sym_header_repeat1,
    STATE(94), 1,
      sym_tagpair,
    STATE(96), 1,
      sym_rest_of_line_comment,
    STATE(260), 1,
      aux_sym_tagpair_delimiter_open_repeat1,
    STATE(315), 1,
      sym_rest_of_line_comment_delimiter_open,
    STATE(316), 1,
      sym_tagpair_delimiter_open,
    ACTIONS(241), 32,
      sym_variation_delimiter_open,
      anon_sym_LBRACE,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      aux_sym_annotation_token1,
      anon_sym_1,
      anon_sym_O,
      anon_sym_0,
      anon_sym_o,
      anon_sym_u00bd,
      aux_sym_result_code_token14,
      anon_sym_STAR,
      aux_sym_result_code_token15,
      anon_sym_u2217,
      aux_sym_result_code_token16,
      anon_sym_u2731,
      aux_sym_result_code_token17,
      anon_sym_u204e,
      aux_sym_result_code_token18,
      anon_sym_u066d,
      aux_sym_result_code_token19,
      aux_sym_result_code_token20,
      aux_sym_result_code_token21,
      aux_sym_result_code_token22,
      aux_sym_result_code_token23,
  [1271] = 12,
    ACTIONS(5), 1,
      anon_sym_SEMI,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      sym__full_line_comment_delimiter_bol_assertion,
    ACTIONS(245), 1,
      sym__empty_line,
    ACTIONS(249), 1,
      sym__novelty_glyph_before_punctuation,
    STATE(17), 1,
      aux_sym_header_repeat1,
    STATE(94), 1,
      sym_tagpair,
    STATE(96), 1,
      sym_rest_of_line_comment,
    STATE(260), 1,
      aux_sym_tagpair_delimiter_open_repeat1,
    STATE(315), 1,
      sym_rest_of_line_comment_delimiter_open,
    STATE(316), 1,
      sym_tagpair_delimiter_open,
    ACTIONS(247), 32,
      sym_variation_delimiter_open,
      anon_sym_LBRACE,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      aux_sym_annotation_token1,
      anon_sym_1,
      anon_sym_O,
      anon_sym_0,
      anon_sym_o,
      anon_sym_u00bd,
      aux_sym_result_code_token14,
      anon_sym_STAR,
      aux_sym_result_code_token15,
      anon_sym_u2217,
      aux_sym_result_code_token16,
      anon_sym_u2731,
      aux_sym_result_code_token17,
      anon_sym_u204e,
      aux_sym_result_code_token18,
      anon_sym_u066d,
      aux_sym_result_code_token19,
      aux_sym_result_code_token20,
      aux_sym_result_code_token21,
      aux_sym_result_code_token22,
      aux_sym_result_code_token23,
  [1339] = 12,
    ACTIONS(251), 1,
      sym__empty_line,
    ACTIONS(254), 1,
      anon_sym_SEMI,
    ACTIONS(257), 1,
      anon_sym_LBRACK,
    ACTIONS(262), 1,
      sym__full_line_comment_delimiter_bol_assertion,
    ACTIONS(265), 1,
      sym__novelty_glyph_before_punctuation,
    STATE(17), 1,
      aux_sym_header_repeat1,
    STATE(94), 1,
      sym_tagpair,
    STATE(96), 1,
      sym_rest_of_line_comment,
    STATE(260), 1,
      aux_sym_tagpair_delimiter_open_repeat1,
    STATE(315), 1,
      sym_rest_of_line_comment_delimiter_open,
    STATE(316), 1,
      sym_tagpair_delimiter_open,
    ACTIONS(260), 32,
      sym_variation_delimiter_open,
      anon_sym_LBRACE,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      aux_sym_annotation_token1,
      anon_sym_1,
      anon_sym_O,
      anon_sym_0,
      anon_sym_o,
      anon_sym_u00bd,
      aux_sym_result_code_token14,
      anon_sym_STAR,
      aux_sym_result_code_token15,
      anon_sym_u2217,
      aux_sym_result_code_token16,
      anon_sym_u2731,
      aux_sym_result_code_token17,
      anon_sym_u204e,
      aux_sym_result_code_token18,
      anon_sym_u066d,
      aux_sym_result_code_token19,
      aux_sym_result_code_token20,
      aux_sym_result_code_token21,
      aux_sym_result_code_token22,
      aux_sym_result_code_token23,
  [1407] = 10,
    ACTIONS(97), 1,
      anon_sym_1,
    STATE(129), 1,
      aux_sym_trailing_garbage_repeat1,
    STATE(134), 1,
      sym_trailing_garbage,
    STATE(151), 1,
      sym_result_code,
    ACTIONS(101), 2,
      anon_sym_u00bd,
      aux_sym_result_code_token14,
    ACTIONS(237), 2,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    ACTIONS(99), 3,
      anon_sym_O,
      anon_sym_0,
      anon_sym_o,
    ACTIONS(267), 4,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      ts_builtin_sym_end,
      sym_old_style_twic_section_comment,
    ACTIONS(103), 14,
      anon_sym_STAR,
      aux_sym_result_code_token15,
      anon_sym_u2217,
      aux_sym_result_code_token16,
      anon_sym_u2731,
      aux_sym_result_code_token17,
      anon_sym_u204e,
      aux_sym_result_code_token18,
      anon_sym_u066d,
      aux_sym_result_code_token19,
      aux_sym_result_code_token20,
      aux_sym_result_code_token21,
      aux_sym_result_code_token22,
      aux_sym_result_code_token23,
    ACTIONS(269), 14,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      sym_variation_delimiter_open,
      anon_sym_LBRACE,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      aux_sym_annotation_token1,
  [1471] = 2,
    ACTIONS(271), 4,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      ts_builtin_sym_end,
      sym_old_style_twic_section_comment,
    ACTIONS(273), 39,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      sym_move_number,
      sym__san_file,
      sym__san_promotable_piece,
      sym__san_major_or_minor_piece,
      sym__san_promotion_symbol,
      anon_sym_P,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      sym_check_or_mate_condition,
      aux_sym_annotation_token1,
      anon_sym_1,
      anon_sym_O,
      anon_sym_0,
      anon_sym_o,
      anon_sym_u00bd,
      aux_sym_result_code_token14,
      anon_sym_STAR,
      aux_sym_result_code_token15,
      anon_sym_u2217,
      aux_sym_result_code_token16,
      anon_sym_u2731,
      aux_sym_result_code_token17,
      anon_sym_u204e,
      aux_sym_result_code_token18,
      anon_sym_u066d,
      aux_sym_result_code_token19,
      aux_sym_result_code_token20,
      aux_sym_result_code_token21,
      aux_sym_result_code_token22,
      aux_sym_result_code_token23,
  [1519] = 33,
    ACTIONS(17), 1,
      sym__san_file,
    ACTIONS(19), 1,
      sym__san_major_or_minor_piece,
    ACTIONS(21), 1,
      anon_sym_P,
    ACTIONS(27), 1,
      aux_sym_annotation_token1,
    ACTIONS(29), 1,
      sym__full_line_comment_delimiter_bol_assertion,
    ACTIONS(31), 1,
      sym__novelty_glyph_before_punctuation,
    ACTIONS(105), 1,
      anon_sym_SEMI,
    ACTIONS(109), 1,
      anon_sym_LBRACE,
    ACTIONS(119), 1,
      sym_variation_delimiter_open,
    ACTIONS(123), 1,
      anon_sym_AT2,
    ACTIONS(275), 1,
      ts_builtin_sym_end,
    ACTIONS(277), 1,
      anon_sym_LBRACK,
    ACTIONS(279), 1,
      sym_move_number,
    STATE(4), 1,
      sym_header,
    STATE(6), 1,
      aux_sym_movetext_repeat1,
    STATE(15), 1,
      sym_tagpair,
    STATE(84), 1,
      sym__lan_move_by_coordinates,
    STATE(98), 1,
      sym_lan_move,
    STATE(103), 1,
      sym_annotation,
    STATE(116), 1,
      sym_san_move,
    STATE(127), 1,
      sym_movetext,
    STATE(147), 1,
      sym_game,
    STATE(207), 1,
      sym_inline_comment_delimiter_open,
    STATE(225), 1,
      sym__san_square_any,
    STATE(249), 1,
      sym__san_square_promoting,
    STATE(260), 1,
      aux_sym_tagpair_delimiter_open_repeat1,
    STATE(316), 1,
      sym_tagpair_delimiter_open,
    STATE(317), 1,
      sym_rest_of_line_comment_delimiter_open,
    ACTIONS(121), 2,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
    ACTIONS(125), 2,
      sym__san_move_castle,
      sym__san_null_move,
    STATE(110), 2,
      sym_rest_of_line_comment,
      sym_inline_comment,
    STATE(113), 2,
      sym__movetext_element,
      sym_variation,
    STATE(83), 6,
      sym__san_move_piece,
      sym__san_square_nonpromoting,
      sym__san_move_pawn,
      sym__san_drop_pawn,
      sym__san_move_major_or_minor_piece,
      sym__san_drop_major_or_minor_piece,
  [1628] = 33,
    ACTIONS(17), 1,
      sym__san_file,
    ACTIONS(19), 1,
      sym__san_major_or_minor_piece,
    ACTIONS(21), 1,
      anon_sym_P,
    ACTIONS(27), 1,
      aux_sym_annotation_token1,
    ACTIONS(29), 1,
      sym__full_line_comment_delimiter_bol_assertion,
    ACTIONS(31), 1,
      sym__novelty_glyph_before_punctuation,
    ACTIONS(105), 1,
      anon_sym_SEMI,
    ACTIONS(109), 1,
      anon_sym_LBRACE,
    ACTIONS(119), 1,
      sym_variation_delimiter_open,
    ACTIONS(123), 1,
      anon_sym_AT2,
    ACTIONS(277), 1,
      anon_sym_LBRACK,
    ACTIONS(279), 1,
      sym_move_number,
    ACTIONS(281), 1,
      ts_builtin_sym_end,
    STATE(4), 1,
      sym_header,
    STATE(6), 1,
      aux_sym_movetext_repeat1,
    STATE(15), 1,
      sym_tagpair,
    STATE(84), 1,
      sym__lan_move_by_coordinates,
    STATE(98), 1,
      sym_lan_move,
    STATE(103), 1,
      sym_annotation,
    STATE(116), 1,
      sym_san_move,
    STATE(127), 1,
      sym_movetext,
    STATE(147), 1,
      sym_game,
    STATE(207), 1,
      sym_inline_comment_delimiter_open,
    STATE(225), 1,
      sym__san_square_any,
    STATE(249), 1,
      sym__san_square_promoting,
    STATE(260), 1,
      aux_sym_tagpair_delimiter_open_repeat1,
    STATE(316), 1,
      sym_tagpair_delimiter_open,
    STATE(317), 1,
      sym_rest_of_line_comment_delimiter_open,
    ACTIONS(121), 2,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
    ACTIONS(125), 2,
      sym__san_move_castle,
      sym__san_null_move,
    STATE(110), 2,
      sym_rest_of_line_comment,
      sym_inline_comment,
    STATE(113), 2,
      sym__movetext_element,
      sym_variation,
    STATE(83), 6,
      sym__san_move_piece,
      sym__san_square_nonpromoting,
      sym__san_move_pawn,
      sym__san_drop_pawn,
      sym__san_move_major_or_minor_piece,
      sym__san_drop_major_or_minor_piece,
  [1737] = 3,
    ACTIONS(287), 1,
      sym_check_or_mate_condition,
    ACTIONS(283), 4,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      ts_builtin_sym_end,
      sym_old_style_twic_section_comment,
    ACTIONS(285), 36,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      aux_sym_annotation_token1,
      anon_sym_1,
      anon_sym_O,
      anon_sym_0,
      anon_sym_o,
      anon_sym_u00bd,
      aux_sym_result_code_token14,
      anon_sym_STAR,
      aux_sym_result_code_token15,
      anon_sym_u2217,
      aux_sym_result_code_token16,
      anon_sym_u2731,
      aux_sym_result_code_token17,
      anon_sym_u204e,
      aux_sym_result_code_token18,
      anon_sym_u066d,
      aux_sym_result_code_token19,
      aux_sym_result_code_token20,
      aux_sym_result_code_token21,
      aux_sym_result_code_token22,
      aux_sym_result_code_token23,
  [1785] = 32,
    ACTIONS(17), 1,
      sym__san_file,
    ACTIONS(19), 1,
      sym__san_major_or_minor_piece,
    ACTIONS(21), 1,
      anon_sym_P,
    ACTIONS(27), 1,
      aux_sym_annotation_token1,
    ACTIONS(29), 1,
      sym__full_line_comment_delimiter_bol_assertion,
    ACTIONS(31), 1,
      sym__novelty_glyph_before_punctuation,
    ACTIONS(105), 1,
      anon_sym_SEMI,
    ACTIONS(109), 1,
      anon_sym_LBRACE,
    ACTIONS(119), 1,
      sym_variation_delimiter_open,
    ACTIONS(123), 1,
      anon_sym_AT2,
    ACTIONS(277), 1,
      anon_sym_LBRACK,
    ACTIONS(279), 1,
      sym_move_number,
    STATE(4), 1,
      sym_header,
    STATE(6), 1,
      aux_sym_movetext_repeat1,
    STATE(15), 1,
      sym_tagpair,
    STATE(84), 1,
      sym__lan_move_by_coordinates,
    STATE(98), 1,
      sym_lan_move,
    STATE(103), 1,
      sym_annotation,
    STATE(116), 1,
      sym_san_move,
    STATE(127), 1,
      sym_movetext,
    STATE(147), 1,
      sym_game,
    STATE(207), 1,
      sym_inline_comment_delimiter_open,
    STATE(225), 1,
      sym__san_square_any,
    STATE(249), 1,
      sym__san_square_promoting,
    STATE(260), 1,
      aux_sym_tagpair_delimiter_open_repeat1,
    STATE(316), 1,
      sym_tagpair_delimiter_open,
    STATE(317), 1,
      sym_rest_of_line_comment_delimiter_open,
    ACTIONS(121), 2,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
    ACTIONS(125), 2,
      sym__san_move_castle,
      sym__san_null_move,
    STATE(110), 2,
      sym_rest_of_line_comment,
      sym_inline_comment,
    STATE(113), 2,
      sym__movetext_element,
      sym_variation,
    STATE(83), 6,
      sym__san_move_piece,
      sym__san_square_nonpromoting,
      sym__san_move_pawn,
      sym__san_drop_pawn,
      sym__san_move_major_or_minor_piece,
      sym__san_drop_major_or_minor_piece,
  [1891] = 4,
    ACTIONS(289), 1,
      sym__san_capture_symbol,
    ACTIONS(223), 2,
      sym__san_file_immediate,
      aux_sym__lan_move_by_coordinates_token1,
    ACTIONS(221), 12,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      sym_check_or_mate_condition,
      aux_sym_annotation_token1,
      anon_sym_1,
      anon_sym_O,
      anon_sym_0,
      anon_sym_o,
      anon_sym_u00bd,
      aux_sym_result_code_token14,
    ACTIONS(219), 26,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      anon_sym_SEMI,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      anon_sym_STAR,
      aux_sym_result_code_token15,
      anon_sym_u2217,
      aux_sym_result_code_token16,
      anon_sym_u2731,
      aux_sym_result_code_token17,
      anon_sym_u204e,
      aux_sym_result_code_token18,
      anon_sym_u066d,
      aux_sym_result_code_token19,
      aux_sym_result_code_token20,
      aux_sym_result_code_token21,
      aux_sym_result_code_token22,
      aux_sym_result_code_token23,
  [1941] = 3,
    ACTIONS(295), 1,
      aux_sym_rest_of_line_comment_token1,
    ACTIONS(291), 3,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      ts_builtin_sym_end,
    ACTIONS(293), 37,
      anon_sym_SEMI,
      sym_old_style_twic_section_comment,
      anon_sym_LBRACK,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      aux_sym_annotation_token1,
      anon_sym_1,
      anon_sym_O,
      anon_sym_0,
      anon_sym_o,
      anon_sym_u00bd,
      aux_sym_result_code_token14,
      anon_sym_STAR,
      aux_sym_result_code_token15,
      anon_sym_u2217,
      aux_sym_result_code_token16,
      anon_sym_u2731,
      aux_sym_result_code_token17,
      anon_sym_u204e,
      aux_sym_result_code_token18,
      anon_sym_u066d,
      aux_sym_result_code_token19,
      aux_sym_result_code_token20,
      aux_sym_result_code_token21,
      aux_sym_result_code_token22,
      aux_sym_result_code_token23,
  [1989] = 3,
    ACTIONS(301), 1,
      sym_check_or_mate_condition,
    ACTIONS(297), 4,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      ts_builtin_sym_end,
      sym_old_style_twic_section_comment,
    ACTIONS(299), 36,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      aux_sym_annotation_token1,
      anon_sym_1,
      anon_sym_O,
      anon_sym_0,
      anon_sym_o,
      anon_sym_u00bd,
      aux_sym_result_code_token14,
      anon_sym_STAR,
      aux_sym_result_code_token15,
      anon_sym_u2217,
      aux_sym_result_code_token16,
      anon_sym_u2731,
      aux_sym_result_code_token17,
      anon_sym_u204e,
      aux_sym_result_code_token18,
      anon_sym_u066d,
      aux_sym_result_code_token19,
      aux_sym_result_code_token20,
      aux_sym_result_code_token21,
      aux_sym_result_code_token22,
      aux_sym_result_code_token23,
  [2037] = 5,
    ACTIONS(303), 1,
      sym__san_file_immediate,
    ACTIONS(305), 1,
      sym__san_capture_symbol,
    STATE(77), 1,
      sym__san_square_any_immediate,
    ACTIONS(227), 12,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      sym_check_or_mate_condition,
      aux_sym_annotation_token1,
      anon_sym_1,
      anon_sym_O,
      anon_sym_0,
      anon_sym_o,
      anon_sym_u00bd,
      aux_sym_result_code_token14,
    ACTIONS(225), 26,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      anon_sym_SEMI,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      anon_sym_STAR,
      aux_sym_result_code_token15,
      anon_sym_u2217,
      aux_sym_result_code_token16,
      anon_sym_u2731,
      aux_sym_result_code_token17,
      anon_sym_u204e,
      aux_sym_result_code_token18,
      anon_sym_u066d,
      aux_sym_result_code_token19,
      aux_sym_result_code_token20,
      aux_sym_result_code_token21,
      aux_sym_result_code_token22,
      aux_sym_result_code_token23,
  [2089] = 2,
    ACTIONS(307), 4,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      ts_builtin_sym_end,
      sym_old_style_twic_section_comment,
    ACTIONS(309), 37,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      sym_check_or_mate_condition,
      aux_sym_annotation_token1,
      anon_sym_1,
      anon_sym_O,
      anon_sym_0,
      anon_sym_o,
      anon_sym_u00bd,
      aux_sym_result_code_token14,
      anon_sym_STAR,
      aux_sym_result_code_token15,
      anon_sym_u2217,
      aux_sym_result_code_token16,
      anon_sym_u2731,
      aux_sym_result_code_token17,
      anon_sym_u204e,
      aux_sym_result_code_token18,
      anon_sym_u066d,
      aux_sym_result_code_token19,
      aux_sym_result_code_token20,
      aux_sym_result_code_token21,
      aux_sym_result_code_token22,
      aux_sym_result_code_token23,
  [2135] = 5,
    ACTIONS(311), 1,
      sym__san_promotable_piece,
    ACTIONS(313), 1,
      sym__san_promotion_symbol,
    STATE(80), 1,
      sym__san_promotion,
    ACTIONS(211), 12,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      sym_check_or_mate_condition,
      aux_sym_annotation_token1,
      anon_sym_1,
      anon_sym_O,
      anon_sym_0,
      anon_sym_o,
      anon_sym_u00bd,
      aux_sym_result_code_token14,
    ACTIONS(209), 26,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      anon_sym_SEMI,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      anon_sym_STAR,
      aux_sym_result_code_token15,
      anon_sym_u2217,
      aux_sym_result_code_token16,
      anon_sym_u2731,
      aux_sym_result_code_token17,
      anon_sym_u204e,
      aux_sym_result_code_token18,
      anon_sym_u066d,
      aux_sym_result_code_token19,
      aux_sym_result_code_token20,
      aux_sym_result_code_token21,
      aux_sym_result_code_token22,
      aux_sym_result_code_token23,
  [2187] = 2,
    ACTIONS(315), 4,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      ts_builtin_sym_end,
      sym_old_style_twic_section_comment,
    ACTIONS(317), 37,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      sym_check_or_mate_condition,
      aux_sym_annotation_token1,
      anon_sym_1,
      anon_sym_O,
      anon_sym_0,
      anon_sym_o,
      anon_sym_u00bd,
      aux_sym_result_code_token14,
      anon_sym_STAR,
      aux_sym_result_code_token15,
      anon_sym_u2217,
      aux_sym_result_code_token16,
      anon_sym_u2731,
      aux_sym_result_code_token17,
      anon_sym_u204e,
      aux_sym_result_code_token18,
      anon_sym_u066d,
      aux_sym_result_code_token19,
      aux_sym_result_code_token20,
      aux_sym_result_code_token21,
      aux_sym_result_code_token22,
      aux_sym_result_code_token23,
  [2233] = 2,
    ACTIONS(319), 4,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      ts_builtin_sym_end,
      sym_old_style_twic_section_comment,
    ACTIONS(321), 37,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      sym_check_or_mate_condition,
      aux_sym_annotation_token1,
      anon_sym_1,
      anon_sym_O,
      anon_sym_0,
      anon_sym_o,
      anon_sym_u00bd,
      aux_sym_result_code_token14,
      anon_sym_STAR,
      aux_sym_result_code_token15,
      anon_sym_u2217,
      aux_sym_result_code_token16,
      anon_sym_u2731,
      aux_sym_result_code_token17,
      anon_sym_u204e,
      aux_sym_result_code_token18,
      anon_sym_u066d,
      aux_sym_result_code_token19,
      aux_sym_result_code_token20,
      aux_sym_result_code_token21,
      aux_sym_result_code_token22,
      aux_sym_result_code_token23,
  [2279] = 2,
    ACTIONS(323), 4,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      ts_builtin_sym_end,
      sym_old_style_twic_section_comment,
    ACTIONS(325), 37,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      sym_check_or_mate_condition,
      aux_sym_annotation_token1,
      anon_sym_1,
      anon_sym_O,
      anon_sym_0,
      anon_sym_o,
      anon_sym_u00bd,
      aux_sym_result_code_token14,
      anon_sym_STAR,
      aux_sym_result_code_token15,
      anon_sym_u2217,
      aux_sym_result_code_token16,
      anon_sym_u2731,
      aux_sym_result_code_token17,
      anon_sym_u204e,
      aux_sym_result_code_token18,
      anon_sym_u066d,
      aux_sym_result_code_token19,
      aux_sym_result_code_token20,
      aux_sym_result_code_token21,
      aux_sym_result_code_token22,
      aux_sym_result_code_token23,
  [2325] = 2,
    ACTIONS(327), 4,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      ts_builtin_sym_end,
      sym_old_style_twic_section_comment,
    ACTIONS(329), 37,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      sym_check_or_mate_condition,
      aux_sym_annotation_token1,
      anon_sym_1,
      anon_sym_O,
      anon_sym_0,
      anon_sym_o,
      anon_sym_u00bd,
      aux_sym_result_code_token14,
      anon_sym_STAR,
      aux_sym_result_code_token15,
      anon_sym_u2217,
      aux_sym_result_code_token16,
      anon_sym_u2731,
      aux_sym_result_code_token17,
      anon_sym_u204e,
      aux_sym_result_code_token18,
      anon_sym_u066d,
      aux_sym_result_code_token19,
      aux_sym_result_code_token20,
      aux_sym_result_code_token21,
      aux_sym_result_code_token22,
      aux_sym_result_code_token23,
  [2371] = 2,
    ACTIONS(331), 4,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      ts_builtin_sym_end,
      sym_old_style_twic_section_comment,
    ACTIONS(333), 37,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      sym_check_or_mate_condition,
      aux_sym_annotation_token1,
      anon_sym_1,
      anon_sym_O,
      anon_sym_0,
      anon_sym_o,
      anon_sym_u00bd,
      aux_sym_result_code_token14,
      anon_sym_STAR,
      aux_sym_result_code_token15,
      anon_sym_u2217,
      aux_sym_result_code_token16,
      anon_sym_u2731,
      aux_sym_result_code_token17,
      anon_sym_u204e,
      aux_sym_result_code_token18,
      anon_sym_u066d,
      aux_sym_result_code_token19,
      aux_sym_result_code_token20,
      aux_sym_result_code_token21,
      aux_sym_result_code_token22,
      aux_sym_result_code_token23,
  [2417] = 2,
    ACTIONS(335), 4,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      ts_builtin_sym_end,
      sym_old_style_twic_section_comment,
    ACTIONS(337), 37,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      sym_check_or_mate_condition,
      aux_sym_annotation_token1,
      anon_sym_1,
      anon_sym_O,
      anon_sym_0,
      anon_sym_o,
      anon_sym_u00bd,
      aux_sym_result_code_token14,
      anon_sym_STAR,
      aux_sym_result_code_token15,
      anon_sym_u2217,
      aux_sym_result_code_token16,
      anon_sym_u2731,
      aux_sym_result_code_token17,
      anon_sym_u204e,
      aux_sym_result_code_token18,
      anon_sym_u066d,
      aux_sym_result_code_token19,
      aux_sym_result_code_token20,
      aux_sym_result_code_token21,
      aux_sym_result_code_token22,
      aux_sym_result_code_token23,
  [2463] = 2,
    ACTIONS(225), 4,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      ts_builtin_sym_end,
      sym_old_style_twic_section_comment,
    ACTIONS(227), 37,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      sym_check_or_mate_condition,
      aux_sym_annotation_token1,
      anon_sym_1,
      anon_sym_O,
      anon_sym_0,
      anon_sym_o,
      anon_sym_u00bd,
      aux_sym_result_code_token14,
      anon_sym_STAR,
      aux_sym_result_code_token15,
      anon_sym_u2217,
      aux_sym_result_code_token16,
      anon_sym_u2731,
      aux_sym_result_code_token17,
      anon_sym_u204e,
      aux_sym_result_code_token18,
      anon_sym_u066d,
      aux_sym_result_code_token19,
      aux_sym_result_code_token20,
      aux_sym_result_code_token21,
      aux_sym_result_code_token22,
      aux_sym_result_code_token23,
  [2509] = 2,
    ACTIONS(339), 4,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      ts_builtin_sym_end,
      sym_old_style_twic_section_comment,
    ACTIONS(342), 37,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      sym_check_or_mate_condition,
      aux_sym_annotation_token1,
      anon_sym_1,
      anon_sym_O,
      anon_sym_0,
      anon_sym_o,
      anon_sym_u00bd,
      aux_sym_result_code_token14,
      anon_sym_STAR,
      aux_sym_result_code_token15,
      anon_sym_u2217,
      aux_sym_result_code_token16,
      anon_sym_u2731,
      aux_sym_result_code_token17,
      anon_sym_u204e,
      aux_sym_result_code_token18,
      anon_sym_u066d,
      aux_sym_result_code_token19,
      aux_sym_result_code_token20,
      aux_sym_result_code_token21,
      aux_sym_result_code_token22,
      aux_sym_result_code_token23,
  [2555] = 2,
    ACTIONS(209), 4,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      ts_builtin_sym_end,
      sym_old_style_twic_section_comment,
    ACTIONS(211), 37,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      sym_check_or_mate_condition,
      aux_sym_annotation_token1,
      anon_sym_1,
      anon_sym_O,
      anon_sym_0,
      anon_sym_o,
      anon_sym_u00bd,
      aux_sym_result_code_token14,
      anon_sym_STAR,
      aux_sym_result_code_token15,
      anon_sym_u2217,
      aux_sym_result_code_token16,
      anon_sym_u2731,
      aux_sym_result_code_token17,
      anon_sym_u204e,
      aux_sym_result_code_token18,
      anon_sym_u066d,
      aux_sym_result_code_token19,
      aux_sym_result_code_token20,
      aux_sym_result_code_token21,
      aux_sym_result_code_token22,
      aux_sym_result_code_token23,
  [2601] = 2,
    ACTIONS(345), 4,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      ts_builtin_sym_end,
      sym_old_style_twic_section_comment,
    ACTIONS(347), 37,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      sym_check_or_mate_condition,
      aux_sym_annotation_token1,
      anon_sym_1,
      anon_sym_O,
      anon_sym_0,
      anon_sym_o,
      anon_sym_u00bd,
      aux_sym_result_code_token14,
      anon_sym_STAR,
      aux_sym_result_code_token15,
      anon_sym_u2217,
      aux_sym_result_code_token16,
      anon_sym_u2731,
      aux_sym_result_code_token17,
      anon_sym_u204e,
      aux_sym_result_code_token18,
      anon_sym_u066d,
      aux_sym_result_code_token19,
      aux_sym_result_code_token20,
      aux_sym_result_code_token21,
      aux_sym_result_code_token22,
      aux_sym_result_code_token23,
  [2647] = 2,
    ACTIONS(349), 4,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      ts_builtin_sym_end,
      sym_old_style_twic_section_comment,
    ACTIONS(351), 37,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      sym_check_or_mate_condition,
      aux_sym_annotation_token1,
      anon_sym_1,
      anon_sym_O,
      anon_sym_0,
      anon_sym_o,
      anon_sym_u00bd,
      aux_sym_result_code_token14,
      anon_sym_STAR,
      aux_sym_result_code_token15,
      anon_sym_u2217,
      aux_sym_result_code_token16,
      anon_sym_u2731,
      aux_sym_result_code_token17,
      anon_sym_u204e,
      aux_sym_result_code_token18,
      anon_sym_u066d,
      aux_sym_result_code_token19,
      aux_sym_result_code_token20,
      aux_sym_result_code_token21,
      aux_sym_result_code_token22,
      aux_sym_result_code_token23,
  [2693] = 2,
    ACTIONS(353), 4,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      ts_builtin_sym_end,
      sym_old_style_twic_section_comment,
    ACTIONS(355), 37,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      sym_check_or_mate_condition,
      aux_sym_annotation_token1,
      anon_sym_1,
      anon_sym_O,
      anon_sym_0,
      anon_sym_o,
      anon_sym_u00bd,
      aux_sym_result_code_token14,
      anon_sym_STAR,
      aux_sym_result_code_token15,
      anon_sym_u2217,
      aux_sym_result_code_token16,
      anon_sym_u2731,
      aux_sym_result_code_token17,
      anon_sym_u204e,
      aux_sym_result_code_token18,
      anon_sym_u066d,
      aux_sym_result_code_token19,
      aux_sym_result_code_token20,
      aux_sym_result_code_token21,
      aux_sym_result_code_token22,
      aux_sym_result_code_token23,
  [2739] = 2,
    ACTIONS(357), 4,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      ts_builtin_sym_end,
      sym_old_style_twic_section_comment,
    ACTIONS(360), 37,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      sym_check_or_mate_condition,
      aux_sym_annotation_token1,
      anon_sym_1,
      anon_sym_O,
      anon_sym_0,
      anon_sym_o,
      anon_sym_u00bd,
      aux_sym_result_code_token14,
      anon_sym_STAR,
      aux_sym_result_code_token15,
      anon_sym_u2217,
      aux_sym_result_code_token16,
      anon_sym_u2731,
      aux_sym_result_code_token17,
      anon_sym_u204e,
      aux_sym_result_code_token18,
      anon_sym_u066d,
      aux_sym_result_code_token19,
      aux_sym_result_code_token20,
      aux_sym_result_code_token21,
      aux_sym_result_code_token22,
      aux_sym_result_code_token23,
  [2785] = 2,
    ACTIONS(363), 4,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      ts_builtin_sym_end,
      sym_old_style_twic_section_comment,
    ACTIONS(365), 37,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      sym_check_or_mate_condition,
      aux_sym_annotation_token1,
      anon_sym_1,
      anon_sym_O,
      anon_sym_0,
      anon_sym_o,
      anon_sym_u00bd,
      aux_sym_result_code_token14,
      anon_sym_STAR,
      aux_sym_result_code_token15,
      anon_sym_u2217,
      aux_sym_result_code_token16,
      anon_sym_u2731,
      aux_sym_result_code_token17,
      anon_sym_u204e,
      aux_sym_result_code_token18,
      anon_sym_u066d,
      aux_sym_result_code_token19,
      aux_sym_result_code_token20,
      aux_sym_result_code_token21,
      aux_sym_result_code_token22,
      aux_sym_result_code_token23,
  [2831] = 2,
    ACTIONS(367), 4,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      ts_builtin_sym_end,
      sym_old_style_twic_section_comment,
    ACTIONS(369), 37,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      sym_check_or_mate_condition,
      aux_sym_annotation_token1,
      anon_sym_1,
      anon_sym_O,
      anon_sym_0,
      anon_sym_o,
      anon_sym_u00bd,
      aux_sym_result_code_token14,
      anon_sym_STAR,
      aux_sym_result_code_token15,
      anon_sym_u2217,
      aux_sym_result_code_token16,
      anon_sym_u2731,
      aux_sym_result_code_token17,
      anon_sym_u204e,
      aux_sym_result_code_token18,
      anon_sym_u066d,
      aux_sym_result_code_token19,
      aux_sym_result_code_token20,
      aux_sym_result_code_token21,
      aux_sym_result_code_token22,
      aux_sym_result_code_token23,
  [2877] = 5,
    ACTIONS(313), 1,
      sym__san_promotion_symbol,
    ACTIONS(371), 1,
      sym__san_promotable_piece,
    STATE(79), 1,
      sym__san_promotion,
    ACTIONS(211), 12,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      sym_check_or_mate_condition,
      aux_sym_annotation_token1,
      anon_sym_1,
      anon_sym_O,
      anon_sym_0,
      anon_sym_o,
      anon_sym_u00bd,
      aux_sym_result_code_token14,
    ACTIONS(209), 26,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      anon_sym_SEMI,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      anon_sym_STAR,
      aux_sym_result_code_token15,
      anon_sym_u2217,
      aux_sym_result_code_token16,
      anon_sym_u2731,
      aux_sym_result_code_token17,
      anon_sym_u204e,
      aux_sym_result_code_token18,
      anon_sym_u066d,
      aux_sym_result_code_token19,
      aux_sym_result_code_token20,
      aux_sym_result_code_token21,
      aux_sym_result_code_token22,
      aux_sym_result_code_token23,
  [2929] = 2,
    ACTIONS(373), 4,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      ts_builtin_sym_end,
      sym_old_style_twic_section_comment,
    ACTIONS(375), 37,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      sym_check_or_mate_condition,
      aux_sym_annotation_token1,
      anon_sym_1,
      anon_sym_O,
      anon_sym_0,
      anon_sym_o,
      anon_sym_u00bd,
      aux_sym_result_code_token14,
      anon_sym_STAR,
      aux_sym_result_code_token15,
      anon_sym_u2217,
      aux_sym_result_code_token16,
      anon_sym_u2731,
      aux_sym_result_code_token17,
      anon_sym_u204e,
      aux_sym_result_code_token18,
      anon_sym_u066d,
      aux_sym_result_code_token19,
      aux_sym_result_code_token20,
      aux_sym_result_code_token21,
      aux_sym_result_code_token22,
      aux_sym_result_code_token23,
  [2975] = 2,
    ACTIONS(377), 4,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      ts_builtin_sym_end,
      sym_old_style_twic_section_comment,
    ACTIONS(379), 36,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      aux_sym_annotation_token1,
      anon_sym_1,
      anon_sym_O,
      anon_sym_0,
      anon_sym_o,
      anon_sym_u00bd,
      aux_sym_result_code_token14,
      anon_sym_STAR,
      aux_sym_result_code_token15,
      anon_sym_u2217,
      aux_sym_result_code_token16,
      anon_sym_u2731,
      aux_sym_result_code_token17,
      anon_sym_u204e,
      aux_sym_result_code_token18,
      anon_sym_u066d,
      aux_sym_result_code_token19,
      aux_sym_result_code_token20,
      aux_sym_result_code_token21,
      aux_sym_result_code_token22,
      aux_sym_result_code_token23,
  [3020] = 2,
    ACTIONS(381), 4,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      ts_builtin_sym_end,
      sym_old_style_twic_section_comment,
    ACTIONS(383), 36,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      aux_sym_annotation_token1,
      anon_sym_1,
      anon_sym_O,
      anon_sym_0,
      anon_sym_o,
      anon_sym_u00bd,
      aux_sym_result_code_token14,
      anon_sym_STAR,
      aux_sym_result_code_token15,
      anon_sym_u2217,
      aux_sym_result_code_token16,
      anon_sym_u2731,
      aux_sym_result_code_token17,
      anon_sym_u204e,
      aux_sym_result_code_token18,
      anon_sym_u066d,
      aux_sym_result_code_token19,
      aux_sym_result_code_token20,
      aux_sym_result_code_token21,
      aux_sym_result_code_token22,
      aux_sym_result_code_token23,
  [3065] = 2,
    ACTIONS(385), 4,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      ts_builtin_sym_end,
      sym_old_style_twic_section_comment,
    ACTIONS(387), 36,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      aux_sym_annotation_token1,
      anon_sym_1,
      anon_sym_O,
      anon_sym_0,
      anon_sym_o,
      anon_sym_u00bd,
      aux_sym_result_code_token14,
      anon_sym_STAR,
      aux_sym_result_code_token15,
      anon_sym_u2217,
      aux_sym_result_code_token16,
      anon_sym_u2731,
      aux_sym_result_code_token17,
      anon_sym_u204e,
      aux_sym_result_code_token18,
      anon_sym_u066d,
      aux_sym_result_code_token19,
      aux_sym_result_code_token20,
      aux_sym_result_code_token21,
      aux_sym_result_code_token22,
      aux_sym_result_code_token23,
  [3110] = 2,
    ACTIONS(389), 4,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      ts_builtin_sym_end,
      sym_old_style_twic_section_comment,
    ACTIONS(391), 36,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      aux_sym_annotation_token1,
      anon_sym_1,
      anon_sym_O,
      anon_sym_0,
      anon_sym_o,
      anon_sym_u00bd,
      aux_sym_result_code_token14,
      anon_sym_STAR,
      aux_sym_result_code_token15,
      anon_sym_u2217,
      aux_sym_result_code_token16,
      anon_sym_u2731,
      aux_sym_result_code_token17,
      anon_sym_u204e,
      aux_sym_result_code_token18,
      anon_sym_u066d,
      aux_sym_result_code_token19,
      aux_sym_result_code_token20,
      aux_sym_result_code_token21,
      aux_sym_result_code_token22,
      aux_sym_result_code_token23,
  [3155] = 2,
    ACTIONS(273), 14,
      sym_move_number,
      sym__san_file,
      sym__san_promotable_piece,
      sym__san_major_or_minor_piece,
      sym__san_promotion_symbol,
      anon_sym_P,
      sym_check_or_mate_condition,
      aux_sym_annotation_token1,
      anon_sym_1,
      anon_sym_O,
      anon_sym_0,
      anon_sym_o,
      anon_sym_u00bd,
      aux_sym_result_code_token14,
    ACTIONS(271), 26,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      anon_sym_SEMI,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      anon_sym_STAR,
      aux_sym_result_code_token15,
      anon_sym_u2217,
      aux_sym_result_code_token16,
      anon_sym_u2731,
      aux_sym_result_code_token17,
      anon_sym_u204e,
      aux_sym_result_code_token18,
      anon_sym_u066d,
      aux_sym_result_code_token19,
      aux_sym_result_code_token20,
      aux_sym_result_code_token21,
      aux_sym_result_code_token22,
      aux_sym_result_code_token23,
  [3200] = 2,
    ACTIONS(393), 4,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      ts_builtin_sym_end,
      sym_old_style_twic_section_comment,
    ACTIONS(395), 36,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      aux_sym_annotation_token1,
      anon_sym_1,
      anon_sym_O,
      anon_sym_0,
      anon_sym_o,
      anon_sym_u00bd,
      aux_sym_result_code_token14,
      anon_sym_STAR,
      aux_sym_result_code_token15,
      anon_sym_u2217,
      aux_sym_result_code_token16,
      anon_sym_u2731,
      aux_sym_result_code_token17,
      anon_sym_u204e,
      aux_sym_result_code_token18,
      anon_sym_u066d,
      aux_sym_result_code_token19,
      aux_sym_result_code_token20,
      aux_sym_result_code_token21,
      aux_sym_result_code_token22,
      aux_sym_result_code_token23,
  [3245] = 2,
    ACTIONS(397), 4,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      ts_builtin_sym_end,
      sym_old_style_twic_section_comment,
    ACTIONS(399), 36,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      aux_sym_annotation_token1,
      anon_sym_1,
      anon_sym_O,
      anon_sym_0,
      anon_sym_o,
      anon_sym_u00bd,
      aux_sym_result_code_token14,
      anon_sym_STAR,
      aux_sym_result_code_token15,
      anon_sym_u2217,
      aux_sym_result_code_token16,
      anon_sym_u2731,
      aux_sym_result_code_token17,
      anon_sym_u204e,
      aux_sym_result_code_token18,
      anon_sym_u066d,
      aux_sym_result_code_token19,
      aux_sym_result_code_token20,
      aux_sym_result_code_token21,
      aux_sym_result_code_token22,
      aux_sym_result_code_token23,
  [3290] = 2,
    ACTIONS(401), 4,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      ts_builtin_sym_end,
      sym_old_style_twic_section_comment,
    ACTIONS(403), 36,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      aux_sym_annotation_token1,
      anon_sym_1,
      anon_sym_O,
      anon_sym_0,
      anon_sym_o,
      anon_sym_u00bd,
      aux_sym_result_code_token14,
      anon_sym_STAR,
      aux_sym_result_code_token15,
      anon_sym_u2217,
      aux_sym_result_code_token16,
      anon_sym_u2731,
      aux_sym_result_code_token17,
      anon_sym_u204e,
      aux_sym_result_code_token18,
      anon_sym_u066d,
      aux_sym_result_code_token19,
      aux_sym_result_code_token20,
      aux_sym_result_code_token21,
      aux_sym_result_code_token22,
      aux_sym_result_code_token23,
  [3335] = 2,
    ACTIONS(405), 4,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      ts_builtin_sym_end,
      sym_old_style_twic_section_comment,
    ACTIONS(407), 36,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      aux_sym_annotation_token1,
      anon_sym_1,
      anon_sym_O,
      anon_sym_0,
      anon_sym_o,
      anon_sym_u00bd,
      aux_sym_result_code_token14,
      anon_sym_STAR,
      aux_sym_result_code_token15,
      anon_sym_u2217,
      aux_sym_result_code_token16,
      anon_sym_u2731,
      aux_sym_result_code_token17,
      anon_sym_u204e,
      aux_sym_result_code_token18,
      anon_sym_u066d,
      aux_sym_result_code_token19,
      aux_sym_result_code_token20,
      aux_sym_result_code_token21,
      aux_sym_result_code_token22,
      aux_sym_result_code_token23,
  [3380] = 2,
    ACTIONS(409), 4,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      ts_builtin_sym_end,
      sym_old_style_twic_section_comment,
    ACTIONS(411), 36,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      aux_sym_annotation_token1,
      anon_sym_1,
      anon_sym_O,
      anon_sym_0,
      anon_sym_o,
      anon_sym_u00bd,
      aux_sym_result_code_token14,
      anon_sym_STAR,
      aux_sym_result_code_token15,
      anon_sym_u2217,
      aux_sym_result_code_token16,
      anon_sym_u2731,
      aux_sym_result_code_token17,
      anon_sym_u204e,
      aux_sym_result_code_token18,
      anon_sym_u066d,
      aux_sym_result_code_token19,
      aux_sym_result_code_token20,
      aux_sym_result_code_token21,
      aux_sym_result_code_token22,
      aux_sym_result_code_token23,
  [3425] = 3,
    ACTIONS(413), 1,
      aux_sym_rest_of_line_comment_token1,
    ACTIONS(291), 2,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
    ACTIONS(293), 37,
      anon_sym_SEMI,
      sym_old_style_twic_section_comment,
      anon_sym_LBRACK,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      aux_sym_annotation_token1,
      anon_sym_1,
      anon_sym_O,
      anon_sym_0,
      anon_sym_o,
      anon_sym_u00bd,
      aux_sym_result_code_token14,
      anon_sym_STAR,
      aux_sym_result_code_token15,
      anon_sym_u2217,
      aux_sym_result_code_token16,
      anon_sym_u2731,
      aux_sym_result_code_token17,
      anon_sym_u204e,
      aux_sym_result_code_token18,
      anon_sym_u066d,
      aux_sym_result_code_token19,
      aux_sym_result_code_token20,
      aux_sym_result_code_token21,
      aux_sym_result_code_token22,
      aux_sym_result_code_token23,
  [3472] = 2,
    ACTIONS(415), 4,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      ts_builtin_sym_end,
      sym_old_style_twic_section_comment,
    ACTIONS(417), 36,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      aux_sym_annotation_token1,
      anon_sym_1,
      anon_sym_O,
      anon_sym_0,
      anon_sym_o,
      anon_sym_u00bd,
      aux_sym_result_code_token14,
      anon_sym_STAR,
      aux_sym_result_code_token15,
      anon_sym_u2217,
      aux_sym_result_code_token16,
      anon_sym_u2731,
      aux_sym_result_code_token17,
      anon_sym_u204e,
      aux_sym_result_code_token18,
      anon_sym_u066d,
      aux_sym_result_code_token19,
      aux_sym_result_code_token20,
      aux_sym_result_code_token21,
      aux_sym_result_code_token22,
      aux_sym_result_code_token23,
  [3517] = 2,
    ACTIONS(419), 4,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      ts_builtin_sym_end,
      sym_old_style_twic_section_comment,
    ACTIONS(421), 36,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      aux_sym_annotation_token1,
      anon_sym_1,
      anon_sym_O,
      anon_sym_0,
      anon_sym_o,
      anon_sym_u00bd,
      aux_sym_result_code_token14,
      anon_sym_STAR,
      aux_sym_result_code_token15,
      anon_sym_u2217,
      aux_sym_result_code_token16,
      anon_sym_u2731,
      aux_sym_result_code_token17,
      anon_sym_u204e,
      aux_sym_result_code_token18,
      anon_sym_u066d,
      aux_sym_result_code_token19,
      aux_sym_result_code_token20,
      aux_sym_result_code_token21,
      aux_sym_result_code_token22,
      aux_sym_result_code_token23,
  [3562] = 2,
    ACTIONS(423), 4,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      ts_builtin_sym_end,
      sym_old_style_twic_section_comment,
    ACTIONS(425), 36,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      aux_sym_annotation_token1,
      anon_sym_1,
      anon_sym_O,
      anon_sym_0,
      anon_sym_o,
      anon_sym_u00bd,
      aux_sym_result_code_token14,
      anon_sym_STAR,
      aux_sym_result_code_token15,
      anon_sym_u2217,
      aux_sym_result_code_token16,
      anon_sym_u2731,
      aux_sym_result_code_token17,
      anon_sym_u204e,
      aux_sym_result_code_token18,
      anon_sym_u066d,
      aux_sym_result_code_token19,
      aux_sym_result_code_token20,
      aux_sym_result_code_token21,
      aux_sym_result_code_token22,
      aux_sym_result_code_token23,
  [3607] = 5,
    ACTIONS(432), 1,
      anon_sym_LBRACK,
    ACTIONS(427), 2,
      ts_builtin_sym_end,
      sym_old_style_twic_section_comment,
    ACTIONS(434), 2,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
    ACTIONS(429), 13,
      anon_sym_SEMI,
      sym_variation_delimiter_open,
      anon_sym_LBRACE,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      aux_sym_annotation_token1,
    ACTIONS(379), 22,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_1,
      anon_sym_O,
      anon_sym_0,
      anon_sym_o,
      anon_sym_u00bd,
      aux_sym_result_code_token14,
      anon_sym_STAR,
      aux_sym_result_code_token15,
      anon_sym_u2217,
      aux_sym_result_code_token16,
      anon_sym_u2731,
      aux_sym_result_code_token17,
      anon_sym_u204e,
      aux_sym_result_code_token18,
      anon_sym_u066d,
      aux_sym_result_code_token19,
      aux_sym_result_code_token20,
      aux_sym_result_code_token21,
      aux_sym_result_code_token22,
      aux_sym_result_code_token23,
  [3658] = 2,
    ACTIONS(437), 4,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      ts_builtin_sym_end,
      sym_old_style_twic_section_comment,
    ACTIONS(439), 36,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      aux_sym_annotation_token1,
      anon_sym_1,
      anon_sym_O,
      anon_sym_0,
      anon_sym_o,
      anon_sym_u00bd,
      aux_sym_result_code_token14,
      anon_sym_STAR,
      aux_sym_result_code_token15,
      anon_sym_u2217,
      aux_sym_result_code_token16,
      anon_sym_u2731,
      aux_sym_result_code_token17,
      anon_sym_u204e,
      aux_sym_result_code_token18,
      anon_sym_u066d,
      aux_sym_result_code_token19,
      aux_sym_result_code_token20,
      aux_sym_result_code_token21,
      aux_sym_result_code_token22,
      aux_sym_result_code_token23,
  [3703] = 2,
    ACTIONS(441), 4,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      ts_builtin_sym_end,
      sym_old_style_twic_section_comment,
    ACTIONS(443), 36,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      aux_sym_annotation_token1,
      anon_sym_1,
      anon_sym_O,
      anon_sym_0,
      anon_sym_o,
      anon_sym_u00bd,
      aux_sym_result_code_token14,
      anon_sym_STAR,
      aux_sym_result_code_token15,
      anon_sym_u2217,
      aux_sym_result_code_token16,
      anon_sym_u2731,
      aux_sym_result_code_token17,
      anon_sym_u204e,
      aux_sym_result_code_token18,
      anon_sym_u066d,
      aux_sym_result_code_token19,
      aux_sym_result_code_token20,
      aux_sym_result_code_token21,
      aux_sym_result_code_token22,
      aux_sym_result_code_token23,
  [3748] = 2,
    ACTIONS(445), 4,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      ts_builtin_sym_end,
      sym_old_style_twic_section_comment,
    ACTIONS(447), 36,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      aux_sym_annotation_token1,
      anon_sym_1,
      anon_sym_O,
      anon_sym_0,
      anon_sym_o,
      anon_sym_u00bd,
      aux_sym_result_code_token14,
      anon_sym_STAR,
      aux_sym_result_code_token15,
      anon_sym_u2217,
      aux_sym_result_code_token16,
      anon_sym_u2731,
      aux_sym_result_code_token17,
      anon_sym_u204e,
      aux_sym_result_code_token18,
      anon_sym_u066d,
      aux_sym_result_code_token19,
      aux_sym_result_code_token20,
      aux_sym_result_code_token21,
      aux_sym_result_code_token22,
      aux_sym_result_code_token23,
  [3793] = 2,
    ACTIONS(449), 4,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      ts_builtin_sym_end,
      sym_old_style_twic_section_comment,
    ACTIONS(451), 36,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      aux_sym_annotation_token1,
      anon_sym_1,
      anon_sym_O,
      anon_sym_0,
      anon_sym_o,
      anon_sym_u00bd,
      aux_sym_result_code_token14,
      anon_sym_STAR,
      aux_sym_result_code_token15,
      anon_sym_u2217,
      aux_sym_result_code_token16,
      anon_sym_u2731,
      aux_sym_result_code_token17,
      anon_sym_u204e,
      aux_sym_result_code_token18,
      anon_sym_u066d,
      aux_sym_result_code_token19,
      aux_sym_result_code_token20,
      aux_sym_result_code_token21,
      aux_sym_result_code_token22,
      aux_sym_result_code_token23,
  [3838] = 2,
    ACTIONS(409), 3,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      sym_old_style_twic_section_comment,
    ACTIONS(411), 36,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      aux_sym_annotation_token1,
      anon_sym_1,
      anon_sym_O,
      anon_sym_0,
      anon_sym_o,
      anon_sym_u00bd,
      aux_sym_result_code_token14,
      anon_sym_STAR,
      aux_sym_result_code_token15,
      anon_sym_u2217,
      aux_sym_result_code_token16,
      anon_sym_u2731,
      aux_sym_result_code_token17,
      anon_sym_u204e,
      aux_sym_result_code_token18,
      anon_sym_u066d,
      aux_sym_result_code_token19,
      aux_sym_result_code_token20,
      aux_sym_result_code_token21,
      aux_sym_result_code_token22,
      aux_sym_result_code_token23,
  [3882] = 2,
    ACTIONS(385), 3,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      sym_old_style_twic_section_comment,
    ACTIONS(387), 36,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      aux_sym_annotation_token1,
      anon_sym_1,
      anon_sym_O,
      anon_sym_0,
      anon_sym_o,
      anon_sym_u00bd,
      aux_sym_result_code_token14,
      anon_sym_STAR,
      aux_sym_result_code_token15,
      anon_sym_u2217,
      aux_sym_result_code_token16,
      anon_sym_u2731,
      aux_sym_result_code_token17,
      anon_sym_u204e,
      aux_sym_result_code_token18,
      anon_sym_u066d,
      aux_sym_result_code_token19,
      aux_sym_result_code_token20,
      aux_sym_result_code_token21,
      aux_sym_result_code_token22,
      aux_sym_result_code_token23,
  [3926] = 4,
    ACTIONS(457), 1,
      anon_sym_RBRACK,
    STATE(69), 1,
      aux_sym_tagpair_delimiter_close_repeat1,
    ACTIONS(453), 3,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      sym__empty_line,
    ACTIONS(455), 34,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      sym_variation_delimiter_open,
      anon_sym_LBRACE,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      aux_sym_annotation_token1,
      anon_sym_1,
      anon_sym_O,
      anon_sym_0,
      anon_sym_o,
      anon_sym_u00bd,
      aux_sym_result_code_token14,
      anon_sym_STAR,
      aux_sym_result_code_token15,
      anon_sym_u2217,
      aux_sym_result_code_token16,
      anon_sym_u2731,
      aux_sym_result_code_token17,
      anon_sym_u204e,
      aux_sym_result_code_token18,
      anon_sym_u066d,
      aux_sym_result_code_token19,
      aux_sym_result_code_token20,
      aux_sym_result_code_token21,
      aux_sym_result_code_token22,
      aux_sym_result_code_token23,
  [3974] = 4,
    ACTIONS(463), 1,
      anon_sym_RBRACK,
    STATE(69), 1,
      aux_sym_tagpair_delimiter_close_repeat1,
    ACTIONS(459), 3,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      sym__empty_line,
    ACTIONS(461), 34,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      sym_variation_delimiter_open,
      anon_sym_LBRACE,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      aux_sym_annotation_token1,
      anon_sym_1,
      anon_sym_O,
      anon_sym_0,
      anon_sym_o,
      anon_sym_u00bd,
      aux_sym_result_code_token14,
      anon_sym_STAR,
      aux_sym_result_code_token15,
      anon_sym_u2217,
      aux_sym_result_code_token16,
      anon_sym_u2731,
      aux_sym_result_code_token17,
      anon_sym_u204e,
      aux_sym_result_code_token18,
      anon_sym_u066d,
      aux_sym_result_code_token19,
      aux_sym_result_code_token20,
      aux_sym_result_code_token21,
      aux_sym_result_code_token22,
      aux_sym_result_code_token23,
  [4022] = 2,
    ACTIONS(401), 3,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      sym_old_style_twic_section_comment,
    ACTIONS(403), 36,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      aux_sym_annotation_token1,
      anon_sym_1,
      anon_sym_O,
      anon_sym_0,
      anon_sym_o,
      anon_sym_u00bd,
      aux_sym_result_code_token14,
      anon_sym_STAR,
      aux_sym_result_code_token15,
      anon_sym_u2217,
      aux_sym_result_code_token16,
      anon_sym_u2731,
      aux_sym_result_code_token17,
      anon_sym_u204e,
      aux_sym_result_code_token18,
      anon_sym_u066d,
      aux_sym_result_code_token19,
      aux_sym_result_code_token20,
      aux_sym_result_code_token21,
      aux_sym_result_code_token22,
      aux_sym_result_code_token23,
  [4066] = 5,
    ACTIONS(427), 1,
      sym_old_style_twic_section_comment,
    ACTIONS(432), 1,
      anon_sym_LBRACK,
    ACTIONS(434), 2,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
    ACTIONS(429), 13,
      anon_sym_SEMI,
      sym_variation_delimiter_open,
      anon_sym_LBRACE,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      aux_sym_annotation_token1,
    ACTIONS(379), 22,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_1,
      anon_sym_O,
      anon_sym_0,
      anon_sym_o,
      anon_sym_u00bd,
      aux_sym_result_code_token14,
      anon_sym_STAR,
      aux_sym_result_code_token15,
      anon_sym_u2217,
      aux_sym_result_code_token16,
      anon_sym_u2731,
      aux_sym_result_code_token17,
      anon_sym_u204e,
      aux_sym_result_code_token18,
      anon_sym_u066d,
      aux_sym_result_code_token19,
      aux_sym_result_code_token20,
      aux_sym_result_code_token21,
      aux_sym_result_code_token22,
      aux_sym_result_code_token23,
  [4116] = 2,
    ACTIONS(445), 3,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      sym_old_style_twic_section_comment,
    ACTIONS(447), 36,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      aux_sym_annotation_token1,
      anon_sym_1,
      anon_sym_O,
      anon_sym_0,
      anon_sym_o,
      anon_sym_u00bd,
      aux_sym_result_code_token14,
      anon_sym_STAR,
      aux_sym_result_code_token15,
      anon_sym_u2217,
      aux_sym_result_code_token16,
      anon_sym_u2731,
      aux_sym_result_code_token17,
      anon_sym_u204e,
      aux_sym_result_code_token18,
      anon_sym_u066d,
      aux_sym_result_code_token19,
      aux_sym_result_code_token20,
      aux_sym_result_code_token21,
      aux_sym_result_code_token22,
      aux_sym_result_code_token23,
  [4160] = 2,
    ACTIONS(309), 12,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      sym_check_or_mate_condition,
      aux_sym_annotation_token1,
      anon_sym_1,
      anon_sym_O,
      anon_sym_0,
      anon_sym_o,
      anon_sym_u00bd,
      aux_sym_result_code_token14,
    ACTIONS(307), 26,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      anon_sym_SEMI,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      anon_sym_STAR,
      aux_sym_result_code_token15,
      anon_sym_u2217,
      aux_sym_result_code_token16,
      anon_sym_u2731,
      aux_sym_result_code_token17,
      anon_sym_u204e,
      aux_sym_result_code_token18,
      anon_sym_u066d,
      aux_sym_result_code_token19,
      aux_sym_result_code_token20,
      aux_sym_result_code_token21,
      aux_sym_result_code_token22,
      aux_sym_result_code_token23,
  [4203] = 2,
    ACTIONS(347), 12,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      sym_check_or_mate_condition,
      aux_sym_annotation_token1,
      anon_sym_1,
      anon_sym_O,
      anon_sym_0,
      anon_sym_o,
      anon_sym_u00bd,
      aux_sym_result_code_token14,
    ACTIONS(345), 26,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      anon_sym_SEMI,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      anon_sym_STAR,
      aux_sym_result_code_token15,
      anon_sym_u2217,
      aux_sym_result_code_token16,
      anon_sym_u2731,
      aux_sym_result_code_token17,
      anon_sym_u204e,
      aux_sym_result_code_token18,
      anon_sym_u066d,
      aux_sym_result_code_token19,
      aux_sym_result_code_token20,
      aux_sym_result_code_token21,
      aux_sym_result_code_token22,
      aux_sym_result_code_token23,
  [4246] = 2,
    ACTIONS(375), 12,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      sym_check_or_mate_condition,
      aux_sym_annotation_token1,
      anon_sym_1,
      anon_sym_O,
      anon_sym_0,
      anon_sym_o,
      anon_sym_u00bd,
      aux_sym_result_code_token14,
    ACTIONS(373), 26,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      anon_sym_SEMI,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      anon_sym_STAR,
      aux_sym_result_code_token15,
      anon_sym_u2217,
      aux_sym_result_code_token16,
      anon_sym_u2731,
      aux_sym_result_code_token17,
      anon_sym_u204e,
      aux_sym_result_code_token18,
      anon_sym_u066d,
      aux_sym_result_code_token19,
      aux_sym_result_code_token20,
      aux_sym_result_code_token21,
      aux_sym_result_code_token22,
      aux_sym_result_code_token23,
  [4289] = 2,
    ACTIONS(342), 12,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      sym_check_or_mate_condition,
      aux_sym_annotation_token1,
      anon_sym_1,
      anon_sym_O,
      anon_sym_0,
      anon_sym_o,
      anon_sym_u00bd,
      aux_sym_result_code_token14,
    ACTIONS(339), 26,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      anon_sym_SEMI,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      anon_sym_STAR,
      aux_sym_result_code_token15,
      anon_sym_u2217,
      aux_sym_result_code_token16,
      anon_sym_u2731,
      aux_sym_result_code_token17,
      anon_sym_u204e,
      aux_sym_result_code_token18,
      anon_sym_u066d,
      aux_sym_result_code_token19,
      aux_sym_result_code_token20,
      aux_sym_result_code_token21,
      aux_sym_result_code_token22,
      aux_sym_result_code_token23,
  [4332] = 2,
    ACTIONS(355), 12,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      sym_check_or_mate_condition,
      aux_sym_annotation_token1,
      anon_sym_1,
      anon_sym_O,
      anon_sym_0,
      anon_sym_o,
      anon_sym_u00bd,
      aux_sym_result_code_token14,
    ACTIONS(353), 26,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      anon_sym_SEMI,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      anon_sym_STAR,
      aux_sym_result_code_token15,
      anon_sym_u2217,
      aux_sym_result_code_token16,
      anon_sym_u2731,
      aux_sym_result_code_token17,
      anon_sym_u204e,
      aux_sym_result_code_token18,
      anon_sym_u066d,
      aux_sym_result_code_token19,
      aux_sym_result_code_token20,
      aux_sym_result_code_token21,
      aux_sym_result_code_token22,
      aux_sym_result_code_token23,
  [4375] = 2,
    ACTIONS(211), 12,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      sym_check_or_mate_condition,
      aux_sym_annotation_token1,
      anon_sym_1,
      anon_sym_O,
      anon_sym_0,
      anon_sym_o,
      anon_sym_u00bd,
      aux_sym_result_code_token14,
    ACTIONS(209), 26,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      anon_sym_SEMI,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      anon_sym_STAR,
      aux_sym_result_code_token15,
      anon_sym_u2217,
      aux_sym_result_code_token16,
      anon_sym_u2731,
      aux_sym_result_code_token17,
      anon_sym_u204e,
      aux_sym_result_code_token18,
      anon_sym_u066d,
      aux_sym_result_code_token19,
      aux_sym_result_code_token20,
      aux_sym_result_code_token21,
      aux_sym_result_code_token22,
      aux_sym_result_code_token23,
  [4418] = 2,
    ACTIONS(360), 12,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      sym_check_or_mate_condition,
      aux_sym_annotation_token1,
      anon_sym_1,
      anon_sym_O,
      anon_sym_0,
      anon_sym_o,
      anon_sym_u00bd,
      aux_sym_result_code_token14,
    ACTIONS(357), 26,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      anon_sym_SEMI,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      anon_sym_STAR,
      aux_sym_result_code_token15,
      anon_sym_u2217,
      aux_sym_result_code_token16,
      anon_sym_u2731,
      aux_sym_result_code_token17,
      anon_sym_u204e,
      aux_sym_result_code_token18,
      anon_sym_u066d,
      aux_sym_result_code_token19,
      aux_sym_result_code_token20,
      aux_sym_result_code_token21,
      aux_sym_result_code_token22,
      aux_sym_result_code_token23,
  [4461] = 2,
    ACTIONS(365), 12,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      sym_check_or_mate_condition,
      aux_sym_annotation_token1,
      anon_sym_1,
      anon_sym_O,
      anon_sym_0,
      anon_sym_o,
      anon_sym_u00bd,
      aux_sym_result_code_token14,
    ACTIONS(363), 26,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      anon_sym_SEMI,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      anon_sym_STAR,
      aux_sym_result_code_token15,
      anon_sym_u2217,
      aux_sym_result_code_token16,
      anon_sym_u2731,
      aux_sym_result_code_token17,
      anon_sym_u204e,
      aux_sym_result_code_token18,
      anon_sym_u066d,
      aux_sym_result_code_token19,
      aux_sym_result_code_token20,
      aux_sym_result_code_token21,
      aux_sym_result_code_token22,
      aux_sym_result_code_token23,
  [4504] = 2,
    ACTIONS(351), 12,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      sym_check_or_mate_condition,
      aux_sym_annotation_token1,
      anon_sym_1,
      anon_sym_O,
      anon_sym_0,
      anon_sym_o,
      anon_sym_u00bd,
      aux_sym_result_code_token14,
    ACTIONS(349), 26,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      anon_sym_SEMI,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      anon_sym_STAR,
      aux_sym_result_code_token15,
      anon_sym_u2217,
      aux_sym_result_code_token16,
      anon_sym_u2731,
      aux_sym_result_code_token17,
      anon_sym_u204e,
      aux_sym_result_code_token18,
      anon_sym_u066d,
      aux_sym_result_code_token19,
      aux_sym_result_code_token20,
      aux_sym_result_code_token21,
      aux_sym_result_code_token22,
      aux_sym_result_code_token23,
  [4547] = 2,
    ACTIONS(369), 12,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      sym_check_or_mate_condition,
      aux_sym_annotation_token1,
      anon_sym_1,
      anon_sym_O,
      anon_sym_0,
      anon_sym_o,
      anon_sym_u00bd,
      aux_sym_result_code_token14,
    ACTIONS(367), 26,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      anon_sym_SEMI,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      anon_sym_STAR,
      aux_sym_result_code_token15,
      anon_sym_u2217,
      aux_sym_result_code_token16,
      anon_sym_u2731,
      aux_sym_result_code_token17,
      anon_sym_u204e,
      aux_sym_result_code_token18,
      anon_sym_u066d,
      aux_sym_result_code_token19,
      aux_sym_result_code_token20,
      aux_sym_result_code_token21,
      aux_sym_result_code_token22,
      aux_sym_result_code_token23,
  [4590] = 3,
    ACTIONS(466), 1,
      sym_check_or_mate_condition,
    ACTIONS(299), 11,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      aux_sym_annotation_token1,
      anon_sym_1,
      anon_sym_O,
      anon_sym_0,
      anon_sym_o,
      anon_sym_u00bd,
      aux_sym_result_code_token14,
    ACTIONS(297), 26,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      anon_sym_SEMI,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      anon_sym_STAR,
      aux_sym_result_code_token15,
      anon_sym_u2217,
      aux_sym_result_code_token16,
      anon_sym_u2731,
      aux_sym_result_code_token17,
      anon_sym_u204e,
      aux_sym_result_code_token18,
      anon_sym_u066d,
      aux_sym_result_code_token19,
      aux_sym_result_code_token20,
      aux_sym_result_code_token21,
      aux_sym_result_code_token22,
      aux_sym_result_code_token23,
  [4635] = 3,
    ACTIONS(468), 1,
      sym_check_or_mate_condition,
    ACTIONS(285), 11,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      aux_sym_annotation_token1,
      anon_sym_1,
      anon_sym_O,
      anon_sym_0,
      anon_sym_o,
      anon_sym_u00bd,
      aux_sym_result_code_token14,
    ACTIONS(283), 26,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      anon_sym_SEMI,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      anon_sym_STAR,
      aux_sym_result_code_token15,
      anon_sym_u2217,
      aux_sym_result_code_token16,
      anon_sym_u2731,
      aux_sym_result_code_token17,
      anon_sym_u204e,
      aux_sym_result_code_token18,
      anon_sym_u066d,
      aux_sym_result_code_token19,
      aux_sym_result_code_token20,
      aux_sym_result_code_token21,
      aux_sym_result_code_token22,
      aux_sym_result_code_token23,
  [4680] = 3,
    ACTIONS(470), 1,
      aux_sym_rest_of_line_comment_token1,
    ACTIONS(291), 2,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
    ACTIONS(293), 35,
      anon_sym_SEMI,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      aux_sym_annotation_token1,
      anon_sym_1,
      anon_sym_O,
      anon_sym_0,
      anon_sym_o,
      anon_sym_u00bd,
      aux_sym_result_code_token14,
      anon_sym_STAR,
      aux_sym_result_code_token15,
      anon_sym_u2217,
      aux_sym_result_code_token16,
      anon_sym_u2731,
      aux_sym_result_code_token17,
      anon_sym_u204e,
      aux_sym_result_code_token18,
      anon_sym_u066d,
      aux_sym_result_code_token19,
      aux_sym_result_code_token20,
      aux_sym_result_code_token21,
      aux_sym_result_code_token22,
      aux_sym_result_code_token23,
  [4725] = 2,
    ACTIONS(321), 12,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      sym_check_or_mate_condition,
      aux_sym_annotation_token1,
      anon_sym_1,
      anon_sym_O,
      anon_sym_0,
      anon_sym_o,
      anon_sym_u00bd,
      aux_sym_result_code_token14,
    ACTIONS(319), 26,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      anon_sym_SEMI,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      anon_sym_STAR,
      aux_sym_result_code_token15,
      anon_sym_u2217,
      aux_sym_result_code_token16,
      anon_sym_u2731,
      aux_sym_result_code_token17,
      anon_sym_u204e,
      aux_sym_result_code_token18,
      anon_sym_u066d,
      aux_sym_result_code_token19,
      aux_sym_result_code_token20,
      aux_sym_result_code_token21,
      aux_sym_result_code_token22,
      aux_sym_result_code_token23,
  [4768] = 2,
    ACTIONS(325), 12,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      sym_check_or_mate_condition,
      aux_sym_annotation_token1,
      anon_sym_1,
      anon_sym_O,
      anon_sym_0,
      anon_sym_o,
      anon_sym_u00bd,
      aux_sym_result_code_token14,
    ACTIONS(323), 26,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      anon_sym_SEMI,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      anon_sym_STAR,
      aux_sym_result_code_token15,
      anon_sym_u2217,
      aux_sym_result_code_token16,
      anon_sym_u2731,
      aux_sym_result_code_token17,
      anon_sym_u204e,
      aux_sym_result_code_token18,
      anon_sym_u066d,
      aux_sym_result_code_token19,
      aux_sym_result_code_token20,
      aux_sym_result_code_token21,
      aux_sym_result_code_token22,
      aux_sym_result_code_token23,
  [4811] = 2,
    ACTIONS(329), 12,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      sym_check_or_mate_condition,
      aux_sym_annotation_token1,
      anon_sym_1,
      anon_sym_O,
      anon_sym_0,
      anon_sym_o,
      anon_sym_u00bd,
      aux_sym_result_code_token14,
    ACTIONS(327), 26,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      anon_sym_SEMI,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      anon_sym_STAR,
      aux_sym_result_code_token15,
      anon_sym_u2217,
      aux_sym_result_code_token16,
      anon_sym_u2731,
      aux_sym_result_code_token17,
      anon_sym_u204e,
      aux_sym_result_code_token18,
      anon_sym_u066d,
      aux_sym_result_code_token19,
      aux_sym_result_code_token20,
      aux_sym_result_code_token21,
      aux_sym_result_code_token22,
      aux_sym_result_code_token23,
  [4854] = 2,
    ACTIONS(333), 12,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      sym_check_or_mate_condition,
      aux_sym_annotation_token1,
      anon_sym_1,
      anon_sym_O,
      anon_sym_0,
      anon_sym_o,
      anon_sym_u00bd,
      aux_sym_result_code_token14,
    ACTIONS(331), 26,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      anon_sym_SEMI,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      anon_sym_STAR,
      aux_sym_result_code_token15,
      anon_sym_u2217,
      aux_sym_result_code_token16,
      anon_sym_u2731,
      aux_sym_result_code_token17,
      anon_sym_u204e,
      aux_sym_result_code_token18,
      anon_sym_u066d,
      aux_sym_result_code_token19,
      aux_sym_result_code_token20,
      aux_sym_result_code_token21,
      aux_sym_result_code_token22,
      aux_sym_result_code_token23,
  [4897] = 2,
    ACTIONS(337), 12,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      sym_check_or_mate_condition,
      aux_sym_annotation_token1,
      anon_sym_1,
      anon_sym_O,
      anon_sym_0,
      anon_sym_o,
      anon_sym_u00bd,
      aux_sym_result_code_token14,
    ACTIONS(335), 26,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      anon_sym_SEMI,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      anon_sym_STAR,
      aux_sym_result_code_token15,
      anon_sym_u2217,
      aux_sym_result_code_token16,
      anon_sym_u2731,
      aux_sym_result_code_token17,
      anon_sym_u204e,
      aux_sym_result_code_token18,
      anon_sym_u066d,
      aux_sym_result_code_token19,
      aux_sym_result_code_token20,
      aux_sym_result_code_token21,
      aux_sym_result_code_token22,
      aux_sym_result_code_token23,
  [4940] = 2,
    ACTIONS(227), 12,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      sym_check_or_mate_condition,
      aux_sym_annotation_token1,
      anon_sym_1,
      anon_sym_O,
      anon_sym_0,
      anon_sym_o,
      anon_sym_u00bd,
      aux_sym_result_code_token14,
    ACTIONS(225), 26,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      anon_sym_SEMI,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      anon_sym_STAR,
      aux_sym_result_code_token15,
      anon_sym_u2217,
      aux_sym_result_code_token16,
      anon_sym_u2731,
      aux_sym_result_code_token17,
      anon_sym_u204e,
      aux_sym_result_code_token18,
      anon_sym_u066d,
      aux_sym_result_code_token19,
      aux_sym_result_code_token20,
      aux_sym_result_code_token21,
      aux_sym_result_code_token22,
      aux_sym_result_code_token23,
  [4983] = 3,
    ACTIONS(472), 1,
      aux_sym_rest_of_line_comment_token1,
    ACTIONS(291), 2,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
    ACTIONS(293), 35,
      sym__empty_line,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      sym_variation_delimiter_open,
      anon_sym_LBRACE,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      aux_sym_annotation_token1,
      anon_sym_1,
      anon_sym_O,
      anon_sym_0,
      anon_sym_o,
      anon_sym_u00bd,
      aux_sym_result_code_token14,
      anon_sym_STAR,
      aux_sym_result_code_token15,
      anon_sym_u2217,
      aux_sym_result_code_token16,
      anon_sym_u2731,
      aux_sym_result_code_token17,
      anon_sym_u204e,
      aux_sym_result_code_token18,
      anon_sym_u066d,
      aux_sym_result_code_token19,
      aux_sym_result_code_token20,
      aux_sym_result_code_token21,
      aux_sym_result_code_token22,
      aux_sym_result_code_token23,
  [5028] = 2,
    ACTIONS(317), 12,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      sym_check_or_mate_condition,
      aux_sym_annotation_token1,
      anon_sym_1,
      anon_sym_O,
      anon_sym_0,
      anon_sym_o,
      anon_sym_u00bd,
      aux_sym_result_code_token14,
    ACTIONS(315), 26,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      anon_sym_SEMI,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      anon_sym_STAR,
      aux_sym_result_code_token15,
      anon_sym_u2217,
      aux_sym_result_code_token16,
      anon_sym_u2731,
      aux_sym_result_code_token17,
      anon_sym_u204e,
      aux_sym_result_code_token18,
      anon_sym_u066d,
      aux_sym_result_code_token19,
      aux_sym_result_code_token20,
      aux_sym_result_code_token21,
      aux_sym_result_code_token22,
      aux_sym_result_code_token23,
  [5071] = 2,
    ACTIONS(474), 3,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      sym__empty_line,
    ACTIONS(476), 34,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      sym_variation_delimiter_open,
      anon_sym_LBRACE,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      aux_sym_annotation_token1,
      anon_sym_1,
      anon_sym_O,
      anon_sym_0,
      anon_sym_o,
      anon_sym_u00bd,
      aux_sym_result_code_token14,
      anon_sym_STAR,
      aux_sym_result_code_token15,
      anon_sym_u2217,
      aux_sym_result_code_token16,
      anon_sym_u2731,
      aux_sym_result_code_token17,
      anon_sym_u204e,
      aux_sym_result_code_token18,
      anon_sym_u066d,
      aux_sym_result_code_token19,
      aux_sym_result_code_token20,
      aux_sym_result_code_token21,
      aux_sym_result_code_token22,
      aux_sym_result_code_token23,
  [5113] = 28,
    ACTIONS(29), 1,
      sym__full_line_comment_delimiter_bol_assertion,
    ACTIONS(105), 1,
      anon_sym_SEMI,
    ACTIONS(109), 1,
      anon_sym_LBRACE,
    ACTIONS(478), 1,
      sym_variation_delimiter_open,
    ACTIONS(480), 1,
      anon_sym_RPAREN,
    ACTIONS(482), 1,
      sym_move_number,
    ACTIONS(484), 1,
      sym__san_file,
    ACTIONS(486), 1,
      sym__san_major_or_minor_piece,
    ACTIONS(488), 1,
      anon_sym_P,
    ACTIONS(492), 1,
      anon_sym_AT2,
    ACTIONS(496), 1,
      aux_sym_annotation_token1,
    ACTIONS(498), 1,
      sym__novelty_glyph_before_punctuation,
    STATE(62), 1,
      sym_variation_delimiter_close,
    STATE(118), 1,
      aux_sym_variation_movetext_repeat1,
    STATE(164), 1,
      sym__lan_move_by_coordinates,
    STATE(185), 1,
      sym_lan_move,
    STATE(196), 1,
      sym_san_move,
    STATE(198), 1,
      sym_annotation,
    STATE(208), 1,
      sym_inline_comment_delimiter_open,
    STATE(227), 1,
      sym__san_square_any,
    STATE(240), 1,
      sym__san_square_promoting,
    STATE(282), 1,
      sym_variation_movetext,
    STATE(302), 1,
      sym_rest_of_line_comment_delimiter_open,
    ACTIONS(490), 2,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
    ACTIONS(494), 2,
      sym__san_move_castle,
      sym__san_null_move,
    STATE(193), 2,
      sym_rest_of_line_comment,
      sym_inline_comment,
    STATE(194), 2,
      sym__variation_movetext_element,
      sym_recursive_variation,
    STATE(163), 6,
      sym__san_move_piece,
      sym__san_square_nonpromoting,
      sym__san_move_pawn,
      sym__san_drop_pawn,
      sym__san_move_major_or_minor_piece,
      sym__san_drop_major_or_minor_piece,
  [5207] = 2,
    ACTIONS(500), 3,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      sym__empty_line,
    ACTIONS(502), 34,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      sym_variation_delimiter_open,
      anon_sym_LBRACE,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      aux_sym_annotation_token1,
      anon_sym_1,
      anon_sym_O,
      anon_sym_0,
      anon_sym_o,
      anon_sym_u00bd,
      aux_sym_result_code_token14,
      anon_sym_STAR,
      aux_sym_result_code_token15,
      anon_sym_u2217,
      aux_sym_result_code_token16,
      anon_sym_u2731,
      aux_sym_result_code_token17,
      anon_sym_u204e,
      aux_sym_result_code_token18,
      anon_sym_u066d,
      aux_sym_result_code_token19,
      aux_sym_result_code_token20,
      aux_sym_result_code_token21,
      aux_sym_result_code_token22,
      aux_sym_result_code_token23,
  [5249] = 2,
    ACTIONS(399), 11,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      aux_sym_annotation_token1,
      anon_sym_1,
      anon_sym_O,
      anon_sym_0,
      anon_sym_o,
      anon_sym_u00bd,
      aux_sym_result_code_token14,
    ACTIONS(397), 26,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      anon_sym_SEMI,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      anon_sym_STAR,
      aux_sym_result_code_token15,
      anon_sym_u2217,
      aux_sym_result_code_token16,
      anon_sym_u2731,
      aux_sym_result_code_token17,
      anon_sym_u204e,
      aux_sym_result_code_token18,
      anon_sym_u066d,
      aux_sym_result_code_token19,
      aux_sym_result_code_token20,
      aux_sym_result_code_token21,
      aux_sym_result_code_token22,
      aux_sym_result_code_token23,
  [5291] = 2,
    ACTIONS(421), 11,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      aux_sym_annotation_token1,
      anon_sym_1,
      anon_sym_O,
      anon_sym_0,
      anon_sym_o,
      anon_sym_u00bd,
      aux_sym_result_code_token14,
    ACTIONS(419), 26,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      anon_sym_SEMI,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      anon_sym_STAR,
      aux_sym_result_code_token15,
      anon_sym_u2217,
      aux_sym_result_code_token16,
      anon_sym_u2731,
      aux_sym_result_code_token17,
      anon_sym_u204e,
      aux_sym_result_code_token18,
      anon_sym_u066d,
      aux_sym_result_code_token19,
      aux_sym_result_code_token20,
      aux_sym_result_code_token21,
      aux_sym_result_code_token22,
      aux_sym_result_code_token23,
  [5333] = 2,
    ACTIONS(443), 11,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      aux_sym_annotation_token1,
      anon_sym_1,
      anon_sym_O,
      anon_sym_0,
      anon_sym_o,
      anon_sym_u00bd,
      aux_sym_result_code_token14,
    ACTIONS(441), 26,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      anon_sym_SEMI,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      anon_sym_STAR,
      aux_sym_result_code_token15,
      anon_sym_u2217,
      aux_sym_result_code_token16,
      anon_sym_u2731,
      aux_sym_result_code_token17,
      anon_sym_u204e,
      aux_sym_result_code_token18,
      anon_sym_u066d,
      aux_sym_result_code_token19,
      aux_sym_result_code_token20,
      aux_sym_result_code_token21,
      aux_sym_result_code_token22,
      aux_sym_result_code_token23,
  [5375] = 2,
    ACTIONS(451), 11,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      aux_sym_annotation_token1,
      anon_sym_1,
      anon_sym_O,
      anon_sym_0,
      anon_sym_o,
      anon_sym_u00bd,
      aux_sym_result_code_token14,
    ACTIONS(449), 26,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      anon_sym_SEMI,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      anon_sym_STAR,
      aux_sym_result_code_token15,
      anon_sym_u2217,
      aux_sym_result_code_token16,
      anon_sym_u2731,
      aux_sym_result_code_token17,
      anon_sym_u204e,
      aux_sym_result_code_token18,
      anon_sym_u066d,
      aux_sym_result_code_token19,
      aux_sym_result_code_token20,
      aux_sym_result_code_token21,
      aux_sym_result_code_token22,
      aux_sym_result_code_token23,
  [5417] = 2,
    ACTIONS(403), 11,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      aux_sym_annotation_token1,
      anon_sym_1,
      anon_sym_O,
      anon_sym_0,
      anon_sym_o,
      anon_sym_u00bd,
      aux_sym_result_code_token14,
    ACTIONS(401), 26,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      anon_sym_SEMI,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      anon_sym_STAR,
      aux_sym_result_code_token15,
      anon_sym_u2217,
      aux_sym_result_code_token16,
      anon_sym_u2731,
      aux_sym_result_code_token17,
      anon_sym_u204e,
      aux_sym_result_code_token18,
      anon_sym_u066d,
      aux_sym_result_code_token19,
      aux_sym_result_code_token20,
      aux_sym_result_code_token21,
      aux_sym_result_code_token22,
      aux_sym_result_code_token23,
  [5459] = 2,
    ACTIONS(411), 11,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      aux_sym_annotation_token1,
      anon_sym_1,
      anon_sym_O,
      anon_sym_0,
      anon_sym_o,
      anon_sym_u00bd,
      aux_sym_result_code_token14,
    ACTIONS(409), 26,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      anon_sym_SEMI,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      anon_sym_STAR,
      aux_sym_result_code_token15,
      anon_sym_u2217,
      aux_sym_result_code_token16,
      anon_sym_u2731,
      aux_sym_result_code_token17,
      anon_sym_u204e,
      aux_sym_result_code_token18,
      anon_sym_u066d,
      aux_sym_result_code_token19,
      aux_sym_result_code_token20,
      aux_sym_result_code_token21,
      aux_sym_result_code_token22,
      aux_sym_result_code_token23,
  [5501] = 2,
    ACTIONS(425), 11,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      aux_sym_annotation_token1,
      anon_sym_1,
      anon_sym_O,
      anon_sym_0,
      anon_sym_o,
      anon_sym_u00bd,
      aux_sym_result_code_token14,
    ACTIONS(423), 26,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      anon_sym_SEMI,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      anon_sym_STAR,
      aux_sym_result_code_token15,
      anon_sym_u2217,
      aux_sym_result_code_token16,
      anon_sym_u2731,
      aux_sym_result_code_token17,
      anon_sym_u204e,
      aux_sym_result_code_token18,
      anon_sym_u066d,
      aux_sym_result_code_token19,
      aux_sym_result_code_token20,
      aux_sym_result_code_token21,
      aux_sym_result_code_token22,
      aux_sym_result_code_token23,
  [5543] = 2,
    ACTIONS(383), 11,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      aux_sym_annotation_token1,
      anon_sym_1,
      anon_sym_O,
      anon_sym_0,
      anon_sym_o,
      anon_sym_u00bd,
      aux_sym_result_code_token14,
    ACTIONS(381), 26,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      anon_sym_SEMI,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      anon_sym_STAR,
      aux_sym_result_code_token15,
      anon_sym_u2217,
      aux_sym_result_code_token16,
      anon_sym_u2731,
      aux_sym_result_code_token17,
      anon_sym_u204e,
      aux_sym_result_code_token18,
      anon_sym_u066d,
      aux_sym_result_code_token19,
      aux_sym_result_code_token20,
      aux_sym_result_code_token21,
      aux_sym_result_code_token22,
      aux_sym_result_code_token23,
  [5585] = 2,
    ACTIONS(391), 11,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      aux_sym_annotation_token1,
      anon_sym_1,
      anon_sym_O,
      anon_sym_0,
      anon_sym_o,
      anon_sym_u00bd,
      aux_sym_result_code_token14,
    ACTIONS(389), 26,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      anon_sym_SEMI,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      anon_sym_STAR,
      aux_sym_result_code_token15,
      anon_sym_u2217,
      aux_sym_result_code_token16,
      anon_sym_u2731,
      aux_sym_result_code_token17,
      anon_sym_u204e,
      aux_sym_result_code_token18,
      anon_sym_u066d,
      aux_sym_result_code_token19,
      aux_sym_result_code_token20,
      aux_sym_result_code_token21,
      aux_sym_result_code_token22,
      aux_sym_result_code_token23,
  [5627] = 2,
    ACTIONS(387), 11,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      aux_sym_annotation_token1,
      anon_sym_1,
      anon_sym_O,
      anon_sym_0,
      anon_sym_o,
      anon_sym_u00bd,
      aux_sym_result_code_token14,
    ACTIONS(385), 26,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      anon_sym_SEMI,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      anon_sym_STAR,
      aux_sym_result_code_token15,
      anon_sym_u2217,
      aux_sym_result_code_token16,
      anon_sym_u2731,
      aux_sym_result_code_token17,
      anon_sym_u204e,
      aux_sym_result_code_token18,
      anon_sym_u066d,
      aux_sym_result_code_token19,
      aux_sym_result_code_token20,
      aux_sym_result_code_token21,
      aux_sym_result_code_token22,
      aux_sym_result_code_token23,
  [5669] = 2,
    ACTIONS(447), 11,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      aux_sym_annotation_token1,
      anon_sym_1,
      anon_sym_O,
      anon_sym_0,
      anon_sym_o,
      anon_sym_u00bd,
      aux_sym_result_code_token14,
    ACTIONS(445), 26,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      anon_sym_SEMI,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      anon_sym_STAR,
      aux_sym_result_code_token15,
      anon_sym_u2217,
      aux_sym_result_code_token16,
      anon_sym_u2731,
      aux_sym_result_code_token17,
      anon_sym_u204e,
      aux_sym_result_code_token18,
      anon_sym_u066d,
      aux_sym_result_code_token19,
      aux_sym_result_code_token20,
      aux_sym_result_code_token21,
      aux_sym_result_code_token22,
      aux_sym_result_code_token23,
  [5711] = 2,
    ACTIONS(504), 3,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      sym__empty_line,
    ACTIONS(506), 34,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      sym_variation_delimiter_open,
      anon_sym_LBRACE,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      aux_sym_annotation_token1,
      anon_sym_1,
      anon_sym_O,
      anon_sym_0,
      anon_sym_o,
      anon_sym_u00bd,
      aux_sym_result_code_token14,
      anon_sym_STAR,
      aux_sym_result_code_token15,
      anon_sym_u2217,
      aux_sym_result_code_token16,
      anon_sym_u2731,
      aux_sym_result_code_token17,
      anon_sym_u204e,
      aux_sym_result_code_token18,
      anon_sym_u066d,
      aux_sym_result_code_token19,
      aux_sym_result_code_token20,
      aux_sym_result_code_token21,
      aux_sym_result_code_token22,
      aux_sym_result_code_token23,
  [5753] = 28,
    ACTIONS(29), 1,
      sym__full_line_comment_delimiter_bol_assertion,
    ACTIONS(105), 1,
      anon_sym_SEMI,
    ACTIONS(109), 1,
      anon_sym_LBRACE,
    ACTIONS(478), 1,
      sym_variation_delimiter_open,
    ACTIONS(482), 1,
      sym_move_number,
    ACTIONS(484), 1,
      sym__san_file,
    ACTIONS(486), 1,
      sym__san_major_or_minor_piece,
    ACTIONS(488), 1,
      anon_sym_P,
    ACTIONS(492), 1,
      anon_sym_AT2,
    ACTIONS(496), 1,
      aux_sym_annotation_token1,
    ACTIONS(498), 1,
      sym__novelty_glyph_before_punctuation,
    ACTIONS(508), 1,
      anon_sym_RPAREN,
    STATE(115), 1,
      sym_variation_delimiter_close,
    STATE(118), 1,
      aux_sym_variation_movetext_repeat1,
    STATE(164), 1,
      sym__lan_move_by_coordinates,
    STATE(185), 1,
      sym_lan_move,
    STATE(196), 1,
      sym_san_move,
    STATE(198), 1,
      sym_annotation,
    STATE(208), 1,
      sym_inline_comment_delimiter_open,
    STATE(227), 1,
      sym__san_square_any,
    STATE(240), 1,
      sym__san_square_promoting,
    STATE(268), 1,
      sym_variation_movetext,
    STATE(302), 1,
      sym_rest_of_line_comment_delimiter_open,
    ACTIONS(490), 2,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
    ACTIONS(494), 2,
      sym__san_move_castle,
      sym__san_null_move,
    STATE(193), 2,
      sym_rest_of_line_comment,
      sym_inline_comment,
    STATE(194), 2,
      sym__variation_movetext_element,
      sym_recursive_variation,
    STATE(163), 6,
      sym__san_move_piece,
      sym__san_square_nonpromoting,
      sym__san_move_pawn,
      sym__san_drop_pawn,
      sym__san_move_major_or_minor_piece,
      sym__san_drop_major_or_minor_piece,
  [5847] = 2,
    ACTIONS(379), 11,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      aux_sym_annotation_token1,
      anon_sym_1,
      anon_sym_O,
      anon_sym_0,
      anon_sym_o,
      anon_sym_u00bd,
      aux_sym_result_code_token14,
    ACTIONS(377), 26,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      anon_sym_SEMI,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      anon_sym_STAR,
      aux_sym_result_code_token15,
      anon_sym_u2217,
      aux_sym_result_code_token16,
      anon_sym_u2731,
      aux_sym_result_code_token17,
      anon_sym_u204e,
      aux_sym_result_code_token18,
      anon_sym_u066d,
      aux_sym_result_code_token19,
      aux_sym_result_code_token20,
      aux_sym_result_code_token21,
      aux_sym_result_code_token22,
      aux_sym_result_code_token23,
  [5889] = 28,
    ACTIONS(29), 1,
      sym__full_line_comment_delimiter_bol_assertion,
    ACTIONS(105), 1,
      anon_sym_SEMI,
    ACTIONS(109), 1,
      anon_sym_LBRACE,
    ACTIONS(478), 1,
      sym_variation_delimiter_open,
    ACTIONS(482), 1,
      sym_move_number,
    ACTIONS(484), 1,
      sym__san_file,
    ACTIONS(486), 1,
      sym__san_major_or_minor_piece,
    ACTIONS(488), 1,
      anon_sym_P,
    ACTIONS(492), 1,
      anon_sym_AT2,
    ACTIONS(496), 1,
      aux_sym_annotation_token1,
    ACTIONS(498), 1,
      sym__novelty_glyph_before_punctuation,
    ACTIONS(510), 1,
      anon_sym_RPAREN,
    STATE(118), 1,
      aux_sym_variation_movetext_repeat1,
    STATE(164), 1,
      sym__lan_move_by_coordinates,
    STATE(185), 1,
      sym_lan_move,
    STATE(186), 1,
      sym_variation_delimiter_close,
    STATE(196), 1,
      sym_san_move,
    STATE(198), 1,
      sym_annotation,
    STATE(208), 1,
      sym_inline_comment_delimiter_open,
    STATE(227), 1,
      sym__san_square_any,
    STATE(240), 1,
      sym__san_square_promoting,
    STATE(279), 1,
      sym_variation_movetext,
    STATE(302), 1,
      sym_rest_of_line_comment_delimiter_open,
    ACTIONS(490), 2,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
    ACTIONS(494), 2,
      sym__san_move_castle,
      sym__san_null_move,
    STATE(193), 2,
      sym_rest_of_line_comment,
      sym_inline_comment,
    STATE(194), 2,
      sym__variation_movetext_element,
      sym_recursive_variation,
    STATE(163), 6,
      sym__san_move_piece,
      sym__san_square_nonpromoting,
      sym__san_move_pawn,
      sym__san_drop_pawn,
      sym__san_move_major_or_minor_piece,
      sym__san_drop_major_or_minor_piece,
  [5983] = 2,
    ACTIONS(417), 11,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      aux_sym_annotation_token1,
      anon_sym_1,
      anon_sym_O,
      anon_sym_0,
      anon_sym_o,
      anon_sym_u00bd,
      aux_sym_result_code_token14,
    ACTIONS(415), 26,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      anon_sym_SEMI,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      anon_sym_STAR,
      aux_sym_result_code_token15,
      anon_sym_u2217,
      aux_sym_result_code_token16,
      anon_sym_u2731,
      aux_sym_result_code_token17,
      anon_sym_u204e,
      aux_sym_result_code_token18,
      anon_sym_u066d,
      aux_sym_result_code_token19,
      aux_sym_result_code_token20,
      aux_sym_result_code_token21,
      aux_sym_result_code_token22,
      aux_sym_result_code_token23,
  [6025] = 2,
    ACTIONS(395), 11,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      aux_sym_annotation_token1,
      anon_sym_1,
      anon_sym_O,
      anon_sym_0,
      anon_sym_o,
      anon_sym_u00bd,
      aux_sym_result_code_token14,
    ACTIONS(393), 26,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      anon_sym_SEMI,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      anon_sym_STAR,
      aux_sym_result_code_token15,
      anon_sym_u2217,
      aux_sym_result_code_token16,
      anon_sym_u2731,
      aux_sym_result_code_token17,
      anon_sym_u204e,
      aux_sym_result_code_token18,
      anon_sym_u066d,
      aux_sym_result_code_token19,
      aux_sym_result_code_token20,
      aux_sym_result_code_token21,
      aux_sym_result_code_token22,
      aux_sym_result_code_token23,
  [6067] = 2,
    ACTIONS(385), 3,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      sym__empty_line,
    ACTIONS(387), 34,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      sym_variation_delimiter_open,
      anon_sym_LBRACE,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      aux_sym_annotation_token1,
      anon_sym_1,
      anon_sym_O,
      anon_sym_0,
      anon_sym_o,
      anon_sym_u00bd,
      aux_sym_result_code_token14,
      anon_sym_STAR,
      aux_sym_result_code_token15,
      anon_sym_u2217,
      aux_sym_result_code_token16,
      anon_sym_u2731,
      aux_sym_result_code_token17,
      anon_sym_u204e,
      aux_sym_result_code_token18,
      anon_sym_u066d,
      aux_sym_result_code_token19,
      aux_sym_result_code_token20,
      aux_sym_result_code_token21,
      aux_sym_result_code_token22,
      aux_sym_result_code_token23,
  [6109] = 2,
    ACTIONS(439), 11,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      aux_sym_annotation_token1,
      anon_sym_1,
      anon_sym_O,
      anon_sym_0,
      anon_sym_o,
      anon_sym_u00bd,
      aux_sym_result_code_token14,
    ACTIONS(437), 26,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      anon_sym_SEMI,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      anon_sym_STAR,
      aux_sym_result_code_token15,
      anon_sym_u2217,
      aux_sym_result_code_token16,
      anon_sym_u2731,
      aux_sym_result_code_token17,
      anon_sym_u204e,
      aux_sym_result_code_token18,
      anon_sym_u066d,
      aux_sym_result_code_token19,
      aux_sym_result_code_token20,
      aux_sym_result_code_token21,
      aux_sym_result_code_token22,
      aux_sym_result_code_token23,
  [6151] = 2,
    ACTIONS(407), 11,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      aux_sym_annotation_token1,
      anon_sym_1,
      anon_sym_O,
      anon_sym_0,
      anon_sym_o,
      anon_sym_u00bd,
      aux_sym_result_code_token14,
    ACTIONS(405), 26,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      anon_sym_SEMI,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      anon_sym_STAR,
      aux_sym_result_code_token15,
      anon_sym_u2217,
      aux_sym_result_code_token16,
      anon_sym_u2731,
      aux_sym_result_code_token17,
      anon_sym_u204e,
      aux_sym_result_code_token18,
      anon_sym_u066d,
      aux_sym_result_code_token19,
      aux_sym_result_code_token20,
      aux_sym_result_code_token21,
      aux_sym_result_code_token22,
      aux_sym_result_code_token23,
  [6193] = 5,
    ACTIONS(514), 1,
      aux_sym_tagpair_value_contents_token1,
    STATE(123), 1,
      aux_sym_tagpair_value_contents_repeat1,
    STATE(124), 1,
      sym_tagpair_value_contents,
    STATE(313), 1,
      sym_double_quote,
    ACTIONS(512), 32,
      anon_sym_DQUOTE,
      aux_sym_double_quote_token1,
      anon_sym_uff02,
      aux_sym_double_quote_token2,
      anon_sym_u201c,
      aux_sym_double_quote_token3,
      anon_sym_u201d,
      aux_sym_double_quote_token4,
      anon_sym_u201f,
      aux_sym_double_quote_token5,
      anon_sym_u2033,
      aux_sym_double_quote_token6,
      anon_sym_u2036,
      aux_sym_double_quote_token7,
      anon_sym_u3003,
      aux_sym_double_quote_token8,
      anon_sym_u05f4,
      aux_sym_double_quote_token9,
      anon_sym_u02dd,
      aux_sym_double_quote_token10,
      anon_sym_u02ba,
      aux_sym_double_quote_token11,
      anon_sym_u02f6,
      aux_sym_double_quote_token12,
      anon_sym_u02ee,
      aux_sym_double_quote_token13,
      anon_sym_u05f2,
      aux_sym_double_quote_token14,
      anon_sym_u00ab,
      aux_sym_double_quote_token15,
      anon_sym_u00bb,
      aux_sym_double_quote_token16,
  [6240] = 26,
    ACTIONS(29), 1,
      sym__full_line_comment_delimiter_bol_assertion,
    ACTIONS(105), 1,
      anon_sym_SEMI,
    ACTIONS(109), 1,
      anon_sym_LBRACE,
    ACTIONS(478), 1,
      sym_variation_delimiter_open,
    ACTIONS(482), 1,
      sym_move_number,
    ACTIONS(484), 1,
      sym__san_file,
    ACTIONS(486), 1,
      sym__san_major_or_minor_piece,
    ACTIONS(488), 1,
      anon_sym_P,
    ACTIONS(492), 1,
      anon_sym_AT2,
    ACTIONS(496), 1,
      aux_sym_annotation_token1,
    ACTIONS(498), 1,
      sym__novelty_glyph_before_punctuation,
    ACTIONS(516), 1,
      anon_sym_RPAREN,
    STATE(119), 1,
      aux_sym_variation_movetext_repeat1,
    STATE(164), 1,
      sym__lan_move_by_coordinates,
    STATE(185), 1,
      sym_lan_move,
    STATE(196), 1,
      sym_san_move,
    STATE(198), 1,
      sym_annotation,
    STATE(208), 1,
      sym_inline_comment_delimiter_open,
    STATE(227), 1,
      sym__san_square_any,
    STATE(240), 1,
      sym__san_square_promoting,
    STATE(302), 1,
      sym_rest_of_line_comment_delimiter_open,
    ACTIONS(490), 2,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
    ACTIONS(494), 2,
      sym__san_move_castle,
      sym__san_null_move,
    STATE(193), 2,
      sym_rest_of_line_comment,
      sym_inline_comment,
    STATE(194), 2,
      sym__variation_movetext_element,
      sym_recursive_variation,
    STATE(163), 6,
      sym__san_move_piece,
      sym__san_square_nonpromoting,
      sym__san_move_pawn,
      sym__san_drop_pawn,
      sym__san_move_major_or_minor_piece,
      sym__san_drop_major_or_minor_piece,
  [6328] = 26,
    ACTIONS(518), 1,
      anon_sym_SEMI,
    ACTIONS(521), 1,
      sym_variation_delimiter_open,
    ACTIONS(524), 1,
      anon_sym_RPAREN,
    ACTIONS(526), 1,
      anon_sym_LBRACE,
    ACTIONS(529), 1,
      sym_move_number,
    ACTIONS(532), 1,
      sym__san_file,
    ACTIONS(535), 1,
      sym__san_major_or_minor_piece,
    ACTIONS(538), 1,
      anon_sym_P,
    ACTIONS(544), 1,
      anon_sym_AT2,
    ACTIONS(550), 1,
      aux_sym_annotation_token1,
    ACTIONS(553), 1,
      sym__full_line_comment_delimiter_bol_assertion,
    ACTIONS(556), 1,
      sym__novelty_glyph_before_punctuation,
    STATE(119), 1,
      aux_sym_variation_movetext_repeat1,
    STATE(164), 1,
      sym__lan_move_by_coordinates,
    STATE(185), 1,
      sym_lan_move,
    STATE(196), 1,
      sym_san_move,
    STATE(198), 1,
      sym_annotation,
    STATE(208), 1,
      sym_inline_comment_delimiter_open,
    STATE(227), 1,
      sym__san_square_any,
    STATE(240), 1,
      sym__san_square_promoting,
    STATE(302), 1,
      sym_rest_of_line_comment_delimiter_open,
    ACTIONS(541), 2,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
    ACTIONS(547), 2,
      sym__san_move_castle,
      sym__san_null_move,
    STATE(193), 2,
      sym_rest_of_line_comment,
      sym_inline_comment,
    STATE(194), 2,
      sym__variation_movetext_element,
      sym_recursive_variation,
    STATE(163), 6,
      sym__san_move_piece,
      sym__san_square_nonpromoting,
      sym__san_move_pawn,
      sym__san_drop_pawn,
      sym__san_move_major_or_minor_piece,
      sym__san_drop_major_or_minor_piece,
  [6416] = 2,
    ACTIONS(559), 1,
      anon_sym_RBRACK,
    ACTIONS(561), 33,
      anon_sym_DQUOTE,
      aux_sym_double_quote_token1,
      anon_sym_uff02,
      aux_sym_double_quote_token2,
      anon_sym_u201c,
      aux_sym_double_quote_token3,
      anon_sym_u201d,
      aux_sym_double_quote_token4,
      anon_sym_u201f,
      aux_sym_double_quote_token5,
      anon_sym_u2033,
      aux_sym_double_quote_token6,
      anon_sym_u2036,
      aux_sym_double_quote_token7,
      anon_sym_u3003,
      aux_sym_double_quote_token8,
      anon_sym_u05f4,
      aux_sym_double_quote_token9,
      anon_sym_u02dd,
      aux_sym_double_quote_token10,
      anon_sym_u02ba,
      aux_sym_double_quote_token11,
      anon_sym_u02f6,
      aux_sym_double_quote_token12,
      anon_sym_u02ee,
      aux_sym_double_quote_token13,
      anon_sym_u05f2,
      aux_sym_double_quote_token14,
      anon_sym_u00ab,
      aux_sym_double_quote_token15,
      anon_sym_u00bb,
      aux_sym_double_quote_token16,
      aux_sym_tagpair_value_contents_token1,
  [6455] = 3,
    STATE(117), 1,
      sym_double_quote,
    STATE(262), 1,
      sym__tagpair_value,
    ACTIONS(563), 32,
      anon_sym_DQUOTE,
      aux_sym_double_quote_token1,
      anon_sym_uff02,
      aux_sym_double_quote_token2,
      anon_sym_u201c,
      aux_sym_double_quote_token3,
      anon_sym_u201d,
      aux_sym_double_quote_token4,
      anon_sym_u201f,
      aux_sym_double_quote_token5,
      anon_sym_u2033,
      aux_sym_double_quote_token6,
      anon_sym_u2036,
      aux_sym_double_quote_token7,
      anon_sym_u3003,
      aux_sym_double_quote_token8,
      anon_sym_u05f4,
      aux_sym_double_quote_token9,
      anon_sym_u02dd,
      aux_sym_double_quote_token10,
      anon_sym_u02ba,
      aux_sym_double_quote_token11,
      anon_sym_u02f6,
      aux_sym_double_quote_token12,
      anon_sym_u02ee,
      aux_sym_double_quote_token13,
      anon_sym_u05f2,
      aux_sym_double_quote_token14,
      anon_sym_u00ab,
      aux_sym_double_quote_token15,
      anon_sym_u00bb,
      aux_sym_double_quote_token16,
  [6496] = 3,
    ACTIONS(568), 1,
      aux_sym_tagpair_value_contents_token1,
    STATE(122), 1,
      aux_sym_tagpair_value_contents_repeat1,
    ACTIONS(565), 32,
      anon_sym_DQUOTE,
      aux_sym_double_quote_token1,
      anon_sym_uff02,
      aux_sym_double_quote_token2,
      anon_sym_u201c,
      aux_sym_double_quote_token3,
      anon_sym_u201d,
      aux_sym_double_quote_token4,
      anon_sym_u201f,
      aux_sym_double_quote_token5,
      anon_sym_u2033,
      aux_sym_double_quote_token6,
      anon_sym_u2036,
      aux_sym_double_quote_token7,
      anon_sym_u3003,
      aux_sym_double_quote_token8,
      anon_sym_u05f4,
      aux_sym_double_quote_token9,
      anon_sym_u02dd,
      aux_sym_double_quote_token10,
      anon_sym_u02ba,
      aux_sym_double_quote_token11,
      anon_sym_u02f6,
      aux_sym_double_quote_token12,
      anon_sym_u02ee,
      aux_sym_double_quote_token13,
      anon_sym_u05f2,
      aux_sym_double_quote_token14,
      anon_sym_u00ab,
      aux_sym_double_quote_token15,
      anon_sym_u00bb,
      aux_sym_double_quote_token16,
  [6537] = 3,
    ACTIONS(574), 1,
      aux_sym_tagpair_value_contents_token1,
    STATE(122), 1,
      aux_sym_tagpair_value_contents_repeat1,
    ACTIONS(571), 32,
      anon_sym_DQUOTE,
      aux_sym_double_quote_token1,
      anon_sym_uff02,
      aux_sym_double_quote_token2,
      anon_sym_u201c,
      aux_sym_double_quote_token3,
      anon_sym_u201d,
      aux_sym_double_quote_token4,
      anon_sym_u201f,
      aux_sym_double_quote_token5,
      anon_sym_u2033,
      aux_sym_double_quote_token6,
      anon_sym_u2036,
      aux_sym_double_quote_token7,
      anon_sym_u3003,
      aux_sym_double_quote_token8,
      anon_sym_u05f4,
      aux_sym_double_quote_token9,
      anon_sym_u02dd,
      aux_sym_double_quote_token10,
      anon_sym_u02ba,
      aux_sym_double_quote_token11,
      anon_sym_u02f6,
      aux_sym_double_quote_token12,
      anon_sym_u02ee,
      aux_sym_double_quote_token13,
      anon_sym_u05f2,
      aux_sym_double_quote_token14,
      anon_sym_u00ab,
      aux_sym_double_quote_token15,
      anon_sym_u00bb,
      aux_sym_double_quote_token16,
  [6578] = 2,
    STATE(305), 1,
      sym_double_quote,
    ACTIONS(576), 32,
      anon_sym_DQUOTE,
      aux_sym_double_quote_token1,
      anon_sym_uff02,
      aux_sym_double_quote_token2,
      anon_sym_u201c,
      aux_sym_double_quote_token3,
      anon_sym_u201d,
      aux_sym_double_quote_token4,
      anon_sym_u201f,
      aux_sym_double_quote_token5,
      anon_sym_u2033,
      aux_sym_double_quote_token6,
      anon_sym_u2036,
      aux_sym_double_quote_token7,
      anon_sym_u3003,
      aux_sym_double_quote_token8,
      anon_sym_u05f4,
      aux_sym_double_quote_token9,
      anon_sym_u02dd,
      aux_sym_double_quote_token10,
      anon_sym_u02ba,
      aux_sym_double_quote_token11,
      anon_sym_u02f6,
      aux_sym_double_quote_token12,
      anon_sym_u02ee,
      aux_sym_double_quote_token13,
      anon_sym_u05f2,
      aux_sym_double_quote_token14,
      anon_sym_u00ab,
      aux_sym_double_quote_token15,
      anon_sym_u00bb,
      aux_sym_double_quote_token16,
  [6616] = 2,
    ACTIONS(578), 1,
      aux_sym_tagpair_value_contents_token1,
    ACTIONS(559), 32,
      anon_sym_DQUOTE,
      aux_sym_double_quote_token1,
      anon_sym_uff02,
      aux_sym_double_quote_token2,
      anon_sym_u201c,
      aux_sym_double_quote_token3,
      anon_sym_u201d,
      aux_sym_double_quote_token4,
      anon_sym_u201f,
      aux_sym_double_quote_token5,
      anon_sym_u2033,
      aux_sym_double_quote_token6,
      anon_sym_u2036,
      aux_sym_double_quote_token7,
      anon_sym_u3003,
      aux_sym_double_quote_token8,
      anon_sym_u05f4,
      aux_sym_double_quote_token9,
      anon_sym_u02dd,
      aux_sym_double_quote_token10,
      anon_sym_u02ba,
      aux_sym_double_quote_token11,
      anon_sym_u02f6,
      aux_sym_double_quote_token12,
      anon_sym_u02ee,
      aux_sym_double_quote_token13,
      anon_sym_u05f2,
      aux_sym_double_quote_token14,
      anon_sym_u00ab,
      aux_sym_double_quote_token15,
      anon_sym_u00bb,
      aux_sym_double_quote_token16,
  [6654] = 2,
    ACTIONS(582), 10,
      anon_sym_SLASH,
      aux_sym_result_code_token9,
      anon_sym_u2215,
      aux_sym_result_code_token10,
      anon_sym_u2044,
      aux_sym_result_code_token11,
      anon_sym_u27cb,
      aux_sym_result_code_token12,
      anon_sym_u29f8,
      aux_sym_result_code_token13,
    ACTIONS(580), 16,
      anon_sym_DASH,
      aux_sym_result_code_token1,
      anon_sym_u2212,
      aux_sym_result_code_token2,
      anon_sym_u2010,
      aux_sym_result_code_token3,
      anon_sym_u2011,
      aux_sym_result_code_token4,
      anon_sym_u2012,
      aux_sym_result_code_token5,
      anon_sym_u2013,
      aux_sym_result_code_token6,
      anon_sym_u2014,
      aux_sym_result_code_token7,
      anon_sym_u2796,
      aux_sym_result_code_token8,
  [6685] = 8,
    ACTIONS(97), 1,
      anon_sym_1,
    STATE(129), 1,
      aux_sym_trailing_garbage_repeat1,
    STATE(135), 1,
      sym_trailing_garbage,
    STATE(145), 1,
      sym_result_code,
    ACTIONS(101), 2,
      anon_sym_u00bd,
      aux_sym_result_code_token14,
    ACTIONS(584), 2,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    ACTIONS(99), 3,
      anon_sym_O,
      anon_sym_0,
      anon_sym_o,
    ACTIONS(117), 14,
      anon_sym_STAR,
      aux_sym_result_code_token15,
      anon_sym_u2217,
      aux_sym_result_code_token16,
      anon_sym_u2731,
      aux_sym_result_code_token17,
      anon_sym_u204e,
      aux_sym_result_code_token18,
      anon_sym_u066d,
      aux_sym_result_code_token19,
      aux_sym_result_code_token20,
      aux_sym_result_code_token21,
      aux_sym_result_code_token22,
      aux_sym_result_code_token23,
  [6727] = 9,
    ACTIONS(588), 1,
      anon_sym_SEMI,
    ACTIONS(591), 1,
      sym_old_style_twic_section_comment,
    ACTIONS(596), 1,
      anon_sym_LBRACE,
    ACTIONS(599), 1,
      sym__full_line_comment_delimiter_bol_assertion,
    STATE(206), 1,
      sym_inline_comment_delimiter_open,
    STATE(318), 1,
      sym_rest_of_line_comment_delimiter_open,
    ACTIONS(586), 2,
      sym__novelty_glyph_before_punctuation,
      ts_builtin_sym_end,
    STATE(128), 3,
      sym_rest_of_line_comment,
      sym_inline_comment,
      aux_sym_freestanding_comment_repeat1,
    ACTIONS(594), 12,
      anon_sym_LBRACK,
      sym_variation_delimiter_open,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      aux_sym_annotation_token1,
  [6769] = 4,
    STATE(130), 1,
      aux_sym_trailing_garbage_repeat1,
    ACTIONS(602), 2,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    ACTIONS(604), 6,
      anon_sym_1,
      anon_sym_O,
      anon_sym_0,
      anon_sym_o,
      anon_sym_u00bd,
      aux_sym_result_code_token14,
    ACTIONS(606), 14,
      anon_sym_STAR,
      aux_sym_result_code_token15,
      anon_sym_u2217,
      aux_sym_result_code_token16,
      anon_sym_u2731,
      aux_sym_result_code_token17,
      anon_sym_u204e,
      aux_sym_result_code_token18,
      anon_sym_u066d,
      aux_sym_result_code_token19,
      aux_sym_result_code_token20,
      aux_sym_result_code_token21,
      aux_sym_result_code_token22,
      aux_sym_result_code_token23,
  [6801] = 4,
    STATE(130), 1,
      aux_sym_trailing_garbage_repeat1,
    ACTIONS(608), 2,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    ACTIONS(611), 6,
      anon_sym_1,
      anon_sym_O,
      anon_sym_0,
      anon_sym_o,
      anon_sym_u00bd,
      aux_sym_result_code_token14,
    ACTIONS(613), 14,
      anon_sym_STAR,
      aux_sym_result_code_token15,
      anon_sym_u2217,
      aux_sym_result_code_token16,
      anon_sym_u2731,
      aux_sym_result_code_token17,
      anon_sym_u204e,
      aux_sym_result_code_token18,
      anon_sym_u066d,
      aux_sym_result_code_token19,
      aux_sym_result_code_token20,
      aux_sym_result_code_token21,
      aux_sym_result_code_token22,
      aux_sym_result_code_token23,
  [6833] = 9,
    ACTIONS(5), 1,
      anon_sym_SEMI,
    ACTIONS(13), 1,
      anon_sym_LBRACE,
    ACTIONS(29), 1,
      sym__full_line_comment_delimiter_bol_assertion,
    ACTIONS(617), 1,
      sym_old_style_twic_section_comment,
    STATE(206), 1,
      sym_inline_comment_delimiter_open,
    STATE(318), 1,
      sym_rest_of_line_comment_delimiter_open,
    ACTIONS(615), 2,
      sym__novelty_glyph_before_punctuation,
      ts_builtin_sym_end,
    STATE(128), 3,
      sym_rest_of_line_comment,
      sym_inline_comment,
      aux_sym_freestanding_comment_repeat1,
    ACTIONS(619), 12,
      anon_sym_LBRACK,
      sym_variation_delimiter_open,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      aux_sym_annotation_token1,
  [6875] = 9,
    ACTIONS(586), 1,
      sym__novelty_glyph_before_punctuation,
    ACTIONS(588), 1,
      anon_sym_SEMI,
    ACTIONS(596), 1,
      anon_sym_LBRACE,
    ACTIONS(599), 1,
      sym__full_line_comment_delimiter_bol_assertion,
    ACTIONS(621), 1,
      sym_old_style_twic_section_comment,
    STATE(210), 1,
      sym_inline_comment_delimiter_open,
    STATE(324), 1,
      sym_rest_of_line_comment_delimiter_open,
    STATE(132), 3,
      sym_rest_of_line_comment,
      sym_inline_comment,
      aux_sym_freestanding_comment_repeat1,
    ACTIONS(594), 12,
      anon_sym_LBRACK,
      sym_variation_delimiter_open,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      aux_sym_annotation_token1,
  [6916] = 9,
    ACTIONS(5), 1,
      anon_sym_SEMI,
    ACTIONS(13), 1,
      anon_sym_LBRACE,
    ACTIONS(29), 1,
      sym__full_line_comment_delimiter_bol_assertion,
    ACTIONS(615), 1,
      sym__novelty_glyph_before_punctuation,
    ACTIONS(624), 1,
      sym_old_style_twic_section_comment,
    STATE(210), 1,
      sym_inline_comment_delimiter_open,
    STATE(324), 1,
      sym_rest_of_line_comment_delimiter_open,
    STATE(132), 3,
      sym_rest_of_line_comment,
      sym_inline_comment,
      aux_sym_freestanding_comment_repeat1,
    ACTIONS(619), 12,
      anon_sym_LBRACK,
      sym_variation_delimiter_open,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      aux_sym_annotation_token1,
  [6957] = 5,
    ACTIONS(97), 1,
      anon_sym_1,
    STATE(160), 1,
      sym_result_code,
    ACTIONS(101), 2,
      anon_sym_u00bd,
      aux_sym_result_code_token14,
    ACTIONS(99), 3,
      anon_sym_O,
      anon_sym_0,
      anon_sym_o,
    ACTIONS(117), 14,
      anon_sym_STAR,
      aux_sym_result_code_token15,
      anon_sym_u2217,
      aux_sym_result_code_token16,
      anon_sym_u2731,
      aux_sym_result_code_token17,
      anon_sym_u204e,
      aux_sym_result_code_token18,
      anon_sym_u066d,
      aux_sym_result_code_token19,
      aux_sym_result_code_token20,
      aux_sym_result_code_token21,
      aux_sym_result_code_token22,
      aux_sym_result_code_token23,
  [6989] = 5,
    ACTIONS(97), 1,
      anon_sym_1,
    STATE(158), 1,
      sym_result_code,
    ACTIONS(101), 2,
      anon_sym_u00bd,
      aux_sym_result_code_token14,
    ACTIONS(99), 3,
      anon_sym_O,
      anon_sym_0,
      anon_sym_o,
    ACTIONS(117), 14,
      anon_sym_STAR,
      aux_sym_result_code_token15,
      anon_sym_u2217,
      aux_sym_result_code_token16,
      anon_sym_u2731,
      aux_sym_result_code_token17,
      anon_sym_u204e,
      aux_sym_result_code_token18,
      anon_sym_u066d,
      aux_sym_result_code_token19,
      aux_sym_result_code_token20,
      aux_sym_result_code_token21,
      aux_sym_result_code_token22,
      aux_sym_result_code_token23,
  [7021] = 5,
    ACTIONS(97), 1,
      anon_sym_1,
    STATE(148), 1,
      sym_result_code,
    ACTIONS(101), 2,
      anon_sym_u00bd,
      aux_sym_result_code_token14,
    ACTIONS(99), 3,
      anon_sym_O,
      anon_sym_0,
      anon_sym_o,
    ACTIONS(117), 14,
      anon_sym_STAR,
      aux_sym_result_code_token15,
      anon_sym_u2217,
      aux_sym_result_code_token16,
      anon_sym_u2731,
      aux_sym_result_code_token17,
      anon_sym_u204e,
      aux_sym_result_code_token18,
      anon_sym_u066d,
      aux_sym_result_code_token19,
      aux_sym_result_code_token20,
      aux_sym_result_code_token21,
      aux_sym_result_code_token22,
      aux_sym_result_code_token23,
  [7053] = 5,
    ACTIONS(626), 1,
      sym__san_promotable_piece,
    ACTIONS(628), 1,
      sym__san_promotion_symbol,
    STATE(179), 1,
      sym__san_promotion,
    ACTIONS(211), 5,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      sym_check_or_mate_condition,
      aux_sym_annotation_token1,
    ACTIONS(209), 12,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      anon_sym_SEMI,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      sym_move_number,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
  [7084] = 5,
    ACTIONS(628), 1,
      sym__san_promotion_symbol,
    ACTIONS(630), 1,
      sym__san_promotable_piece,
    STATE(180), 1,
      sym__san_promotion,
    ACTIONS(211), 5,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      sym_check_or_mate_condition,
      aux_sym_annotation_token1,
    ACTIONS(209), 12,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      anon_sym_SEMI,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      sym_move_number,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
  [7115] = 4,
    ACTIONS(289), 1,
      sym__san_capture_symbol,
    ACTIONS(223), 2,
      sym__san_file_immediate,
      aux_sym__lan_move_by_coordinates_token1,
    ACTIONS(221), 5,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      sym_check_or_mate_condition,
      aux_sym_annotation_token1,
    ACTIONS(219), 12,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      anon_sym_SEMI,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      sym_move_number,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
  [7144] = 5,
    ACTIONS(632), 1,
      sym__san_file_immediate,
    ACTIONS(634), 1,
      sym__san_capture_symbol,
    STATE(178), 1,
      sym__san_square_any_immediate,
    ACTIONS(227), 5,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      sym_check_or_mate_condition,
      aux_sym_annotation_token1,
    ACTIONS(225), 12,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      anon_sym_SEMI,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      sym_move_number,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
  [7175] = 2,
    ACTIONS(273), 7,
      sym__san_file,
      sym__san_promotable_piece,
      sym__san_major_or_minor_piece,
      sym__san_promotion_symbol,
      anon_sym_P,
      sym_check_or_mate_condition,
      aux_sym_annotation_token1,
    ACTIONS(271), 12,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      anon_sym_SEMI,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      sym_move_number,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
  [7199] = 3,
    ACTIONS(636), 1,
      aux_sym_rest_of_line_comment_token1,
    ACTIONS(291), 3,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      ts_builtin_sym_end,
    ACTIONS(293), 15,
      anon_sym_SEMI,
      sym_old_style_twic_section_comment,
      anon_sym_LBRACK,
      sym_variation_delimiter_open,
      anon_sym_LBRACE,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      aux_sym_annotation_token1,
  [7225] = 2,
    ACTIONS(638), 4,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      ts_builtin_sym_end,
      sym_old_style_twic_section_comment,
    ACTIONS(640), 14,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      sym_variation_delimiter_open,
      anon_sym_LBRACE,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      aux_sym_annotation_token1,
  [7248] = 2,
    ACTIONS(642), 4,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      ts_builtin_sym_end,
      sym_old_style_twic_section_comment,
    ACTIONS(644), 14,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      sym_variation_delimiter_open,
      anon_sym_LBRACE,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      aux_sym_annotation_token1,
  [7271] = 2,
    ACTIONS(646), 4,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      ts_builtin_sym_end,
      sym_old_style_twic_section_comment,
    ACTIONS(648), 14,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      sym_variation_delimiter_open,
      anon_sym_LBRACE,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      aux_sym_annotation_token1,
  [7294] = 2,
    ACTIONS(650), 4,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      ts_builtin_sym_end,
      sym_old_style_twic_section_comment,
    ACTIONS(652), 14,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      sym_variation_delimiter_open,
      anon_sym_LBRACE,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      aux_sym_annotation_token1,
  [7317] = 2,
    ACTIONS(654), 4,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      ts_builtin_sym_end,
      sym_old_style_twic_section_comment,
    ACTIONS(656), 14,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      sym_variation_delimiter_open,
      anon_sym_LBRACE,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      aux_sym_annotation_token1,
  [7340] = 2,
    ACTIONS(658), 4,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      ts_builtin_sym_end,
      sym_old_style_twic_section_comment,
    ACTIONS(660), 14,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      sym_variation_delimiter_open,
      anon_sym_LBRACE,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      aux_sym_annotation_token1,
  [7363] = 2,
    ACTIONS(401), 4,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      ts_builtin_sym_end,
      sym_old_style_twic_section_comment,
    ACTIONS(403), 14,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      sym_variation_delimiter_open,
      anon_sym_LBRACE,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      aux_sym_annotation_token1,
  [7386] = 2,
    ACTIONS(409), 4,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      ts_builtin_sym_end,
      sym_old_style_twic_section_comment,
    ACTIONS(411), 14,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      sym_variation_delimiter_open,
      anon_sym_LBRACE,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      aux_sym_annotation_token1,
  [7409] = 2,
    ACTIONS(662), 4,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      ts_builtin_sym_end,
      sym_old_style_twic_section_comment,
    ACTIONS(664), 14,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      sym_variation_delimiter_open,
      anon_sym_LBRACE,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      aux_sym_annotation_token1,
  [7432] = 2,
    ACTIONS(445), 4,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      ts_builtin_sym_end,
      sym_old_style_twic_section_comment,
    ACTIONS(447), 14,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      sym_variation_delimiter_open,
      anon_sym_LBRACE,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      aux_sym_annotation_token1,
  [7455] = 2,
    ACTIONS(666), 4,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      ts_builtin_sym_end,
      sym_old_style_twic_section_comment,
    ACTIONS(668), 14,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      sym_variation_delimiter_open,
      anon_sym_LBRACE,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      aux_sym_annotation_token1,
  [7478] = 2,
    ACTIONS(670), 4,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      ts_builtin_sym_end,
      sym_old_style_twic_section_comment,
    ACTIONS(672), 14,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      sym_variation_delimiter_open,
      anon_sym_LBRACE,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      aux_sym_annotation_token1,
  [7501] = 2,
    ACTIONS(674), 4,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      ts_builtin_sym_end,
      sym_old_style_twic_section_comment,
    ACTIONS(676), 14,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      sym_variation_delimiter_open,
      anon_sym_LBRACE,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      aux_sym_annotation_token1,
  [7524] = 2,
    ACTIONS(385), 4,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      ts_builtin_sym_end,
      sym_old_style_twic_section_comment,
    ACTIONS(387), 14,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      sym_variation_delimiter_open,
      anon_sym_LBRACE,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      aux_sym_annotation_token1,
  [7547] = 2,
    ACTIONS(678), 4,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      ts_builtin_sym_end,
      sym_old_style_twic_section_comment,
    ACTIONS(680), 14,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      sym_variation_delimiter_open,
      anon_sym_LBRACE,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      aux_sym_annotation_token1,
  [7570] = 2,
    ACTIONS(682), 4,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      ts_builtin_sym_end,
      sym_old_style_twic_section_comment,
    ACTIONS(684), 14,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      sym_variation_delimiter_open,
      anon_sym_LBRACE,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      aux_sym_annotation_token1,
  [7593] = 3,
    ACTIONS(686), 1,
      aux_sym_rest_of_line_comment_token1,
    ACTIONS(291), 2,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
    ACTIONS(293), 15,
      anon_sym_SEMI,
      sym_old_style_twic_section_comment,
      anon_sym_LBRACK,
      sym_variation_delimiter_open,
      anon_sym_LBRACE,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      aux_sym_annotation_token1,
  [7618] = 2,
    ACTIONS(688), 4,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      ts_builtin_sym_end,
      sym_old_style_twic_section_comment,
    ACTIONS(690), 14,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      sym_variation_delimiter_open,
      anon_sym_LBRACE,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      aux_sym_annotation_token1,
  [7641] = 2,
    ACTIONS(321), 5,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      sym_check_or_mate_condition,
      aux_sym_annotation_token1,
    ACTIONS(319), 12,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      anon_sym_SEMI,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      sym_move_number,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
  [7663] = 2,
    ACTIONS(385), 3,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      sym_old_style_twic_section_comment,
    ACTIONS(387), 14,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      sym_variation_delimiter_open,
      anon_sym_LBRACE,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      aux_sym_annotation_token1,
  [7685] = 3,
    ACTIONS(692), 1,
      sym_check_or_mate_condition,
    ACTIONS(299), 4,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      aux_sym_annotation_token1,
    ACTIONS(297), 12,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      anon_sym_SEMI,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      sym_move_number,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
  [7709] = 3,
    ACTIONS(694), 1,
      sym_check_or_mate_condition,
    ACTIONS(285), 4,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      aux_sym_annotation_token1,
    ACTIONS(283), 12,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      anon_sym_SEMI,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      sym_move_number,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
  [7733] = 2,
    ACTIONS(309), 5,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      sym_check_or_mate_condition,
      aux_sym_annotation_token1,
    ACTIONS(307), 12,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      anon_sym_SEMI,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      sym_move_number,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
  [7755] = 2,
    ACTIONS(375), 5,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      sym_check_or_mate_condition,
      aux_sym_annotation_token1,
    ACTIONS(373), 12,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      anon_sym_SEMI,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      sym_move_number,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
  [7777] = 2,
    ACTIONS(317), 5,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      sym_check_or_mate_condition,
      aux_sym_annotation_token1,
    ACTIONS(315), 12,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      anon_sym_SEMI,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      sym_move_number,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
  [7799] = 3,
    ACTIONS(696), 1,
      aux_sym_rest_of_line_comment_token1,
    ACTIONS(291), 2,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
    ACTIONS(293), 14,
      anon_sym_SEMI,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      aux_sym_annotation_token1,
  [7823] = 2,
    ACTIONS(325), 5,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      sym_check_or_mate_condition,
      aux_sym_annotation_token1,
    ACTIONS(323), 12,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      anon_sym_SEMI,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      sym_move_number,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
  [7845] = 2,
    ACTIONS(329), 5,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      sym_check_or_mate_condition,
      aux_sym_annotation_token1,
    ACTIONS(327), 12,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      anon_sym_SEMI,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      sym_move_number,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
  [7867] = 2,
    ACTIONS(333), 5,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      sym_check_or_mate_condition,
      aux_sym_annotation_token1,
    ACTIONS(331), 12,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      anon_sym_SEMI,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      sym_move_number,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
  [7889] = 2,
    ACTIONS(337), 5,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      sym_check_or_mate_condition,
      aux_sym_annotation_token1,
    ACTIONS(335), 12,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      anon_sym_SEMI,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      sym_move_number,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
  [7911] = 2,
    ACTIONS(227), 5,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      sym_check_or_mate_condition,
      aux_sym_annotation_token1,
    ACTIONS(225), 12,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      anon_sym_SEMI,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      sym_move_number,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
  [7933] = 2,
    ACTIONS(342), 5,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      sym_check_or_mate_condition,
      aux_sym_annotation_token1,
    ACTIONS(339), 12,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      anon_sym_SEMI,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      sym_move_number,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
  [7955] = 2,
    ACTIONS(211), 5,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      sym_check_or_mate_condition,
      aux_sym_annotation_token1,
    ACTIONS(209), 12,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      anon_sym_SEMI,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      sym_move_number,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
  [7977] = 2,
    ACTIONS(347), 5,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      sym_check_or_mate_condition,
      aux_sym_annotation_token1,
    ACTIONS(345), 12,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      anon_sym_SEMI,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      sym_move_number,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
  [7999] = 2,
    ACTIONS(351), 5,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      sym_check_or_mate_condition,
      aux_sym_annotation_token1,
    ACTIONS(349), 12,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      anon_sym_SEMI,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      sym_move_number,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
  [8021] = 2,
    ACTIONS(355), 5,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      sym_check_or_mate_condition,
      aux_sym_annotation_token1,
    ACTIONS(353), 12,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      anon_sym_SEMI,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      sym_move_number,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
  [8043] = 2,
    ACTIONS(360), 5,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      sym_check_or_mate_condition,
      aux_sym_annotation_token1,
    ACTIONS(357), 12,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      anon_sym_SEMI,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      sym_move_number,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
  [8065] = 2,
    ACTIONS(365), 5,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      sym_check_or_mate_condition,
      aux_sym_annotation_token1,
    ACTIONS(363), 12,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      anon_sym_SEMI,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      sym_move_number,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
  [8087] = 2,
    ACTIONS(369), 5,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      sym_check_or_mate_condition,
      aux_sym_annotation_token1,
    ACTIONS(367), 12,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      anon_sym_SEMI,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      sym_move_number,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
  [8109] = 2,
    ACTIONS(401), 3,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      sym_old_style_twic_section_comment,
    ACTIONS(403), 14,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      sym_variation_delimiter_open,
      anon_sym_LBRACE,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      aux_sym_annotation_token1,
  [8131] = 2,
    ACTIONS(409), 3,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      sym_old_style_twic_section_comment,
    ACTIONS(411), 14,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      sym_variation_delimiter_open,
      anon_sym_LBRACE,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      aux_sym_annotation_token1,
  [8153] = 2,
    ACTIONS(445), 3,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      sym_old_style_twic_section_comment,
    ACTIONS(447), 14,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      sym_variation_delimiter_open,
      anon_sym_LBRACE,
      sym_move_number,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
      aux_sym_annotation_token1,
  [8175] = 2,
    ACTIONS(700), 4,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      aux_sym_annotation_token1,
    ACTIONS(698), 12,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      anon_sym_SEMI,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      sym_move_number,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
  [8196] = 2,
    ACTIONS(704), 4,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      aux_sym_annotation_token1,
    ACTIONS(702), 12,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      anon_sym_SEMI,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      sym_move_number,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
  [8217] = 2,
    ACTIONS(387), 4,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      aux_sym_annotation_token1,
    ACTIONS(385), 12,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      anon_sym_SEMI,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      sym_move_number,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
  [8238] = 2,
    ACTIONS(447), 4,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      aux_sym_annotation_token1,
    ACTIONS(445), 12,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      anon_sym_SEMI,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      sym_move_number,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
  [8259] = 2,
    ACTIONS(417), 4,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      aux_sym_annotation_token1,
    ACTIONS(415), 12,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      anon_sym_SEMI,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      sym_move_number,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
  [8280] = 1,
    ACTIONS(706), 16,
      anon_sym_DASH,
      aux_sym_result_code_token1,
      anon_sym_u2212,
      aux_sym_result_code_token2,
      anon_sym_u2010,
      aux_sym_result_code_token3,
      anon_sym_u2011,
      aux_sym_result_code_token4,
      anon_sym_u2012,
      aux_sym_result_code_token5,
      anon_sym_u2013,
      aux_sym_result_code_token6,
      anon_sym_u2014,
      aux_sym_result_code_token7,
      anon_sym_u2796,
      aux_sym_result_code_token8,
  [8299] = 1,
    ACTIONS(708), 16,
      anon_sym_DASH,
      aux_sym_result_code_token1,
      anon_sym_u2212,
      aux_sym_result_code_token2,
      anon_sym_u2010,
      aux_sym_result_code_token3,
      anon_sym_u2011,
      aux_sym_result_code_token4,
      anon_sym_u2012,
      aux_sym_result_code_token5,
      anon_sym_u2013,
      aux_sym_result_code_token6,
      anon_sym_u2014,
      aux_sym_result_code_token7,
      anon_sym_u2796,
      aux_sym_result_code_token8,
  [8318] = 2,
    ACTIONS(712), 4,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      aux_sym_annotation_token1,
    ACTIONS(710), 12,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      anon_sym_SEMI,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      sym_move_number,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
  [8339] = 2,
    ACTIONS(716), 4,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      aux_sym_annotation_token1,
    ACTIONS(714), 12,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      anon_sym_SEMI,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      sym_move_number,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
  [8360] = 2,
    ACTIONS(720), 4,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      aux_sym_annotation_token1,
    ACTIONS(718), 12,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      anon_sym_SEMI,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      sym_move_number,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
  [8381] = 2,
    ACTIONS(724), 4,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      aux_sym_annotation_token1,
    ACTIONS(722), 12,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      anon_sym_SEMI,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      sym_move_number,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
  [8402] = 2,
    ACTIONS(728), 4,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      aux_sym_annotation_token1,
    ACTIONS(726), 12,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      anon_sym_SEMI,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      sym_move_number,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
  [8423] = 2,
    ACTIONS(399), 4,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      aux_sym_annotation_token1,
    ACTIONS(397), 12,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      anon_sym_SEMI,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      sym_move_number,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
  [8444] = 2,
    ACTIONS(732), 4,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      aux_sym_annotation_token1,
    ACTIONS(730), 12,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      anon_sym_SEMI,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      sym_move_number,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
  [8465] = 1,
    ACTIONS(734), 16,
      anon_sym_DASH,
      aux_sym_result_code_token1,
      anon_sym_u2212,
      aux_sym_result_code_token2,
      anon_sym_u2010,
      aux_sym_result_code_token3,
      anon_sym_u2011,
      aux_sym_result_code_token4,
      anon_sym_u2012,
      aux_sym_result_code_token5,
      anon_sym_u2013,
      aux_sym_result_code_token6,
      anon_sym_u2014,
      aux_sym_result_code_token7,
      anon_sym_u2796,
      aux_sym_result_code_token8,
  [8484] = 2,
    ACTIONS(403), 4,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      aux_sym_annotation_token1,
    ACTIONS(401), 12,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      anon_sym_SEMI,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      sym_move_number,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
  [8505] = 2,
    ACTIONS(411), 4,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      aux_sym_annotation_token1,
    ACTIONS(409), 12,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      anon_sym_SEMI,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      sym_move_number,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
  [8526] = 2,
    ACTIONS(443), 4,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      aux_sym_annotation_token1,
    ACTIONS(441), 12,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      anon_sym_SEMI,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      sym_move_number,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
  [8547] = 2,
    ACTIONS(451), 4,
      sym__san_file,
      sym__san_major_or_minor_piece,
      anon_sym_P,
      aux_sym_annotation_token1,
    ACTIONS(449), 12,
      sym__full_line_comment_delimiter_bol_assertion,
      sym__novelty_glyph_before_punctuation,
      anon_sym_SEMI,
      sym_variation_delimiter_open,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      sym_move_number,
      anon_sym_u2659,
      anon_sym_u265fufe0e,
      anon_sym_AT2,
      sym__san_move_castle,
      sym__san_null_move,
  [8568] = 1,
    ACTIONS(736), 10,
      anon_sym_SLASH,
      aux_sym_result_code_token9,
      anon_sym_u2215,
      aux_sym_result_code_token10,
      anon_sym_u2044,
      aux_sym_result_code_token11,
      anon_sym_u27cb,
      aux_sym_result_code_token12,
      anon_sym_u29f8,
      aux_sym_result_code_token13,
  [8581] = 8,
    ACTIONS(738), 1,
      anon_sym_LBRACE,
    ACTIONS(740), 1,
      anon_sym_RBRACE,
    ACTIONS(742), 1,
      sym_command_delimiter_open,
    ACTIONS(744), 1,
      aux_sym_inline_comment_text_token1,
    STATE(56), 1,
      sym_inline_comment_delimiter_close,
    STATE(212), 1,
      sym__recursive_inline_comment_delimiter_open,
    STATE(281), 1,
      sym_inline_comment_text,
    STATE(213), 3,
      sym_command,
      sym__recursive_inline_comment,
      aux_sym_inline_comment_text_repeat1,
  [8608] = 8,
    ACTIONS(738), 1,
      anon_sym_LBRACE,
    ACTIONS(742), 1,
      sym_command_delimiter_open,
    ACTIONS(744), 1,
      aux_sym_inline_comment_text_token1,
    ACTIONS(746), 1,
      anon_sym_RBRACE,
    STATE(150), 1,
      sym_inline_comment_delimiter_close,
    STATE(212), 1,
      sym__recursive_inline_comment_delimiter_open,
    STATE(286), 1,
      sym_inline_comment_text,
    STATE(213), 3,
      sym_command,
      sym__recursive_inline_comment,
      aux_sym_inline_comment_text_repeat1,
  [8635] = 8,
    ACTIONS(738), 1,
      anon_sym_LBRACE,
    ACTIONS(742), 1,
      sym_command_delimiter_open,
    ACTIONS(744), 1,
      aux_sym_inline_comment_text_token1,
    ACTIONS(748), 1,
      anon_sym_RBRACE,
    STATE(102), 1,
      sym_inline_comment_delimiter_close,
    STATE(212), 1,
      sym__recursive_inline_comment_delimiter_open,
    STATE(290), 1,
      sym_inline_comment_text,
    STATE(213), 3,
      sym_command,
      sym__recursive_inline_comment,
      aux_sym_inline_comment_text_repeat1,
  [8662] = 8,
    ACTIONS(738), 1,
      anon_sym_LBRACE,
    ACTIONS(742), 1,
      sym_command_delimiter_open,
    ACTIONS(744), 1,
      aux_sym_inline_comment_text_token1,
    ACTIONS(750), 1,
      anon_sym_RBRACE,
    STATE(201), 1,
      sym_inline_comment_delimiter_close,
    STATE(212), 1,
      sym__recursive_inline_comment_delimiter_open,
    STATE(267), 1,
      sym_inline_comment_text,
    STATE(213), 3,
      sym_command,
      sym__recursive_inline_comment,
      aux_sym_inline_comment_text_repeat1,
  [8689] = 8,
    ACTIONS(738), 1,
      anon_sym_LBRACE,
    ACTIONS(742), 1,
      sym_command_delimiter_open,
    ACTIONS(744), 1,
      aux_sym_inline_comment_text_token1,
    ACTIONS(752), 1,
      anon_sym_RBRACE,
    STATE(66), 1,
      sym_inline_comment_delimiter_close,
    STATE(212), 1,
      sym__recursive_inline_comment_delimiter_open,
    STATE(295), 1,
      sym_inline_comment_text,
    STATE(213), 3,
      sym_command,
      sym__recursive_inline_comment,
      aux_sym_inline_comment_text_repeat1,
  [8716] = 8,
    ACTIONS(738), 1,
      anon_sym_LBRACE,
    ACTIONS(742), 1,
      sym_command_delimiter_open,
    ACTIONS(744), 1,
      aux_sym_inline_comment_text_token1,
    ACTIONS(754), 1,
      anon_sym_RBRACE,
    STATE(183), 1,
      sym_inline_comment_delimiter_close,
    STATE(212), 1,
      sym__recursive_inline_comment_delimiter_open,
    STATE(266), 1,
      sym_inline_comment_text,
    STATE(213), 3,
      sym_command,
      sym__recursive_inline_comment,
      aux_sym_inline_comment_text_repeat1,
  [8743] = 7,
    ACTIONS(738), 1,
      anon_sym_LBRACE,
    ACTIONS(742), 1,
      sym_command_delimiter_open,
    ACTIONS(756), 1,
      anon_sym_RBRACE,
    ACTIONS(758), 1,
      aux_sym_inline_comment_text_token1,
    STATE(212), 1,
      sym__recursive_inline_comment_delimiter_open,
    STATE(233), 1,
      sym__recursive_inline_comment_delimiter_close,
    STATE(215), 3,
      sym_command,
      sym__recursive_inline_comment,
      aux_sym__recursive_inline_comment_text,
  [8767] = 7,
    ACTIONS(738), 1,
      anon_sym_LBRACE,
    ACTIONS(742), 1,
      sym_command_delimiter_open,
    ACTIONS(760), 1,
      anon_sym_RBRACE,
    ACTIONS(762), 1,
      aux_sym_inline_comment_text_token1,
    STATE(212), 1,
      sym__recursive_inline_comment_delimiter_open,
    STATE(230), 1,
      sym__recursive_inline_comment_delimiter_close,
    STATE(211), 3,
      sym_command,
      sym__recursive_inline_comment,
      aux_sym__recursive_inline_comment_text,
  [8791] = 6,
    ACTIONS(738), 1,
      anon_sym_LBRACE,
    ACTIONS(742), 1,
      sym_command_delimiter_open,
    ACTIONS(764), 1,
      anon_sym_RBRACE,
    ACTIONS(766), 1,
      aux_sym_inline_comment_text_token1,
    STATE(212), 1,
      sym__recursive_inline_comment_delimiter_open,
    STATE(214), 3,
      sym_command,
      sym__recursive_inline_comment,
      aux_sym_inline_comment_text_repeat1,
  [8812] = 6,
    ACTIONS(768), 1,
      anon_sym_LBRACE,
    ACTIONS(771), 1,
      anon_sym_RBRACE,
    ACTIONS(773), 1,
      sym_command_delimiter_open,
    ACTIONS(776), 1,
      aux_sym_inline_comment_text_token1,
    STATE(212), 1,
      sym__recursive_inline_comment_delimiter_open,
    STATE(214), 3,
      sym_command,
      sym__recursive_inline_comment,
      aux_sym_inline_comment_text_repeat1,
  [8833] = 6,
    ACTIONS(779), 1,
      anon_sym_LBRACE,
    ACTIONS(782), 1,
      anon_sym_RBRACE,
    ACTIONS(784), 1,
      sym_command_delimiter_open,
    ACTIONS(787), 1,
      aux_sym_inline_comment_text_token1,
    STATE(212), 1,
      sym__recursive_inline_comment_delimiter_open,
    STATE(215), 3,
      sym_command,
      sym__recursive_inline_comment,
      aux_sym__recursive_inline_comment_text,
  [8854] = 6,
    ACTIONS(790), 1,
      sym__san_file_immediate,
    ACTIONS(794), 1,
      sym__san_capture_symbol,
    ACTIONS(796), 1,
      anon_sym_AT,
    STATE(75), 1,
      sym__san_square_any_immediate,
    STATE(243), 1,
      sym__san_rank_any,
    ACTIONS(792), 2,
      sym__san_rank_promoting,
      sym__san_rank_nonpromoting,
  [8874] = 6,
    ACTIONS(798), 1,
      sym__san_file_immediate,
    ACTIONS(802), 1,
      sym__san_capture_symbol,
    ACTIONS(804), 1,
      anon_sym_AT,
    STATE(166), 1,
      sym__san_square_any_immediate,
    STATE(244), 1,
      sym__san_rank_any,
    ACTIONS(800), 2,
      sym__san_rank_promoting,
      sym__san_rank_nonpromoting,
  [8894] = 7,
    ACTIONS(806), 1,
      sym__san_file_immediate,
    ACTIONS(808), 1,
      sym__san_rank_promoting,
    ACTIONS(810), 1,
      sym__san_rank_nonpromoting,
    ACTIONS(812), 1,
      sym__san_capture_symbol,
    STATE(73), 1,
      sym__san_square_nonpromoting_immediate,
    STATE(239), 1,
      sym__san_square_promoting_immediate,
    STATE(248), 1,
      sym__san_rank_any,
  [8916] = 7,
    ACTIONS(808), 1,
      sym__san_rank_promoting,
    ACTIONS(814), 1,
      sym__san_file_immediate,
    ACTIONS(816), 1,
      sym__san_rank_nonpromoting,
    ACTIONS(818), 1,
      sym__san_capture_symbol,
    STATE(165), 1,
      sym__san_square_nonpromoting_immediate,
    STATE(242), 1,
      sym__san_square_promoting_immediate,
    STATE(248), 1,
      sym__san_rank_any,
  [8938] = 6,
    ACTIONS(820), 1,
      sym__san_file_immediate,
    ACTIONS(824), 1,
      sym__san_capture_symbol,
    ACTIONS(826), 1,
      anon_sym_AT,
    STATE(46), 1,
      sym__san_square_any_immediate,
    STATE(256), 1,
      sym__san_rank_any,
    ACTIONS(822), 2,
      sym__san_rank_promoting,
      sym__san_rank_nonpromoting,
  [8958] = 7,
    ACTIONS(808), 1,
      sym__san_rank_promoting,
    ACTIONS(828), 1,
      sym__san_file_immediate,
    ACTIONS(830), 1,
      sym__san_rank_nonpromoting,
    ACTIONS(832), 1,
      sym__san_capture_symbol,
    STATE(28), 1,
      sym__san_square_nonpromoting_immediate,
    STATE(248), 1,
      sym__san_rank_any,
    STATE(254), 1,
      sym__san_square_promoting_immediate,
  [8980] = 5,
    ACTIONS(834), 1,
      sym__san_file_immediate,
    ACTIONS(838), 1,
      sym__san_capture_symbol,
    STATE(27), 1,
      sym__san_rank_any,
    STATE(88), 1,
      sym__san_square_any_immediate,
    ACTIONS(836), 2,
      sym__san_rank_promoting,
      sym__san_rank_nonpromoting,
  [8997] = 5,
    ACTIONS(840), 1,
      sym__san_file_immediate,
    ACTIONS(844), 1,
      sym__san_capture_symbol,
    STATE(140), 1,
      sym__san_rank_any,
    STATE(170), 1,
      sym__san_square_any_immediate,
    ACTIONS(842), 2,
      sym__san_rank_promoting,
      sym__san_rank_nonpromoting,
  [9014] = 5,
    ACTIONS(846), 1,
      sym__san_file_immediate,
    ACTIONS(850), 1,
      sym__san_capture_symbol,
    STATE(13), 1,
      sym__san_rank_any,
    STATE(33), 1,
      sym__san_square_any_immediate,
    ACTIONS(848), 2,
      sym__san_rank_promoting,
      sym__san_rank_nonpromoting,
  [9031] = 5,
    ACTIONS(806), 1,
      sym__san_file_immediate,
    ACTIONS(852), 1,
      sym__san_capture_symbol,
    ACTIONS(854), 1,
      aux_sym__lan_move_by_coordinates_token1,
    STATE(73), 1,
      sym__san_square_nonpromoting_immediate,
    STATE(239), 1,
      sym__san_square_promoting_immediate,
  [9047] = 5,
    ACTIONS(828), 1,
      sym__san_file_immediate,
    ACTIONS(856), 1,
      sym__san_capture_symbol,
    ACTIONS(858), 1,
      aux_sym__lan_move_by_coordinates_token1,
    STATE(28), 1,
      sym__san_square_nonpromoting_immediate,
    STATE(254), 1,
      sym__san_square_promoting_immediate,
  [9063] = 5,
    ACTIONS(814), 1,
      sym__san_file_immediate,
    ACTIONS(860), 1,
      sym__san_capture_symbol,
    ACTIONS(862), 1,
      aux_sym__lan_move_by_coordinates_token1,
    STATE(165), 1,
      sym__san_square_nonpromoting_immediate,
    STATE(242), 1,
      sym__san_square_promoting_immediate,
  [9079] = 2,
    ACTIONS(864), 2,
      sym__san_promotable_piece,
      sym__san_promotion_symbol,
    ACTIONS(289), 3,
      sym__san_file_immediate,
      sym__san_capture_symbol,
      aux_sym__lan_move_by_coordinates_token1,
  [9089] = 1,
    ACTIONS(866), 4,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      sym_command_delimiter_open,
      aux_sym_inline_comment_text_token1,
  [9096] = 1,
    ACTIONS(868), 4,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      sym_command_delimiter_open,
      aux_sym_inline_comment_text_token1,
  [9103] = 1,
    ACTIONS(870), 4,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      sym_command_delimiter_open,
      aux_sym_inline_comment_text_token1,
  [9110] = 1,
    ACTIONS(872), 4,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      sym_command_delimiter_open,
      aux_sym_inline_comment_text_token1,
  [9117] = 1,
    ACTIONS(874), 4,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      sym_command_delimiter_open,
      aux_sym_inline_comment_text_token1,
  [9124] = 3,
    ACTIONS(876), 1,
      sym__san_promotable_piece,
    ACTIONS(878), 1,
      sym__san_promotion_symbol,
    STATE(81), 1,
      sym__san_promotion,
  [9134] = 3,
    ACTIONS(880), 1,
      anon_sym_LBRACK,
    ACTIONS(883), 1,
      sym_tagpair_key,
    STATE(235), 1,
      aux_sym_tagpair_delimiter_open_repeat1,
  [9144] = 1,
    ACTIONS(885), 3,
      anon_sym_O,
      anon_sym_0,
      anon_sym_o,
  [9150] = 3,
    ACTIONS(887), 1,
      sym__san_file_immediate,
    STATE(45), 1,
      sym__san_square_promoting_immediate,
    STATE(76), 1,
      sym__san_square_nonpromoting_immediate,
  [9160] = 3,
    ACTIONS(887), 1,
      sym__san_file_immediate,
    STATE(29), 1,
      sym__san_square_promoting_immediate,
    STATE(78), 1,
      sym__san_square_nonpromoting_immediate,
  [9170] = 3,
    ACTIONS(878), 1,
      sym__san_promotion_symbol,
    ACTIONS(889), 1,
      sym__san_promotable_piece,
    STATE(87), 1,
      sym__san_promotion,
  [9180] = 3,
    ACTIONS(891), 1,
      sym__san_promotable_piece,
    ACTIONS(893), 1,
      sym__san_promotion_symbol,
    STATE(165), 1,
      sym__san_promotion,
  [9190] = 3,
    ACTIONS(814), 1,
      sym__san_file_immediate,
    STATE(169), 1,
      sym__san_square_nonpromoting_immediate,
    STATE(250), 1,
      sym__san_square_promoting_immediate,
  [9200] = 3,
    ACTIONS(893), 1,
      sym__san_promotion_symbol,
    ACTIONS(895), 1,
      sym__san_promotable_piece,
    STATE(169), 1,
      sym__san_promotion,
  [9210] = 3,
    ACTIONS(834), 1,
      sym__san_file_immediate,
    ACTIONS(838), 1,
      sym__san_capture_symbol,
    STATE(88), 1,
      sym__san_square_any_immediate,
  [9220] = 3,
    ACTIONS(840), 1,
      sym__san_file_immediate,
    ACTIONS(844), 1,
      sym__san_capture_symbol,
    STATE(170), 1,
      sym__san_square_any_immediate,
  [9230] = 2,
    STATE(173), 1,
      sym__san_rank_any,
    ACTIONS(897), 2,
      sym__san_rank_promoting,
      sym__san_rank_nonpromoting,
  [9238] = 3,
    ACTIONS(899), 1,
      sym__san_file_immediate,
    STATE(137), 1,
      sym__san_square_promoting_immediate,
    STATE(174), 1,
      sym__san_square_nonpromoting_immediate,
  [9248] = 3,
    ACTIONS(899), 1,
      sym__san_file_immediate,
    STATE(138), 1,
      sym__san_square_promoting_immediate,
    STATE(175), 1,
      sym__san_square_nonpromoting_immediate,
  [9258] = 1,
    ACTIONS(901), 3,
      sym__san_file_immediate,
      sym__san_capture_symbol,
      aux_sym__lan_move_by_coordinates_token1,
  [9264] = 3,
    ACTIONS(878), 1,
      sym__san_promotion_symbol,
    ACTIONS(903), 1,
      sym__san_promotable_piece,
    STATE(73), 1,
      sym__san_promotion,
  [9274] = 3,
    ACTIONS(893), 1,
      sym__san_promotion_symbol,
    ACTIONS(905), 1,
      sym__san_promotable_piece,
    STATE(177), 1,
      sym__san_promotion,
  [9284] = 3,
    ACTIONS(806), 1,
      sym__san_file_immediate,
    STATE(87), 1,
      sym__san_square_nonpromoting_immediate,
    STATE(234), 1,
      sym__san_square_promoting_immediate,
  [9294] = 3,
    ACTIONS(907), 1,
      sym__san_promotable_piece,
    ACTIONS(909), 1,
      sym__san_promotion_symbol,
    STATE(28), 1,
      sym__san_promotion,
  [9304] = 3,
    ACTIONS(828), 1,
      sym__san_file_immediate,
    STATE(32), 1,
      sym__san_square_nonpromoting_immediate,
    STATE(255), 1,
      sym__san_square_promoting_immediate,
  [9314] = 3,
    ACTIONS(909), 1,
      sym__san_promotion_symbol,
    ACTIONS(911), 1,
      sym__san_promotable_piece,
    STATE(32), 1,
      sym__san_promotion,
  [9324] = 3,
    ACTIONS(909), 1,
      sym__san_promotion_symbol,
    ACTIONS(913), 1,
      sym__san_promotable_piece,
    STATE(40), 1,
      sym__san_promotion,
  [9334] = 3,
    ACTIONS(846), 1,
      sym__san_file_immediate,
    ACTIONS(850), 1,
      sym__san_capture_symbol,
    STATE(33), 1,
      sym__san_square_any_immediate,
  [9344] = 2,
    STATE(36), 1,
      sym__san_rank_any,
    ACTIONS(915), 2,
      sym__san_rank_promoting,
      sym__san_rank_nonpromoting,
  [9352] = 3,
    ACTIONS(917), 1,
      sym__san_file_immediate,
    STATE(11), 1,
      sym__san_square_promoting_immediate,
    STATE(37), 1,
      sym__san_square_nonpromoting_immediate,
  [9362] = 3,
    ACTIONS(917), 1,
      sym__san_file_immediate,
    STATE(10), 1,
      sym__san_square_promoting_immediate,
    STATE(38), 1,
      sym__san_square_nonpromoting_immediate,
  [9372] = 3,
    ACTIONS(919), 1,
      anon_sym_LBRACK,
    ACTIONS(921), 1,
      sym_tagpair_key,
    STATE(235), 1,
      aux_sym_tagpair_delimiter_open_repeat1,
  [9382] = 2,
    STATE(91), 1,
      sym__san_rank_any,
    ACTIONS(923), 2,
      sym__san_rank_promoting,
      sym__san_rank_nonpromoting,
  [9390] = 3,
    ACTIONS(925), 1,
      anon_sym_RBRACK,
    STATE(68), 1,
      aux_sym_tagpair_delimiter_close_repeat1,
    STATE(108), 1,
      sym_tagpair_delimiter_close,
  [9400] = 2,
    ACTIONS(834), 1,
      sym__san_file_immediate,
    STATE(82), 1,
      sym__san_square_any_immediate,
  [9407] = 2,
    ACTIONS(834), 1,
      sym__san_file_immediate,
    STATE(89), 1,
      sym__san_square_any_immediate,
  [9414] = 1,
    ACTIONS(271), 2,
      sym__san_promotable_piece,
      sym__san_promotion_symbol,
  [9419] = 2,
    ACTIONS(927), 1,
      anon_sym_RBRACE,
    STATE(184), 1,
      sym_inline_comment_delimiter_close,
  [9426] = 2,
    ACTIONS(929), 1,
      anon_sym_RBRACE,
    STATE(188), 1,
      sym_inline_comment_delimiter_close,
  [9433] = 2,
    ACTIONS(508), 1,
      anon_sym_RPAREN,
    STATE(105), 1,
      sym_variation_delimiter_close,
  [9440] = 2,
    ACTIONS(834), 1,
      sym__san_file_immediate,
    STATE(93), 1,
      sym__san_square_any_immediate,
  [9447] = 2,
    ACTIONS(834), 1,
      sym__san_file_immediate,
    STATE(88), 1,
      sym__san_square_any_immediate,
  [9454] = 2,
    ACTIONS(840), 1,
      sym__san_file_immediate,
    STATE(167), 1,
      sym__san_square_any_immediate,
  [9461] = 1,
    ACTIONS(885), 2,
      anon_sym_u00bd,
      aux_sym_result_code_token14,
  [9466] = 2,
    ACTIONS(834), 1,
      sym__san_file_immediate,
    STATE(90), 1,
      sym__san_square_any_immediate,
  [9473] = 2,
    ACTIONS(931), 1,
      sym__san_rank_promoting,
    ACTIONS(933), 1,
      sym__san_rank_nonpromoting,
  [9480] = 2,
    ACTIONS(834), 1,
      sym__san_file_immediate,
    STATE(77), 1,
      sym__san_square_any_immediate,
  [9487] = 2,
    ACTIONS(935), 1,
      sym_command_name,
    STATE(287), 1,
      sym__command_text,
  [9494] = 2,
    ACTIONS(840), 1,
      sym__san_file_immediate,
    STATE(170), 1,
      sym__san_square_any_immediate,
  [9501] = 2,
    ACTIONS(840), 1,
      sym__san_file_immediate,
    STATE(171), 1,
      sym__san_square_any_immediate,
  [9508] = 2,
    ACTIONS(510), 1,
      anon_sym_RPAREN,
    STATE(195), 1,
      sym_variation_delimiter_close,
  [9515] = 2,
    ACTIONS(840), 1,
      sym__san_file_immediate,
    STATE(172), 1,
      sym__san_square_any_immediate,
  [9522] = 2,
    ACTIONS(937), 1,
      anon_sym_RBRACE,
    STATE(64), 1,
      sym_inline_comment_delimiter_close,
  [9529] = 2,
    ACTIONS(480), 1,
      anon_sym_RPAREN,
    STATE(50), 1,
      sym_variation_delimiter_close,
  [9536] = 2,
    ACTIONS(840), 1,
      sym__san_file_immediate,
    STATE(181), 1,
      sym__san_square_any_immediate,
  [9543] = 2,
    ACTIONS(846), 1,
      sym__san_file_immediate,
    STATE(30), 1,
      sym__san_square_any_immediate,
  [9550] = 2,
    ACTIONS(931), 1,
      sym__san_rank_promoting,
    ACTIONS(939), 1,
      sym__san_rank_nonpromoting,
  [9557] = 2,
    ACTIONS(941), 1,
      anon_sym_RBRACE,
    STATE(152), 1,
      sym_inline_comment_delimiter_close,
  [9564] = 2,
    ACTIONS(943), 1,
      anon_sym_RBRACK,
    STATE(232), 1,
      sym_command_delimiter_close,
  [9571] = 2,
    ACTIONS(846), 1,
      sym__san_file_immediate,
    STATE(33), 1,
      sym__san_square_any_immediate,
  [9578] = 2,
    ACTIONS(846), 1,
      sym__san_file_immediate,
    STATE(34), 1,
      sym__san_square_any_immediate,
  [9585] = 2,
    ACTIONS(945), 1,
      anon_sym_RBRACE,
    STATE(107), 1,
      sym_inline_comment_delimiter_close,
  [9592] = 2,
    ACTIONS(846), 1,
      sym__san_file_immediate,
    STATE(35), 1,
      sym__san_square_any_immediate,
  [9599] = 2,
    ACTIONS(931), 1,
      sym__san_rank_promoting,
    ACTIONS(947), 1,
      sym__san_rank_nonpromoting,
  [9606] = 2,
    ACTIONS(846), 1,
      sym__san_file_immediate,
    STATE(41), 1,
      sym__san_square_any_immediate,
  [9613] = 2,
    ACTIONS(846), 1,
      sym__san_file_immediate,
    STATE(44), 1,
      sym__san_square_any_immediate,
  [9620] = 2,
    ACTIONS(949), 1,
      anon_sym_RBRACE,
    STATE(72), 1,
      sym_inline_comment_delimiter_close,
  [9627] = 2,
    ACTIONS(947), 1,
      sym__san_rank_nonpromoting,
    ACTIONS(951), 1,
      sym__san_rank_promoting,
  [9634] = 2,
    ACTIONS(933), 1,
      sym__san_rank_nonpromoting,
    ACTIONS(953), 1,
      sym__san_rank_promoting,
  [9641] = 2,
    ACTIONS(939), 1,
      sym__san_rank_nonpromoting,
    ACTIONS(955), 1,
      sym__san_rank_promoting,
  [9648] = 2,
    ACTIONS(840), 1,
      sym__san_file_immediate,
    STATE(178), 1,
      sym__san_square_any_immediate,
  [9655] = 1,
    ACTIONS(957), 1,
      sym__san_promotable_piece,
  [9659] = 1,
    ACTIONS(959), 1,
      anon_sym_1,
  [9663] = 1,
    ACTIONS(961), 1,
      sym_rest_of_line_comment_text,
  [9667] = 1,
    ACTIONS(963), 1,
      anon_sym_RBRACK,
  [9671] = 1,
    ACTIONS(965), 1,
      anon_sym_2,
  [9675] = 1,
    ACTIONS(967), 1,
      anon_sym_RBRACK,
  [9679] = 1,
    ACTIONS(969), 1,
      sym_rest_of_line_comment_text,
  [9683] = 1,
    ACTIONS(971), 1,
      sym__san_promotable_piece,
  [9687] = 1,
    ACTIONS(578), 1,
      anon_sym_RBRACK,
  [9691] = 1,
    ACTIONS(885), 1,
      anon_sym_1,
  [9695] = 1,
    ACTIONS(973), 1,
      sym_rest_of_line_comment_text,
  [9699] = 1,
    ACTIONS(975), 1,
      anon_sym_2,
  [9703] = 1,
    ACTIONS(977), 1,
      sym__san_promotable_piece,
  [9707] = 1,
    ACTIONS(979), 1,
      anon_sym_RBRACK,
  [9711] = 1,
    ACTIONS(981), 1,
      ts_builtin_sym_end,
  [9715] = 1,
    ACTIONS(983), 1,
      sym_rest_of_line_comment_text,
  [9719] = 1,
    ACTIONS(985), 1,
      sym_tagpair_key,
  [9723] = 1,
    ACTIONS(987), 1,
      sym_rest_of_line_comment_text,
  [9727] = 1,
    ACTIONS(989), 1,
      sym_rest_of_line_comment_text,
  [9731] = 1,
    ACTIONS(991), 1,
      anon_sym_AT,
  [9735] = 1,
    ACTIONS(993), 1,
      sym_rest_of_line_comment_text,
  [9739] = 1,
    ACTIONS(995), 1,
      sym_rest_of_line_comment_text,
  [9743] = 1,
    ACTIONS(997), 1,
      anon_sym_PERCENT,
  [9747] = 1,
    ACTIONS(999), 1,
      sym_command_parameters,
  [9751] = 1,
    ACTIONS(1001), 1,
      sym_rest_of_line_comment_text,
  [9755] = 1,
    ACTIONS(1003), 1,
      anon_sym_AT,
  [9759] = 1,
    ACTIONS(1005), 1,
      anon_sym_AT,
};

static const uint32_t ts_small_parse_table_map[] = {
  [SMALL_STATE(2)] = 0,
  [SMALL_STATE(3)] = 112,
  [SMALL_STATE(4)] = 224,
  [SMALL_STATE(5)] = 344,
  [SMALL_STATE(6)] = 463,
  [SMALL_STATE(7)] = 574,
  [SMALL_STATE(8)] = 685,
  [SMALL_STATE(9)] = 804,
  [SMALL_STATE(10)] = 923,
  [SMALL_STATE(11)] = 978,
  [SMALL_STATE(12)] = 1033,
  [SMALL_STATE(13)] = 1084,
  [SMALL_STATE(14)] = 1139,
  [SMALL_STATE(15)] = 1203,
  [SMALL_STATE(16)] = 1271,
  [SMALL_STATE(17)] = 1339,
  [SMALL_STATE(18)] = 1407,
  [SMALL_STATE(19)] = 1471,
  [SMALL_STATE(20)] = 1519,
  [SMALL_STATE(21)] = 1628,
  [SMALL_STATE(22)] = 1737,
  [SMALL_STATE(23)] = 1785,
  [SMALL_STATE(24)] = 1891,
  [SMALL_STATE(25)] = 1941,
  [SMALL_STATE(26)] = 1989,
  [SMALL_STATE(27)] = 2037,
  [SMALL_STATE(28)] = 2089,
  [SMALL_STATE(29)] = 2135,
  [SMALL_STATE(30)] = 2187,
  [SMALL_STATE(31)] = 2233,
  [SMALL_STATE(32)] = 2279,
  [SMALL_STATE(33)] = 2325,
  [SMALL_STATE(34)] = 2371,
  [SMALL_STATE(35)] = 2417,
  [SMALL_STATE(36)] = 2463,
  [SMALL_STATE(37)] = 2509,
  [SMALL_STATE(38)] = 2555,
  [SMALL_STATE(39)] = 2601,
  [SMALL_STATE(40)] = 2647,
  [SMALL_STATE(41)] = 2693,
  [SMALL_STATE(42)] = 2739,
  [SMALL_STATE(43)] = 2785,
  [SMALL_STATE(44)] = 2831,
  [SMALL_STATE(45)] = 2877,
  [SMALL_STATE(46)] = 2929,
  [SMALL_STATE(47)] = 2975,
  [SMALL_STATE(48)] = 3020,
  [SMALL_STATE(49)] = 3065,
  [SMALL_STATE(50)] = 3110,
  [SMALL_STATE(51)] = 3155,
  [SMALL_STATE(52)] = 3200,
  [SMALL_STATE(53)] = 3245,
  [SMALL_STATE(54)] = 3290,
  [SMALL_STATE(55)] = 3335,
  [SMALL_STATE(56)] = 3380,
  [SMALL_STATE(57)] = 3425,
  [SMALL_STATE(58)] = 3472,
  [SMALL_STATE(59)] = 3517,
  [SMALL_STATE(60)] = 3562,
  [SMALL_STATE(61)] = 3607,
  [SMALL_STATE(62)] = 3658,
  [SMALL_STATE(63)] = 3703,
  [SMALL_STATE(64)] = 3748,
  [SMALL_STATE(65)] = 3793,
  [SMALL_STATE(66)] = 3838,
  [SMALL_STATE(67)] = 3882,
  [SMALL_STATE(68)] = 3926,
  [SMALL_STATE(69)] = 3974,
  [SMALL_STATE(70)] = 4022,
  [SMALL_STATE(71)] = 4066,
  [SMALL_STATE(72)] = 4116,
  [SMALL_STATE(73)] = 4160,
  [SMALL_STATE(74)] = 4203,
  [SMALL_STATE(75)] = 4246,
  [SMALL_STATE(76)] = 4289,
  [SMALL_STATE(77)] = 4332,
  [SMALL_STATE(78)] = 4375,
  [SMALL_STATE(79)] = 4418,
  [SMALL_STATE(80)] = 4461,
  [SMALL_STATE(81)] = 4504,
  [SMALL_STATE(82)] = 4547,
  [SMALL_STATE(83)] = 4590,
  [SMALL_STATE(84)] = 4635,
  [SMALL_STATE(85)] = 4680,
  [SMALL_STATE(86)] = 4725,
  [SMALL_STATE(87)] = 4768,
  [SMALL_STATE(88)] = 4811,
  [SMALL_STATE(89)] = 4854,
  [SMALL_STATE(90)] = 4897,
  [SMALL_STATE(91)] = 4940,
  [SMALL_STATE(92)] = 4983,
  [SMALL_STATE(93)] = 5028,
  [SMALL_STATE(94)] = 5071,
  [SMALL_STATE(95)] = 5113,
  [SMALL_STATE(96)] = 5207,
  [SMALL_STATE(97)] = 5249,
  [SMALL_STATE(98)] = 5291,
  [SMALL_STATE(99)] = 5333,
  [SMALL_STATE(100)] = 5375,
  [SMALL_STATE(101)] = 5417,
  [SMALL_STATE(102)] = 5459,
  [SMALL_STATE(103)] = 5501,
  [SMALL_STATE(104)] = 5543,
  [SMALL_STATE(105)] = 5585,
  [SMALL_STATE(106)] = 5627,
  [SMALL_STATE(107)] = 5669,
  [SMALL_STATE(108)] = 5711,
  [SMALL_STATE(109)] = 5753,
  [SMALL_STATE(110)] = 5847,
  [SMALL_STATE(111)] = 5889,
  [SMALL_STATE(112)] = 5983,
  [SMALL_STATE(113)] = 6025,
  [SMALL_STATE(114)] = 6067,
  [SMALL_STATE(115)] = 6109,
  [SMALL_STATE(116)] = 6151,
  [SMALL_STATE(117)] = 6193,
  [SMALL_STATE(118)] = 6240,
  [SMALL_STATE(119)] = 6328,
  [SMALL_STATE(120)] = 6416,
  [SMALL_STATE(121)] = 6455,
  [SMALL_STATE(122)] = 6496,
  [SMALL_STATE(123)] = 6537,
  [SMALL_STATE(124)] = 6578,
  [SMALL_STATE(125)] = 6616,
  [SMALL_STATE(126)] = 6654,
  [SMALL_STATE(127)] = 6685,
  [SMALL_STATE(128)] = 6727,
  [SMALL_STATE(129)] = 6769,
  [SMALL_STATE(130)] = 6801,
  [SMALL_STATE(131)] = 6833,
  [SMALL_STATE(132)] = 6875,
  [SMALL_STATE(133)] = 6916,
  [SMALL_STATE(134)] = 6957,
  [SMALL_STATE(135)] = 6989,
  [SMALL_STATE(136)] = 7021,
  [SMALL_STATE(137)] = 7053,
  [SMALL_STATE(138)] = 7084,
  [SMALL_STATE(139)] = 7115,
  [SMALL_STATE(140)] = 7144,
  [SMALL_STATE(141)] = 7175,
  [SMALL_STATE(142)] = 7199,
  [SMALL_STATE(143)] = 7225,
  [SMALL_STATE(144)] = 7248,
  [SMALL_STATE(145)] = 7271,
  [SMALL_STATE(146)] = 7294,
  [SMALL_STATE(147)] = 7317,
  [SMALL_STATE(148)] = 7340,
  [SMALL_STATE(149)] = 7363,
  [SMALL_STATE(150)] = 7386,
  [SMALL_STATE(151)] = 7409,
  [SMALL_STATE(152)] = 7432,
  [SMALL_STATE(153)] = 7455,
  [SMALL_STATE(154)] = 7478,
  [SMALL_STATE(155)] = 7501,
  [SMALL_STATE(156)] = 7524,
  [SMALL_STATE(157)] = 7547,
  [SMALL_STATE(158)] = 7570,
  [SMALL_STATE(159)] = 7593,
  [SMALL_STATE(160)] = 7618,
  [SMALL_STATE(161)] = 7641,
  [SMALL_STATE(162)] = 7663,
  [SMALL_STATE(163)] = 7685,
  [SMALL_STATE(164)] = 7709,
  [SMALL_STATE(165)] = 7733,
  [SMALL_STATE(166)] = 7755,
  [SMALL_STATE(167)] = 7777,
  [SMALL_STATE(168)] = 7799,
  [SMALL_STATE(169)] = 7823,
  [SMALL_STATE(170)] = 7845,
  [SMALL_STATE(171)] = 7867,
  [SMALL_STATE(172)] = 7889,
  [SMALL_STATE(173)] = 7911,
  [SMALL_STATE(174)] = 7933,
  [SMALL_STATE(175)] = 7955,
  [SMALL_STATE(176)] = 7977,
  [SMALL_STATE(177)] = 7999,
  [SMALL_STATE(178)] = 8021,
  [SMALL_STATE(179)] = 8043,
  [SMALL_STATE(180)] = 8065,
  [SMALL_STATE(181)] = 8087,
  [SMALL_STATE(182)] = 8109,
  [SMALL_STATE(183)] = 8131,
  [SMALL_STATE(184)] = 8153,
  [SMALL_STATE(185)] = 8175,
  [SMALL_STATE(186)] = 8196,
  [SMALL_STATE(187)] = 8217,
  [SMALL_STATE(188)] = 8238,
  [SMALL_STATE(189)] = 8259,
  [SMALL_STATE(190)] = 8280,
  [SMALL_STATE(191)] = 8299,
  [SMALL_STATE(192)] = 8318,
  [SMALL_STATE(193)] = 8339,
  [SMALL_STATE(194)] = 8360,
  [SMALL_STATE(195)] = 8381,
  [SMALL_STATE(196)] = 8402,
  [SMALL_STATE(197)] = 8423,
  [SMALL_STATE(198)] = 8444,
  [SMALL_STATE(199)] = 8465,
  [SMALL_STATE(200)] = 8484,
  [SMALL_STATE(201)] = 8505,
  [SMALL_STATE(202)] = 8526,
  [SMALL_STATE(203)] = 8547,
  [SMALL_STATE(204)] = 8568,
  [SMALL_STATE(205)] = 8581,
  [SMALL_STATE(206)] = 8608,
  [SMALL_STATE(207)] = 8635,
  [SMALL_STATE(208)] = 8662,
  [SMALL_STATE(209)] = 8689,
  [SMALL_STATE(210)] = 8716,
  [SMALL_STATE(211)] = 8743,
  [SMALL_STATE(212)] = 8767,
  [SMALL_STATE(213)] = 8791,
  [SMALL_STATE(214)] = 8812,
  [SMALL_STATE(215)] = 8833,
  [SMALL_STATE(216)] = 8854,
  [SMALL_STATE(217)] = 8874,
  [SMALL_STATE(218)] = 8894,
  [SMALL_STATE(219)] = 8916,
  [SMALL_STATE(220)] = 8938,
  [SMALL_STATE(221)] = 8958,
  [SMALL_STATE(222)] = 8980,
  [SMALL_STATE(223)] = 8997,
  [SMALL_STATE(224)] = 9014,
  [SMALL_STATE(225)] = 9031,
  [SMALL_STATE(226)] = 9047,
  [SMALL_STATE(227)] = 9063,
  [SMALL_STATE(228)] = 9079,
  [SMALL_STATE(229)] = 9089,
  [SMALL_STATE(230)] = 9096,
  [SMALL_STATE(231)] = 9103,
  [SMALL_STATE(232)] = 9110,
  [SMALL_STATE(233)] = 9117,
  [SMALL_STATE(234)] = 9124,
  [SMALL_STATE(235)] = 9134,
  [SMALL_STATE(236)] = 9144,
  [SMALL_STATE(237)] = 9150,
  [SMALL_STATE(238)] = 9160,
  [SMALL_STATE(239)] = 9170,
  [SMALL_STATE(240)] = 9180,
  [SMALL_STATE(241)] = 9190,
  [SMALL_STATE(242)] = 9200,
  [SMALL_STATE(243)] = 9210,
  [SMALL_STATE(244)] = 9220,
  [SMALL_STATE(245)] = 9230,
  [SMALL_STATE(246)] = 9238,
  [SMALL_STATE(247)] = 9248,
  [SMALL_STATE(248)] = 9258,
  [SMALL_STATE(249)] = 9264,
  [SMALL_STATE(250)] = 9274,
  [SMALL_STATE(251)] = 9284,
  [SMALL_STATE(252)] = 9294,
  [SMALL_STATE(253)] = 9304,
  [SMALL_STATE(254)] = 9314,
  [SMALL_STATE(255)] = 9324,
  [SMALL_STATE(256)] = 9334,
  [SMALL_STATE(257)] = 9344,
  [SMALL_STATE(258)] = 9352,
  [SMALL_STATE(259)] = 9362,
  [SMALL_STATE(260)] = 9372,
  [SMALL_STATE(261)] = 9382,
  [SMALL_STATE(262)] = 9390,
  [SMALL_STATE(263)] = 9400,
  [SMALL_STATE(264)] = 9407,
  [SMALL_STATE(265)] = 9414,
  [SMALL_STATE(266)] = 9419,
  [SMALL_STATE(267)] = 9426,
  [SMALL_STATE(268)] = 9433,
  [SMALL_STATE(269)] = 9440,
  [SMALL_STATE(270)] = 9447,
  [SMALL_STATE(271)] = 9454,
  [SMALL_STATE(272)] = 9461,
  [SMALL_STATE(273)] = 9466,
  [SMALL_STATE(274)] = 9473,
  [SMALL_STATE(275)] = 9480,
  [SMALL_STATE(276)] = 9487,
  [SMALL_STATE(277)] = 9494,
  [SMALL_STATE(278)] = 9501,
  [SMALL_STATE(279)] = 9508,
  [SMALL_STATE(280)] = 9515,
  [SMALL_STATE(281)] = 9522,
  [SMALL_STATE(282)] = 9529,
  [SMALL_STATE(283)] = 9536,
  [SMALL_STATE(284)] = 9543,
  [SMALL_STATE(285)] = 9550,
  [SMALL_STATE(286)] = 9557,
  [SMALL_STATE(287)] = 9564,
  [SMALL_STATE(288)] = 9571,
  [SMALL_STATE(289)] = 9578,
  [SMALL_STATE(290)] = 9585,
  [SMALL_STATE(291)] = 9592,
  [SMALL_STATE(292)] = 9599,
  [SMALL_STATE(293)] = 9606,
  [SMALL_STATE(294)] = 9613,
  [SMALL_STATE(295)] = 9620,
  [SMALL_STATE(296)] = 9627,
  [SMALL_STATE(297)] = 9634,
  [SMALL_STATE(298)] = 9641,
  [SMALL_STATE(299)] = 9648,
  [SMALL_STATE(300)] = 9655,
  [SMALL_STATE(301)] = 9659,
  [SMALL_STATE(302)] = 9663,
  [SMALL_STATE(303)] = 9667,
  [SMALL_STATE(304)] = 9671,
  [SMALL_STATE(305)] = 9675,
  [SMALL_STATE(306)] = 9679,
  [SMALL_STATE(307)] = 9683,
  [SMALL_STATE(308)] = 9687,
  [SMALL_STATE(309)] = 9691,
  [SMALL_STATE(310)] = 9695,
  [SMALL_STATE(311)] = 9699,
  [SMALL_STATE(312)] = 9703,
  [SMALL_STATE(313)] = 9707,
  [SMALL_STATE(314)] = 9711,
  [SMALL_STATE(315)] = 9715,
  [SMALL_STATE(316)] = 9719,
  [SMALL_STATE(317)] = 9723,
  [SMALL_STATE(318)] = 9727,
  [SMALL_STATE(319)] = 9731,
  [SMALL_STATE(320)] = 9735,
  [SMALL_STATE(321)] = 9739,
  [SMALL_STATE(322)] = 9743,
  [SMALL_STATE(323)] = 9747,
  [SMALL_STATE(324)] = 9751,
  [SMALL_STATE(325)] = 9755,
  [SMALL_STATE(326)] = 9759,
};

static const TSParseActionEntry ts_parse_actions[] = {
  [0] = {.entry = {.count = 0, .reusable = false}},
  [1] = {.entry = {.count = 1, .reusable = false}}, RECOVER(),
  [3] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_series_of_games, 0, 0, 0),
  [5] = {.entry = {.count = 1, .reusable = false}}, SHIFT(310),
  [7] = {.entry = {.count = 1, .reusable = true}}, SHIFT(131),
  [9] = {.entry = {.count = 1, .reusable = false}}, SHIFT(260),
  [11] = {.entry = {.count = 1, .reusable = false}}, SHIFT(109),
  [13] = {.entry = {.count = 1, .reusable = false}}, SHIFT(229),
  [15] = {.entry = {.count = 1, .reusable = false}}, SHIFT(104),
  [17] = {.entry = {.count = 1, .reusable = false}}, SHIFT(218),
  [19] = {.entry = {.count = 1, .reusable = false}}, SHIFT(216),
  [21] = {.entry = {.count = 1, .reusable = false}}, SHIFT(319),
  [23] = {.entry = {.count = 1, .reusable = false}}, SHIFT(269),
  [25] = {.entry = {.count = 1, .reusable = false}}, SHIFT(83),
  [27] = {.entry = {.count = 1, .reusable = false}}, SHIFT(97),
  [29] = {.entry = {.count = 1, .reusable = true}}, SHIFT(322),
  [31] = {.entry = {.count = 1, .reusable = true}}, SHIFT(97),
  [33] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_movetext, 1, 0, 6),
  [35] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_movetext, 1, 0, 6),
  [37] = {.entry = {.count = 1, .reusable = false}}, SHIFT(95),
  [39] = {.entry = {.count = 1, .reusable = false}}, SHIFT(48),
  [41] = {.entry = {.count = 1, .reusable = false}}, SHIFT(221),
  [43] = {.entry = {.count = 1, .reusable = false}}, SHIFT(220),
  [45] = {.entry = {.count = 1, .reusable = false}}, SHIFT(326),
  [47] = {.entry = {.count = 1, .reusable = false}}, SHIFT(284),
  [49] = {.entry = {.count = 1, .reusable = false}}, SHIFT(26),
  [51] = {.entry = {.count = 1, .reusable = false}}, SHIFT(53),
  [53] = {.entry = {.count = 1, .reusable = true}}, SHIFT(53),
  [55] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_movetext_repeat1, 2, 0, 27),
  [57] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_movetext_repeat1, 2, 0, 27), SHIFT_REPEAT(310),
  [60] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_movetext_repeat1, 2, 0, 27),
  [62] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_movetext_repeat1, 2, 0, 27), SHIFT_REPEAT(95),
  [65] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_movetext_repeat1, 2, 0, 27), SHIFT_REPEAT(229),
  [68] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_movetext_repeat1, 2, 0, 27), SHIFT_REPEAT(48),
  [71] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_movetext_repeat1, 2, 0, 27), SHIFT_REPEAT(221),
  [74] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_movetext_repeat1, 2, 0, 27), SHIFT_REPEAT(220),
  [77] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_movetext_repeat1, 2, 0, 27), SHIFT_REPEAT(326),
  [80] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_movetext_repeat1, 2, 0, 27), SHIFT_REPEAT(284),
  [83] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_movetext_repeat1, 2, 0, 27), SHIFT_REPEAT(26),
  [86] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_movetext_repeat1, 2, 0, 27), SHIFT_REPEAT(53),
  [89] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_movetext_repeat1, 2, 0, 27), SHIFT_REPEAT(322),
  [92] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_movetext_repeat1, 2, 0, 27), SHIFT_REPEAT(53),
  [95] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5),
  [97] = {.entry = {.count = 1, .reusable = false}}, SHIFT(126),
  [99] = {.entry = {.count = 1, .reusable = false}}, SHIFT(190),
  [101] = {.entry = {.count = 1, .reusable = false}}, SHIFT(191),
  [103] = {.entry = {.count = 1, .reusable = false}}, SHIFT(143),
  [105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(310),
  [107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(95),
  [109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(229),
  [111] = {.entry = {.count = 1, .reusable = true}}, SHIFT(326),
  [113] = {.entry = {.count = 1, .reusable = true}}, SHIFT(284),
  [115] = {.entry = {.count = 1, .reusable = true}}, SHIFT(26),
  [117] = {.entry = {.count = 1, .reusable = true}}, SHIFT(143),
  [119] = {.entry = {.count = 1, .reusable = true}}, SHIFT(109),
  [121] = {.entry = {.count = 1, .reusable = true}}, SHIFT(319),
  [123] = {.entry = {.count = 1, .reusable = true}}, SHIFT(269),
  [125] = {.entry = {.count = 1, .reusable = true}}, SHIFT(83),
  [127] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_movetext_repeat1, 2, 0, 27), SHIFT_REPEAT(310),
  [130] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_movetext_repeat1, 2, 0, 27), SHIFT_REPEAT(109),
  [133] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_movetext_repeat1, 2, 0, 27), SHIFT_REPEAT(229),
  [136] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_movetext_repeat1, 2, 0, 27), SHIFT_REPEAT(104),
  [139] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_movetext_repeat1, 2, 0, 27), SHIFT_REPEAT(218),
  [142] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_movetext_repeat1, 2, 0, 27), SHIFT_REPEAT(216),
  [145] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_movetext_repeat1, 2, 0, 27), SHIFT_REPEAT(319),
  [148] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_movetext_repeat1, 2, 0, 27), SHIFT_REPEAT(319),
  [151] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_movetext_repeat1, 2, 0, 27), SHIFT_REPEAT(269),
  [154] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_movetext_repeat1, 2, 0, 27), SHIFT_REPEAT(83),
  [157] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_movetext_repeat1, 2, 0, 27), SHIFT_REPEAT(97),
  [160] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_movetext_repeat1, 2, 0, 27), SHIFT_REPEAT(97),
  [163] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_series_of_games, 1, 0, 10),
  [165] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_series_of_games_repeat1, 2, 0, 26),
  [167] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_series_of_games_repeat1, 2, 0, 26), SHIFT_REPEAT(310),
  [170] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_series_of_games_repeat1, 2, 0, 26), SHIFT_REPEAT(133),
  [173] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_series_of_games_repeat1, 2, 0, 26), SHIFT_REPEAT(260),
  [176] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_series_of_games_repeat1, 2, 0, 26), SHIFT_REPEAT(109),
  [179] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_series_of_games_repeat1, 2, 0, 26), SHIFT_REPEAT(229),
  [182] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_series_of_games_repeat1, 2, 0, 26), SHIFT_REPEAT(104),
  [185] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_series_of_games_repeat1, 2, 0, 26), SHIFT_REPEAT(218),
  [188] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_series_of_games_repeat1, 2, 0, 26), SHIFT_REPEAT(216),
  [191] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_series_of_games_repeat1, 2, 0, 26), SHIFT_REPEAT(319),
  [194] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_series_of_games_repeat1, 2, 0, 26), SHIFT_REPEAT(269),
  [197] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_series_of_games_repeat1, 2, 0, 26), SHIFT_REPEAT(83),
  [200] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_series_of_games_repeat1, 2, 0, 26), SHIFT_REPEAT(97),
  [203] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_series_of_games_repeat1, 2, 0, 26), SHIFT_REPEAT(322),
  [206] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_series_of_games_repeat1, 2, 0, 26), SHIFT_REPEAT(97),
  [209] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__lan_move_by_coordinates, 3, 0, 0),
  [211] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__lan_move_by_coordinates, 3, 0, 0),
  [213] = {.entry = {.count = 1, .reusable = false}}, SHIFT(43),
  [215] = {.entry = {.count = 1, .reusable = false}}, SHIFT(312),
  [217] = {.entry = {.count = 1, .reusable = false}}, SHIFT(42),
  [219] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__san_square_nonpromoting, 2, 0, 0),
  [221] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__san_square_nonpromoting, 2, 0, 0),
  [223] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__san_rank_any, 1, 0, 0),
  [225] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__san_square_any_immediate, 2, 0, 0),
  [227] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__san_square_any_immediate, 2, 0, 0),
  [229] = {.entry = {.count = 1, .reusable = false}}, SHIFT(257),
  [231] = {.entry = {.count = 1, .reusable = false}}, SHIFT(294),
  [233] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_game, 2, 0, 20),
  [235] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_game, 2, 0, 20),
  [237] = {.entry = {.count = 1, .reusable = false}}, SHIFT(129),
  [239] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16),
  [241] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_header, 1, 0, 5),
  [243] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_header, 1, 0, 5),
  [245] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17),
  [247] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_header, 2, 0, 22),
  [249] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_header, 2, 0, 22),
  [251] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_header_repeat1, 2, 0, 34), SHIFT_REPEAT(17),
  [254] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_header_repeat1, 2, 0, 34), SHIFT_REPEAT(310),
  [257] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_header_repeat1, 2, 0, 34), SHIFT_REPEAT(260),
  [260] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_header_repeat1, 2, 0, 34),
  [262] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_header_repeat1, 2, 0, 34), SHIFT_REPEAT(322),
  [265] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_header_repeat1, 2, 0, 34),
  [267] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_game, 3, 0, 31),
  [269] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_game, 3, 0, 31),
  [271] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__san_square_promoting_immediate, 2, 0, 0),
  [273] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__san_square_promoting_immediate, 2, 0, 0),
  [275] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_series_of_games, 1, 0, 3),
  [277] = {.entry = {.count = 1, .reusable = true}}, SHIFT(260),
  [279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(104),
  [281] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_series_of_games, 2, 0, 25),
  [283] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lan_move, 1, -1, 0),
  [285] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_lan_move, 1, -1, 0),
  [287] = {.entry = {.count = 1, .reusable = false}}, SHIFT(65),
  [289] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__san_rank_any, 1, 0, 0),
  [291] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_rest_of_line_comment, 2, 0, 19),
  [293] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_rest_of_line_comment, 2, 0, 19),
  [295] = {.entry = {.count = 1, .reusable = true}}, SHIFT(49),
  [297] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_san_move, 1, 0, 0),
  [299] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_san_move, 1, 0, 0),
  [301] = {.entry = {.count = 1, .reusable = false}}, SHIFT(63),
  [303] = {.entry = {.count = 1, .reusable = false}}, SHIFT(261),
  [305] = {.entry = {.count = 1, .reusable = true}}, SHIFT(263),
  [307] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__san_move_pawn, 2, 0, 0),
  [309] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__san_move_pawn, 2, 0, 0),
  [311] = {.entry = {.count = 1, .reusable = false}}, SHIFT(80),
  [313] = {.entry = {.count = 1, .reusable = false}}, SHIFT(300),
  [315] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__san_drop_pawn, 2, 0, 0),
  [317] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__san_drop_pawn, 2, 0, 0),
  [319] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__san_square_nonpromoting_immediate, 2, 0, 0),
  [321] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__san_square_nonpromoting_immediate, 2, 0, 0),
  [323] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__san_move_pawn, 3, 0, 0),
  [325] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__san_move_pawn, 3, 0, 0),
  [327] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__san_move_major_or_minor_piece, 3, 0, 0),
  [329] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__san_move_major_or_minor_piece, 3, 0, 0),
  [331] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__san_drop_major_or_minor_piece, 3, 0, 0),
  [333] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__san_drop_major_or_minor_piece, 3, 0, 0),
  [335] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__san_drop_pawn, 3, 0, 0),
  [337] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__san_drop_pawn, 3, 0, 0),
  [339] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__san_move_pawn, 3, 0, 0), REDUCE(sym__lan_move_by_coordinates, 3, 0, 0),
  [342] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__san_move_pawn, 3, 0, 0), REDUCE(sym__lan_move_by_coordinates, 3, 0, 0),
  [345] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__san_promotion, 2, 0, 0),
  [347] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__san_promotion, 2, 0, 0),
  [349] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__san_move_pawn, 4, 0, 0),
  [351] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__san_move_pawn, 4, 0, 0),
  [353] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__san_move_major_or_minor_piece, 4, 0, 0),
  [355] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__san_move_major_or_minor_piece, 4, 0, 0),
  [357] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__san_move_pawn, 4, 0, 0), REDUCE(sym__lan_move_by_coordinates, 4, 0, 0),
  [360] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__san_move_pawn, 4, 0, 0), REDUCE(sym__lan_move_by_coordinates, 4, 0, 0),
  [363] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__lan_move_by_coordinates, 4, 0, 0),
  [365] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__lan_move_by_coordinates, 4, 0, 0),
  [367] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__san_move_major_or_minor_piece, 5, 0, 0),
  [369] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__san_move_major_or_minor_piece, 5, 0, 0),
  [371] = {.entry = {.count = 1, .reusable = false}}, SHIFT(79),
  [373] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__san_move_major_or_minor_piece, 2, 0, 0),
  [375] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__san_move_major_or_minor_piece, 2, 0, 0),
  [377] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__movetext_element, 1, 0, 4),
  [379] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__movetext_element, 1, 0, 4),
  [381] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__movetext_element, 1, 0, 1),
  [383] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__movetext_element, 1, 0, 1),
  [385] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_rest_of_line_comment, 3, 0, 19),
  [387] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_rest_of_line_comment, 3, 0, 19),
  [389] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variation, 3, 0, 29),
  [391] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_variation, 3, 0, 29),
  [393] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_movetext_repeat1, 1, 0, 6),
  [395] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_movetext_repeat1, 1, 0, 6),
  [397] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_annotation, 1, 0, 0),
  [399] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_annotation, 1, 0, 0),
  [401] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_inline_comment_delimiter_close, 1, 0, 0),
  [403] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_inline_comment_delimiter_close, 1, 0, 0),
  [405] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__movetext_element, 1, 0, 7),
  [407] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__movetext_element, 1, 0, 7),
  [409] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_inline_comment, 2, 0, 24),
  [411] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_inline_comment, 2, 0, 24),
  [413] = {.entry = {.count = 1, .reusable = true}}, SHIFT(67),
  [415] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variation_delimiter_close, 1, 0, 0),
  [417] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_variation_delimiter_close, 1, 0, 0),
  [419] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__movetext_element, 1, 0, 8),
  [421] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__movetext_element, 1, 0, 8),
  [423] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__movetext_element, 1, 0, 9),
  [425] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__movetext_element, 1, 0, 9),
  [427] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_freestanding_comment_repeat1, 1, 0, 0),
  [429] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__movetext_element, 1, 0, 4), REDUCE(aux_sym_freestanding_comment_repeat1, 1, 0, 0),
  [432] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_freestanding_comment_repeat1, 1, 0, 0),
  [434] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__movetext_element, 1, 0, 4), REDUCE(aux_sym_freestanding_comment_repeat1, 1, 0, 0),
  [437] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variation, 2, 0, 13),
  [439] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_variation, 2, 0, 13),
  [441] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_san_move, 2, 0, 0),
  [443] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_san_move, 2, 0, 0),
  [445] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_inline_comment, 3, 0, 36),
  [447] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_inline_comment, 3, 0, 36),
  [449] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lan_move, 2, -1, 0),
  [451] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_lan_move, 2, -1, 0),
  [453] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tagpair_delimiter_close, 1, 0, 0),
  [455] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_tagpair_delimiter_close, 1, 0, 0),
  [457] = {.entry = {.count = 1, .reusable = false}}, SHIFT(69),
  [459] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_tagpair_delimiter_close_repeat1, 2, 0, 0),
  [461] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_tagpair_delimiter_close_repeat1, 2, 0, 0),
  [463] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_tagpair_delimiter_close_repeat1, 2, 0, 0), SHIFT_REPEAT(69),
  [466] = {.entry = {.count = 1, .reusable = false}}, SHIFT(99),
  [468] = {.entry = {.count = 1, .reusable = false}}, SHIFT(100),
  [470] = {.entry = {.count = 1, .reusable = true}}, SHIFT(106),
  [472] = {.entry = {.count = 1, .reusable = false}}, SHIFT(114),
  [474] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_header_repeat1, 1, 0, 5),
  [476] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_header_repeat1, 1, 0, 5),
  [478] = {.entry = {.count = 1, .reusable = true}}, SHIFT(111),
  [480] = {.entry = {.count = 1, .reusable = true}}, SHIFT(58),
  [482] = {.entry = {.count = 1, .reusable = true}}, SHIFT(192),
  [484] = {.entry = {.count = 1, .reusable = false}}, SHIFT(219),
  [486] = {.entry = {.count = 1, .reusable = false}}, SHIFT(217),
  [488] = {.entry = {.count = 1, .reusable = false}}, SHIFT(325),
  [490] = {.entry = {.count = 1, .reusable = true}}, SHIFT(325),
  [492] = {.entry = {.count = 1, .reusable = true}}, SHIFT(271),
  [494] = {.entry = {.count = 1, .reusable = true}}, SHIFT(163),
  [496] = {.entry = {.count = 1, .reusable = false}}, SHIFT(197),
  [498] = {.entry = {.count = 1, .reusable = true}}, SHIFT(197),
  [500] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_header_repeat1, 1, 0, 4),
  [502] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_header_repeat1, 1, 0, 4),
  [504] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tagpair, 4, 0, 41),
  [506] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_tagpair, 4, 0, 41),
  [508] = {.entry = {.count = 1, .reusable = true}}, SHIFT(112),
  [510] = {.entry = {.count = 1, .reusable = true}}, SHIFT(189),
  [512] = {.entry = {.count = 1, .reusable = false}}, SHIFT(120),
  [514] = {.entry = {.count = 1, .reusable = true}}, SHIFT(123),
  [516] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variation_movetext, 1, 0, 14),
  [518] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_variation_movetext_repeat1, 2, 0, 30), SHIFT_REPEAT(310),
  [521] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_variation_movetext_repeat1, 2, 0, 30), SHIFT_REPEAT(111),
  [524] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_variation_movetext_repeat1, 2, 0, 30),
  [526] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_variation_movetext_repeat1, 2, 0, 30), SHIFT_REPEAT(229),
  [529] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_variation_movetext_repeat1, 2, 0, 30), SHIFT_REPEAT(192),
  [532] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_variation_movetext_repeat1, 2, 0, 30), SHIFT_REPEAT(219),
  [535] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_variation_movetext_repeat1, 2, 0, 30), SHIFT_REPEAT(217),
  [538] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_variation_movetext_repeat1, 2, 0, 30), SHIFT_REPEAT(325),
  [541] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_variation_movetext_repeat1, 2, 0, 30), SHIFT_REPEAT(325),
  [544] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_variation_movetext_repeat1, 2, 0, 30), SHIFT_REPEAT(271),
  [547] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_variation_movetext_repeat1, 2, 0, 30), SHIFT_REPEAT(163),
  [550] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_variation_movetext_repeat1, 2, 0, 30), SHIFT_REPEAT(197),
  [553] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_variation_movetext_repeat1, 2, 0, 30), SHIFT_REPEAT(322),
  [556] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_variation_movetext_repeat1, 2, 0, 30), SHIFT_REPEAT(197),
  [559] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_double_quote, 1, 0, 0),
  [561] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_tagpair_value_contents_repeat1, 1, 0, 0),
  [563] = {.entry = {.count = 1, .reusable = true}}, SHIFT(125),
  [565] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_tagpair_value_contents_repeat1, 2, 0, 0), SHIFT_REPEAT(122),
  [568] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_tagpair_value_contents_repeat1, 2, 0, 0), SHIFT_REPEAT(122),
  [571] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_tagpair_value_contents, 1, 0, 0), SHIFT(122),
  [574] = {.entry = {.count = 1, .reusable = true}}, SHIFT(122),
  [576] = {.entry = {.count = 1, .reusable = true}}, SHIFT(308),
  [578] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_double_quote, 1, 0, 0),
  [580] = {.entry = {.count = 1, .reusable = true}}, SHIFT(236),
  [582] = {.entry = {.count = 1, .reusable = true}}, SHIFT(304),
  [584] = {.entry = {.count = 1, .reusable = true}}, SHIFT(129),
  [586] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_freestanding_comment_repeat1, 2, 0, 0),
  [588] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_freestanding_comment_repeat1, 2, 0, 0), SHIFT_REPEAT(310),
  [591] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_freestanding_comment_repeat1, 2, 0, 0), SHIFT_REPEAT(128),
  [594] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_freestanding_comment_repeat1, 2, 0, 0),
  [596] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_freestanding_comment_repeat1, 2, 0, 0), SHIFT_REPEAT(229),
  [599] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_freestanding_comment_repeat1, 2, 0, 0), SHIFT_REPEAT(322),
  [602] = {.entry = {.count = 1, .reusable = true}}, SHIFT(130),
  [604] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_trailing_garbage, 1, 0, 0),
  [606] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_trailing_garbage, 1, 0, 0),
  [608] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_trailing_garbage_repeat1, 2, 0, 0), SHIFT_REPEAT(130),
  [611] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_trailing_garbage_repeat1, 2, 0, 0),
  [613] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_trailing_garbage_repeat1, 2, 0, 0),
  [615] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_freestanding_comment, 1, 0, 0),
  [617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(128),
  [619] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_freestanding_comment, 1, 0, 0),
  [621] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_freestanding_comment_repeat1, 2, 0, 0), SHIFT_REPEAT(132),
  [624] = {.entry = {.count = 1, .reusable = true}}, SHIFT(132),
  [626] = {.entry = {.count = 1, .reusable = false}}, SHIFT(179),
  [628] = {.entry = {.count = 1, .reusable = false}}, SHIFT(307),
  [630] = {.entry = {.count = 1, .reusable = false}}, SHIFT(180),
  [632] = {.entry = {.count = 1, .reusable = false}}, SHIFT(245),
  [634] = {.entry = {.count = 1, .reusable = true}}, SHIFT(283),
  [636] = {.entry = {.count = 1, .reusable = true}}, SHIFT(156),
  [638] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_result_code, 1, 0, 0),
  [640] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_result_code, 1, 0, 0),
  [642] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_game, 3, 0, 32),
  [644] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_game, 3, 0, 32),
  [646] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_game, 2, 0, 23),
  [648] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_game, 2, 0, 23),
  [650] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_game, 3, 0, 33),
  [652] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_game, 3, 0, 33),
  [654] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_series_of_games_repeat1, 2, 0, 18),
  [656] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_series_of_games_repeat1, 2, 0, 18),
  [658] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_game, 4, 0, 39),
  [660] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_game, 4, 0, 39),
  [662] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_game, 4, 0, 38),
  [664] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_game, 4, 0, 38),
  [666] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_game, 2, 0, 21),
  [668] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_game, 2, 0, 21),
  [670] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_series_of_games_repeat1, 1, 0, 2),
  [672] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_series_of_games_repeat1, 1, 0, 2),
  [674] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_result_code, 7, 0, 0),
  [676] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_result_code, 7, 0, 0),
  [678] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_result_code, 3, 0, 0),
  [680] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_result_code, 3, 0, 0),
  [682] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_game, 3, 0, 35),
  [684] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_game, 3, 0, 35),
  [686] = {.entry = {.count = 1, .reusable = true}}, SHIFT(162),
  [688] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_game, 5, 0, 44),
  [690] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_game, 5, 0, 44),
  [692] = {.entry = {.count = 1, .reusable = false}}, SHIFT(202),
  [694] = {.entry = {.count = 1, .reusable = false}}, SHIFT(203),
  [696] = {.entry = {.count = 1, .reusable = true}}, SHIFT(187),
  [698] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__variation_movetext_element, 1, 0, 16),
  [700] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__variation_movetext_element, 1, 0, 16),
  [702] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_recursive_variation, 2, 0, 28),
  [704] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_recursive_variation, 2, 0, 28),
  [706] = {.entry = {.count = 1, .reusable = true}}, SHIFT(309),
  [708] = {.entry = {.count = 1, .reusable = true}}, SHIFT(272),
  [710] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__variation_movetext_element, 1, 0, 11),
  [712] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__variation_movetext_element, 1, 0, 11),
  [714] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__variation_movetext_element, 1, 0, 12),
  [716] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__variation_movetext_element, 1, 0, 12),
  [718] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_variation_movetext_repeat1, 1, 0, 14),
  [720] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_variation_movetext_repeat1, 1, 0, 14),
  [722] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_recursive_variation, 3, 0, 37),
  [724] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_recursive_variation, 3, 0, 37),
  [726] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__variation_movetext_element, 1, 0, 15),
  [728] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__variation_movetext_element, 1, 0, 15),
  [730] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__variation_movetext_element, 1, 0, 17),
  [732] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__variation_movetext_element, 1, 0, 17),
  [734] = {.entry = {.count = 1, .reusable = true}}, SHIFT(301),
  [736] = {.entry = {.count = 1, .reusable = true}}, SHIFT(311),
  [738] = {.entry = {.count = 1, .reusable = false}}, SHIFT(212),
  [740] = {.entry = {.count = 1, .reusable = false}}, SHIFT(54),
  [742] = {.entry = {.count = 1, .reusable = false}}, SHIFT(276),
  [744] = {.entry = {.count = 1, .reusable = false}}, SHIFT(213),
  [746] = {.entry = {.count = 1, .reusable = false}}, SHIFT(149),
  [748] = {.entry = {.count = 1, .reusable = false}}, SHIFT(101),
  [750] = {.entry = {.count = 1, .reusable = false}}, SHIFT(200),
  [752] = {.entry = {.count = 1, .reusable = false}}, SHIFT(70),
  [754] = {.entry = {.count = 1, .reusable = false}}, SHIFT(182),
  [756] = {.entry = {.count = 1, .reusable = false}}, SHIFT(233),
  [758] = {.entry = {.count = 1, .reusable = false}}, SHIFT(215),
  [760] = {.entry = {.count = 1, .reusable = false}}, SHIFT(230),
  [762] = {.entry = {.count = 1, .reusable = false}}, SHIFT(211),
  [764] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_inline_comment_text, 1, 0, 0),
  [766] = {.entry = {.count = 1, .reusable = false}}, SHIFT(214),
  [768] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_inline_comment_text_repeat1, 2, 0, 0), SHIFT_REPEAT(212),
  [771] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_inline_comment_text_repeat1, 2, 0, 0),
  [773] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_inline_comment_text_repeat1, 2, 0, 0), SHIFT_REPEAT(276),
  [776] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_inline_comment_text_repeat1, 2, 0, 0), SHIFT_REPEAT(214),
  [779] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__recursive_inline_comment_text, 2, 0, 0), SHIFT_REPEAT(212),
  [782] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__recursive_inline_comment_text, 2, 0, 0),
  [784] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__recursive_inline_comment_text, 2, 0, 0), SHIFT_REPEAT(276),
  [787] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__recursive_inline_comment_text, 2, 0, 0), SHIFT_REPEAT(215),
  [790] = {.entry = {.count = 1, .reusable = true}}, SHIFT(222),
  [792] = {.entry = {.count = 1, .reusable = true}}, SHIFT(243),
  [794] = {.entry = {.count = 1, .reusable = true}}, SHIFT(270),
  [796] = {.entry = {.count = 1, .reusable = true}}, SHIFT(264),
  [798] = {.entry = {.count = 1, .reusable = true}}, SHIFT(223),
  [800] = {.entry = {.count = 1, .reusable = true}}, SHIFT(244),
  [802] = {.entry = {.count = 1, .reusable = true}}, SHIFT(277),
  [804] = {.entry = {.count = 1, .reusable = true}}, SHIFT(278),
  [806] = {.entry = {.count = 1, .reusable = true}}, SHIFT(292),
  [808] = {.entry = {.count = 1, .reusable = true}}, SHIFT(228),
  [810] = {.entry = {.count = 1, .reusable = true}}, SHIFT(24),
  [812] = {.entry = {.count = 1, .reusable = true}}, SHIFT(251),
  [814] = {.entry = {.count = 1, .reusable = true}}, SHIFT(274),
  [816] = {.entry = {.count = 1, .reusable = true}}, SHIFT(139),
  [818] = {.entry = {.count = 1, .reusable = true}}, SHIFT(241),
  [820] = {.entry = {.count = 1, .reusable = true}}, SHIFT(224),
  [822] = {.entry = {.count = 1, .reusable = true}}, SHIFT(256),
  [824] = {.entry = {.count = 1, .reusable = true}}, SHIFT(288),
  [826] = {.entry = {.count = 1, .reusable = true}}, SHIFT(289),
  [828] = {.entry = {.count = 1, .reusable = true}}, SHIFT(285),
  [830] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12),
  [832] = {.entry = {.count = 1, .reusable = true}}, SHIFT(253),
  [834] = {.entry = {.count = 1, .reusable = true}}, SHIFT(261),
  [836] = {.entry = {.count = 1, .reusable = true}}, SHIFT(27),
  [838] = {.entry = {.count = 1, .reusable = true}}, SHIFT(275),
  [840] = {.entry = {.count = 1, .reusable = true}}, SHIFT(245),
  [842] = {.entry = {.count = 1, .reusable = true}}, SHIFT(140),
  [844] = {.entry = {.count = 1, .reusable = true}}, SHIFT(299),
  [846] = {.entry = {.count = 1, .reusable = true}}, SHIFT(257),
  [848] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13),
  [850] = {.entry = {.count = 1, .reusable = true}}, SHIFT(293),
  [852] = {.entry = {.count = 1, .reusable = true}}, SHIFT(237),
  [854] = {.entry = {.count = 1, .reusable = true}}, SHIFT(238),
  [856] = {.entry = {.count = 1, .reusable = true}}, SHIFT(258),
  [858] = {.entry = {.count = 1, .reusable = true}}, SHIFT(259),
  [860] = {.entry = {.count = 1, .reusable = true}}, SHIFT(246),
  [862] = {.entry = {.count = 1, .reusable = true}}, SHIFT(247),
  [864] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__san_square_promoting, 2, 0, 0),
  [866] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_inline_comment_delimiter_open, 1, 0, 0),
  [868] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__recursive_inline_comment, 2, 0, 0),
  [870] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_command_delimiter_close, 1, 0, 0),
  [872] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_command, 3, 0, 43),
  [874] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__recursive_inline_comment, 3, 0, 0),
  [876] = {.entry = {.count = 1, .reusable = true}}, SHIFT(81),
  [878] = {.entry = {.count = 1, .reusable = true}}, SHIFT(300),
  [880] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_tagpair_delimiter_open_repeat1, 2, 0, 0), SHIFT_REPEAT(235),
  [883] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_tagpair_delimiter_open_repeat1, 2, 0, 0),
  [885] = {.entry = {.count = 1, .reusable = true}}, SHIFT(157),
  [887] = {.entry = {.count = 1, .reusable = true}}, SHIFT(296),
  [889] = {.entry = {.count = 1, .reusable = true}}, SHIFT(87),
  [891] = {.entry = {.count = 1, .reusable = true}}, SHIFT(165),
  [893] = {.entry = {.count = 1, .reusable = true}}, SHIFT(307),
  [895] = {.entry = {.count = 1, .reusable = true}}, SHIFT(169),
  [897] = {.entry = {.count = 1, .reusable = true}}, SHIFT(173),
  [899] = {.entry = {.count = 1, .reusable = true}}, SHIFT(297),
  [901] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__san_square_any, 2, 0, 0),
  [903] = {.entry = {.count = 1, .reusable = true}}, SHIFT(73),
  [905] = {.entry = {.count = 1, .reusable = true}}, SHIFT(177),
  [907] = {.entry = {.count = 1, .reusable = true}}, SHIFT(28),
  [909] = {.entry = {.count = 1, .reusable = true}}, SHIFT(312),
  [911] = {.entry = {.count = 1, .reusable = true}}, SHIFT(32),
  [913] = {.entry = {.count = 1, .reusable = true}}, SHIFT(40),
  [915] = {.entry = {.count = 1, .reusable = true}}, SHIFT(36),
  [917] = {.entry = {.count = 1, .reusable = true}}, SHIFT(298),
  [919] = {.entry = {.count = 1, .reusable = false}}, SHIFT(235),
  [921] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_tagpair_delimiter_open, 1, 0, 0),
  [923] = {.entry = {.count = 1, .reusable = true}}, SHIFT(91),
  [925] = {.entry = {.count = 1, .reusable = true}}, SHIFT(68),
  [927] = {.entry = {.count = 1, .reusable = true}}, SHIFT(182),
  [929] = {.entry = {.count = 1, .reusable = true}}, SHIFT(200),
  [931] = {.entry = {.count = 1, .reusable = true}}, SHIFT(265),
  [933] = {.entry = {.count = 1, .reusable = true}}, SHIFT(161),
  [935] = {.entry = {.count = 1, .reusable = true}}, SHIFT(323),
  [937] = {.entry = {.count = 1, .reusable = true}}, SHIFT(54),
  [939] = {.entry = {.count = 1, .reusable = true}}, SHIFT(31),
  [941] = {.entry = {.count = 1, .reusable = true}}, SHIFT(149),
  [943] = {.entry = {.count = 1, .reusable = true}}, SHIFT(231),
  [945] = {.entry = {.count = 1, .reusable = true}}, SHIFT(101),
  [947] = {.entry = {.count = 1, .reusable = true}}, SHIFT(86),
  [949] = {.entry = {.count = 1, .reusable = true}}, SHIFT(70),
  [951] = {.entry = {.count = 1, .reusable = true}}, SHIFT(51),
  [953] = {.entry = {.count = 1, .reusable = true}}, SHIFT(141),
  [955] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19),
  [957] = {.entry = {.count = 1, .reusable = true}}, SHIFT(74),
  [959] = {.entry = {.count = 1, .reusable = true}}, SHIFT(204),
  [961] = {.entry = {.count = 1, .reusable = true}}, SHIFT(168),
  [963] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__command_text, 2, 0, 42),
  [965] = {.entry = {.count = 1, .reusable = true}}, SHIFT(199),
  [967] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__tagpair_value, 3, 0, 45),
  [969] = {.entry = {.count = 1, .reusable = true}}, SHIFT(25),
  [971] = {.entry = {.count = 1, .reusable = true}}, SHIFT(176),
  [973] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_rest_of_line_comment_delimiter_open, 1, 0, 0),
  [975] = {.entry = {.count = 1, .reusable = true}}, SHIFT(155),
  [977] = {.entry = {.count = 1, .reusable = true}}, SHIFT(39),
  [979] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__tagpair_value, 2, 0, 40),
  [981] = {.entry = {.count = 1, .reusable = true}},  ACCEPT_INPUT(),
  [983] = {.entry = {.count = 1, .reusable = true}}, SHIFT(92),
  [985] = {.entry = {.count = 1, .reusable = true}}, SHIFT(121),
  [987] = {.entry = {.count = 1, .reusable = true}}, SHIFT(85),
  [989] = {.entry = {.count = 1, .reusable = true}}, SHIFT(142),
  [991] = {.entry = {.count = 1, .reusable = true}}, SHIFT(273),
  [993] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_rest_of_line_comment_delimiter_open, 2, 0, 0),
  [995] = {.entry = {.count = 1, .reusable = true}}, SHIFT(57),
  [997] = {.entry = {.count = 1, .reusable = true}}, SHIFT(320),
  [999] = {.entry = {.count = 1, .reusable = true}}, SHIFT(303),
  [1001] = {.entry = {.count = 1, .reusable = true}}, SHIFT(159),
  [1003] = {.entry = {.count = 1, .reusable = true}}, SHIFT(280),
  [1005] = {.entry = {.count = 1, .reusable = true}}, SHIFT(291),
};

enum ts_external_scanner_symbol_identifiers {
  ts_external_token__full_line_comment_delimiter_bol_assertion = 0,
  ts_external_token__novelty_glyph_before_punctuation = 1,
};

static const TSSymbol ts_external_scanner_symbol_map[EXTERNAL_TOKEN_COUNT] = {
  [ts_external_token__full_line_comment_delimiter_bol_assertion] = sym__full_line_comment_delimiter_bol_assertion,
  [ts_external_token__novelty_glyph_before_punctuation] = sym__novelty_glyph_before_punctuation,
};

static const bool ts_external_scanner_states[2][EXTERNAL_TOKEN_COUNT] = {
  [1] = {
    [ts_external_token__full_line_comment_delimiter_bol_assertion] = true,
    [ts_external_token__novelty_glyph_before_punctuation] = true,
  },
};

#ifdef __cplusplus
extern "C" {
#endif
void *tree_sitter_pgn_external_scanner_create(void);
void tree_sitter_pgn_external_scanner_destroy(void *);
bool tree_sitter_pgn_external_scanner_scan(void *, TSLexer *, const bool *);
unsigned tree_sitter_pgn_external_scanner_serialize(void *, char *);
void tree_sitter_pgn_external_scanner_deserialize(void *, const char *, unsigned);

#ifdef TREE_SITTER_HIDE_SYMBOLS
#define TS_PUBLIC
#elif defined(_WIN32)
#define TS_PUBLIC __declspec(dllexport)
#else
#define TS_PUBLIC __attribute__((visibility("default")))
#endif

TS_PUBLIC const TSLanguage *tree_sitter_pgn(void) {
  static const TSLanguage language = {
    .abi_version = LANGUAGE_VERSION,
    .symbol_count = SYMBOL_COUNT,
    .alias_count = ALIAS_COUNT,
    .token_count = TOKEN_COUNT,
    .external_token_count = EXTERNAL_TOKEN_COUNT,
    .state_count = STATE_COUNT,
    .large_state_count = LARGE_STATE_COUNT,
    .production_id_count = PRODUCTION_ID_COUNT,
    .supertype_count = SUPERTYPE_COUNT,
    .field_count = FIELD_COUNT,
    .max_alias_sequence_length = MAX_ALIAS_SEQUENCE_LENGTH,
    .parse_table = &ts_parse_table[0][0],
    .small_parse_table = ts_small_parse_table,
    .small_parse_table_map = ts_small_parse_table_map,
    .parse_actions = ts_parse_actions,
    .symbol_names = ts_symbol_names,
    .field_names = ts_field_names,
    .field_map_slices = ts_field_map_slices,
    .field_map_entries = ts_field_map_entries,
    .symbol_metadata = ts_symbol_metadata,
    .public_symbol_map = ts_symbol_map,
    .alias_map = ts_non_terminal_alias_map,
    .alias_sequences = &ts_alias_sequences[0][0],
    .lex_modes = (const void*)ts_lex_modes,
    .lex_fn = ts_lex,
    .external_scanner = {
      &ts_external_scanner_states[0][0],
      ts_external_scanner_symbol_map,
      tree_sitter_pgn_external_scanner_create,
      tree_sitter_pgn_external_scanner_destroy,
      tree_sitter_pgn_external_scanner_scan,
      tree_sitter_pgn_external_scanner_serialize,
      tree_sitter_pgn_external_scanner_deserialize,
    },
    .primary_state_ids = ts_primary_state_ids,
    .name = "pgn",
    .max_reserved_word_set_size = 0,
    .metadata = {
      .major_version = 1,
      .minor_version = 2,
      .patch_version = 12,
    },
  };
  return &language;
}
#ifdef __cplusplus
}
#endif
